```@meta
EditURL = "../../../examples/2_concept_labeling_in_city_of_austin_community_survey.jl"
```

# Example 2: Label Arbitrary Concepts in the City of Austin Community Survey
For this tutorial, we will use the [City of Austin's Community Survey](https://data.austintexas.gov/Health-and-Community-Services/2019-City-of-Austin-Community-Survey/s2py-ceb7).

We will pick one open-ended question. Let's say we want to help the mayor to prioritize ideas,
so we will lay out the verbatims against the concepts of being "action-oriented" and "forward-looking".

You can choose any concepts that you want.

Necessary imports

````julia
using Downloads, CSV, DataFrames
import PlotlyJS, PlotlyDocumenter
using LLMTextAnalysis
````

## Prepare the Data
Download the survey data

````julia
Downloads.download("https://data.austintexas.gov/api/views/s2py-ceb7/rows.csv?accessType=DOWNLOAD",
    joinpath(@__DIR__, "cityofaustin.csv"));
````

Read the survey data into a DataFrame

````julia
df = CSV.read(joinpath(@__DIR__, "cityofaustin.csv"), DataFrame);
````

Let's select one of the open-ended questions, eg,

````julia
col = "Q25 - If there was one thing you could share with the Mayor regarding the City of Austin (any comment, suggestion, etc.), what would it be?"
docs = df[!, col] |> skipmissing |> collect;
````

## Build the Index
Index the documents (ie, embed them)

````julia
index = build_index(docs)
````

````
DocIndex(Documents: 2933, PlotData: None, Topic Levels: None)
````

Sometimes you know what you're looking for, but it's hard to define the exact keywords. For example, you might want to identify documents that are "action-oriented" or "pessimistic" or "forward-looking".

For these situations, `LLMTextAnalysis` offers two distinct functions for document analysis: `train_concept` and `train_spectrum`. Each serves a different purpose in text analysis:

- **`train_concept`**: Focuses on analyzing a single, specific concept within documents (eg, "action-oriented")
- **`train_spectrum`**: Analyzes documents in the context of two opposing concepts (eg, "optimistic" vs. "pessimistic" or "forward-looking" vs. "backward-looking")

The resulting return types are `TrainedConcept` and `TrainedSpectrum`, respectively. Both can be used to score documents on the presence of the concept or their position on the spectrum.

Why do we need `train_spectrum` and not simply use two `TrainedConcepts`? It's because opposite of "forward-looking" can be many things, eg, "short-sighted", "dwelling in the past", or simply "not-forward looking".

`train_spectrum` allows you to define the opposite concept that you need and score documents on the spectrum between the two.

## Score Documents against a Concept

Let's say we want to identify documents that are "action-oriented".
We can use `train_concept` to train a model to identify documents that are "action-oriented" and score the documents against the concept.

Let's show the top 5 documents that are most "action-oriented".

````julia
concept = train_concept(index,
    "action-oriented";
    aigenerate_kwargs = (; model = "gpt3t"))

scores = score(index, concept)
index.docs[first(sortperm(scores, rev = true), 5)]
````

````
5-element Vector{String}:
 "stop delaying important decisions and make the best one available and move on to solutions"
 "We need real transportation options, not just more lip service and endless studies that do not achieve implementation."
 "We need a comprehensive plan/vision for managing the growth of this city!"
 "Ensure that all citizens, regardless of race/ethnicity, gender, gender identity feel protected and respected by our police services."
 "we need to plan for global climate change, water and energy programs must be robust"
````

## Score Documents along a Spectrum

We may want to define an arbitrary "spectrum" (axis/polar opposites) and score documents on it.
Let's introduce a spectrum for "dwelling in the past" vs "forward-looking".
The higher the score (eg, 100%), the more "forward-looking" the document/text is.

Let's show the top 5 documents that are most "forward-looking".

````julia
spectrum = train_spectrum(index,
    ("dwelling in the past", "forward-looking");
    aigenerate_kwargs = (; model = "gpt3t"))

scores = score(index, spectrum)
index.docs[first(sortperm(scores, rev = true), 5)]
````

````
5-element Vector{String}:
 "Enhance affordability and ensure a diverse, healthy population."
 "MANAGING GROWTH IN A WAY THAT IMPROVES QUALITY OF LIFE FOR ALL CITIZENS"
 "Affordable housing. Better planning for future. Mass transit (rail system that covers City wide."
 "Plan for greater urban density and more public transportation."
 "need more affordable housing and more public transportation to ensure diverse and successful population"
````

And how about the ones "dwelling in the past" (set `rev=false`)?

````julia
index.docs[first(sortperm(scores, rev = false), 5)]
````

````
5-element Vector{String}:
 "It is so sad to see long time local business disappearing. We loved Austin because it was unique, and used to have the feeling of a small town with the advantages of a big city. Now, it is just another city in Texas with gas stations,  banks and Walgreen's on every corner of every rd. So sad to see Austin go down that rd!"
 "The cost of living in Austin and the surrounding v areas is 100% absurd. Beyond ridiculous. I would do anything to have the \"old Austin\" back."
 "Used to be proud of Austin and tour visiting friends around.\nNow it's just a crowded nasty city."
 "I WISH I HAD BUS STOP BACK AT LEDESMA AND LOTT. I USED TO RIDE THE BUS TO WORK."
 "I'm really sad about what Austin has become.  It used to feel like home.  Now, it just feels like a big, impersonal city with not much personality, and a lot of traffic (and high taxes).  The city that I loved is gone, which makes me sad and angry."
````

## Summarize via Plot

Let's interactively explore our results.

We can use `plot` to plot the documents along the trained concepts and spectrums (simple scatter plot).
The positions of args `concept` and `spectrum` are important, as they determine the position of the concepts in the plot (x-axis, y-axis)

````julia
pl = PlotlyJS.plot(index, spectrum, concept;
    title = "Prioritizing Action-Oriented and Forward-Looking Ideas (Top-right Corner)")
````

```@raw html
<div
    class="webio-mountpoint"
    data-webio-mountpoint="13266353168721363940"
>
    <script>
    (function(){
    // Some integrations (namely, IJulia/Jupyter) use an alternate render pathway than
    // just putting the html on the page. If WebIO isn't defined, then it's pretty likely
    // that we're in one of those situations and the integration just isn't installed
    // correctly.
    if (typeof window.WebIO === "undefined") {
        document
            .querySelector('[data-webio-mountpoint="13266353168721363940"]')
            .innerHTML = (
                '<div style="padding: 1em; background-color: #f8d6da; border: 1px solid #f5c6cb; font-weight: bold;">' +
                '<p><strong>WebIO not detected.</strong></p>' +
                '<p>Please read ' +
                '<a href="https://juliagizmos.github.io/WebIO.jl/latest/troubleshooting/not-detected/" target="_blank">the troubleshooting guide</a> ' +
                'for more information on how to resolve this issue.</p>' +
                '<p><a href="https://juliagizmos.github.io/WebIO.jl/latest/troubleshooting/not-detected/" target="_blank">https://juliagizmos.github.io/WebIO.jl/latest/troubleshooting/not-detected/</a></p>' +
                '</div>'
            );
        return;
    }
    WebIO.mount(
        document.querySelector('[data-webio-mountpoint="13266353168721363940"]'),
        {"props":{},"nodeType":"Scope","type":"node","instanceArgs":{"imports":{"data":[{"name":"Plotly","type":"js","url":"\/assetserver\/46b0af2f03ca323adf531facbdab5be59e805cc6-plotly.min.js"},{"name":null,"type":"js","url":"\/assetserver\/98d4c49067b4a590fb2b4b4ced9a48a1db12cda2-plotly_webio.bundle.js"}],"type":"async_block"},"id":"4964793602311326205","handlers":{"_toImage":["(function (options){return this.Plotly.toImage(this.plotElem,options).then((function (data){return WebIO.setval({\"name\":\"image\",\"scope\":\"4964793602311326205\",\"id\":\"225\",\"type\":\"observable\"},data)}))})"],"__get_gd_contents":["(function (prop){prop==\"data\" ? (WebIO.setval({\"name\":\"__gd_contents\",\"scope\":\"4964793602311326205\",\"id\":\"226\",\"type\":\"observable\"},this.plotElem.data)) : undefined; return prop==\"layout\" ? (WebIO.setval({\"name\":\"__gd_contents\",\"scope\":\"4964793602311326205\",\"id\":\"226\",\"type\":\"observable\"},this.plotElem.layout)) : undefined})"],"_downloadImage":["(function (options){return this.Plotly.downloadImage(this.plotElem,options)})"],"_commands":["(function (args){var fn=args.shift(); var elem=this.plotElem; var Plotly=this.Plotly; args.unshift(elem); return Plotly[fn].apply(this,args)})"]},"systemjs_options":null,"mount_callbacks":["function () {\n    var handler = ((function (Plotly,PlotlyWebIO){PlotlyWebIO.init(WebIO); var gd=this.dom.querySelector(\"#plot-9d05c4e5-e10b-410d-918b-100dfa4fd08b\"); this.plotElem=gd; this.Plotly=Plotly; (window.Blink!==undefined) ? (gd.style.width=\"100%\", gd.style.height=\"100vh\", gd.style.marginLeft=\"0%\", gd.style.marginTop=\"0vh\") : undefined; window.onresize=(function (){return Plotly.Plots.resize(gd)}); Plotly.newPlot(gd,[{\"mode\":\"markers\",\"y\":[0.010497245666318258,0.011371461286391353,0.014319480018637873,0.013681638648458023,0.014145668919556976,0.005770417067952613,0.014192259246077372,0.041899484647719004,0.009971644353611161,0.012063328794736577,0.019661729508262504,0.009746577967492866,0.01870861832246189,0.014303726769484888,0.013609116463374052,0.019483415677392143,0.005225379993386947,0.011093839056387193,0.014315268359949838,0.012987581774341955,0.010708054062470947,0.009656298625632113,0.0069191482910223165,0.007651882321485074,0.0076966015093259165,0.01181406653758852,0.03604746548477594,0.0139976298263827,0.00994785255423364,0.020690400357952513,0.025105865569306607,0.012758917283138707,0.009969765608735533,0.01439539336868701,0.00912905276187417,0.014841539234477228,0.011377530869555782,0.006690898576979331,0.01303852997418496,0.015184269952668479,0.03058980512920448,0.025056923004425854,0.02272718208916611,0.013847204290317574,0.007932093072345008,0.005826877646772216,0.013422583738819164,0.011975442813724724,0.007213335248494975,0.010938869867658135,0.0060548873841391624,0.016578260953428344,0.014416408872022035,0.012751315874469895,0.02241961935635276,0.010488977179080367,0.019850646120569443,0.007864389678492551,0.007245703833624772,0.01646074720504683,0.009792957605889642,0.005559702540304578,0.015193878677101329,0.014011186329686403,0.033463514041721654,0.006380162927024356,0.010971791950810425,0.010527277899671842,0.008671303596514992,0.009753755477148343,0.005276280969046452,0.0072853759440079015,0.004486733649550748,0.009151747156173052,0.015060944935488386,0.014020735010333275,0.01795621719910027,0.0427396349936957,0.0044447172355888,0.024232487825241816,0.009004351796518357,0.011481112775882586,0.02737125141531873,0.01165095215102433,0.01952275799470211,0.009457211802235525,0.016264424964189835,0.020174585151319393,0.0153814234388334,0.011902318750982991,0.009427183794265983,0.010638860867868452,0.014746324781863029,0.02041337743419426,0.011722726116953405,0.017607490598768462,0.014872734926792017,0.009900690197574937,0.014314023947421473,0.02762357816718975,0.01737465505068889,0.021767814517866125,0.017212445772824658,0.0301908731068657,0.0040719568761276,0.012023562042633228,0.0091226195125309,0.006375445817174052,0.015367463424717169,0.007289822501898762,0.010161251885582343,0.012335060955841118,0.011022024708400543,0.020718133907410938,0.007546073119624649,0.008226564424590192,0.027622905777023306,0.010914897079095863,0.0059406357031335545,0.016049819682592628,0.017425159834549255,0.006756941366397971,0.011104745628362106,0.007852574433265699,0.009005322451169183,0.017947004633534522,0.01000796150318861,0.012490722870853595,0.0037056224067117363,0.00957556640872134,0.01224777486266433,0.016195416521173327,0.014517264837078391,0.02141457207779774,0.01112962482265005,0.012440189389431117,0.010400616393952547,0.014418489530336448,0.015553216207587593,0.02580160273795572,0.007225088130728938,0.01622912344631142,0.014235059416103216,0.01452083364953267,0.016006856452550292,0.009402106995306192,0.015621189026434112,0.019063504192976092,0.01356821118178693,0.02552699130913373,0.006953080182904543,0.01981552806472883,0.012644638878405714,0.015220536483500073,0.004354343470235542,0.01299417922791147,0.004693515970995824,0.007754197523202634,0.008572718164238007,0.010871637014460292,0.02291504386301149,0.010616994546186502,0.006646660559154782,0.009326079210197668,0.016127582525556634,0.008928637724025721,0.0074566825522434845,0.011898584610200436,0.014196377298360255,0.011020387195021722,0.011997269054264046,0.006998832851497894,0.009084912939485575,0.012929329915420567,0.011006919129140674,0.012992271664086655,0.008876463549524892,0.004088859828524439,0.01277161433879525,0.01599073876220004,0.026267597137723316,0.004709778309263177,0.00799586541919974,0.022048519628594006,0.018684245488451497,0.019218110347688243,0.007794898632776492,0.007841615543188563,0.016615796593401677,0.011929104322416373,0.008498954068156461,0.013360533075810362,0.006278652170659852,0.008692742728386608,0.007870351995176142,0.007723853384442262,0.009906497753140524,0.007615380521516913,0.008019679639887799,0.01213053653783648,0.012038344301496454,0.0069471858681756215,0.009032913430214968,0.007380975629918675,0.010863323048682476,0.01999231710043069,0.013020244298452784,0.01381829644416495,0.01133646070839387,0.0073350177818443316,0.01150845266135602,0.006097874155419865,0.007768361163362343,0.009906885615046688,0.008923605111410942,0.00807319884243416,0.01449804693592264,0.004730555537108904,0.00863592372171732,0.008523637141160969,0.014367384878796565,0.010131100171067435,0.013552219657790738,0.022960258618220625,0.00949604084097399,0.009040676560884479,0.013801418238084784,0.03123507988868785,0.012449061680659419,0.016509290033897877,0.011416046307313327,0.024403583345381025,0.010992638474771412,0.009278483774333615,0.011234159001850732,0.010949317304987004,0.018662898547257833,0.010967374253864692,0.012341830048804427,0.012633814751409126,0.026799472687987807,0.010622164740964389,0.017442574589589414,0.012025522306787889,0.011215048590957217,0.007756358776804136,0.007970469759804708,0.011364301413055231,0.056754073331881344,0.006447552589277343,0.00946189923776097,0.01428208890805197,0.0083082237419258,0.009482640059249137,0.006338663526222042,0.007913948848063134,0.0126915234175707,0.014658826526669385,0.011961538222860307,0.00892685721189769,0.009375125618472042,0.00895877298055613,0.030864761155264486,0.00658468564244944,0.005713153923190439,0.012786611518681318,0.011646395003935385,0.0084405733011102,0.008807382848879792,0.016948495050396015,0.0089381659111587,0.008505607047858965,0.014638233316052582,0.011212002673320828,0.018797393875114615,0.011266190657963172,0.009323696267391591,0.018014067030355515,0.01917022717696203,0.020596494092406874,0.019482823433791145,0.013071375281765265,0.02003815553939455,0.008972101823279604,0.01061169191927983,0.019541522940811944,0.008267214080300817,0.013662232285258305,0.01330721678330482,0.009379603812782616,0.014841539234477228,0.013552303732404866,0.008780225147341345,0.023793814773596874,0.014385256692301892,0.006757991394945283,0.013453887854569253,0.013325109513405575,0.0187916697700095,0.012920607053240626,0.027486223283413828,0.017350443563337817,0.007482227483417132,0.006970654243381516,0.004427398527749472,0.01085370493891106,0.018879488419331136,0.010892516181875237,0.012482150093017121,0.008435689676133541,0.009644996404245381,0.025547948549746742,0.020321809005662873,0.008693996232858109,0.01437983558065805,0.01056370833616758,0.005651016287888652,0.014963846769898547,0.012118816026290967,0.04437892461555443,0.016417587305329082,0.014808722178284939,0.01609607640331188,0.00885376348444012,0.01137314460350484,0.005226646871081919,0.018784632607815977,0.011170291551495477,0.010478179665702645,0.00814183054902134,0.014537723635957086,0.009515225289684716,0.004625281351991421,0.00808292297518068,0.015597925020905803,0.015245321239617504,0.019121697675064917,0.008600670536285982,0.008897353853163386,0.02089225145521867,0.017269988171286103,0.017519584423139025,0.010559990821882977,0.017463172779716436,0.015695515242900467,0.02389362204793308,0.01425140233964291,0.022475788567565446,0.008442265146201866,0.02455263126592293,0.014444546933371508,0.013922056579385793,0.008632838032330463,0.012244821697489229,0.020987998097065967,0.010252492020746528,0.021986903339452177,0.014126491331422238,0.009996794393399394,0.03323054635932113,0.014176784520273456,0.01291755479455025,0.010377506008323573,0.010550698281840937,0.008789172644826685,0.00838331457397844,0.018703970341238437,0.0057417443369532015,0.00788846089912036,0.01808031679178109,0.026665039161835012,0.01040829976780007,0.00948075931426809,0.008226342925126673,0.013137779495553852,0.009644535810357487,0.010181386236687868,0.02260962924016797,0.010358497979858968,0.011608047379452662,0.00515213159067346,0.01156026845661261,0.008410821720315665,0.0083467869913613,0.01652751043908135,0.00864724730525617,0.01682099472457405,0.0044867314993526225,0.007497047156833866,0.005290881415827466,0.01355700796734866,0.011913787560421305,0.011407977228607953,0.01285389346308046,0.00624857458206174,0.02030931921200982,0.007774766200029635,0.01682062451470762,0.00654576733480717,0.007177724695442841,0.01196762590650621,0.007909850682498599,0.008450859328447078,0.006837237320448969,0.006062953656464512,0.011533921240192202,0.02822256230987823,0.007060093965093385,0.019401133291907777,0.012357003826304301,0.009529675138789636,0.007846877646492272,0.019399137641789372,0.014604116053875854,0.020803689150296463,0.01932727311333775,0.009821217897856846,0.03707317059373373,0.006668495510243288,0.0068546730040874295,0.006009722516175155,0.019374081991897805,0.007674207771774757,0.0239441038749416,0.01855632257721543,0.008363043580764923,0.015197488388713981,0.019657061718287724,0.016152774049036422,0.010191015451122632,0.01609972415195073,0.015724418622576584,0.019668257219724858,0.007712798978939149,0.009681763151655004,0.01376598786863917,0.03442833666023438,0.016242962357846818,0.008642543346899288,0.014903458739016301,0.007818891769684626,0.005158976876391273,0.010408775861029755,0.0044447172355888,0.018460040368662802,0.015260719481821079,0.012695514920368266,0.007445207528229953,0.016395863431934467,0.009723424103441944,0.00673596479570352,0.01486512264701526,0.008701721270733325,0.015613008187800169,0.020787779313184283,0.009779524955277655,0.010106226719292984,0.01286858680292414,0.017471618051490435,0.013674143670732228,0.02872879908021902,0.009286324245268294,0.0082393391229308,0.0081469494065193,0.008962080182829936,0.005385408055431837,0.007568898037925796,0.010846427130367315,0.013190328085661455,0.010747723287780639,0.0076985028704928,0.014977431924399803,0.006080374768411629,0.007094268381923125,0.008663457792544715,0.007264456085822029,0.013254347110754171,0.008728803406332418,0.013525345524635989,0.011272794981803577,0.02004199932827375,0.01876199625052086,0.007819883511943381,0.007932828541914254,0.011351515573518626,0.007338702461952373,0.008865788872038864,0.017978530475421108,0.01290973781428778,0.012373169163289358,0.015205848924591533,0.016713478015073013,0.017302413172602567,0.007721255330777725,0.010086025008681913,0.01219921714740547,0.007980860353697663,0.0167606323599178,0.016006404906650878,0.017413349911655867,0.009516470205052226,0.026553434248484654,0.010036877899380207,0.00661704421998118,0.01008541035728985,0.015040347954924855,0.018758406233872697,0.018709179119635717,0.01969707363838561,0.011405336714651828,0.015006244778606027,0.015271909122633062,0.01177608335258998,0.010314241588634945,0.019008884599978362,0.006565816357915538,0.010754123561328707,0.010285689353536201,0.008925916162498907,0.009268880556664617,0.014372443576382225,0.010561056956562061,0.018117687144648665,0.012149888421472984,0.008744487077643949,0.01959882459685981,0.023719156586661502,0.011238959072360574,0.007681575623187397,0.014024327937646353,0.013069081410250722,0.005390232128879319,0.017078327962478546,0.0060296688116816,0.01179544400615294,0.016671120455942528,0.007897892836744002,0.009259374381870073,0.007478849620186138,0.008256493535126254,0.005642882254342482,0.009569192154068432,0.00818038181273047,0.012290692429810405,0.009391179691000727,0.006033156399655738,0.008969006932518474,0.0147551395666083,0.015552741910594397,0.026173916802880982,0.01873092790274757,0.006411702609548091,0.010945073055389892,0.00784317386208695,0.011216608165535338,0.016737404009126197,0.007048453601373037,0.012018822323766746,0.021085372577770933,0.01691766455636854,0.00509556200310573,0.01652946341037717,0.0103593387733456,0.02504294368461543,0.008505385721176206,0.01402862086108752,0.016862896783265295,0.014165152764524005,0.012744324477004026,0.015379638476646997,0.014614825988994502,0.012734249488383805,0.009488356833796596,0.01971899469715023,0.007777209344660699,0.009167001731191969,0.008174475967145432,0.011019883157559055,0.008536905383522128,0.017040540057398974,0.010390055124239603,0.014383302411588812,0.018005026274958806,0.015231897363191596,0.011303730493234252,0.007618877554816485,0.01371674470102411,0.008941398137185983,0.016452203638445906,0.013063442692357678,0.02828992729273714,0.01413708067213259,0.00625296375559476,0.011527590422967374,0.02380970113804166,0.009018949758053351,0.014673178874930158,0.01073878906618367,0.019142033194060264,0.018968286816612303,0.005218182135226687,0.02428512866595488,0.007150296536116875,0.026772537804628207,0.013725262286000907,0.006749575267816094,0.0061666390810187184,0.01489384307444592,0.009028893810338948,0.014154947822312813,0.008794591680390883,0.012389670800117401,0.013336813245236617,0.013211447569335354,0.027531770436807865,0.02082958222760139,0.01847131908882417,0.011845393182066708,0.015783301360604098,0.004964873309215031,0.008090121104925671,0.013582832771734377,0.008349427410139759,0.008702490831716899,0.004560722517099056,0.010832710037067188,0.0050467569681108505,0.030540818449756146,0.00844463280163089,0.013894555849018402,0.014986664050586395,0.024351247120792754,0.01336259527470689,0.01496939925509331,0.007317768187896562,0.01068980354941408,0.00702072536639839,0.009068285423508828,0.005469554529587514,0.013872914106835367,0.011193373746827974,0.011531247470677453,0.015935386016890863,0.009000191921511998,0.005413976826864018,0.03283647842347225,0.010765553284897433,0.01771629769765309,0.017974986255317706,0.018287095767628093,0.010313083505117083,0.012023115363916363,0.007725114366135954,0.006669345151230577,0.01584449877774256,0.02469829747907663,0.012445767212346408,0.00929807124184569,0.021540573706439015,0.007719520022446163,0.006267131308048496,0.012219333455645997,0.01117827373142345,0.010970793710207729,0.008292398137348412,0.011813343547914648,0.01942902052815831,0.01154069695518497,0.024680627349491332,0.010736647097930293,0.012662314640047778,0.00831154811334478,0.013062212434155524,0.04481357153193525,0.032723959686005076,0.016937581564252957,0.01246082107448533,0.010204102287032417,0.007552753800232796,0.012273986559407877,0.019933208725432413,0.013811260784383767,0.011156427287624258,0.008784645689688047,0.01356249428954961,0.011426685379863273,0.016053668676416832,0.016494447853731577,0.011897542364888889,0.00928647359711702,0.007173719247670205,0.012160028618817355,0.012779577635895137,0.011558569048587401,0.017276610097956634,0.0359605852539158,0.01346863070496781,0.005740764570400531,0.018676728320873467,0.014722193736260984,0.013901888971346976,0.019596121531177235,0.016833790464311164,0.006962598344470558,0.015465824906925638,0.017597561968633265,0.011211072439426963,0.021590826073287935,0.007663401551202692,0.011564165626463474,0.008138704204187889,0.009731981444846412,0.01332048358705078,0.027255021240480667,0.014143208401587183,0.00976605124420068,0.020447909561931245,0.03126286686037009,0.015571626309005875,0.021583862821799582,0.0064865119528255116,0.005636376646465981,0.005005650987064789,0.012753447425987446,0.007805231741934761,0.012936220677681022,0.020721220912952913,0.0103461286477697,0.006256348973219302,0.011128927425335987,0.010316179342785895,0.009690961599032323,0.00594435907208642,0.005709089252345038,0.011681498773938152,0.009589228505772691,0.013099763264394803,0.010966365806678646,0.017892542635256796,0.01158594359295251,0.012555037005519458,0.007150788053156053,0.01117827373142345,0.011372752837504956,0.0033978409483178314,0.006271736256341142,0.01141679407691093,0.015940897836968587,0.011316474314576781,0.009310597929877996,0.009184351370950411,0.011395990588778646,0.017081818996342785,0.008963486130846163,0.007226158836122679,0.006119848400776859,0.015014585358282038,0.011477774902612911,0.009530769292296461,0.01022935028734928,0.014489675917977769,0.010055349223002717,0.02067248995214345,0.017571696205867907,0.010225589906973283,0.00934288854297214,0.006162397452444432,0.017567153261926118,0.013012612620125569,0.019070152560347522,0.006030543243953032,0.009540509936005241,0.008356991562098539,0.010851432438424628,0.010410838608173054,0.011954501534899189,0.0207411374014902,0.012187449731140054,0.02712328500660017,0.010301530721074141,0.013688344125171819,0.008928249696725466,0.008476578336855648,0.012329304711948116,0.009904991519636929,0.007469291860163222,0.01641121286803762,0.020656008557921515,0.00880330005543704,0.006086002111564881,0.011783172085446696,0.010930160202332048,0.015934069674598365,0.0095870464864819,0.008486290224366269,0.012587579675945116,0.008614863821239473,0.006858355124992099,0.005825193356847669,0.0121666453171151,0.011535247930560398,0.016734351427380605,0.01089122641880219,0.0072391696340163205,0.011906907517979546,0.010180242770269982,0.03324084899946432,0.018919918232903427,0.00985987857196052,0.008454888372599768,0.010778068104970385,0.014481669758443646,0.00489415976247314,0.00946701319532858,0.015798249298162606,0.010824022836547693,0.013003796411693495,0.02486162668277422,0.01185934436840839,0.022190621249189153,0.005032253615876478,0.029466675254519105,0.02137161022117086,0.02110370686662635,0.016018448982684525,0.019467631453520866,0.01616550999790149,0.01407064370897668,0.00905269330264936,0.00947355258944879,0.007189103050355643,0.015480469802117687,0.0064285959517188275,0.006681220668476843,0.014470411126954807,0.015767776567507146,0.009812810047349624,0.011477428156616737,0.010448349892178055,0.009456376662073345,0.008040935448291415,0.006402216392295965,0.006059658454437584,0.007837120489628695,0.01293839534363072,0.011970456702440194,0.014388839866852294,0.030126694758743033,0.006630702471407777,0.008393254505694352,0.009222432142067334,0.010240967291363692,0.004708108887087141,0.009493534506953961,0.009168366254519673,0.0101503274083079,0.009806107330310622,0.03090920903274659,0.014093848307043568,0.010630176475106083,0.006876358384013809,0.006062835868904866,0.011563686115512995,0.008522271026060053,0.01640157839164124,0.009347302655792953,0.0049741116372930255,0.006490759709868905,0.004538571730811782,0.009954006614487214,0.010022877842658743,0.006962803250767267,0.005131909638735832,0.018364909113161604,0.017535530915985725,0.011979381921947205,0.006084675365912875,0.011841453960556735,0.011783172085446696,0.010465885701687922,0.00973610919013179,0.009288684829605869,0.007010905972599527,0.010160000316259776,0.007894598152293491,0.010978976924397156,0.010699444163092077,0.01335945864185904,0.016155487694585947,0.006574117162251671,0.011284258505874018,0.0097857982885604,0.015091426837114556,0.01292643415942773,0.017633590030198088,0.006556973562898111,0.022902747457771794,0.0206556667634796,0.01946804927760856,0.01581220115824084,0.028128472212907846,0.02183338319493131,0.013353891784491628,0.021261775554213862,0.014512196890759159,0.009116897261223465,0.011676577545518759,0.031147737522232554,0.021655025361287446,0.010652641728687606,0.014209135509743197,0.006464209676488676,0.034494910058532814,0.011766315403179793,0.010459527505017416,0.010901859559209618,0.012159478116149215,0.012036109061811231,0.01687428444380017,0.017644066443629973,0.010603464392699019,0.009723828059941549,0.012743832553631786,0.017313533304431653,0.015222401383989814,0.009831266626153095,0.011139952365892769,0.0062132052036731255,0.009420471254992173,0.007248146378581161,0.005134108369358109,0.009177224362942868,0.02456737378088119,0.018184107288341755,0.010285835450646047,0.015053505339048992,0.011178167913698049,0.012138944384534256,0.013077515347911775,0.019004963878142444,0.0157944685017108,0.008467429608741856,0.01026910167140849,0.00943979791780263,0.01410871716398768,0.016977429055195295,0.007240567684547416,0.008774321560221541,0.007018222469384964,0.012807817271283743,0.007275482060634642,0.009223922268300079,0.012151318926880714,0.021841836819289178,0.012503557025013505,0.01212184212195865,0.018026690014222947,0.008381785092825878,0.015528106308387964,0.01576929323796748,0.006683246289801981,0.012302252544017636,0.012005274289815557,0.014472438689614486,0.011335071518306506,0.013912796849835055,0.017475235627764627,0.009090992951969674,0.017742489168136723,0.010409905930259858,0.014498877673241633,0.013873175475580589,0.017638182833318822,0.007755441358764308,0.02086275660822945,0.01418372332476465,0.008794541522659672,0.005429167326645401,0.015772564699981687,0.010398387754857564,0.017444813667623942,0.013814827224543746,0.0096143957737501,0.016927889929453994,0.009404128038546363,0.011913657613412754,0.008859874506291077,0.019191565269580494,0.010338217100823882,0.011363219639005896,0.019877722102705456,0.01752950963058463,0.012775108499532941,0.03246172966716462,0.007270200387560609,0.018838346970697167,0.009992783988917914,0.018602561215819984,0.02159630276674619,0.008929607939851592,0.021825619342662073,0.01760820849455809,0.015529229474897432,0.012451735654455216,0.008434796133888745,0.011858114804739446,0.014970300277460864,0.013927587849148684,0.005528677229216211,0.011267359609741135,0.01048181883611762,0.02532826286266067,0.020788925050383468,0.016824323027720946,0.0121396650533486,0.012697875107400374,0.006080691262958907,0.019434763497275846,0.014303082126941818,0.02468604498848633,0.016875123033824532,0.02123447929783264,0.035143156844690306,0.00806612608589804,0.011077262792407977,0.02449284449672943,0.01622212850459988,0.01213955037021498,0.030944314246083814,0.015180870472447146,0.01009352637264127,0.00852656315337119,0.013991175030483473,0.018426145524122497,0.013633186040587728,0.013155194094615385,0.009791889477872476,0.02020326421010211,0.013493140242411626,0.017517746354334215,0.02016444998790413,0.007598441123037911,0.017284925992910347,0.009721082538422424,0.014034907377663561,0.010457380342930143,0.01903366454531263,0.010721620205385383,0.007704748796809,0.007821466809070447,0.02034948507987249,0.011388638505435826,0.009998191397720032,0.008438198686128068,0.01888811960880991,0.008329190619264317,0.004632025847631539,0.01516367658998678,0.01745808349077491,0.016433310201423145,0.012408156712050524,0.008279405162841293,0.024501339823556408,0.015768989690820873,0.01821718508826555,0.006005986741483675,0.014447425543765265,0.021656247224752217,0.01698517432150888,0.016059265590494608,0.010060353524654436,0.006084675365912875,0.006806680550899089,0.021669540987864368,0.01236043213229525,0.011114568961935281,0.006466537130687278,0.005845622094125255,0.014394568123969527,0.0074105442174947685,0.015143055033253095,0.011944345140105386,0.013637393209457987,0.010527934061616109,0.013550989485246013,0.004640837186180876,0.010532206186706883,0.010636883738451728,0.011427789235617505,0.009731981444846412,0.015189483804157269,0.005766252273009028,0.016597224543713082,0.013096367994032136,0.006513443319248171,0.009335666395226355,0.005982229484990251,0.01295998237619584,0.013501704967268111,0.01316739474507712,0.032919338428590836,0.005179693130686481,0.010551947725223327,0.011323054595088408,0.017569556325540265,0.014854854296695658,0.006761042299843808,0.009355258578627654,0.007300348241404301,0.009332192061228841,0.011181768748478281,0.014854854296695658,0.011421553459191292,0.00983160142169373,0.008007386696932217,0.01000892060932603,0.013701786275048474,0.022869883133661846,0.005482312773740244,0.011053098758567139,0.022707611351484188,0.01317553226297547,0.015195426996344552,0.009885678738369213,0.006926711469321906,0.018090058741762935,0.011875510094618475,0.016360443007125115,0.008517296860338478,0.015400904441237229,0.011018262026194431,0.009804316107212566,0.00554814891822271,0.018701455094256705,0.008803470342624199,0.04582278560668379,0.012801680220528945,0.0166094557137677,0.03032754615208499,0.02388820701120115,0.015246631763692097,0.009209652822395465,0.010047112704547646,0.01883572101830042,0.018067207691354992,0.007130132534558883,0.01781603387319111,0.0179741025753368,0.01460605918779203,0.01264896224988475,0.019767670450950736,0.027553450871487827,0.015746175570962848,0.01999663752829648,0.006130432204076341,0.008307556027452862,0.007488661196128969,0.03687787299484725,0.008341156561635159,0.006823851117262971,0.006193759307390728,0.0291812553091564,0.016208991518573957,0.00979156177023835,0.009294803449498757,0.009945556364842695,0.010127514174787858,0.00595943589778098,0.007922942804564107,0.013625409759208056,0.01572616753194063,0.007858632393391607,0.016843619206367556,0.011668793642131296,0.016287190972756806,0.02043949148281749,0.007361970908891566,0.012341940450739958,0.018032337057441825,0.009471565935892344,0.015024863953520495,0.012084390482399258,0.011045084864765293,0.016513224236260858,0.00994879186681407,0.01352757898630471,0.010603464392699019,0.009462766096076908,0.010044926737988364,0.02090776636617495,0.006934745396033156,0.016843327001708017,0.01252534870384639,0.010177638112720261,0.015227671534366357,0.009042505266263118,0.019998249970038174,0.01405184964417962,0.018042979822785868,0.01654861319257989,0.019745636634157744,0.01781147869572012,0.011620166172844476,0.008838553442121339,0.011160861778748721,0.012509399562755102,0.008308121576763222,0.008972936538476415,0.02444922465784292,0.01232712127503394,0.008210442706930443,0.006753098690907037,0.007317508358033572,0.010990082580737555,0.01741592860149583,0.013970488153831413,0.016844014239895094,0.014234739401922002,0.009639363716097088,0.009931086569461652,0.011063966425886062,0.01657560990661803,0.014467813992691475,0.015215154698975653,0.015563273680569008,0.015920609757215924,0.010648843200024828,0.015314434174350543,0.0125291585020949,0.005876943953274278,0.013447699793070483,0.006362530659289279,0.008604948804060356,0.004456396591008926,0.004456701158452605,0.006050979614045076,0.013348358111827328,0.012390277481451498,0.010882974644309762,0.015268511200173803,0.009859762125114538,0.01079863712024919,0.009681429186711051,0.018960196562755563,0.0192134367406112,0.014697797068536755,0.004564239321420411,0.0076871890231407424,0.009568351788769757,0.01047503523991996,0.013960946799134046,0.006836148974974037,0.015318396790092783,0.007995124067402253,0.026076533368082945,0.0077549132190113945,0.022281069352616215,0.003990693334861345,0.005434358085523144,0.013118042061764049,0.013321762978890608,0.010037882530000994,0.01937594789284423,0.014867972333084687,0.010786684330652298,0.015082053079455789,0.0058650018614507865,0.016284884088605216,0.031346487719943125,0.011962969483712694,0.005816685818641991,0.013286809765732191,0.004444820633690785,0.007126940249562532,0.0089245329126536,0.011895849240585909,0.0108989550816403,0.023517734293669525,0.010488977179080367,0.009440721249437739,0.014128396241841425,0.018834459738597726,0.01115816247524738,0.004401598292768748,0.01341111463314761,0.011969148249249988,0.005152334521859881,0.021123856805740276,0.010384927340290898,0.014142570516206198,0.005547290917470758,0.008268035437645664,0.01003257264165999,0.00893735532506057,0.020827452346627907,0.013149500628572054,0.0073785308126505505,0.008831388081399267,0.021357134163023147,0.00802256296869106,0.03731874051528516,0.010522441230128228,0.006177683626923185,0.014176457921049355,0.020377041812330417,0.01858355806259545,0.013122506091104665,0.02568147850328268,0.020168317559909315,0.017114722713274792,0.015364908968377045,0.011006452368114575,0.010023511723934354,0.01117827373142345,0.014440154805968683,0.0038652448806265924,0.005244105022933357,0.022501847228059188,0.007454847869278078,0.00789049102281465,0.00818399605186128,0.007759967220011517,0.01288067655785067,0.018540420030929934,0.010182654946731628,0.013934092228526682,0.010121694003009048,0.015542786508611814,0.006492875382980674,0.0071697739589162415,0.005924379368920168,0.012542563876436147,0.00881128817225466,0.019431437145367228,0.00845977077966051,0.014339947966924643,0.007371685309035207,0.004071301449755061,0.01894780499309761,0.012471357799670062,0.010414799389249314,0.013469245230241761,0.01288728619347998,0.007475289773558124,0.014853032915391584,0.026353695090771782,0.007818237432197643,0.00985893372598976,0.014952639858723837,0.013576688683002571,0.014555988059096832,0.014917109277453657,0.016198546886335072,0.022558732572087407,0.013205561625769545,0.018560187822213192,0.01300401702610298,0.012884344644423269,0.00996642475498344,0.007499211584963678,0.027813164675846404,0.012109612540810536,0.011586697397863896,0.011914320372795186,0.015614723099919002,0.00777013278146294,0.012927937342428681,0.017001655259115307,0.008014859580971166,0.016733072815267497,0.01317247620583803,0.016903737091381574,0.047710668169394496,0.00790703729456163,0.0072156781571482125,0.010748068767894211,0.009959952589312595,0.00996599660232144,0.021297487415793178,0.008277655105619171,0.01623989227095389,0.013150434684110951,0.011391065376434768,0.00991186312505908,0.015415480978425301,0.019378448735012592,0.01797229358247257,0.008694271314171427,0.02489856085588803,0.008919371999233764,0.025520142390369666,0.03762573386392837,0.006495739846887831,0.027524202480710306,0.009187775727202018,0.011686669019360147,0.008930241279078283,0.011266678740891574,0.01374245602365843,0.01941580314421002,0.0191888862805363,0.00929782522029416,0.008158663700121305,0.014182216246120833,0.0164072952829339,0.00946104073324798,0.012827625745171706,0.01585929425825959,0.021036659595704908,0.010444923690744769,0.03361936848261153,0.02239974953405062,0.006126780873816042,0.013252015373599622,0.019782367096842696,0.013781922981602617,0.01734351133725271,0.005109347409818295,0.013141953897080831,0.00954996851698764,0.016581766584613033,0.012190458049913616,0.009246937435232036,0.01304712971010172,0.01462035400638659,0.009392421298020412,0.014447696268578652,0.010528098114883115,0.018878030942099756,0.02831088624119915,0.014137399360067823,0.007844160976938925,0.01352799923871977,0.008412038960617214,0.017006564625808414,0.013332321582855142,0.013941262518572377,0.01534382844393571,0.01204902786503162,0.01211925639737092,0.02246196865603234,0.02013646405737491,0.01099880405460063,0.010039934692014172,0.011327282874588401,0.009824325128556757,0.008740119671197274,0.014551222586012656,0.011607839719850343,0.011653845439132192,0.014630965289633327,0.01435325799858605,0.014804590742386884,0.0253235650947407,0.012201889360239577,0.007835719154941315,0.015307503633827022,0.01268900712333552,0.019234046986737634,0.019320595230935593,0.007268734437647998,0.024286496611902908,0.012107672860788735,0.013188906595248222,0.010634625184877951,0.013811196750862014,0.00811414026000139,0.01447372997911296,0.033559552382264275,0.008161731707853195,0.01905262358414835,0.024153284313743556,0.013933732278268132,0.015489483307107262,0.007915600107109896,0.007836823876483448,0.017752247845607236,0.022958670032438896,0.009898493468808289,0.00802808605129236,0.007400740570932986,0.01957234474515873,0.022376279559408952,0.024558885526648616,0.013673326300132809,0.007731780276150179,0.010970633016874697,0.006136635270595876,0.014940937064129576,0.010061711194068233,0.010613755093625868,0.022895152387473625,0.007971178914324605,0.018398658899024038,0.01088694840344636,0.008958125179875685,0.013372198188725797,0.011509082219358337,0.006849026598188941,0.01910115200471233,0.009513593990363015,0.006586673002480053,0.02086195302272465,0.013472736908712422,0.011872577762069092,0.014665239437401351,0.0066723369041440045,0.014602175063671174,0.00823052192907379,0.017840631837562484,0.008277110945252865,0.012892819486854532,0.011701951286449522,0.010487453094427564,0.014995494098395803,0.011355267340256126,0.007916656222622132,0.00511189564856279,0.011073867406591702,0.014333520077065417,0.006216097012695688,0.01695911979021577,0.01517429039538918,0.006623015159586106,0.008587279450260022,0.010713490233805871,0.0057515003608729475,0.01018052110082166,0.00522661727581396,0.0177342971432414,0.005724061057815847,0.006938217300781925,0.010374989145886332,0.01057802662568198,0.01775342004117479,0.014218442362870114,0.00986403685889066,0.022319530355341188,0.007628166015971007,0.007385102750358037,0.012637110849787664,0.017222363108150902,0.0132272278335298,0.011034105616338882,0.007391583028818895,0.01739972989478747,0.01831558954701223,0.0069667439390996705,0.01093926700434576,0.006627926227507896,0.009584162499053993,0.01155714731245096,0.010356254621705389,0.006746542340431292,0.013253043112936307,0.0078123728765371265,0.021521282009791403,0.020252504252621064,0.012015645861132898,0.016127400955251236,0.020161247526412494,0.010917326274564026,0.009025199664088943,0.006511638351300385,0.008621883330799716,0.013021195006978905,0.012949617400811268,0.0061907601657607775,0.01338613492511559,0.017242333037414844,0.005499965549684782,0.014593189458950197,0.008874986813326402,0.0052689334003634455,0.014678267849719765,0.014404246193131322,0.009025604865365123,0.004504431128274907,0.009165607490019871,0.021135093790284276,0.015246172433940367,0.009864549096060743,0.013283089356016629,0.014262949629171144,0.011769925752809829,0.05177253650452233,0.02564511938191255,0.007656318945686001,0.0062350280978702285,0.011920182287699718,0.01251063655136637,0.009813379429383193,0.009665208538053145,0.011066198955857118,0.011910211803533119,0.010371651094656589,0.0056065557417962755,0.00494874892990176,0.008234119580182529,0.00750758508266122,0.010709553687978357,0.01585029194166983,0.0059218606439878875,0.010324185668355385,0.014953448447384105,0.008667693301258883,0.016332251261876745,0.01795690723125416,0.01009247793463944,0.014018461691156621,0.007198571094182587,0.014587608901789173,0.00686137593746365,0.018143055400601463,0.012518403166275801,0.018012029686483192,0.014271345009373628,0.009841549491418829,0.006810475470659701,0.012839199681527665,0.006732029064335685,0.01714462784351289,0.013700163632249194,0.0074520505078369565,0.02126159793385906,0.024217376973093938,0.008512824409682273,0.008830970381295095,0.009424997628865839,0.009536433246495175,0.014601036416035518,0.010605315846601912,0.007401567208671995,0.012149178925653387,0.02119601804908727,0.006828180246621334,0.013964590974347501,0.009573708063989404,0.011221088715790948,0.0041901870239237585,0.02753629643199582,0.02108375812133343,0.00570982590850931,0.021110681613194175,0.020747506680668024,0.010654948651035962,0.004597951787034907,0.019082479691598524,0.013659539886769384,0.012904136634675751,0.013056337730736145,0.012753464798950393,0.010373511140531429,0.008030163596081153,0.02376906045277311,0.012545074049454995,0.016330688467497852,0.009992302530010565,0.010543084861006264,0.005335155135982306,0.014576823704420734,0.007597470400342962,0.017164871860300215,0.01143655691508929,0.020559681616063256,0.015597896249927632,0.00848189033711489,0.013867781235412442,0.00934661411287959,0.0086207259425762,0.010095398403230725,0.00769276006525981,0.01337559604785588,0.008442133558092773,0.014543477476927686,0.011109223862997992,0.01388680966037643,0.011040481484669826,0.011519013684453268,0.013131309083477264,0.01081330629346768,0.01551521671285432,0.0073908861450995966,0.019197300848252316,0.014201416284432248,0.00871634363642143,0.009039001936180254,0.016510095857108668,0.01040838820543607,0.011298723006036841,0.012425545743502615,0.008061026953136364,0.017499306253279733,0.011349481903667082,0.01964060209581971,0.021027033049413096,0.013187205456785773,0.018054751745441664,0.015497265821288167,0.011860679366669112,0.007992825287993742,0.011914343115847244,0.015504222579845765,0.007551153430160069,0.008904707160057954,0.012678683325236976,0.02452864438593241,0.013605353204921603,0.020986438839642324,0.015012569843120065,0.03030287617463179,0.016581417318252533,0.015140380500938303,0.010929422871571776,0.00949899731920311,0.007753555344556483,0.025173546841394192,0.016069161931881744,0.0143833497626789,0.013935121818557212,0.009855746022044892,0.014067813619071487,0.01589442392778243,0.009466637131575436,0.014764049710169692,0.01374739414972191,0.011755685303303622,0.022012915827115512,0.008323528924282063,0.026230893986138485,0.007858137688754749,0.009084114553878158,0.012157680305099599,0.006641697467721093,0.020670222567763255,0.006829056124950386,0.018403348861346144,0.010855420053291539,0.010524904223789117,0.015973325793840365,0.021654202514836133,0.01615988362398262,0.00855243376875021,0.011953932416213396,0.011238529278207104,0.009476801351068884,0.0269060247473352,0.00970143757760125,0.01135366700437543,0.014268413423882544,0.007460431911833577,0.007349377350649048,0.01091150510623508,0.010843102689903825,0.009225848593373427,0.00976294803609234,0.006551639749386984,0.010550155617854032,0.01451723750278971,0.011065015322537277,0.006312994725909817,0.008644071429395791,0.005191995536227471,0.01633669505737449,0.008514462380025832,0.010679858308056615,0.014812708606021867,0.018656043782036343,0.01052582296634157,0.012682951468493454,0.01217958683331207,0.011007444167067391,0.013056300014393885,0.016136050423680274,0.011946601955906072,0.006995367234364229,0.016820593214912107,0.0062892761871877305,0.008597694577841403,0.008858115922968885,0.010349073575839739,0.01629529148850374,0.01825247507207682,0.009045282795171257,0.009461193026181414,0.009022909593711608,0.003887893225315206,0.013348476380268632,0.005644648466545493,0.014563089536690381,0.02483430313909366,0.012934388804932815,0.009575942082032433,0.011363787101349094,0.02355341099652751,0.008887015730462628,0.014477901075481655,0.009580288602978125,0.006440049055061162,0.01327766665106638,0.0076465148362409524,0.01101424645452052,0.049234546332665434,0.010888114143774245,0.005999041962079237,0.01416201062691035,0.01830093357492189,0.005736846334698274,0.01466581867967351,0.00740134987448898,0.005400749080337379,0.01126870803100064,0.012223057368319945,0.008552268032485726,0.011745032295433729,0.010358777137633859,0.009993557315115911,0.014058251993995383,0.006542452968632045,0.03173887683696056,0.018672874242454462,0.012379970803096201,0.02069716010146775,0.01347147543140285,0.007783024903933927,0.011671351787625421,0.04369216676439224,0.01923475827889475,0.01670759371938159,0.011514573307540802,0.022623643219181214,0.010836839798532274,0.014982018308942632,0.011981436232984966,0.012777652833535567,0.008194883062297355,0.008848755758489566,0.016045128883619076,0.005658625557359852,0.006941563277418598,0.010353518238802343,0.01381540530683919,0.009114308808403143,0.014091854221901118,0.007726287403131094,0.026403807714640976,0.018822823880251503,0.016639023188594743,0.006354977713553957,0.010685790300659326,0.009388486969599229,0.020877032222324336,0.008566949127007412,0.014649083415237452,0.011202238122941384,0.013125044810924934,0.013884048618745202,0.015621936549469962,0.016583143865339385,0.008549284204866085,0.020488095999184677,0.01613684604881066,0.013991437887321915,0.0067375887253953515,0.015941032579315065,0.01243523945274017,0.01278322326782263,0.01008467318486539,0.005890345346841988,0.006661098810940603,0.00736184189833433,0.022089246474445236,0.006453664997513504,0.011974946094378896,0.011835400952741108,0.00832110031112073,0.012220979765062779,0.009334131972086764,0.010128833676455508,0.008346064703014336,0.01065166176227986,0.02711228569918564,0.007778912980710881,0.010451426645412753,0.014724012940577657,0.008700191219412727,0.010562193099117904,0.009124516457433217,0.012820176754744088,0.01116371547175198,0.009532339935204059,0.01773222063215951,0.010228119400059368,0.016921725914826935,0.01129133146172485,0.013906203152024618,0.030078725105599224,0.007018145809218362,0.009919611280076523,0.007416993693359779,0.008379367903425534,0.008204147265545048,0.009672500063648462,0.016669392501673017,0.015340220702931158,0.011917795651521226,0.014360594088065792,0.007027167116426378,0.0063149601807534015,0.016616489614440445,0.00914192866572703,0.005243286459566346,0.027824261698185984,0.019668556787082906,0.012470294664370855,0.016005519481510654,0.011820927095745252,0.014286472594359638,0.023985459986048497,0.014200386970078886,0.010892320661304272,0.022308791030733136,0.00844047709508287,0.026221456193861768,0.022208569289780555,0.01717693453469132,0.03222055663253492,0.029456599541763256,0.019185458209580696,0.01566349396226156,0.007218588658854386,0.010054751416998707,0.005466652842103103,0.01865897845537989,0.011002435239019158,0.009533798753867796,0.018970008103414565,0.009146348271326779,0.005411302236620948,0.014414790116621978,0.026432022773097745,0.008125780979354,0.01812164864530058,0.005731015333981442,0.008447395928696998,0.01732770355708913,0.009192629821384324,0.012667740868000037,0.015738683483478146,0.008174638600357578,0.008451403142349712,0.023054377916821522,0.011547504034560755,0.010481571564003025,0.006071444717761569,0.009104465461351172,0.008070560759028752,0.010267851547322111,0.008126215240299065,0.014688326359837325,0.02291330931437946,0.013630948759667067,0.013590649294846125,0.01717914870864434,0.029473118978334767,0.009478310388776903,0.009481582991484574,0.003597432701286833,0.0065028246446099565,0.011328185499037547,0.012474429570275926,0.007790268049006559,0.008804802121020082,0.009755662600492323,0.009106702213783503,0.00788318556670711,0.019786713742234396,0.00565604259983257,0.010750562700160251,0.029433044718592767,0.00990980903400607,0.0075201808809131805,0.019937065423439423,0.008232145601553276,0.014890540237642897,0.011197875930248045,0.010814714189625822,0.01387382747200323,0.012112025143688915,0.009306850787122333,0.007196512695746057,0.00907172233575256,0.00837016845193903,0.006852764277289343,0.009237868777889558,0.00961951851033677,0.014589343029879926,0.015516120354342675,0.010047728858504348,0.011922513486188169,0.01567912532223239,0.01633696282085822,0.01414900083584376,0.006634868513967028,0.01108035020710141,0.013773311791517253,0.01262730921512649,0.008679021099227899,0.018906433765420564,0.010447970110030822,0.007654804927220017,0.004910296209932546,0.010122477248328373,0.01469997953227032,0.007623677698602295,0.03665134517290456,0.014816461021274586,0.011500611698260913,0.0066604550118460485,0.006849337975365125,0.006571850027526441,0.010462306020854689,0.006739395011370981,0.010385309958779497,0.0059344493990754225,0.007869119690864245,0.009768033790457223,0.009299546984806076,0.008251255358953404,0.009774812109753648,0.012448275436328806,0.011184763899440548,0.00676811891300722,0.0068189406648321476,0.008657722141626337,0.014183643512161528,0.027334778778216388,0.014005601941584699,0.018747487553893556,0.013381197412579196,0.016120736285899055,0.018115897960966344,0.006226111515190208,0.012060674748891602,0.011641208628022742,0.015604164332784233,0.008620073949859254,0.008619018497695186,0.006023970136050395,0.010158360116780221,0.013002890809922799,0.011718473054494494,0.021110219206640236,0.009965234354299997,0.008921796241181463,0.010007635219741623,0.00873674477336402,0.02757707134161762,0.005872516147716864,0.006754886846678107,0.016090050860823612,0.017850209515799177,0.005153984487871944,0.011404638076413998,0.024737065351604172,0.016540970710611697,0.02519048972143956,0.009824997479510954,0.014044571197613863,0.013913600270391254,0.014288325884411202,0.01032755833047052,0.019171393622182602,0.012352942895064544,0.010638670029886358,0.01730450560493322,0.01862993402514285,0.016168035466259438,0.013797109272343329,0.020952225514568143,0.013451141656822454,0.009652140883906701,0.012547224881857623,0.01401481632284717,0.005689555633689712,0.012005167629681904,0.01493943506157935,0.012913627309358182,0.005413979510380828,0.017764924182393258,0.01824053283197103,0.014492441146847973,0.02006084586543123,0.02280063430963857,0.013095276750518654,0.012058050712036947,0.01280310325217499,0.019550990396115936,0.012845353883756565,0.021206740071252717,0.01789841754976765,0.011389535099948661,0.009126991228487365,0.01120711922946267,0.00860364686136111,0.01673636748094379,0.008618961821218617,0.01646309384756051,0.008135729228789081,0.011348459937829016,0.010618517806505478,0.01868097137573556,0.009429980852545898,0.010816816009402654,0.014948664716956536,0.014109526664736194,0.00764972799436729,0.024225109135621113,0.010415286008750392,0.012703926555424601,0.010789925407659834,0.04629572315036053,0.016642011505628957,0.007927415568899362,0.015280818499359548,0.011774501832624242,0.020379180373595502,0.015578088986172712,0.012213694933448632,0.006849899241594408,0.01799348334766759,0.009934528763231814,0.008657365881238631,0.016478581910610055,0.012164336217605305,0.01228403801386434,0.01310513463078219,0.023369977000349554,0.010874037066734475,0.014506538412245027,0.012799198800153233,0.02328964658895929,0.007736094542403445,0.015691846386267336,0.024401602509415286,0.018033190497656594,0.009993722662454225,0.015033899452080248,0.023619925924631115,0.03470723417128872,0.012945759901152676,0.01624849466322512,0.015144888744481652,0.031218281577362554,0.009548646650972749,0.038047124070861145,0.015180613770634583,0.012262944122638423,0.01859101358696269,0.012032016591022878,0.024294322514397136,0.005803508689278944,0.020514021222070477,0.014401247100182235,0.01290750158916326,0.017889291040348015,0.004957321993176875,0.006200140528697835,0.02541290739621234,0.013196660159219348,0.03661731771275302,0.012207759162013035,0.00854140651952151,0.017007536687877214,0.00411583937474612,0.010849645837767034,0.011007355424745421,0.00667854420861809,0.01958047160475329,0.010846478291527406,0.0086529268093184,0.017132779564475623,0.007851152047785455,0.0145313991837618,0.005026140748199828,0.008001461204341026,0.015876786292899042,0.010708619216232866,0.026124713857327793,0.013638932893353434,0.01826751048724743,0.014991043482855664,0.010260996564219534,0.005642941045490529,0.006557548299831328,0.01912970859565679,0.016111406085622944,0.010058781619025488,0.009150787484912985,0.026880110119201123,0.02436004515469796,0.00695612670603476,0.014197330678266121,0.014571743256182946,0.005951983074048133,0.008272102386452816,0.01585652669334826,0.01328660369505282,0.017833915134336707,0.004259252074139946,0.009937694555247,0.008086157754230577,0.02588920568736106,0.007747343175290023,0.006482407606700176,0.011378528444584885,0.04987519974794516,0.012014457460697412,0.010042470874443984,0.00931078245607405,0.01482482162303023,0.015449961929691664,0.007620824003921115,0.008456255336691827,0.009313158139872307,0.0161560173898563,0.024534291704103026,0.020620704085533632,0.012060408409786678,0.027713131705246048,0.016114656607956503,0.017056009991673823,0.007121624316278534,0.011113132797494119,0.029574070612290348,0.02732308043800896,0.009412664986626995,0.005222951723240939,0.016904988501249316,0.006095811278385644,0.010815570883775522,0.01606710349676349,0.014156106630026451,0.011930627739692548,0.01997405104513576,0.0056366117612493775,0.010045315507149256,0.008130109541118237,0.009217814901337058,0.012421995286783831,0.012625715802720108,0.02151908782262645,0.02058335416711161,0.011617597462195964,0.02116723393837291,0.017424873744045978,0.0072572410458019215,0.00618206471113214,0.006276769363971405,0.006028680387213193,0.018010507549299525,0.006905345162417751,0.012890259510490349,0.008307556027452862,0.017191680177457088,0.013815262601926455,0.013656110075715395,0.012690638669132785,0.010939623995495017,0.008452709562508178,0.006365404276406336,0.0079816301690421,0.016202225210089852,0.007271391806480855,0.014799661127144053,0.009197460649826081,0.021448717940326115,0.016606504323998128,0.011798045246662874,0.015553559491160612,0.004990966743160401,0.008260703236227802,0.0075245343034765376,0.011839037789140625,0.0048727788059104455,0.016601124025995492,0.011055209414876524,0.011833465852526046,0.01583196701609118,0.011093707601515566,0.011543727884657134,0.023000171967838504,0.006558316085096793,0.008716145983475419,0.003915322079092422,0.005825971676084295,0.007361475566081363,0.014854854296695658,0.0070201538058111655,0.013294975576040886,0.0066340068162152556,0.011213039538557143,0.010745021905754307,0.016984832064986886,0.0032027526783517746,0.01311909770971294,0.01282479418461649,0.012131570600230077,0.014885539703025124,0.021455318552682668,0.01875295670754211,0.010052454189440353,0.01680182677820626,0.015592471569482572,0.031483011064943375,0.019526243678499276,0.012715492883963075,0.007894598152293491,0.01978363759500929,0.027643937097135626,0.011470824887363241,0.009167590965636782,0.015962784031711225,0.008317587777704801,0.009956036720785095,0.007379274390868688,0.016950949947416256,0.0178590151258386,0.01664742785796012,0.022853362790421543,0.01085517461847629,0.012239239634249627,0.005615018254635457,0.01490205744623085,0.006060431199087976,0.01596022995920931,0.011648195903544776,0.02044898464157566,0.008263368128220904,0.010133109156435206,0.014682000144723085,0.015385532772433753,0.012305056731294688,0.010529633190838274,0.006313401585941584,0.02409822187547199,0.01101129104262322,0.021396977500622374,0.009379701810611919,0.014358001618386199,0.011476351869893585,0.008235525265749817,0.008506053599844925,0.011282264399494351,0.013924576837748913,0.011651940244691456,0.013337961404047567,0.010261693862180517,0.012609764948409175,0.006780904742132444,0.009216652078134527,0.008204368084887968,0.013992154819811189,0.02656947984251129,0.011804807465330268,0.010644457795494718,0.01434333280478187,0.0059638438327597534,0.01776133851806,0.013276547676229376,0.009177719159777123,0.00915082645565701,0.018449109098416478,0.016866470664119212,0.011386449072718312,0.012123567672792426,0.017126261820837367,0.010204131679947197,0.013676632045883165,0.015855886022270484,0.02722243025903387,0.012501443791239852,0.04200853634919275,0.010341867393829219,0.014149407125462315,0.007737361351516416,0.012405193804179617,0.014234825974387045,0.010711388106724234,0.005787191776140514,0.008991260699296344,0.014769468199083128,0.00760592365154898,0.00825093540019668,0.019017555894684946,0.009386593639457036,0.016565003725078468,0.015504448160313572,0.010731061770248584,0.014113759451024376,0.011751631660512404,0.0090946881572897,0.0036643472255273313,0.014005561534627948,0.016238231426265345,0.008512212406300202,0.02339125765308262,0.022353352384640972,0.01139132871255876,0.007766394770956177,0.007922538137701851,0.00875342790613279,0.012945759901152676,0.009723249546911793,0.004205978720196714,0.025107079860538783,0.008831158400953403,0.010747251813770934,0.012851873121875022,0.02037166570990566,0.012645537964544215,0.01864872572897983,0.011725549221372611,0.010178305947893181,0.010674836982570074,0.01740853701256558,0.019210346197195072,0.003643212853888241,0.012109270199177687,0.012582555259393285,0.013724862742995579,0.023734685503465715,0.007216610978793607,0.01608675299975871,0.010013022001116258,0.0059334538022913,0.018538802038544053,0.007260069363705923,0.01206418708620594,0.012143583570844689,0.007978274492402434,0.01117827373142345,0.010907167581533308,0.018086942122530366,0.009571587620789518,0.027738899398131997,0.013500148832054614,0.018499717928418886,0.009462989496653458,0.012756850948296369,0.014261715847454741,0.008869934048678392,0.00716498611576215,0.010500376524121577,0.005132888361871136,0.007229118469142389,0.007603958337418458,0.009432199195911352,0.008392437099781398,0.013515348662730945,0.008188835526871085,0.02376050960956279,0.011691390185608134,0.008801286081482403,0.010478965438809476,0.008841883403733852,0.020964613417755653,0.007254765063107799,0.010598902864118348,0.0047274737886551736,0.014687649877408684,0.013275385863504742,0.009255206936547123,0.01209627107932493,0.020336252878772446,0.009645410905380972,0.01454149610596281,0.011143125985539917,0.02111847927356891,0.006239094721978719,0.006383456002066519,0.011700759363856908,0.01349749491264349,0.006545354816537607,0.010698288781480481,0.006300897466392361,0.009862192503418457,0.0075956582264411565,0.019685656093666667,0.0192211174195556,0.012924815345693844,0.010394493025002708,0.008813024654240135,0.008496885236039572,0.010255201734195673,0.009014126661573847,0.010202932268804981,0.017097125373614817,0.01615283476260797,0.011778481302721312,0.01578478300048045,0.01377993360248668,0.005207267704459907,0.010915318837868974,0.012876451415346704,0.030158574572938367,0.013578003700304353,0.012276137414964203,0.0170765835367935,0.005155189808934834,0.008496977774781339,0.016504228144461106,0.01257187811516593,0.006755446666492805,0.011872236862139682,0.011517862784074608,0.010894339568066432,0.009306675007304567,0.008170761637142056,0.008408527465224016,0.006883767518230388,0.014178523569502156,0.014544468364904679,0.008293088603532763,0.009104942956218097,0.018302878340988857,0.00913121000933101,0.007052556374123394,0.010035006763401012,0.0054014230000101375,0.0108971147487666,0.0560950309877841,0.006092954370711127,0.008179433833558581,0.014383998504007968,0.01414390739470007,0.03513350602285707,0.009773043959609842,0.017748257530098253,0.016331163582322568,0.008967934870810889,0.005662839336375646,0.009379692413471028,0.025159478175776594,0.01880334535775555,0.012883920371568677,0.007770206482068538,0.007573792938307148,0.009902382896873094,0.008199573843864905,0.02333189384016784,0.014841539234477228,0.010510993953403816,0.01285284099149423,0.013777055597932642,0.013820174510913311,0.012477114454050564,0.009557250205167487,0.01756628097472274,0.01017226937484299,0.012944096616178185,0.007002644583945505,0.010831422761325264,0.014461689024918368,0.014854854296695658,0.009797846898625489,0.005663988970708977,0.010040910705207896,0.010492615455233832,0.0073393484424434646,0.014712561104968654,0.01190409155920422,0.017158412789217346,0.013578975711025738,0.0035514761364604415,0.007623868375662112,0.008040699662089645,0.011043772677851992,0.015552275023910354,0.015172110597407643,0.005704170818051869,0.009446305881952744,0.012076007944780861,0.007733855123094873,0.015544194761151443,0.014835935081465098,0.02096047299231413,0.01828858463416761,0.021593264361805795,0.007448065777003756,0.007453443839979328,0.01165627367769521,0.0261893917498181,0.01937748756752154,0.013526529167455711,0.030777277595619112,0.009746914267875651,0.008443917959379621,0.020538299889702537,0.01573228044969606,0.008282295134486509,0.01326569588125,0.011378035561395966,0.01196339204953592,0.011981001439946867,0.010325993746515414,0.007594022905128596,0.0279088198041217,0.01103665043317792,0.013976454400260694,0.006541724806957929,0.01666017996838084,0.010852501626153045,0.012237147386801579,0.010606111363845648,0.011668937001610586,0.00912098611755183,0.011578683004312766,0.010338412805333269,0.011891562436010226,0.005940497850267837,0.009487021753951073,0.00843247576271181,0.00705810866682886,0.007215773494121824,0.009407673708066977,0.010027061253722318,0.01447062999328203,0.009319283875830099,0.00927001857087308,0.012988664152081688,0.013824704951947042,0.013702438018243921,0.010955076347116581,0.008636678842746184,0.014089138264610553,0.014373409718390961,0.007994439414577116,0.007842750553717146,0.0140606121459651,0.008226210753973085,0.012121476668709847,0.011377638520222973,0.006736356683178978,0.0071369476981394345,0.03311195247583982,0.004853044630889878,0.012306726222287989,0.005885215488454656,0.011878559061329931,0.005664273392461216,0.020131980961614195,0.020266161909273085,0.00934598231570613,0.010412263579805046,0.008129348130129607,0.008313207078784114,0.016692269707151097,0.008934884249785204,0.00831198875263729,0.026439956625980577,0.015514473858800438,0.008655614741673102,0.008247127926625528,0.005901420983938763,0.010671815852554507,0.015248027657524775,0.00598537758082648,0.009409380334960788,0.01142748734774045,0.01504869194223558,0.009176816998843656,0.004489117643432432,0.015056009176593483,0.012013795626887466,0.0226108363889353,0.011572082280867023,0.011731596411673848,0.011258555345043645,0.01093743128745212,0.010197843072784896,0.010315911407136688,0.015306541902405848,0.010633200813130938,0.02119259436276214,0.009618373535618186,0.009995841421259298,0.018839673761105888,0.020039209408912732,0.02397341765877643,0.021106643040211995,0.01095481814502079,0.018353540192932574,0.007929894678061293,0.012541872584862793,0.03594993306974474,0.015073789946313884,0.008812004365932949,0.03152314319446479,0.011424573903540482,0.00628185390989715,0.012262470303233063,0.015281465207478254,0.010135065647654604,0.01573685904674293,0.018596882576106373,0.01005627036906494,0.008660292316580623,0.005487980680860977,0.018451673808891327,0.008193615678591622,0.006097741390485268,0.016652752528271576,0.00824456217558014,0.005909320922220511,0.00855727476077928,0.007892313087443592,0.018537964307431896,0.011276648170504241,0.009416085189593974,0.01431513390294472,0.022306632637388475,0.008786074254634605,0.011400859570117522,0.03213298395446879,0.010655597436419605,0.010485617395603419,0.007832550080317222,0.006635100935318801,0.010773270138565138,0.005976711654031421,0.012945759901152676,0.0072008814750907256,0.008109210535514638,0.007415681083167402,0.014920085928912858,0.008909210972157695,0.013253199900746604,0.013916656774633869,0.009198490170917228,0.01097829276123009,0.015734739414386592,0.00672779885918147,0.016249767777662134,0.007096189555404277,0.009890243887715791,0.004695679338752968,0.01220790242619394,0.03103937822729894,0.017251384518635542,0.021659414335530723,0.012702683058017434,0.0067843001257770486,0.006227055690416818,0.008995246873449644,0.005818067151020284,0.009776131715235555,0.006614982406242244,0.008057782523725125,0.008270193647159689,0.010302702407833802,0.017168146507664312,0.010902358298745678,0.007579874009577086,0.014562727098191747,0.004559216067507787,0.005567941786733624,0.008647435570099898,0.014267253240261799,0.006411480557373046,0.009140706500904885,0.011603736369115533,0.007975697100704615,0.007877779974865055,0.008199957546301338,0.004339232993425866,0.014303256939516382,0.009852218970437405,0.009893625709779632,0.00932934911362215,0.012767364670873037,0.005812327693742409,0.007699278873999261,0.0064218808028526884,0.013150607525319574,0.010013253779588477,0.004789393061211873,0.018392381373616436,0.009566074533231293,0.018047588342264737,0.008008542314788406,0.012723540715048777,0.020323650789589774,0.006728544857718627,0.011354388919352757,0.006564578601252735,0.008150144423926897,0.010428268538416966,0.0074807823818991,0.008728072774781602,0.005328289063584255,0.01250261480658253,0.013037769963612772,0.016709309366733593,0.010811276285220658,0.00865499689515721,0.0059090742285072256,0.009987807851743477,0.007817811681947858,0.005783384981625115,0.015721098274735643,0.021981212027247433,0.012519747171255627,0.016156184669263343,0.00971583236216026,0.018684419944711667,0.018577062914366036,0.02619693450376634,0.008284715807991446,0.04250574464950848,0.013261015848933362,0.01357411564282404,0.008955280986698805,0.011711831333616526,0.00821799815077486,0.010385751033567325,0.015881428233203227,0.021910903538079667,0.01450785988147059,0.025885984514464982,0.01761607843477208,0.017931724090425566,0.014949213709817687,0.013837446322253552,0.01072679011575787,0.017262908624671478,0.011896460351046871,0.021163406063166,0.008886931975089307,0.012261263548503517,0.00983569160208192,0.013495445060775425,0.0083366258697448,0.00976800176055354,0.01155933662572882,0.009508499955639285,0.019942478535194277,0.014952626212408244,0.009802427303325863,0.01987977974990111,0.019012957247971918,0.012008301148608956,0.014893624757742249,0.007263977803724075,0.011764264502800242,0.028659690662860303,0.01164837602413853,0.014907672676769578,0.006471137645864978,0.00933239472059527,0.009734421524098842,0.009600974161343128,0.007180702213421654,0.01128575964996511,0.008871858261450967,0.012070547576589296,0.008986048835588461,0.011228752157456109,0.009846554750050671,0.005541580498737171,0.006990241223906591,0.009308038466105253,0.01285855918447351,0.029564711546583897,0.012376467375565145,0.010801729601899665,0.010833772851973015,0.007384665865729701,0.014169915308291226,0.013467021302063443,0.025984684990807267,0.010048976801761637,0.014833265526339763,0.0063934080466643865,0.015510009968878096,0.00464248291229663,0.006195012247570218,0.014208406951530743,0.008121550624303309,0.011666516984104957,0.01573380918566986,0.01302091948124145,0.026905823152798294,0.009363415343465365,0.009622912681347325,0.01109188727185795,0.01787998602307611,0.01831799438421655,0.004523587281469409,0.019778677456371418,0.010133013584308487,0.00867802872782914,0.013223518031661908,0.014972817559795829,0.009487169390907975,0.011781350389829382,0.023469120725359702,0.01876714603987331,0.011062083020818292,0.0068505257634271025,0.013127274227749074,0.025000076294178143,0.013971092739800656,0.006180541874406628,0.009594153094493536,0.015570244525254368,0.015046727716701085,0.00731088892515676,0.006749789378062773,0.009322582168626985,0.02773115848653699,0.01132202955879656,0.012870154912785337,0.015171341406458075,0.008377576942846583,0.015632096174029195,0.00681863417355534,0.008248060001817352,0.024810364126808992,0.006169307656753187,0.014754855536442317,0.01391504636579399,0.00840091338910313],\"type\":\"scatter\",\"customdata\":[\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\",\"\"],\"text\":[\"I would suggest keeping up with<br>the population growth and help<br>reduce traffic.\",\"Better public transit,<br>specifically trains.\",\"Cities need to have dense,<br>mixed income housing. Fight the<br>moneyed interests and loosen<br>zoning laws.\",\"Stop raising taxes and think of<br>the people who were here for<br>the past 40 years. Be<br>affordable\",\"BUILD LIGHT RAIL, AFFORDABLE<br>HOUSING, FIX 1ST STREET, STOP<br>GIVING TAX BREAKS TO MAJOR<br>DEVELOPMENTS\",\"Prices to live here are too<br>high.\",\"HOMELESS POPULATION NEEDS TO BE<br>ADDRESSED.\",\"Either develop great<br>initiatives to include and<br>engage people of color, or if<br>the programs exist learn how to<br>promote them to the people they<br>are meant to reach.\",\"PLEASE DO NOT DESTROY SINGLE<br>FMAILY NEIGHBORHOODS BY GIVING<br>PRIORITY TO DENSIFYING THE<br>INNER STREETS. PLACE DENSITY ON<br>THE CORRIDORS AS WAS PLANNED<br>AND PROMISED. LOBBY THE<br>APPRAISAL DISTRICT AND TEXAS<br>LEGISLATURE TO CHANGE THE WAY<br>RESIDENTIAL PROPERTIES ARE<br>APPRAISED SO THEY ARE NOT<br>INCREASED UNLESS A PROPERTY IS<br>SOLD.\",\"INVEST IN PUBLIC TRANSPORTATION\",\"Be more diligent with our<br>property taxes\/bonds. We vote<br>yes for bonds but it takes 2-3<br>years to enact. By then things<br>have changed and more expensive<br>and often too late. Stop<br>spending years on feasibility<br>studies. $8 million on<br>CodeNEXT. Those are my tax<br>dollars as a home owner!\",\"Don't forget the original<br>Austinites! We are still here<br>but barely, between the rent<br>rates and cost of living, its<br>cheaper to move outside of<br>Austin and commute. But we<br>would rather live in Austin. I<br>was born at Brackenridge<br>Hospital and I don't intend on<br>leaving Austin but if the rent<br>rates continue to climb to<br>rates that only transplants can<br>afford we will have to. We<br>don't want to leave!\",\"Please give us different<br>electricity\/water\/gas service<br>providers!!! Please help raise<br>minimum wage!\",\"Please read Walkable City and<br>the sequel, 101 Rules for<br>Walkable Cities.\",\"I love it here.\",\"More affordable housing for<br>Austin natives FIRST!\",\"Taxes are to high and home<br>insurance too higher\",\"MORE FOCUS ON AFRICAN AMERICAN<br>CULTURE.\",\"Please work harder to improve<br>affordable Housing to off set<br>chronic homelessness and<br>vagrants squatting in city<br>parks, trashing city<br>under\/over-passes, and<br>squatting and polluting wooded<br>neighborhoods.\",\"As a Texan native who worked<br>and was educated in the City of<br>Austin, it is astonishing to<br>see now the city has embraced<br>outsiders and forget about the<br>people who contributed to<br>making the city great. The cost<br>of living and pay gaps need to<br>be remedied and PEOPLE need to<br>be the focus in order to<br>maintain the true character of<br>the city.\",\"Austin is so spread out it's<br>difficult to get around<br>effectively without a car, even<br>when one really wants to do so.\",\"I WOULD LIKE TO SEE THE ISSUES<br>OF GENTRIFICATION AND OUR BLACK<br>AND BROWN POPULATIONS GETTING<br>PUSHED OUT OF AUSTIN ADDRESSED.\",\"I AM AGAINST YOUR DECISION FOR<br>THE HOMELESS TENT CITY MY<br>NEIGHBORHOOD WAS SAFE FOR MY<br>KIDS AND NOW I AM ALWAYS<br>CHECKING FOR HOMELESS.\",\"Traffic Congestion especially<br>on IH 35.\",\"PLEASE MAKE MORE LANES.\",\"YOU ARE IN OFFICE BECASUE THE<br>PEOPLE PUT YOU THERE, SO START<br>LISTENING TO ALL THE PEOPLE<br>INSTEAD OF THE ONES WHO ONLY<br>BELIEVE IN YOUR AGENDA. YOU<br>SHOULD BE ASHAMED FOR THE WAY<br>YOU ARE IGNORING FEDERAL LAWS<br>REGARDING IMMIGRATION, ETC AND<br>GIVING SERVICES AND BENEFITS<br>AND SCHOOLING TO PEOPLE HERE<br>ILLEGALLY, RATHER THAN TAKING<br>CARE OF THE CITIZENS.\",\"Thank you for creating the<br>Health Equity office and your<br>work with Community<br>organizations!\",\"You have created a problem at<br>Manchaca and Ben White by<br>allowing public camping. They<br>are blocking the sidewalks and<br>posing a health and safety<br>hazard to the children who have<br>to walk to school.\",\"You , do not and have never<br>representative any of the<br>people that liv east of I-35!!!\",\"Fix this traffic mess!!!!!\",\"Open your mind, expand your<br>world of people with different<br>view points and life<br>experiences, learn to listen to<br>people with different idea s<br>and points of view and remember<br>that you serve all of the<br>community, not just your<br>supporters and niche interest<br>groups.\",\"More affordable housing and the<br>highways need to be expanded\",\"Repair roads going towards<br>\\\"Goodnight\\\" sub-division from<br>Thaxton to Nuckols Crossing.\",\"Broaden your mind. Talk AND<br>LISTEN to people who have<br>different points of view and<br>who belong to the other<br>political party. Research your<br>planned projects EFORE you<br>implement them.\",\"AS WE TRANSITION TO A BIG CITY<br>MORE ATTENTION NEEDS TO PUT ON<br>AFFORDABILITY TO CITIZENS WHO<br>WERE ALREADY HERE AND NOT THOSE<br>RELOCATING HERE.\",\"Affordable housing\",\"Rethink creating bait to draw<br>in illegals, homeless, vagrants<br>and gays. I have nothing<br>against any of these but think<br>Austin is wrong to encourage<br>their moving here. If they move<br>here without our programs<br>designed to draw them here.<br>that's fine. If tough love is<br>good for kids it's good for<br>Austin.\",\"CONFUSING TX TOLL TAGS AND FEES\",\"Stop pandering to the real<br>estate developers and contain<br>the growth of the area until<br>there is sufficient<br>infrastructure to accommodate<br>the growth.\",\"More programs to help people<br>buy homes.\",\"More initiatives to protect<br>residents of East Austin. Limit<br>gentrification!\",\"Apply fairness in employment<br>and treatment to minorities\",\"Will you please find innovative<br>and new options to help the<br>homeless yet alleviate the city<br>from the vast amounts living on<br>our streets and in our parks.\",\"Working middle class needs<br>help. We take care of stuff<br>rich people don't want to do,<br>make it easier on us to help us<br>help you. What are you going to<br>do when we all leave to live<br>some place we can afford?\",\"More jobs south.\",\"PROVIDE BETTER ROADS AND<br>TRAFFIC CONGESTION.\",\"IMPROVING AND EXPANDING STREETS<br>FOR AUTOMOBILE TRAFFIC.\",\"Love Austin but we need<br>affordable housing for Seniors<br>where the rent does not<br>continue to increase every<br>year. We are on a fixed income<br>and it is getting harder and<br>harder to survive . I should be<br>able to survive here. Right?\",\"The new homeless shelter to be<br>put on Ben White is a scam. How<br>did the city pay close to three<br>to the value of the property?<br>Place homeless shelters outside<br>of business and residential<br>areas\",\"Stop raising our taxes and stop<br>wasting our money. The high<br>cost of living is forcing us<br>and many other families to move<br>out of the City.\",\"Housing cost and traffic is<br>this city are ridiculous\",\"Get rid of the tent cities and<br>come up with some reasonable<br>solutions to the homeless<br>problem.\",\"Austin needs diversity and<br>affordable housing.\",\"Tell the Mayor that, \\\"he is<br>doing a good job\\\", but I know<br>it takes time to get things in<br>order. To keep the homeless<br>camps cleaner.\",\"Homelessness - I believe we are<br>too laxed in addressing this<br>issue on our city. Though we<br>need to be compassionate, we<br>also need rules, laws, ordices<br>that address where they can<br>setup their tents, trash that<br>is left around their areas,<br>panhandling, roaming through<br>residential neighborhoods,<br>etc...\",\"More affordable housing\",\"Be inclusive of all Austinites<br>and not just your circle. We<br>all something to bring to the<br>table not just the loudest<br>people.\",\"fix the roads, toll roads are<br>more expensive in Central Texas<br>then anywhere else in Texas.<br>The cost of living in Austin<br>has to be regulated . Taxing<br>out longtime residents has to<br>stop . Bike lanes are not the<br>answer, During rush hour theirs<br>nobody riding bike on the bike<br>lanes. Bike lanes create more<br>congestion . Austin not only<br>20-30 years old. Older<br>Generation is not trying to get<br>on a bike or bus. To get around<br>.\",\"Housing prices are way too<br>high.\",\"Change the homeless policy and<br>further restrict the number of<br>scooters allowed. Our downtown<br>looks cluttered and dirty and<br>has become unsafe.\",\"The amount of homeless<br>personnel living throughout the<br>Austin area.\",\"My work and my kids school are<br>not where I live. Unfortunately<br>quality isn't a known in my<br>neighborhood. But the cost of<br>living in my neighborhood is<br>unreasonably high.\",\"Do a better job be consistent<br>treat everyone the same be<br>equal to everyone make it<br>reasonable for all residents<br>fair housing, to many<br>apartments not enough housing<br>residents are totally divided<br>and being treated differently<br>and you're all allowing it to<br>happen talking about, do<br>something about it stop smiling<br>in everyone faces lead by<br>example.\",\"I would love to see a Ficial<br>income raised and better<br>housing affordability\",\"We need to do more for our<br>children\",\"LESS homelessness LESS taxes<br>LESS restrictions(let someone<br>drink a beer and drive a car)<br>LESS growth\/people. thanx ~\",\"STOP OUT OF CONTROL SPENDING\",\"REDUCE TRAVIS COUNTY PROPERTY<br>TAXES\",\"Work on homelessness.. there<br>are areas I won't go because of<br>the aggressive behavior.\",\"ALL RESIDENTS SHOULD PAY FOR<br>SOME CITY TAXES. EVERYONE WHO<br>HAS KIDS IN SCHOOL SHOULD PAY<br>CITY TAXES.\",\"parking is too costly. more<br>parking for seniors.\",\"NEED HOUSING THAT NORMAL MIDDLE<br>CLASS WORKING PEOPLE CAN<br>AFFORD.\",\"PROPERTY TAX IS HIGH.\",\"TRAFFIC AND AFFORDABLE HOUSING\",\"Austin is a beautiful city. I<br>appreciate your efforts to<br>decriminalize homelessness. I<br>just hope that we continue to<br>work towards housing the<br>homeless.\",\"Listen to people\",\"I would like to sit down with<br>the mayor. I have tried three<br>times with no success. He is<br>taking the city in the wrong<br>direction. He had better vision<br>and talking points when running<br>for Mayor in 2014.\",\"We appreciate your efforts!\",\"PROPERTY TAXES TOO HIGH\",\"Traffic issues need to be<br>addressed.\",\"Do the city a favor and quit<br>your job\",\"SOMETHING NEEDS TO BE DONE<br>ABOUT FM620 IN NORTH WEST<br>AUSTIN. CITY NEEDS REAL RAIL<br>SYSTEM.\",\"Affordable housing is greatly<br>needed for those that have been<br>and continue to be displaced in<br>east Austin. Clean up our<br>streets by providing affordable<br>places to live.\",\"Please disallow panhandling in<br>Austin and overnight camping.<br>Please work with TXDOT to<br>control homelessness and drug<br>sales under I-35.\",\"Planning for change and<br>addressing the issue of the<br>cost of living in Austin\",\"Hard job to dissuade zealots<br>and bigots to your moderate<br>mind-set philosophy. Had to<br>start affordable housing all<br>the way at Wells Branch in<br>PVille!! Don't give up trying<br>to convince the State Reps to<br>lower taxes and the speed in<br>which taxes are raised yearly,<br>creating this negative impact<br>on the ingenious population on<br>the Eastside of Austin, unless<br>this is the intent. In which<br>case, people have no choice but<br>to rebel eventually.\",\"Need more focus on East Austin<br>Neighborhood and their<br>surrounding. Visit with the<br>elders and ho around and<br>questions in person how they<br>can make this a safe and drug<br>free neighborhood.\",\"Cost of living and child care<br>cost needs to be addressed\",\"Better education and funding to<br>schools and teachers\",\"HELP AUSTIN BECOME A BETTER<br>PLACE.\",\"Water Bill Rates\",\"Concentrate on City business<br>and stay out of the politics of<br>others and follow the laws .\",\"Please focus on working with<br>developers to build more 3+<br>bedroom housing in the downtown<br>area.\",\"You need to stop focusing on<br>the needs of the few and focus<br>on the needs of the many. We do<br>not want to be Portland. We<br>create waste and will never be<br>zero waste We need cost<br>effective energy. We don't want<br>any more bike lanes. We do not<br>want to be a sanctuary for the<br>homeless We want leaders that<br>will focus on the real problems\",\"More street police downtown for<br>events.\",\"The city needs to make housing<br>more affordable and stop the<br>gentrification of East Austin<br>and other areas.\",\"All the bicycles lanes should<br>be ONLY accessible when a<br>cyclist is riding their bike in<br>that lane. The COA has<br>congested traffic by doing so.<br>There are more vehicles than<br>bikes that utilize the lane.<br>You're FORCED to be at the<br>mercy of the driver before you,<br>not even going the speed limit!<br>Spray BIKE on the pavement<br>EVERYWHERE!\",\"How do you pay rent when you<br>only make $1200 a month and<br>rent is that??\",\"Read : \\\"Anatomy of the State\\\"<br>by Murray Rothbard \\\"Economics<br>in one lesson\\\" by Henry Hazzlit<br>\\\"It's a Jetsons World\\\" by<br>Jeffrey Tucker \\\"The Law\\\" by<br>Fredrick Bastiat \\\"The Not So<br>Wild West\\\" Terry Anderson \\\"Free<br>To Choose\\\" by Milton Friedman<br>\\\"Human Action\\\" by Ludwig Von<br>Mises \\\"The Most Dangerous<br>Superstition\\\" by Larken Rose<br>Thank you.\",\"Please focus on transportation<br>as the thing that can Austin a<br>scalable city. This includes<br>public transport and<br>improvements to ABIA. The arts,<br>cultural and affordability all<br>must occur to support growth<br>but we cannot continue to just<br>let growth happen to us. We<br>must become a pioneer in Texas<br>to addressing these items in a<br>meaningful way and take curses<br>from cities who have succeeded<br>and build a best in class<br>solution that makes our city a<br>truly world class one that<br>retains the aspects that make<br>it great today.\",\"The city of Austin needs to<br>embrace diversity and strive<br>for affordable living\",\"Expand the definition of<br>diversity to mean more than gay<br>pride...have low cost events to<br>encourage interaction from all<br>citizens regardless of income<br>and social status....build more<br>affordable housing...train<br>police officers to deal with<br>mental health issues or<br>incidents\",\"Austin is no longer a small -<br>medium city, we are one of the<br>fastest growing cities in the<br>country. Trying to maintain the<br>infrastructure for a city that<br>no longer exists is folly that<br>will lead to it suffering and<br>inevitably the poor suffer<br>first.\",\"Grow a pair!\",\"UTILITIES ARE TOO HIGH.\",\"Keep Austin weird, save, and<br>diverse\",\"I want to live in a city with<br>singles, couples and families.<br>It feels like the market for<br>city planning are directed to<br>shape a specialized place that<br>no longer works for families<br>with children.\",\"DO NOT IMPOSE REZONING AND<br>ADDED DENSITY ON MY<br>HOME\/NEIGHBORHOOD.\",\"Affordability is important.<br>People born here should be able<br>to afford a home here. We need<br>better public transit.\",\"OLDER CITIZENS HAVE BEEN PUSHED<br>OUT.\",\"APD WORKING WITHIN THE<br>COMMUNITY. TAXES,<br>GENTRIFICATION. AFFORDABLE<br>HOUSING\",\"Too many homeless ppl under<br>bridges, it makes living<br>environment looks really<br>deplorable regardless of where<br>one lives or how high rent is.<br>Some needs to be done .\",\"SENIOR ASSISTANCE.\",\"Wake up, represent all<br>residents, not just the wacky<br>liberal element - quit wasting<br>money as taxes are already too<br>high!\",\"KEEP TIGHT TAB ON CITY<br>EXPENDITURES AND SIZE\",\"EFFICIENT PUBLC TANSP TO AND<br>FROM AIRPORTS AROUND CITY, FIX<br>I-35, BUS STOPS SHOULD NOT TAKE<br>PLACE IN LANES OF TRAFFIC FLOW,<br>THIS SURVEY COULD'VE BEEN DONE<br>ONLINE, IN DC THEY HAVE MAJOR<br>ROADS TO AND FROM THE CITY WITH<br>MULTIPLE LANES, THE MIDDLE LANE<br>WILL TRAVEL INA DIFFERENCT<br>DIRECTION DEPENDING ON THE TIME<br>OF DAY\/TRAFFIC PATTERN. FOR<br>EXAMPLE THE MIDDLE LANE ON S<br>LAMAR WOULD TRAVEL NORTH<br>TOWARDS THE CITY IN THE AM AND<br>SOUTH AWAY FROM THE CITY IN<br>TRAFFIC RUSH HOUR PM\",\"Help keep our children, and<br>community safe from the<br>negative that people bring into<br>our neighborhoods\",\"Make sure lyft and uber and<br>ride share ALWAYS stay in<br>Austin, or you'll lose<br>diversity and the appeal of the<br>city. Yellow cab is an<br>advertisement for drinking and<br>driving. They are unsafe to<br>use.\",\"STOP PAVING THE STREETS THE<br>NEIGHBORHOOD WITH THOSE CRYSTAL<br>ROCKS BECAUSE THE PAVING IS<br>UNSATISFACTORY IN MY STREET.\",\"Please quit trying to further<br>politicize our city further to<br>the left.\",\"The mayor should resign, fire<br>25% of the workforce, get the<br>bums off the street, and audit<br>the city government financials.\",\"TRAFFIC CONGESTION IN<br>NEIGHBORHOODS.\",\"BE FAIR\",\"THE WAY MINORITIES ESPECIALLY<br>BLACKS ARE TREATED IN THIS<br>CITY. HOW THEY ARE LOOKED AT,<br>TREATED AND DISENFRACHISED. IF<br>YOU GO IN CERTAIN PARTS OF TOWN<br>, HOW YOU ARE TREATED AND GIVEN<br>AN UNSPOKEN MESSAGE OF WHAT OR<br>WHY ARE YOU HERE.\",\"AFFORDABLE HOUSING IN EAST<br>AUSTIN. GENTRIFICATION HAS<br>TAKEN OVER. IT HAVE LEFT OUR<br>SCHOOLS WITH LOW ENROLLMENT SO<br>MANY HAVE HAD TO LEAVE . BUILD<br>AFFORDABLE HOMES, BRING PEOPLE<br>BACK, STOP PUSHING BLACKS AND<br>MEXICANS OUT OF EAST AUSTIN. IT<br>IS NOT FAIR TO PEOPLE,<br>BUSINESSES, ETC.\",\"Make our city more affordable,<br>and manage traffic.\",\"There should be a cutoff for<br>property taxes.\",\"YOU MUST RESTORE INTEGRITY TO<br>THE CITY. NO ONE BELIEVES YOU<br>ARE WORKING HARD TO IMPROVE OUR<br>CITY. NOT WHEN WE ALL SEE THE<br>MOST PUBLIC WORKERS CONSTANTLY<br>SLACKING OFF AND OVERSTAFFING<br>POTHOLE FILLS.\",\"CURRENT GROWTH PROGRAM DOES NOT<br>APPEAR TO BE MAKING A DENT.<br>QUALITY OF LIFE IS BAD.\",\"MORE PUBLIC TRANSPORTATION FOR<br>DISABLED CITIZENS\",\"Stop gentrification in East<br>Austin and increased high taxes<br>which are designed to take<br>peoples homes and up root them<br>to live in other neighborhoods.<br>Give incentives to APD to<br>encourage them to live in inter<br>city neighborhoods so policemen<br>can get involved with<br>interacting and knowing their<br>neighbors. This will enable<br>less crime and better or<br>improved neighborhoods.\",\"While tackling the big problems<br>look for & solve easier<br>problems too. Like running red<br>lights.\",\"REPRESENT ALL RESIDENTS, NOT<br>JUST THE LIBERAL ELEMENT.\",\"Funding for all city services<br>should be considered when<br>making a decision on the COAs<br>budget. Keep taxpayers informed<br>about issues before decisions<br>are made. Better address<br>affordable housing for longtime<br>residents of Austin including<br>more City-owned public housing<br>on city-owned property. Support<br>legislation for affordable<br>housing and health for all<br>people.\",\"AUSTIN IS GROWING AT A FAST<br>RATE PLANS INVOLVING MOBILITY<br>SHOULD LOOK OUT 5-10 YEARS.\",\"Affordable housing rent and<br>owning. More black owned<br>businesses and cultural events.\",\"don't overlook oak hill\",\"FOCUS ON CORE SERVICES.\",\"That you help all people, not<br>just one\",\"Thank you for your service!\",\"Taxes too high. Quit providing<br>all free services, health care<br>for example. Fix the traffic<br>problems.\",\"Stop catering to special<br>interests\",\"Listen to residents about Code<br>Next. Many of our neighbors are<br>very against it or do not<br>understand it.\",\"Urban rail along Lamar, 360 to<br>airport.\",\"The tax base should be more<br>fair. The schools should be<br>more equitable and<br>desegregated.\",\"Sick and tired of construction<br>work on roads. Construction in<br>every direction.\",\"improve public transit options\",\"Better communication to city's<br>transplants. I want to get<br>involved civically, but don't<br>know where to start.\",\"STOP GENTRIFICATION\",\"Quality should be a serious<br>priority in housing,<br>employment, education and city<br>services. Address the real cost<br>of gentrification in East<br>Austin!\",\"Property taxes are too high.\",\"Mr. Mayor I have tried to<br>contact you personally for<br>three years. There are some 22<br>items you could have done in<br>your 4 years to improve lives<br>of the citizens. I ran for<br>mayor in 2014 and you seem to<br>understand and take many of my<br>suggestions.\",\"Need a well thought out zoning<br>and an answer to traffic and<br>housing difficulties.\",\"Homelessness is out of control.<br>You have to balance services<br>versus enabling the problems.<br>Arch is crowded, messy, trashy<br>and overflowing every time I<br>drive by. Start with keeping<br>outside cleaner and then do<br>something that is productive<br>for them.\",\"COST OF HOUSING SOME APARTMENTS<br>CLAIM TO UPGRADE BY PAINTING OR<br>ADD A FEW ITEMS BUT STILL HAVE<br>ISSUES WITH THE BUILDING.\",\"Make it more inviting for<br>seniors to retire and live<br>here.\",\"LOWER UTILITIES\",\"Why can't all of Austin look<br>like North and West Austin?\",\"that soccer stadium m deal of<br>mckalla place for millionaires<br>is b********, make him pay<br>market value for the land and<br>bill him for the taxes and<br>infrastructure\",\"It would benefit African<br>American if east Austin stop<br>gentrification. Minorities are<br>being forced out due to pricey<br>property taxes and it seems<br>city never interested in east<br>side until it became appealing<br>to whites.\",\"Develop programs to educate<br>youth with mental and emotional<br>challenges. Public schools are<br>struggling to help these kids<br>and they need financial help.\",\"WORK ON HOUSING, ROADS AND<br>SCHOOLS\",\"OVERALL CLEANLINESS IS BETTER<br>THAN NY FOR SURE. NEIGHBORHOOD<br>LIBRARIES SUFFER LACK. REMIND<br>POLICE TO SERVE ALL .\",\"less social engineering more<br>streets, traffic light that<br>work and treat everyone the<br>same instead of constantly<br>looking for ways to favor your<br>constituency\",\"THE MAJOR COUNCIL'S JOB IS TO<br>TAKE CARE OF OUR CITY SERVICES<br>ANS STRUCTURE.\",\"STOP RAISING PROPERTY TAXES!<br>THIS CITY HAS PLENTY OF MONEY<br>SPENDING IS CRAZY!\",\"BETTER PUBLIC TRANSPORTATION\",\"NO MORE TOLL ROADS. ADDRESS<br>PUBLIC TRANSPORTATION AND<br>AFFORDABLE HOUSING\",\"Please spend money on<br>infrastructure. Let's expand<br>the roads to accommodate the<br>people moving here. We are<br>spending way too much time<br>getting from point a to point<br>b. Oh, thank you for bringing<br>MLS to ATX. Thanks.\",\"REDUCE THE RAPID ESCALATION OF<br>PROPERTY TAX. FOCUS ON HELPING<br>THE NATIVE BORN MIDDLE CLASS IN<br>AUSTIN.\",\"CITY NEEDS AN AUDIT.\",\"STOP TRYING TO BE SEATTLE OR<br>SAN FRANCISCO-STOP THE BE<br>FEEL-GOOD PROGRAMS\",\"THIS CITY IS GROWING AT A RATE<br>WHERE SOON IT WILL HAVE ALL THE<br>PROBLEMS OF DALLAS AND HOUSTON.<br>PLEASE SAVE OUR NEIGHBORHOODS<br>BY MAKING IT MORE DIFFICULT FOR<br>BIG BUILDERS TO BUY UP SMALLER<br>HOMES AND TURN THEM INTO<br>CHARACTERLESS MONSTROSITIES.\",\"NEED MULTI FACETED<br>TRANSPORTATION SOLUTIONS TO<br>MAKE SURE RESIDENTS AREN'T LEFT<br>BEHIND AS THE TECH ELITE REAP<br>THE BENEFITS OF AUSTIN'S<br>GROWTH.\",\"Communication of HEBS education<br>center is awful unclear use<br>every day language not gov't.<br>No more resurfacing please<br>repave as that is the only<br>answer.\",\"The city and this area have<br>changed in ways that are not<br>sustainable and there seems to<br>be little you can do.<br>Redevelopment to bring or<br>require commercial areas to<br>include residence might help to<br>make the city more livable if<br>the price is livable. Just<br>remember Detroit was once fast<br>growing too.\",\"put a cap on the rents here and<br>increase the salaries for<br>workers all over Austin so they<br>will stay and I won't become<br>homeless thanks\",\"OVERALL COST OF LIVING IS TOO<br>HIGH AND DRIVING OUT LOCALS.\",\"BIKE LANES ON SOUTH FIRST\",\"In all honesty. I have no clue<br>what to say to the mayor. I<br>appreciate the effort that the<br>city has put in police<br>relations with it's residents.<br>I'd like to see programs that<br>would let children be involved<br>in our city's government .<br>Getting to know the men and<br>women who run our city. Getting<br>them interested in the state.\",\"Affordable housing to end<br>homelessness.\",\"(1) High tax rate. (2) Very<br>poor traffic on main highways.<br>(3) High water rates.\",\"The transportation inside the<br>city is pathetic. Why not copy<br>European cities like Amsterdam,<br>Copenhagen. More public<br>transportation and less cars.<br>Bike lanes that go somewhere<br>would be nice.\",\"To get fire and emergency<br>services out to the Del Valle<br>area.\",\"Congestion, congestion,<br>congestion!!\",\"Do something about traffic.\",\"out of state investors should<br>not be allowed to purchase<br>Austin real estate and gouge<br>the prices for local who<br>live\/work here. you are making<br>it unaffordable for the artists<br>that make Austin what it is,<br>keep amazon away, they are<br>going to make traffic\/housing<br>worse, legalize\/discriminate<br>cannabis\",\"Less taxes\",\"Start providing equal services<br>to NW Austin that are provided<br>else where and stop wasting<br>money on special interest<br>groups\",\"Expand IH-35 to six or more<br>lanes from Buda to Georgetown.<br>Stop adding bile lanes.\",\"AFFORDABLE HOUSING OR RENTAL.\",\"THE MAYOR SHOULD VOTE FOR<br>TRAVIS DUNCAN FOR MAYOR AND TRY<br>REALLY HARD TO FOCUS ON<br>PROVIDING AFFORDABLE HOUSING<br>FOR THE RESIDENTS.\",\"lower property taxes\",\"If you are going to buy out the<br>east \\\"central\\\" Austin, please<br>don't take away from the city's<br>history and culture of that<br>side of town for what you<br>believe the aliens think it<br>should look like.\",\"Affordable housing, traffic\",\"AUSTIN IS A BEAUTIFUL CITY WITH<br>GREAT DIVERSITY AND FRIENDLY<br>PEOPLE\",\"DISCOURAGE THE SALE OF<br>ALCOHOLIC BEVERAGE .\",\"The cost to live here is way<br>out of control. I am going to<br>have to move away to be able to<br>live decently.\",\"Bad increase in prejudice and<br>decreased quality of life.\",\"Get rid of the Link and other<br>motorized scooters downtown.<br>They are dangerous, they drive<br>between cars, they leave them<br>everywhere.\",\"When I was five, I told my<br>Auntie \\\"one day\\\" I'm going to<br>move back to this city because<br>I was born here and this is<br>where I belong\\\". When I was 23<br>I did move back. Now I can't<br>figure out why it meant so much<br>to me. Why? Because this city<br>has lost it's authenticity and<br>now I'm not sure why I would<br>choose to stay. Please help me<br>feel happy in my home.\",\"Traffic is a huge problem.<br>Construction time takes too<br>long. Train services are far<br>too limited. Bus services are<br>far too limited. Not enough<br>sidewalks in north Austin.\",\"THE HOMELESS DOWNTOWN. THE<br>NUMBER IS GROWING TOO FAST. I<br>UNDERSTAND WE WILL HAVE THIS<br>PART OF SOCIETY TO HELP, BUT<br>NOW I CANNOT GO ANYWHERE<br>WITHOUT EVERY CORNER BEING<br>OCCUPIED OR BEING APPROACHED. I<br>HAVE BEGUN TO LIMIT MY WALKING<br>EXPERIENCE DURING THE EVENING.\",\"Keep the homeless areas clean.<br>Like benwhite& manchaca\",\"Austin is growing rapidly and<br>the city needs to account for<br>that more efficiently. I know<br>many people agree that highways<br>and housing need more<br>attention. Housing is only<br>rising, everywhere in Austin,<br>making it harder for middle<br>class. I know sections of<br>highways that have been under<br>construction for five plus<br>years Traffic hasn't gotten any<br>better\",\"Please protect\/provide open<br>green areas in our<br>neighborhoods.\",\"Please get the traffic cut<br>down, homeless population down,<br>increase funds to animal<br>shelters and libraries.\",\"Work for the people and bring<br>down the cost of living in<br>Austin.\",\"Austin is growing so quickly,<br>it does not seem like it can<br>catch up to how many folks move<br>here with housing and<br>employment. It would be great<br>to feel safe in our hometown<br>again. We will probably move<br>away when our child has<br>finished high school to the<br>outskirts or another town.\",\"More scooters in locations like<br>Byrd and Lime. Less major<br>events.\",\"Traffic flow.\",\"BUS TRANSPORTATION IS NOT THE<br>ANSWER.LIMIT RAIL FROM<br>AIRPORT-DOWNTOWN THEN BRANCH<br>OUT.\",\"THE TRAFFIC CONGESTION IS JUST<br>AWFUL, BUT DON'T KNOW WHAT THE<br>POOR MAYOR CAN DO TO EASE THE<br>PROBLEM.\",\"Sidewalk improvement in older<br>neighborhoods. City road work<br>done during off traffic days.<br>Monorail networks. Move ACL out<br>of Barton Springs area.\",\"Austin is a nice, little<br>capital city but it needs a lot<br>of work if it envisions itself<br>as a great place in the larger<br>world\",\"UPDATE YOUR WATER FACILITIES<br>THIS IS COMPLETELY RIDICULOUS.\",\"Get the affordable housing for<br>single and married families.\",\"NOT AN AFFORDABLE COMMUNITY TO<br>RAISE CHILDREN.\",\"TOLL ROADS AND INFRASTRUCTURE\",\"KEEP UP THE RACIAL EQUALITY<br>WORK. SPEND MORE MONEY ON<br>SOCIAL SERVICES AND HOUSING AND<br>LESS ON THE POLICE.\",\"GET RID OF DAY LIGHT SAVINGS!\",\"I'm sure you agree that the<br>traffic and lack of public<br>transportation options have<br>been an ongoing issue. I am<br>also concerned with the amount<br>of homeless that have taken up<br>residence on public land, which<br>has increased the amount of<br>litter and trash. The remodel<br>of our house has gone on for<br>two years due to the inspectors<br>contradicting each other with<br>each visit, causing thousands<br>of dollars in excess of budget.\",\"Stop allowing the homeless to<br>camp anywhere. It's hurting<br>businesses everywhere. My<br>customers are starting to feel<br>unsafe by their erratic<br>behavior. By the time we call<br>911, they're long gone.\",\"Do more for women's<br>reproductive right please\",\"PLEASE PROCEED WITH CAUTION AND<br>CARE WITH REGARD TO EXPANDING<br>THE FREEDOM OF HOMELESS TO<br>PANHANDLE AND CAMP. THE<br>INTERSECTIONS IN NW AUSTIN ARE<br>BECOMING MORE POPULAR FOR<br>PANHANDLERS WHO ARE VERY<br>COMFORTABLE GOING INTO LANES OF<br>TRAFFIC.\",\"WE CANNOT PROVIDE EVERYTHING<br>FOR EVERYONE.\",\"Think about the needs of<br>retired people.\",\"Public transportation and<br>affordable housing are the<br>biggest issues facing this city<br>and need massive improvements!\",\"Property taxes are too high and<br>should be replaced with some<br>sort of consumption based tax<br>and\/or income tax.\",\"I would go back to work<br>full-time if childcare was<br>affordable and I felt VERY<br>comfortable with the childcare<br>facility. This would also make<br>it easier for our family to<br>afford to buy a home. My<br>student loans are holding us<br>back.\",\"focus on city issues and<br>problems not on politics\",\"Great job!\",\"Very disappointed to hear of<br>plans to reduce Jollyville to<br>two lanes. It is a very<br>important road to our northwest<br>community. Simply complete the<br>remaining sidewalk sections.\",\"FIX TRAFFIC ON 183 MOPAC AND<br>I-35.\",\"there is a lot of homeless in<br>the city are there programs we<br>can provided to help lesson the<br>amount\",\"Pave the bike paths around Lake<br>Bird Lake (10-mile trail) and<br>get the scooters off the trails<br>(Lime, T-Bird). Too many<br>accidents and bike cops just<br>issue warnings!\",\"WE NEED TO DRASTICALLY IMPROVE<br>MASS TRANSPORTATION AND<br>AFFORDABLE LIVING OPTIONS FOR<br>PEOPLE IN THE MEDIAN INCOME<br>RANGE.\",\"Keep Austin affordable.\",\"Increase options for public<br>transportation it is dangerous<br>to drive or be a pedestrian in<br>Austin.\",\"ANY BENEFITS THAT CAN BE<br>AFFORDED TO TEACHERS SHOULD BE.\",\"Please help provide more<br>transportation options and help<br>with securing better bike<br>lanes, especially in\/around<br>major highways and highly<br>congregated parts of town.<br>Thank you for all that y'all<br>do!\",\"Nurture what you already have.<br>Be discriminate about<br>development. Austin feels like<br>a free for all now instead of a<br>thoughtful, calm and affordable<br>place. The low tier workers are<br>being marginalized rather than<br>protected. Purge APD of racial<br>bias. Enforce noise code<br>violations. Legalize pot.\",\"Plan for future generations.<br>Stop developing beyond the<br>city's ability to manage,<br>citizen's ability to afford and<br>the water resources supply to<br>provide.\",\"Better services for the<br>homeless.\",\"SOLUTIONS TO THE TRAFFIC\",\"STOP DEVELOPING!!! GROW UP, NOT<br>OUT!!!!! NO MORE TRAFFIC!!! WE<br>DO NOT WANT PEOPLE MOVING<br>HERE!!!!\",\"AFFORDABILITY IS BIGGEST ISSUE.\",\"Rename IH35 the Rick Perry<br>memorial tollway, force all<br>traffic not ending in Austin to<br>use Tx130, rename that road<br>IH35.\",\"stop delaying important<br>decisions and make the best one<br>available and move on to<br>solutions\",\"PLEASE LOWER PROPERTY TAXES AND<br>GIVE RETIREES A BREAK SO THEY<br>CAN AFFORD TO STAY IN THEIR<br>HOMES.\",\"DON'T LET SPECIAL INTEREST<br>GROUPS AFFECT YOUR ATTENTION TO<br>LOW INCOME FAMILY WELFARE.\",\"You have a tough job and a very<br>engaged electorate, which in<br>some ways can be a blessing but<br>in many other ways can be a<br>curse. Minding the basics is<br>the most important thing cities<br>can do for most folks\",\"Reduce property taxes.\",\"DISCONTINUE AUSTIN AS A<br>SANCTUARY CITY.\",\"DO THE AUDIT, THE HOMELESS GET<br>AWAY WITH TOO MUCH.\",\"SANCTUARY CITIES LIKE AUSTIN<br>ARE ON A PATH FOR DISASTER.\",\"Cut frivolous programs, leave<br>the social programs to<br>charities, focus on city<br>infrastructure, police, fire,<br>and ems. Lower property taxes.<br>Austin citizens should not be<br>considered an bottomless piggy<br>bank.\",\"Please create a way to keep<br>your musicians here by making<br>it affordable to live here. We<br>are leaving by the dozens. We<br>are the very reason people are<br>drawn to Austin. Please!\",\"INCREASE PUBLIC EDUCATION\/<br>INFORMATION ABOUT POLLUTION AND<br>LITTERING\",\"KEEP CITY OF AUSTIN OPEN AND<br>FRIENDLY\",\"TRAFFIC CONGESTIONS\",\"SCOOTERS ARE DANGEROUS AND<br>VIOLATE CITY RULES.\",\"Thank you for being the<br>positive change that Austin<br>needs in order to make this<br>city an outstanding community.\",\"I HAVE NO FAITH IN THE CITY<br>COUNCIL LISTENING TO THE<br>RESIDENTS. OVERCROWDING.\",\"My land value increased<br>$50,000, with no improvement of<br>services. Traffic is horrible,<br>both want to make me leave<br>Austin.\",\"VOTE WITH RESIDENTS IN MIND, WE<br>ARE FEELING LARGELY IGNORED BY<br>THE MAYOR AND COUNCIL.\",\"WE PAY THE CITY MANAGER WAY TOO<br>MUCH TO STILL HAVE SO MUCH<br>WASTE AND WE ONLY EVER HEAR<br>ABOUT RAISING TAXES. YOU NEED<br>TO HOLD THAT MANAGER<br>ACCOUNTABLE TO OUR HARD EARNED<br>MONEY AND STOP HAVING YOUR<br>CITIZENS BAIL OUT AN<br>INEFFECTUAL CITY GOVERNMENT.\",\"RESCIND THE CALIFORNIA TYPE<br>ORDINANCES BEING ENABLED. IT IS<br>A NIGHTMARE LIVING THERE-WE<br>DON'T NEED THAT HERE\",\"STOP WASTING MONEY ON THE<br>HOMELESS OR PUT A SHELTER IN<br>TARRYTOWN. FOCUS ON<br>ROADS,POLICE, FIRE AND BASIC<br>CITY SERVICES. FOCUS ON GROWTH.<br>ITS HAPPENING WHETHER YOU LIKE<br>IT OR NOT. THE CITY IS GOING<br>DOWNHILL\",\"Change is inevitable but not<br>always a good thing.\",\"BETTER BALANCE INTERESTS OFLONG<br>TIME NEIGHBORHOOD RESIDENTS<br>WITH DENSITY\/GROWTH NEEDS.<br>DON'T GIVE AWAY TO DEVELOPERS<br>AT EXPENSE OF LONG TERM<br>RESIDENTS. ESPECIALLY DON'T<br>REDUCE PARKING REQUIREMENTS<br>FORDEVELOPERS AND MAKE THEM<br>BUILD AFFORDABLE UNITS-NOT JUST<br>TOSS PENNIES INTO A JAR, WHILE<br>THEY CONCENTRATE ON LUXURY<br>UNITS.\",\"RUN OUR CITY LIKE A BUSINESS,<br>IT REAKS OF CORRUPTION.\",\"Make it more affordable for the<br>middle class that built Austin.<br>It's really unfair that we have<br>to spend 60 minutes in a car<br>going to and from work in the<br>City Center fighting traffic<br>every day!\",\"Stop worrying about what<br>popular and do what's right for<br>the city. Not a special group\",\"Increase the recycling rate,<br>ban use of single plastic and<br>Styrofoam.\",\"Why are you providing services,<br>even lawyers, to illegals, but<br>not to US citizens living under<br>bridges? Stop raising my taxes<br>to help not citizen<br>criminal(illegal crossing is a<br>crime just like trespassing,<br>breaking and entering, etc.)\",\"Homeless camps everywhere!! You<br>allow them to: Trash our city!<br>Anyone else would be<br>ticketed!!! No city clean up -<br>you want to give in to trash<br>and camps, yet you do nothing<br>to CLEAN UP!! Needles<br>everywhere ALLOW FIRES in city<br>limits and in the woods where a<br>wild fire could start! I pay<br>plenty in taxes for what?? You<br>have created 3rd world<br>conditions in our city!!! Where<br>do you think these folks<br>defecate! Now in our<br>neighborhood at night using our<br>electric outlets and water<br>sprockets!! City Council has<br>destroyed quality of life for<br>those of us who pay<br>taxes\/follow the law etc. This<br>city accommodates this group of<br>folks and yet many refuse<br>services and would rather be<br>out enjoying the street life<br>and free squatting rights!!<br>Austin use to be the cleanest<br>city in Texas and you have<br>destroyed that!! You should be<br>embarrassed!!! Joke of a<br>council!!\",\"Get serious about traffic<br>issues. Revision of City's<br>building code situation.\",\"PRIORITIZE MASS TRANSIT\",\"REPAIR STREETS!\",\"Please continue efforts to<br>increase housing affordability<br>in Austin.\",\"Realize you screwed up on the<br>Homeless issue and try to work<br>with TXDOT and CTRMA to get<br>traffic moving.\",\"Fix traffic, fix zoning and<br>code compliance and address<br>skyrocketing housing costs.\",\"You can't please all the people<br>all the time, yes. But Mr<br>Adler, you are on the wrong<br>side of the fence. Especially<br>with the homeless issues and<br>that ordice. Disrespectful of<br>all hard working, tax paying<br>Austin residents and families.<br>We are no longer safe with the<br>homeless crazies running a muck<br>with no recourse for their<br>crazy behaviors. Tweak that<br>ordice back a bit. So crimes<br>like assault, burglary,<br>indecent exposure, etc. are<br>addressed by APD.\",\"Fix Traffic\",\"Defeat San Antonio in the<br>breakfast taco war!\",\"The changes to the homeless<br>ordice has decreased the safety<br>of people that work downtown\",\"FOCUS ON HEALTH AND SAFETY OF<br>CITIZENS AND FIXING ROAD<br>SYSTEM.\",\"It's getting too expensive to<br>live here!\",\"PLEASE STOP THE HOMELESS COMING<br>FROM OTHER PLACES. PLEASE USE<br>THE CAMERAS AT INTERSECTIONS.\",\"Affordable housing\",\"Do not limit transportation<br>discussions to mass transit and<br>bike lanes. invest in major<br>hwys and major streets.<br>consider another bridge across<br>the river.\",\"Not all are wealthy. City has<br>lost perspective and touch with<br>its former self.\",\"welcome an external audit\",\"light rail? use the Bergstrom<br>spur to connect AVIA to other<br>city transportation.\",\"PAN HANDLERS AND HOMELESS<br>LIVING UNDER PASSES OR VACANT<br>LOTS. TIRED OF SMELLING URINE<br>AND SEEING DRUNK PEOPLE YELLING<br>PROFANITIES.\",\"Please do your best to keep up<br>with growth on the roads and<br>highways.\",\"The rapidly increasing homeless<br>population and all its<br>associated problems(public<br>camping, rising crime, lack of<br>drug addiction services,<br>insufficient mental health<br>resources, code violation<br>enforcement conflicts) are a<br>huge detractor to tax-paying<br>residents, the business<br>community and tourism. We do<br>not want to be the next Seattle<br>or San Francisco. Please learn<br>from their policy mistakes. Do<br>better.\",\"Create an affordable housing<br>purchase opportunity for young<br>families just starting out.<br>Preserve our older<br>neighborhoods by limiting or<br>restricting gentrification<br>actions. The charm of old<br>Austin is fast disappearing and<br>changing us into just another<br>Dallas or Houston.\",\"Obviously the city is growing<br>at a very rapid pace. I would<br>like for it to remain a city<br>people want to come to for<br>generations. Preserving the<br>natural resources in the middle<br>of growth is going to help keep<br>that true.\",\"STOP putting the needs of<br>illegals, homeless and liberal<br>policies and blind agendas<br>ahead of the population that<br>works hard every day to<br>struggle to pay to live here!\",\"Please make Austin more<br>affordable by using<br>market-based principles that<br>have shown to work for other<br>local governments.\",\"IMPROVE TRAFFIC FLOW. OTHERWISE<br>WE LOVE LIVING IN AUSTIN AND<br>WHAT'S AVAILABLE HERE.\",\"I can no longer afford to live<br>in Austin. I am sad.\",\"PROPERTY TAXES ARE TOO HIGH TO<br>LIVE IN AUSTIN IF YOU ARE POOR.\",\"TRY TO GET THE CITY COUNCIL TO<br>BE IN THE CENTER OF THE<br>POLITICAL SPECTRUM RATHER THAN<br>ON THE FAR LEFT OR RIGHT.\",\"Higher pressure on new<br>employers coming here to<br>support affordable housing<br>programs.\",\"WORK ON THE HOMELESS ISSUES.\",\"Lower taxes and spend taxes on<br>streets and highway<br>infrastructure.\",\"MORE PUBLIC TRANSPORTATION<br>ROUTES AND TIMING OF BUSES.\",\"Please do not allow camping<br>under Mopac, it is dangerous<br>and dirty.\",\"Homeless must be address<br>quickly, as the quality of life<br>in Austin is rapidly declining.\",\"I think that if someone calls<br>in asking for help with<br>speeders on their neighborhood<br>street and ask for road hump or<br>something to stop them that it<br>should be done right away and<br>not told to get a petition with<br>signatures of neighbors who<br>agree and then come up with the<br>money for them. The city should<br>just do this.\",\"Stop building high rise<br>buildings. Austin is losing its<br>sky.\",\"Give tax payers more of your<br>attention instead of people who<br>choose to live on the streets<br>and have their hands out<br>begging all of us who worked<br>hard all our lives to have what<br>we have.\",\"Dealing with the homeless is<br>not and easy problem to have.<br>Mental illness and drug<br>addiction is a horrible thing.<br>There are no easy answers to<br>this problem, but having them<br>live and camp on our streets<br>and under bridges make Austin<br>look and feel like a dirty<br>place to live. Maybe the tolls<br>that are collected for the<br>roads that we have already been<br>taxed on (183 at Ed Bluestien)<br>could be used to get them the<br>help and housing that is<br>needed.\",\"I WISH YOU HAD DONE MORE<br>RESEARCH BEFORE CHANGING CITY<br>ORDINANCES ON HOMELESSNESS.\",\"Rescind the homeless camping<br>ordice in Austin.\",\"Clean up downtown and outer<br>lying areas that have homeless<br>and trash, it is out of hand.\",\"Policies need to reflect the<br>values of our community.<br>Inclusion is an important<br>value.\",\"The homeless situation is out<br>of control.\",\"The biggest issue in the city<br>right now is the traffic.\",\"Provide better access to and<br>respect from city hall<br>regarding massive development<br>plans\",\"Rid homeless around the city<br>move them and not permit more<br>homeless come to Austin\",\"Property taxes are driving us<br>out. Austin Energy should be<br>run like a business and not<br>used to fund other city<br>services.\",\"STOP BRINGING NEW TOURIST<br>EVENTS TO AUSTIN BECAUSE IT IS<br>DECREASING YOUR CITIZENS'<br>QUALITY OF LIFE\",\"Stop the madness of allowing<br>homeless to destroy the City.\",\"Add at least one streetlight on<br>opposite side if street on<br>blocks please.\",\"311 IS SUPER HELPFUL AND IS A<br>GREAT WAY TO MAKE INDIVIDUAL<br>CITIZENS FEEL THE CITY IS<br>LOOKING OUT FOR THEM\",\"Slow down growth. Austin is<br>becoming too large and crowded.\",\"It is very important the city<br>develop and change as an<br>emergency traffic necessities.<br>You need to make use of the<br>High Way 45 for heavy traffic<br>as the trailers, 18 wheels etc.<br>that make impossible to move in<br>the city, or make other ways of<br>transportation as use of the<br>train, highways above in<br>downtown or more lines. Stop<br>the immigration of other people<br>in our city, they are<br>destroying our city and<br>impossible to live with all the<br>cost of living here.\",\"Leave the middle lanes on<br>Anderson and Burnet in place.<br>Stop with all the bike lanes on<br>major roads like Burnet and<br>Lamar where very few people use<br>them. I see just maybe 2 bikes<br>a day using these bike lanes<br>that are dangerous for us all.\",\"HOMELESSNESS, MORE LOW INCOME<br>HOUSING. PROPERTY TAX STARTED<br>AT 700 A YEAR, NOW IT IS 6000 A<br>YEAR.\",\"CLEAN UP THE HOMELESS MESS AND<br>KEEP THEM OUT OF NEIGHBORHOODS.\",\"remember the baseball movie<br>\\\"Field of Dreams' where the<br>narrator says \\\"If they build<br>it, they will come\\\"? It seems<br>to me like the city powers<br>believe strongly in this adage.<br>we are already \\\"to big for our<br>britches\\\" and if we continue to<br>sacrifice quality of life for<br>growth-everyone<br>suffers-including our formerly<br>pristine environment. please<br>consider a moratorium on things<br>that promote growth ( corporate<br>incentives) and concentrate<br>more on establishing proper<br>infrastructure first\",\"Work vigorously on fixing<br>traffic problems. This one<br>thing is making Austin a less<br>desirable town in which to<br>live. Stop the lengthy traffic<br>studies and get on with the<br>work.\",\"Put a real plan in place to<br>resolve Austin's traffic issues<br>and fix the homeless issue<br>(starting by rescinding the<br>recent ordice change). The<br>answer to the homelessness<br>issue is NOT to let them build<br>their own homes on public<br>property. It is just crazy.\",\"Transportation and<br>affordability (driven heavily<br>by outside investment money) is<br>making Austin less enjoyable<br>every year. The city does great<br>work to make Austin a good<br>place to live but unsustainable<br>growth is driving away all of<br>the creative elements that made<br>Austin to begin with. Please<br>try to do whatever you can to<br>ensure Austin retains its<br>character and doesn't become<br>just another boring concrete<br>wasteland of AMLI apartment<br>complexes and TGI Friday's.\",\"Stay out of politics and manage<br>the city. I don't want to know<br>your party affiliation or who<br>you support for other public<br>office. Focus Austin Tx.\",\"Thank you, please keep fighting<br>for mixed use, the missing<br>middle in housing, and<br>alternative transportation<br>options!\",\"The ability to afford to live<br>in central Austin is NOT only<br>an East Austin issue. We MUST<br>figure out a way to make it<br>easier for folks who bought<br>their homes DECADES AGO to be<br>able to continue to stay in<br>them in them!\",\"The Budget! Austin has the<br>highest spending in the state<br>of Texas!\",\"make the city safer -<br>discourage homeless and drug<br>users to leave city reduce the<br>number of events and festivals<br>brings more traffic, crime and<br>drugs to our city\",\"Please help get the homeless<br>off every street corner. It is<br>not safe and a dangerous<br>distraction to drivers.\",\"Please stop imitating San Fran<br>and take care of your tax<br>paying residents. We are moving<br>100% in the WRONG direction<br>right now with your policies.\",\"Get back to the fundamentals of<br>cost effective City services<br>and get that right first.\",\"AISD is the worst part about<br>living in Austin. Figure out<br>how to fix it, because the AISD<br>board is too incompetent to do<br>so.\",\"The homeless situation and tent<br>cities cropping up needs to be<br>repaired. A) we know the root<br>cause of the majority of<br>homelessness is a breakdown in<br>the support or family system.<br>There are programs available to<br>help these individuals. B) It's<br>not acceptable for us to accept<br>humans living on the streets of<br>Austin. We should expect more<br>of ourselves and Austin as a<br>community to allow this to<br>happen. We have programs and<br>communities that work, such as<br>Mobile Leaves and Fishes and<br>Community First!\",\"Budget for police, fire and<br>EMS. Get rid of bike lanes.<br>Stop building new buildings and<br>sell or rent out the ones that<br>are already there. Try to cut<br>down on drug use in the city.<br>DO NOT legalize pot. Thank you\",\"Make the arts a higher<br>priority. Please do something<br>about roadway construction so<br>we can get to our museums,<br>parks, libraries and<br>workplaces.\",\"Stop wasting our hard earned<br>money\",\"Work on solving the homeless<br>situation by building low<br>income housing. Quit focusing<br>on programs that don't help the<br>citizens of Austin.\",\"Too much emphasis on growth.\",\"Austin is a lovely city with so<br>many opportunities, but traffic<br>issues prevent many of us from<br>enjoying those opportunities.\",\"Implement programs to either<br>incentivize cleaning up or<br>increasing public waste staff<br>to address the trash problem<br>created by the homeless and<br>their \\\"camping.\\\"\",\"This homeless thing . . . what<br>were you thinking?\",\"I applaud Mr. Adler's courage<br>in re-examining the homeless<br>camping ordice. I do not want<br>homeless people to be arrested<br>for vagrancy, nevertheless<br>allowing them to camp anywhere<br>is a threat TO THEIR OWN SAFETY<br>and to the safety of the other<br>citizens of Austin. I feel that<br>a task force must be created<br>immediately to plan for an<br>increase in homelessness. The<br>homeless policies of Nashville,<br>Columbus and Salt Lake City and<br>other middle sized cities could<br>perhaps help for us to plan and<br>act. Austin has a 'we vs they'<br>attitude problem. I actually<br>heard someone say this at<br>Barton Springs, \\\"Where were you<br>while I was here trying to<br>solve the problem? In<br>California?\\\" That may be an<br>interesting question, but<br>ultimately it is<br>non-productive. They are here<br>now. We live here together,<br>now. Austin is proud of being<br>compared to Silicon Valley, but<br>we must get over the chip on<br>our shoulder or we will look<br>exactly like San Francisco.<br>Nobody wants that!\",\"stop meddling\",\"My biggest complaints are the<br>woefully inadequate road<br>improvements needed to keep up<br>with city growth, the lack of<br>affordable parking downtown and<br>poor public transportation<br>options. The current online<br>options for city services are<br>embarrassing for a tech city.<br>And the skyrocketing costs of<br>housing and property taxes<br>which have pushed many of my<br>friends out of Austin.<br>Especially musicians which is<br>seriously affecting our claim<br>to the Live Music Capital.\",\"Please remember what is<br>critical to maintain Austin as<br>a sustainable place to live.<br>Please be cognizant that Austin<br>is in a critical growth stage<br>and any missteps that you make<br>right now will impact Austin<br>permanently. Austin must not<br>loss its sense of self or of<br>place. Austin is counting on<br>you. Rise to the challenge.<br>Break free of bureaucracy. Lead<br>with a rebel's heart. Be<br>radical. Radical in thinking<br>and radical in action. Uphold<br>the pillars of what has always<br>made Austin amazing. That's<br>what we all want.\",\"Hi Steve. Great work.\",\"Tired of all the homeless you<br>refuse to deal with in any<br>meaningful way.\",\"Clean up sixth street, which<br>includes the homeless there,<br>the drug selling and the<br>tourists drinking and driving<br>after partying.\",\"AUSTIN HAS TO HAVE A LIGHT RAIL<br>SYSTEM TO SOLVE TRAFFIC<br>PROBLEM.\",\"I live in the Austin City<br>limits, but don't feel I am<br>part of Austin or welcomed any<br>longer. Mobility and access to<br>areas is so restrictive due to<br>traffic and events (that serve<br>others) that prefer to stay<br>away from downtown areas,<br>central library and the town<br>lake (Lady Bird) parks and<br>trails. Real fairness and<br>equality issue at play here.<br>Should already be a major<br>inter-connected light rail<br>network in-place for a city<br>this size with restricted<br>geography and size of existing<br>streets.\",\"SLOW DOWN THE RAPID GROWTH IN<br>EAST AUSTIN. Growth is okay but<br>it is being forced down our<br>throats.\",\"The city needs it's own public<br>transportation system cap metro<br>has failed us for decades and<br>their plans for the future are<br>bleak.\",\"I AM GETTING TAXED OUT OF MY<br>NEIGHBORHOOD AND I DO NOT FEEL<br>SAFE AT NIGHT BECAUSE OF THE<br>HOMELESS POPULATION.\",\"The city services I have used<br>seem adequate, but East Austin<br>is severely neglected. There<br>aren't as many parks,<br>libraries, etc. Access to<br>emergency services takes<br>longer. The landscaping is not<br>attended as frequently. There<br>are less grocery stores and<br>restaurants. The traffic all<br>over the city is terrible and<br>keeps getting worse.\",\"Encourage pay increases for<br>teachers & first responders.<br>Decrease pay for government<br>officials.\",\"Hold developers accountable for<br>making the neighborhoods they<br>build in more livable and<br>walkable.\",\"Remove the homeless center from<br>downtown Austin\",\"Raising a family in Austin is<br>super difficult in this city.<br>Our mortgage is way more of our<br>combined income than is<br>recommended by ficial experts,<br>but we love the city and for<br>now, we will scrape by and<br>endure the chronic ficial<br>stress in order to stay in the<br>city my husband and I were<br>raised in. Our family support<br>network in Austin and it would<br>be difficult to leave in that<br>regard.\",\"DONT USE MY TAX DOLLARS TO<br>SUPPORT A SANCTUARY CITY<br>STATUS. INSTEAD FUND THE US<br>CITIZENS THAT ARE HOMELESS, NOT<br>ILLEGAL ALIENS.\",\"Don't take rights away from<br>home owners -- urban density is<br>NOT a fix-all for our problems.\",\"Downtown is becoming a<br>urine-soaked homeless camp, and<br>that is spreading across the<br>city. Most overpasses in the<br>city look like homeless camps,<br>and there seems to be a<br>panhandler at almost every<br>traffic light. I've stopped<br>visiting major cities in<br>California because they have<br>gotten so disgusting, and<br>seldom go downtown at night now<br>for the same reason. I am<br>sympathetic to the plight of<br>the homeless and am fully<br>supportive of providing<br>shelters to help them get<br>cleaned up and off the streets.<br>But we have gone too far in<br>allowing downtown to get<br>overrun, just like San<br>Francisco, San Jose, etc.<br>Eventually, people will no<br>longer feel safe to go<br>downtown, or the urine and<br>feces will drive them away. The<br>City needs to develop a spine<br>and take measures to make it<br>less attractive to camp out in<br>our once-beautiful downtown.<br>Eventually, the move to drive<br>more dense urban population<br>downtown will reverse and<br>people will move out of<br>downtown if they don't feel<br>comfortable walking on the<br>sidewalks in front of their<br>buildings.\",\"PROLIFERATION OF SHORT TERM<br>RENTALS\",\"Find ways to help the entire<br>community not just the rich and<br>poor\",\"MENTAL SERVICES\",\"I love Austin!!! The only major<br>issue I have with the city is<br>with public transportation and<br>traffic flow, though some<br>issues with traffic flow seem<br>to be being worked on.\",\"TAXES ARE TOO HIGH\",\"PUT MORE MONEY INTO AFFORDABLE<br>HOUSING, REDUCE CONGESTION,<br>POLLUTION.\",\"PLEASE WORK ON MAKING HOUSING<br>AFFORDABLE. AND LIVABLE WAGES<br>SO MY CHILDREN IN THEIR 30'S<br>DON'T HAVE TO MOVE OUT OF<br>AUSTIN WITH MY GRANDCHILDREN\",\"FIX ROADS\/BRIDGES-DO SOMETHING<br>ABOUT GETTING THE HOMELESS OUT<br>OF THE CITY WITHOUT SPENDING<br>ANY MONEY ON HOUSING FOR THEM.<br>THAT WILL NOT WORK! GET RID OF<br>THE BIKE LANES-ITS DIFFICULT<br>FOR TRAFFIC WHEN ROADS ARE<br>REDUCED FOR BIKE LANES. PICK UP<br>YARD TRIMMINGS ON TIME.\",\"MANAGING GROWTH IN A WAY THAT<br>IMPROVES QUALITY OF LIFE FOR<br>ALL CITIZENS\",\"PUBLIC TRANSPORTATION TO HELP<br>TRAFFIC\",\"TACKLE THE HOMELESS PROBLEM\",\"DO NOT OFFER BIG INCENTIVES TO<br>MAJOR COMPANIES TO LOCATE HERE.\",\"KEEP DEVELOPERS FROM DESTROYING<br>OUR CITY BY DRIVING UP OUR<br>PROPERTY TAX.\",\"LESS TAXES\",\"I immigrated to Austin from<br>another country legally! It was<br>difficult. Please do not make<br>Austin a sanctuary city. As<br>difficult as it was, it was<br>worth the wait. Be supportive<br>of (legal) immigration.\",\"MORE PROACTIVE THINKING AND<br>ACTION FOR CITY GROWTH. LOWER<br>PROPERTY TAX.\",\"Make Austin more affordable.\",\"Provide more support for low<br>income population.\",\"SLOW DEVELOPMENT DOWN, STOP<br>INCENTIVES FOR COMPANIES TO<br>RELOCATE HERE.\",\"focus on smart growth,<br>sustainability and<br>affordability are just as<br>important as business<br>development and should not be<br>sacrificed for economic growth.\",\"Austin is a great place to live<br>- keep it that way.\",\"Need to invest in mass transit,<br>not cars.\",\"please no more improvements to<br>draw new people to town.\",\"Police force is racist.<br>Property tax is too high. Roads<br>are bad.\",\"Do not allow homeless people to<br>camp in public spaces. Please,<br>that was the worst idea ever.\",\"Concerns about diversity and<br>cost of living\",\"MORE SIDEWALKS IN OUR<br>NEIGHBORHOODS.\",\"I THINK MAYOR ADLER IS A DECENT<br>MAN AND DOES HIS BEST FOR HIS<br>CONSTITUENCY. HOWEVER I THINK<br>THE OVERALL TONE AND TEMPER OF<br>THE CITY IS TO CREATE A CITY<br>THAT DOES NOT REFLECT THE GOALS<br>OF THE MAJORITY.\",\"More off leash dog areas. Light<br>at Lamar and 45th will not let<br>you turn west when northbound<br>unless a green arrow, waste of<br>time to sit there.\",\"FOCUS ON HOMELESS POPULATION\",\"Transportation and<br>affordability are the two most<br>important issues facing us.<br>Both issues have reached a<br>crisis point where poor<br>handling could kill the local<br>economic dream. Affordability<br>cannot be addressed long-term<br>by bond-supported subsidy<br>programs. It must be addressed<br>through transportation<br>improvements and tax reduction.\",\"THE DISAPPOINTMENT I HAVE THAT<br>OUR STREETS ARE FILLED WITH<br>HOMELESSNESS AND TENTS UNDER<br>BRIDGES AND THE PANHANDLING<br>THAT COMES WITH IT. AUSTIN IS<br>TURNING INTO SAN FRANCISCO WITH<br>NEEDLES AND POOP ON THE STREET.\",\"We need better mass transit.\",\"WHAT DOES THE CITY FOR THE<br>FUTURE IN THE NEXT 20 YEARS?\",\"KEEP AUSTIN AFFORDABLE\",\"Homelessness\/transients\",\"Continue to make people feel<br>welcome regardless of what<br>Governor Abbott says. I would<br>like our island of blue to grow<br>in the sea of red.\",\"FOCUS ON BUILDING THE<br>INFRASTRUCTURE\",\"You have a hard job, keep<br>pushing forward!\",\"LET'S IMPROVE PUBLIC TRANSIT\",\"Please clean up the homeless<br>camps. The camps are eyesores<br>and lower the city of Austin's<br>appeal.\",\"Let's clean up the trash on our<br>roads, waterways, and<br>neighborhoods and take more<br>pride in the appearance of our<br>city\",\"HOMELESS CAMP IS AN EYESORE\",\"YOU ARE A JOKE, NO VISIBILITY.<br>NO INDEPENDENT AUDIT. WASTEFUL<br>SPENDING, ANTI-CAR AND FAVORING<br>THE HOMELESS OVER RESIDENTS AND<br>TOURISTS. LET THEM CAMP IN YOUR<br>YARD!\",\"HIGHWAY SYSTEM ARE VERY<br>INADEQUATE\",\"WE NEED A TRANSPORTATION PLAN<br>FOR 20 YEARS IN THE FUTURE.\",\"The homeless, lawn care,<br>security at night.\",\"Address mobility<br>(traffic\/public<br>transportation)!\",\"Strive for efficiency, reduce<br>spending, reduce taxes.\",\"WHEN YOU EXPAND OR WIDEN A<br>FREEWAY ADD TWO LANES, NOT ONE!<br>PLAN LONG TERM.\",\"Get the homeless off our<br>streets. They are trashing our<br>city that was once the most<br>beautiful city in Texas.\",\"LET'S FUND AND BUILD A STATE OF<br>THE ART LIGHT RAIL SYSTEM.\",\"CONTROL HOMELESS POPULATION\",\"sidewalks, lighting, subways\",\"FOCUS ON DELIVERABLES.\",\"Homeless community is getting<br>out of control.\",\"BUILD TRANSPORTATION<br>INFRASTRUCTURE FASTER.\",\"KEEP AUSTIN A NEIGHBORHOOD<br>FRIENDLY CITY FOR ALL INCOME<br>LEVELS.\",\"REDUCE SIZE OF BUREAUCRACY.\",\"STOP THE RISE IN PROPERTY TAXES<br>DUE TO INFLUX IN POPULATION.<br>PROVIDE BETTER QUICKER ROAD<br>INFRASTRUCTURE TO ACCOMMODATE<br>GROWTH.\",\"Fix the transportation problem!\",\"Change recapture\",\"STOP WASTING MONEY AND RAISING<br>TAXES.\",\"INVEST AND PROTECT IN THE<br>CITY'S PARKS AND TRAILS\",\"DEAL WITH THE HOMELESS<br>POPULATION.\",\"TRAFFIC, PROPERTY TAXES\",\"Don't even suggest I should<br>allow a homeless person camp in<br>my neighborhood. The Mayor is<br>way to far left on the homeless<br>support a beggar issue. He will<br>not have my vote for any future<br>election.\",\"PROPERTY TAXES TOO HIGH\",\"Continue efforts to take<br>homeless off the streets<br>through advances in very<br>affordable housing, cheap<br>public transportation and jobs.\",\"Please limit useless bicycle<br>lanes where they mess with the<br>traffic!\",\"TAX RELIEF\",\"ADD MORE SIDEWALKS IN<br>RESIDENTIAL AREAS, SLOW TRAFFIC<br>THROUGH RESIDENTIAL AREAS<br>(78757) AND PAVE N LAMAR<br>BETWEEN 45TH ST & 183\",\"Stop increasing the property<br>taxes!\",\"Lack of communication, false<br>information from public works<br>employees. Poor quality you of<br>work that you do. Avoidance of<br>issues is alarming and<br>disappointing.\",\"PLEASE STOP BUILDING NEW TOLL<br>ROADS. THESE ROADS ARE NOT<br>WORKING TO REDUCE TRAFFIC. WE<br>NEED MORE MAJOR ROADS, BUT WHEN<br>THEY HAVE TOLLS ON THEM, A HIGH<br>PERCENTAGE OF DRIVERS WON'T USE<br>THEM AND THEY ARE OFTEN EMPTY,<br>WHICH IS A WASTE OF THE<br>RESOURCES USED FOR THOSE ROADS.\",\"We can't do everything we would<br>like, so watch the budget.\",\"OUTSIDE AUDIT\",\"Control the panhandler<br>epidemic. Make it illegal to<br>give money to panhandlers. They<br>need to move on with their<br>live. People enable them to be<br>stuck by giving money.\",\"Stop encouraging homelessness!\",\"ALARMING SIGNIFICANT REDUCTION<br>IN LIZARDS AND BIRDS\",\"Be more discriminating about<br>the cost of non-essential<br>services that are considered by<br>the City Council.\",\"PLEASE BE MORE TRANSPARENT AND<br>OPEN TO INPUT FROM WE CITIZENS\",\"To stop pandering\",\"Don't run for reelection.<br>Thanks for your efforts, but I<br>could have done a better job!<br>And that's a fact!\",\"WE NEED A BOLD COMPREHENSIVE<br>PLAN TO MANAGE GROWTH.\",\"CONTINUE TO KEEP IT GREEN AND<br>CLEAN. THANK YOU\",\"MOVE ON ADLER.I'M VOTING<br>AGAINST ALL THOSE IDIOTS. WE<br>CAN'T AFFORD TO LIVE HERE<br>ANYMORE, AFTER 3 GENERATIONS.\",\"THE MAYOR IS DOING A GOOD JOB.\",\"I am disappointed in the<br>process used to approve the<br>soccer stadium. On the other<br>hand, I am glad that the<br>council changed laws regarding<br>homeless Austinites.\",\"LAND TAX HAS TRIPLED SINCE<br>BUYINT.\",\"HOMELESS PROBLEM GETTING WORSE<br>IT NEEDS TO BE IMPROVED.\",\"AFFORDABLE HOUSING AND PUBLIC<br>TRANSIT\",\"DO SOMETHING ABOUT THE ARCH.\",\"Stop spending my money. Your<br>battle cry to make Austin<br>affordable is a joke. Austin<br>will never be affordable if you<br>keep raising our taxes. Now<br>that I am retired, I am<br>seriously considering selling<br>my house and moving out of<br>Austin. I will gladly take my<br>tax dollars somewhere else.\",\"Let AUSTIN ,Tx be AUSTIN ,Tx<br>not AUSTIN, California\",\"Need better mental health<br>services, more locations,<br>accessibility to treatment<br>centers.\",\"PLEASE DON'T ALLOW DOWNTOWN<br>AUSTIN TO BECOME MANHATTAN.\",\"spend less money\",\"ALLOW ME TO PARK IN FRONT OF MY<br>HOUSE.\",\"Lower taxes\",\"Stick to the basics; don't try<br>to fix the human condition.\",\"HOMELESS SITUATION\",\"We actually need another way in<br>or out of Craigwood drive and<br>969 subdivision.\",\"THE PANHANDLING ON STREET<br>CORNERS IS DANGEROUS. THE<br>HOMELESS CAMPING PLAN ADOPTED<br>BY COUNCIL IS TERRIBLE IDEA!\",\"SOCIAL JUSTICE\",\"Stop tearing up streets. Give<br>the police the tools they need<br>to manage drug addicted<br>homeless population. Manage the<br>scooters blocking our sidewalks<br>or eliminate them.\",\"MORE ALL HOMELESS SHELTERS OUT<br>INTO SCHOOLS ALL OVER TOWN.\",\"BACK OFF MAKING AUSTIN A HOME<br>FOR THE PANHANDLERS AND<br>HOMELESS. THE MAYOR AND CITY<br>COUNCIL ARE RUINING AND MAKING<br>AUSTIN UNSAFE.\",\"Better mass transportation(rail<br>and train) from south Austin to<br>North Austin or surrounding<br>cities North or South.\",\"Leave Burnet Road alone.<br>There's nothing wrong with it.<br>The medians will kill<br>businesses and degrade the<br>neighborhood.\",\"KEEP THE HOMELESS AND<br>PANHANDLERS AWAY FROM SCHOOLS<br>AND CHILDREN\",\"Fix the transportation problem.\",\"DECONGEST THE ROADS\",\"Please add shade to public park<br>playscapes. They are unusable<br>in the summer without shade.\",\"RESOLVE THE CAMPING PROBLEM of<br>the unhoused - the streets and<br>underpasses are filthy, smelly,<br>unsafe and a blight\",\"Austin is a special city.<br>Please continue to preserve and<br>improve what we have like<br>Barton Springs and fight to<br>preserve what we have with our<br>Edwards recharge zones.\",\"DON'T LET UP ON THE AFFORDABLE<br>HOUSING AND HOMELESS ISSUES!\",\"RAIL HAS TO GO DOWNTOWN TO<br>AIRPORT.\",\"Overall property taxes are too<br>high mostly due to state not<br>fully funding schools but more<br>efforts need to be undertaken<br>to lower property taxes<br>considering property values<br>have been rising so much\",\"TRAFFIC IS AWFUL!\",\"Electric rates and water rates<br>are too high along with taxes.<br>Need to reduce number of city<br>employees\",\"Repair the homelessness<br>problems\",\"fix the homeless nightmare\",\"Improve traffic on I-35, Mopac<br>and major arteries. I am very<br>interested in progress toward<br>zero waste.\",\"East Austin needs more<br>north\/south roads crossing the<br>river and the greenbelt between<br>William cannon and stassney,<br>east of 35. Pleasant valley<br>can't handle it all.\",\"Fix the out-of-control homeless<br>problem in the downtown area of<br>risk losing the Austin music<br>and tourism industry! Stop<br>talking, stop the phony<br>promises and fix the problem.\",\"STOP ENCOURAGING MORE PEOPLE TO<br>MOVE HERE! AND STOP TEARING<br>DOWN ICONIC AUSTIN INSTITUTIONS<br>LIKE THREADGILLS! START<br>RESPECTING LONG TERM RESIDENTS!<br>WE DO NOT WANT MORE CONDOS AND<br>MORE DENSITY! WE DO NOT WANT<br>MORE FESTIVALS!\",\"All interactions I have had<br>moving to Austin with<br>government employees has been<br>excellent. My only problem with<br>Austin is that employees will<br>not hire older workers.\",\"Try to improve traffic on<br>Brodie between Slaughter and<br>1626.\",\"Musicians USED to be able to<br>make a living to afford to live<br>here...we should figure out a<br>way to make that possible for<br>them again.\",\"Austin is a wonderful place to<br>live for me and my family, but<br>we want to be sure it remains<br>that way and also to extend<br>that sense of welcome and<br>inclusion to others. Make sure<br>our city is welcoming to all<br>races and income levels. Be<br>welcoming to immigrants. Let's<br>be a city that is not just<br>known for our music festivals,<br>but also for our efforts to<br>build an inclusive, welcoming,<br>sustainable community for<br>everyone who chooses to live<br>here.\",\"Get the traffic under control,<br>especially on MOPAC.\",\"You know what city department<br>is well run? ABIA. They have a<br>vision, they don't spend a lot<br>of time to debate it, they<br>execute. We are the fast<br>growing large city in the US<br>and acting like a podunk<br>backwater college town that we<br>were in 1968 - just stop. That<br>kind of endless dickering<br>doesn't solve problems - it's<br>can kicking and every year the<br>problems get worse. . .and<br>worse. . .and worse. And you<br>know what - one of these days<br>we're going to get into a<br>pickle where we just don't have<br>the resources to solve it any<br>more. Our economic success is<br>masquerading a huge problem -<br>but we won't have that forever.<br>When we do hit a hiccup it's<br>going to be very painful for<br>all. We could fix it now, when<br>we have the resources and<br>energy that come from this<br>tremendous growth. We use that<br>to our advantage, or we get run<br>over by it.\",\"Traffic congestion\",\"Austin is doing an amazing job<br>with its animal services . The<br>no-kill initiative has been so<br>successful. Please keep it up!<br>Improvements to I-35,<br>especially between slaughter<br>lane and downtown , are<br>desperately needed .\",\"This survey should have been<br>administered online. Paper,<br>postage, etc. wasteful! Why do<br>you hate the environment?\",\"We need to quit wasting money<br>on Code Next consultants, trips<br>to the border for problems that<br>aren't in your jurisdiction and<br>make the city efficient. You<br>need to find ways to cut<br>spending and stop wasting. My<br>property taxes are over $1,000<br>per month for 1 person. How<br>would someone be able to retire<br>when you raise taxes every year<br>regardless of the ability to<br>pay?\",\"Austin is turning into cement<br>city! I live within the city<br>limits and more and more of<br>what little GREENBELTS that we<br>had are being torn down and<br>more office buildings,<br>apartments and condos are<br>taking over everywhere.\",\"The city has to become more<br>affordable for everyone. Even<br>middle class people like my<br>husband and I will have to move<br>in order to accomplish our<br>goals in life.\",\"Quit giving away freebies<br>because you think it is cool to<br>have in Austin. Also, worry<br>about Austin residents and not<br>state and federal issues<br>(immigration on border).\",\"Please keep the growth in<br>check. We are beginning to look<br>like a sprawling Los Angeles.<br>:(\",\"Try and do things the Texas<br>way, not the California way.\",\"Austin has been good to me and<br>my family over the past 25<br>years. Growth is exciting, but<br>my neighbors and I share<br>concerns about a loss in the<br>quality of life due to the<br>growth. Improved, smart,<br>greatly expanded public<br>transportation options and<br>policies that help people live<br>in and stay in the City are<br>critical to keeping Austin<br>livable. As property values<br>sky-rocket, that again is<br>exciting. But those of us who<br>do not want to cash out and<br>leave are being pressured by<br>high taxes. And one by one, we<br>watch our neighbors move out of<br>the neighborhood replaced by<br>investors who will never lay<br>eyes on their investment much<br>less become a part of the<br>neighborhood. Change is hard.<br>But people and quality of life<br>spurs Austin's growth too. I<br>sometimes worry that the City<br>is more concerned about<br>attracting big business here<br>than about keeping us here.\",\"I want to stay within the city<br>and would love assistance on<br>home buying that I qualify for<br>with my income. I've been<br>attempting however at this<br>moment what I qualify for isn't<br>exactly how I would like to<br>live or they get taken by<br>investors at cash or someone<br>who can offer more than I can.<br>I love being here in Austin and<br>want to raise my son here as<br>well Simply need better<br>resources\",\"That we need better highway<br>roads or over access highway<br>for better traffic control.\",\"I know the voters make it<br>really hard by rejecting the<br>various proposals on the<br>ballot, but traffic and<br>transportation really is<br>becoming a nightmare here in<br>Austin. I'm fortunate to live<br>close to work, but I actively<br>avoid driving to the north side<br>of the city unless absolutely<br>necessary because traffic has<br>become so bad. And yes, the bus<br>system is an option, but it is<br>very slow and adds significant<br>time to my travel.\",\"Affordability is KILLING our<br>Creative Class. Something MUST<br>be done or we will become<br>another DFW.\",\"I hope you are voted out in the<br>next election.\",\"GET ALL THIS GODDAMN ROAD<br>CONSTRUCTION......MOVING!! 35s<br>been messed up since BEFORE I<br>moved here 10 freaking years<br>ago!\",\"Get more funding for public<br>education.\",\"Fix the traffic situation!!\",\"Make property taxes cheaper for<br>Senior Citizens receiving only<br>Social Security income.\",\"Wish there would be better<br>education of residents on<br>services offered by the city.\",\"Stop wasting tax dollars on<br>non-essential city services,<br>focus on fixing the most<br>pressing problems of the city,<br>stop taxing and spending like<br>liberals, and make city<br>government more fiscally<br>transparent. I'm also amazed<br>that there was not a single<br>question about schools (unless<br>they are after this question).\",\"Get ahead of infrastructure<br>growth even if that makes<br>people upset, commute times are<br>insane\",\"VERY DISSATISFIED. VOTED FOR<br>ELECTED OFFICIALS AND WILL NOT<br>IN THE COMING ELECTIONS. WHAT<br>THEY STATED THEY WERE GOING TO<br>DO HAVE NOT BEEN FULFILLED.<br>THEY HAVE LIED ON LOWERING<br>PROPERTY TAXERS AND COST OF<br>LIVING AND MAKING IT<br>AFFORDABLE. THEY GIVE TAX<br>BREAKS TO LARGE CORPORATIONS<br>AND COST BREAKS ON UTILITIES,<br>FREE HOUSING . HOME TAXES HAVE<br>SKY ROCKETED AS WELL AS<br>UTILITIES. AUSTINITES ARE BEING<br>PUSHED OUT. MIDDLE INCOME<br>FAMILIES AND SENIORS LOSE THEIR<br>HOMES. MAYOR AND COUNCIL NO<br>ACCOUNTABILITY ON HANDLING CITY<br>FUNDS. HAVE LOST TOTAL<br>CONFIDENCE IN GOVERNMENT. TIRED<br>OF ALL THE LIES.\",\"SUPPORT DIVERSITY AND<br>AFFORDABLE HOUSING.\",\"BE FAIR ABOUT CITY SERVICES.<br>WHY ARE OUR TAXES GOING UP WITH<br>ALL THE GROWTH.\",\"GET PROPERTY TAXES UNDER<br>CONTROL\",\"PLAN FOR ACCELERATED GROWTH.<br>CLIMATE CHANGES PROMISES TO<br>DELIVER MORE COASTAL CRISIS AND<br>POPULATION DISPLACEMENT. AUSTIN<br>WILL EXPAND AS A RESULT. THINK<br>BIG. THANK YOU FOR PRIORITIZING<br>SMART GROWTH AND A DENSE URBAN<br>LANDSCAPE.\",\"THERE ARE TOO MANY HOMELESS<br>PEOPLE NOW. THEY ARE THE MAJOR<br>PROBLEM TO THIS CITY. MANY OF<br>THEM ARE DANGEROUS.\",\"PUT AN END TO CONDO\/APARTMENT<br>DEVELOPMENT. IT IS RUNNING OUT<br>WHAT MAKES AUSTIN GREAT. MAKE<br>OWNING A HOME FEASIBLE AND STOP<br>WITH THE INSANE PROPERTY TAXES.<br>GET THE HOMELESS SHELTERS OUT<br>OF CENTRAL DOWNTOWN,\",\"Cost of living. Keep it<br>affordable. It really isn't<br>anymore.\",\"HOMELESS SITUATION IS SCARY,<br>URGEN, BAD, DANGEROUS,<br>DISGUSTING, ETC. RUINS ENTIRE<br>BLOCKS OF DOWNTOWN THAT USED TO<br>BE SO FUN.\",\"TRAFFIC PROBLEMS BECOMING WORSE<br>EACH YEAR.\",\"IMPROVEMENT ON WATER INSPECTION<br>WHEN BILLS ARE HIGH AND FINDING<br>A SOLUTION\",\"utilities are too expensive do<br>begin with but the city<br>arbitrarily triples bill for a<br>month\",\"please find a way to get the<br>homeless people off the streets<br>and into some kind of housing\",\"IMPROVE THE ISSUE WITH<br>HOMELESS.\",\"1. Keep taxes down so people<br>can continue to live in their<br>homes - not have to move. 2.<br>Homeless\",\"FIX THE STREETS IN THE CROSSING<br>AT ONION CREEK NEIGHBORHOOD OFF<br>SLAUGHTER LANE. HORRIBLE GRAVEL<br>WORK . LOOK AT HOW MANY STREET<br>CALLS IT HAS GOTTEN.\",\"transportation...congestion,<br>lack of public options, NO PLAN<br>FOR THE FUTURE!\",\"Need to improve planning for<br>traffic congestion.\",\"Affordable housing should be a<br>priority.\",\"Plan for better transportation<br>options before inviting more<br>growth.\",\"NEED TO MAKE COST OF LIVING<br>BALANCED FOR MORE PEOPLE\",\"ADDRESS THE BURDEN OF PROPERTY<br>TAX ON FIXED INCOME. FIND A<br>BETTER FOR SOLUTION FOR TRAFFIC<br>PROBLEMS.\",\"It's become a city for the rich<br>and it didn't used to be this<br>way. We would move to the small<br>city's nearby because of<br>traffic and affordability, but<br>our children and medical care<br>keep us here.\",\"I'm not a tea party activist<br>and believe taxes are needed<br>for city services, but I am<br>curious why Austin has higher<br>effective tax rates than either<br>Houston or Dallas, which dwarf<br>Austin in size.\",\"Keep walking areas for children<br>clear of debris.\",\"Concern with public<br>transportation, poor options.\",\"Visit France and see how they<br>save energy, also parking on<br>the streets and go paperless.\",\"Start working on a subway.\",\"Work harder for healthcare.\",\"AUSTIN HAS A LOT OF IDENTITY<br>WITH THE MONEY AND GROWTH GREED<br>AND ATTITUDE. IT IS GETTING<br>WORSE FOR THE PEOPLE THAT WORK.\",\"Improve alternative modes of<br>transportation as much as<br>possible. More protected bike<br>lanes. Increase late night bus<br>options.\",\"Pay teachers more.\",\"Please introduce a program to<br>better assist the homeless<br>people resources for jobs,<br>housing, and health\/mental<br>care.\",\"Stop the sanctuary city<br>business: it is lowering school<br>standards and scores, costing<br>me more and more money in taxes<br>to provide them education,<br>housing, medical, and crime<br>costs\",\"Plan for traffic problems\",\"fix mopac\",\"I love employees at Austin<br>Downtown Alliance.\",\"THINK BIGGER\",\"THE CITY OF AUSTIN SHOULD<br>CONSIDER INVESTING IN A<br>CONTINUOUS IMPROVEMENT PROGRAM<br>FOR SYSTEMAKE PROCESS<br>IMPROVEMENT.\",\"Better job opportunities are<br>needed in such a booming city.\",\"Please continue to focus on<br>preservation\/improvement of<br>Austin's' natural beauty i.e.;<br>Greenbelt, Barton Springs etc.\",\"STOP WITH SOCIAL ENGINEERING<br>AND STICK TO THE BUSINESS OF<br>MANAGING A CITY\",\"WE NEED SUSTAINABLE<br>TRANSPORTATION ,ENERGY AND<br>PRACTICES IN PLACE TO SUPPORT<br>AUSTIN FOR THE GREATER GOOD.\",\"More recycling resources for<br>cartons and other items not<br>accepted at recycling center<br>currently. Expand I-35. More<br>low income housing.\",\"I feel my Hobbs Addition<br>neighborhood is being left out<br>of city budgets for<br>renovations. Th streets are and<br>drainage system is need of<br>major repairs, water sits on<br>streets and dose not drain, the<br>access to my home street is<br>dangerous, there is no money or<br>time spent to update the roads<br>and signage on Ledesma from<br>Spring Dale to Terry Dr. New<br>homes are built everyday and no<br>improvement to the roads or<br>infrastructure are made. taxes<br>are paid and no update to my<br>hood. very disappointing\",\"Please move the homeless<br>shelter outside downtown area,<br>kills the buzz of people<br>wanting to come visit and<br>diminishes tourism.\",\"PALACE PKWY AT DITTMAR NEEDS<br>SPEED BUMPS ON STREET, CARE GO<br>SO FASE, ITS UNSAFE FOR PARKED<br>CARS AND PEOPLE CAUSE CARS GO<br>FAST ALONG PALACE PKWY THANK<br>YOU\",\"PLEASE DO SOMETHING ABOUT THE<br>TRAFFIC. TOO MUCH DEVELOPMENT<br>NOT ENOUGH INFRASTRUCTURE.STOP<br>WITH THE HORRIBLE BLACK PAVING<br>IN OUR NEIGHBORHOOD IT IS CHEAP<br>AND UNSAFE.\",\"Listen to the working, tax<br>paying citizens.\",\"traffic is a problem but it'll<br>take time and money to keep up<br>with the fast population<br>increase\",\"Traffic congestion and lack of<br>quality\/professional transit<br>options is unacceptable if you<br>continue to allow development<br>structures in the city - work<br>with surrounding<br>counties\/cities to deliver best<br>for all<br>transportation\/roads\/hwy use.\",\"DO SOMETHING About traffic\",\"Fix the homeless problem. Get<br>them out of the middle of the<br>streets and street corners<br>begging!\",\"Affordability and property<br>taxes are too high. Do not give<br>new businesses tax incentives<br>that cause home owners to pay<br>so much. We won't be able to<br>afford to live here. Fix<br>transportation issues. No<br>development without<br>transportation options first.\",\"THE CITY NEEDS MORE SIDEWALKS<br>AND BETTER CULTURAL<br>INFRASTRUCTURE.\",\"STOP BEING A SANCTUARY CITY!\",\"WORK ON INFRASTRUCTURE AND<br>IMPROVE TRAFFIC\",\"It's time to realize that<br>Austin is a great place to live<br>but if we continue to grow at<br>the pace predicted the city<br>infrastructure and transit<br>systems will need to be<br>expanded. Austin,<br>unfortunately, is getting<br>bigger so we need to figure out<br>how to manage and plan for that<br>growth now not in 5 or 10 years<br>when it is too late. We need to<br>expand on what made Austin what<br>it is today and not lose that<br>through the growing pains. I<br>get to travel all over this<br>country for work and I can live<br>anywhere but I choose to live<br>here for the people, community,<br>and uniqueness that is Austin.<br>Don't lose sight of that.\",\"More police presence in<br>neighborhoods.\",\"Finalize the contract with APD!\",\"Expand public transportation.\",\"LOWER THE RENT, HAVE TO CHOOSE<br>BETWEEN RENT AND MEDICINE.\",\"Not everyone in this city is<br>rich!\",\"Obey the rule of law, eliminate<br>\\\"Sanctuary City\\\" policies.\",\"CITY NEEDS TO TAKE CARE OF<br>MEIDIAN STRIPS. BASIC MOWING.<br>HOMELESS NEED A PLACE TO<br>SHOWER, USE THE BATHROOM,<br>MENTAL HEALTH SERVICES\",\"Make Capital Metro train: (1)<br>More frequent, every 20 or 30<br>minutes. (2) Longer hours,<br>especially on weekends, (last<br>train @ 2 AM). (3) Add more<br>stops SOUTH (e.g. One at South<br>Congress and another at South<br>Lamar). We don't need more<br>stops further north!\",\"Living wages, if the people<br>legally here can not afford to<br>live here, what does that say<br>about the wonderful city Austin<br>in the great state of Texas?\",\"Fix our streets, more access to<br>north and south Austin. Fix I<br>35 through downtown!!\",\"Please do something about the<br>increasing number of homeless<br>panhandlers, clean up for this<br>population is absent.\",\"You're pricing families out of<br>the city between actual costs,<br>taxes and electric services.\",\"LEAD IN HOW WE PLAN FOR GROWTH<br>AND BECOME 100 PERCENT RELIABLE<br>ON RENEWABLE ENERGY\",\"NOT HAPPY WITH THE CODE<br>NEXT\/HOW IT WAS HANDLED\",\"INVEST IN PROACTIVE FLOOD<br>MANAGEMENT\",\"INVEST MORE IN THE COMMUNITY.<br>ENHANCE PARKS, PRESERVE THE<br>GREEN.\",\"Downtown parking - high rise<br>buildings are taking over (okay<br>with that), but parking is<br>terrible unless you Uber or<br>Valet.\",\"STOP BEING SO LIBERAL THIS<br>ISN'T CALIFORNIA THAT'S WHY WE<br>MOVED HERE.\",\"Thank you for continuing to<br>make Austin great.\",\"PLEASE ONLY MESS UP ONE AREA AT<br>A TIME. I'M SO TIRED OF<br>UNFINISHED PROJECTS ALL OVER<br>THE PLACE.\",\"Do not rename everything to<br>satisfy some malcontents or<br>perceptions of wrongs of past.\",\"Traffic is a huge problem. The<br>city is out of control with<br>bars, drinking, and drugs.\",\"PLEASE FOCUS ON DIVERSITY AND<br>PUBLIC TRANSPORTATION.\",\"AUSTIN NEEDS TO INCREASE<br>EDUCATION STANDARDS ACROSS THE<br>CITY.\",\"The city needs more public<br>transportation!! The traffic on<br>roads has gotten much worse<br>through the years.\",\"Focus on the essentials -<br>water, safety, housing. Very<br>critical in our current rate of<br>growth.\",\"Run city government like a<br>business. Make city employees<br>and officials accountable for<br>their performance. Let the<br>out-of-the-box ideas be given<br>consideration.\",\"All Austin residents deserve<br>safety, cultural enrichment,<br>food and housing security and<br>confidence that they will enjoy<br>equal rights and protection. We<br>have improved as a city over<br>the last few decades, but we<br>have not always ensured<br>equality of opportunity or well<br>managed growth. This is a great<br>city - thanks for reaching out<br>and asking people about their<br>perceptions and goals.\",\"DON'T LET DIVERSITY SAIL OUT OF<br>YOUR TEAM.\",\"WE NEED TO FIND A WAY TO INVEST<br>IN EXPANDED PUBLIC TRANSIT IN A<br>WAY THAT WE CAN AGREE TO REDUCE<br>TRAFFIC AND MAKE DOWNTOWN MORE<br>ACCESSIBLE. NEED MORE SERVICES<br>FOR HOMELESS.\",\"WOULD PREFER TO WORK TOWARDS<br>LOWER TAXES\",\"MORE PUBLIC TRANSPORTATION\",\"STOP GENTRIFICATION\",\"PUBLIC TRANSPORTATION , TRAFFIC<br>CONTROL.\",\"ADDRESS ISSUES OUTSIDE DOWNTOWN<br>CITY CORE AREA\",\"I SEE INCREASED DEVELOPMENT<br>WITHOUT SAME LEVEL OF WERVICES.<br>COST OF LIVING IS INCREASING<br>WHILE SALARIES ARE NOT.\",\"fix the william cannon 290<br>intersection please\",\"I MAKE A GOOD SALARY, YET I AM<br>UNABLE TO AFFORD TO BUY A<br>HOUSE\/TOWNHOUSE\/CONDO IN AUSTIN<br>BECAUSE IT IS SO EXPENSIVE.<br>PROPERTY TAXES ARE OUTRAGEOUS.<br>AUSTIN IS NO LONGER AFFORDABLE<br>AND TRAFFIC IS BAD-DO<br>SOMETHING.\",\"Always put the interests of the<br>most vulnerable people first.<br>Live to serve, not to lead.\",\"TRAFFIC\",\"QUIT CHOOSING A SIDE FOR VOTES\",\"PUBLIC LIGHT RAIL\/CITY TRAIN TO<br>IMPROVE WALKABILITY--LOOK AT<br>HOW THEY DO IT IN BROOKLYN<br>WHERE ALL NEIGHBORHOODS ARE<br>WALKABLE AND PEOPLE CONGREGATE<br>WITH THEIR NEIGHBORS AT LOCAL<br>BUSINESSES, PARKS, COFFEE<br>SHOPS. LET'S DO THAT IN ATX AND<br>SHOW TEXAS HOW ITS DONE.\",\"We need a world class museum.\",\"Negotiate a fair contract w\/apd<br>and get more cops on patrol.<br>Safety is #1 and the Mayor and<br>council seem not to care. Crime<br>is on the rise because there is<br>no police presence.\",\"Need to plan for growth but do<br>not do at the expense of our<br>original downtown neighborhoods<br>the provide housing for<br>families & some of our older &<br>retired residents.\",\"Education needs improvements.<br>Traffic, high rent. My daughter<br>goes to a school rated 1 out of<br>10 where are my taxes dollars<br>going.\",\"THE HOMELESS LIVING HERE UNDER<br>BRIDGE 183 IS OUT OF CONTROL,<br>CAN NOT STOP WITHOUT BEING<br>CONFRONTED, SHAME, FILTHY<br>CONDITIONS TO WTINESS, DALLAS<br>DOES NOT ALLOW WHATS HAPPENING<br>TOSTATE CAPTIAL AUSTIN\",\"DIFFERENT SERVICES TO GET<br>AROUND AUSTIN GROCERY SERVICE<br>FOR ELDERLY, NOT JUST ROUTINE<br>VALUES\",\"homeless\/panhandling\",\"PLEASE TAKE INTO CONSIDERATION<br>PEOPLE WHO HAVE LIVED HERE<br>THEIR WHOLE LIVES AND WOULD<br>RATHER LEAVE THAN HAVE TO MOVE<br>TO A POORER PART OF AUSTIN\",\"WE ARE LUCKY TO HAVE MAYOR<br>ADLER\",\"PLEASE LOOK FOR SOLUTIONS ON<br>PUBLIC TRANSPORTATION, LIGHT<br>RAIL SYSTEMS, SELF DRIVING<br>CARS.\",\"Stop spending money on bike<br>lanes - it's ruining<br>transportation because bicycles<br>don't obey traffic laws. We do<br>not need a soccer team - with<br>any hope, the current mayor<br>will be gone soon after the<br>next election.\",\"There are only 2 \\\"gender<br>identities\\\". Small Business<br>owner and self employed were<br>left off as an option but that<br>isn't surprising seeing as the<br>Mayor seems to be at war with<br>us just like the obama<br>administration was. Cut the<br>liberal garbage and get the<br>business done. Stop blowing<br>money on diversity and trying<br>to make Austin more affordable<br>or inclusive because spending<br>money on nonsense just makes it<br>more unaffordable for everyone.<br>Get to work you bums and focus<br>on what matters instead of<br>pandering to your voting base.\",\"Our low income neighborhood<br>doesn't get the attention of<br>upkeep of sidewalks, low<br>hanging limbs over sidewalks,<br>loud music and partying of<br>neighbors (too often) after<br>11:00 pm.\",\"THE AIRPORT IS TERRIBLE.\",\"I'd like to see the city do<br>what it can to push back<br>against the Trump<br>Administration's immigration<br>policies and foster an<br>environment that treats people<br>justly but also humanely and<br>with compassion.\",\"Traffic. Street light timings.<br>Add Metered on-ramp to Highway<br>5.\",\"Imagine Austin in 20 years -<br>2338, without bold,<br>transformational choices about<br>congestion, cultural<br>attractions, and job diversity,<br>ATX will be all condos and<br>bars. Time to put some 200-year<br>steaks in the ground to make<br>sure Austin has some history to<br>lean on. Let's get a museum<br>district going. Let's support<br>ethnic enclaves that give<br>Austin unique points of view.<br>Let's have teacher's able to<br>live in the city limits and for<br>gosh sake, bring back<br>\\\"Auditorium Shores\\\".\",\"Open all pools in the summer.\",\"Transparency\",\"Clamp down on homeless people<br>turning Austin into a (terrible<br>place.)\",\"Stop raising taxes to subsidize<br>political causes, and wasting<br>resources on stupid things like<br>trying to change the city name.\",\"More trains - less toll roads.\",\"We need better cost of living<br>$1600 + for a 2 bedroom apt<br>really, and 2 people working 2<br>jobs to make ends meet and<br>still live pay check to<br>paycheck... 30 min to get out<br>of downtown from The capital to<br>Riverside, really. Better<br>traffic system to get people in<br>and out Look at Las Vegas for<br>ideas...they have a great<br>system...when making new<br>subdivisions, improve the roads<br>to get the new residence and<br>older ones in and out of the<br>area, don't leave one lane for<br>a subdivision of 365+ houses<br>and expect that the traffic is<br>going to flow so great...Look<br>to larger cities on loops<br>around the city for traffic<br>flow. Do not just spend more<br>money on the more rich side to<br>have better roads then those on<br>the south or east side...\",\"ECOURAGE TRANSPARENCY,<br>EFFICIENCY AUDITS, MAINTAINING<br>OUR NEIGHBORHODD AND POOLS\",\"continue working on fastening a<br>sense of community here in<br>Austin, we want this city to<br>feel like a family where<br>everyone respects, cares for,<br>and loo0ks out for on another\",\"Expand trains, extensively.<br>Build bypass for I-35, 71, 183.<br>Do better with preserving the<br>east code and avoiding<br>gentrification. Work to reduce<br>traffic and vehicular<br>reliance\/dependence.\",\"Focus on Austinites. It is hard<br>to keep up with the increasing<br>cost of living in Austin.<br>Having a bond to help low<br>income people increases the<br>taxes and impacts current<br>resident low income people.<br>Also, the train is a mess. Does<br>anyone pay to ride? No one ever<br>checks for a ticket. There are<br>so many people standing,<br>someone is going to get hurt<br>and sue the city.\",\"Invest more in transportation,<br>mobility and thoughtful<br>development to ease congestion.<br>Support sustainable grown to<br>preserve Austin's character.\",\"stop subsidizing city govt with<br>high elec\/water rates\",\"More walk-able areas, less<br>cars.\",\"WE HAVE TO FIGURE OUT A WAY TO<br>MANAGE GROWTH AND KEEP AUSTIN<br>AFFORDABLE\",\"Traffic\",\"ROLL BACK PROPERTY TAXES FOR<br>HOMEOWNERS OVER 65\",\"FIX THE TRAFFIC. STOP BUILDING<br>TOLL ROADS\",\"Highway development\",\"INCREMENTAL CHANGES AND GRAND<br>BARGAINS WITH DEVELOPERS AND<br>LANDLORDS WILL NEVER STEM THE<br>TIDE OF GENTRIFICATION. WE HAVE<br>TO SHIFT POWER TO WORKING<br>PEOPLE AND TENANTS.\",\"Fix the traffic situation on<br>I-35, Mopac, 290 and other<br>major roads. Toll roads are not<br>the solution. Also, small<br>\\\"construction\\\" fixes along<br>these major roads won't work.<br>By the time construction is<br>done, the city growth will have<br>already outgrown the \\\"new\\\"<br>road. One solution would be an<br>affordable rail system along<br>I-35, Mopac, 183 and Ben White<br>with park and ride locations<br>along the route.\",\"we need to solve the<br>traffic\/transportation problems<br>plaguing this city\",\"Need more affordable housing.\",\"Quit trying to change this city<br>into a bastion for homeless<br>people. Fix our traffic<br>problems Stop spending money on<br>worthless projects.\",\"Austin has been home for a long<br>time. It is a great place to<br>bring up a family, outside of<br>the summer heat and allergy<br>seasons.\",\"I want this city to be diverse,<br>affordable, and accessible for<br>middle class families. There<br>are a lot of cool things in the<br>city I don't take advantage of<br>because it's too much effort<br>and time to drive downtown and<br>park.\",\"Austin's ready for change.<br>Share a bold vision and we'll<br>get behind the Mayor and City<br>Council. Be transparent about<br>the trade-offs we'll make as a<br>community and the consequences<br>for not seizing this moment.<br>You weren't elected to lead<br>Austin in the '60s or the '80s;<br>you were elected now and we<br>need leadership more than ever.<br>Change is the only constant. We<br>either find a way to gracefully<br>grow this city, helping as many<br>residents benefit from that<br>growth as possible, or someone<br>else - big developers, big<br>corporations, etc. - will<br>impose their vision on us<br>during a moment of disunion and<br>weakness.\",\"KEEP MOVING FORWARD ON CLIMATE<br>CHANGE\",\"Help make transportation<br>options more comprehensive -<br>y'all have done a good job with<br>buses and biking\/walking<br>corridors. Keep at it!\",\"CITY PLANNING NEEDS TO BE<br>ADDRESSED.\",\"INVEST IN A DART LIKE LIGHT<br>RAIN THAT IS VIABLE\",\"Build more non toll roads.\",\"east river dr needs repaved and<br>construction areas need better<br>street clearing crews to<br>prevent so many flat tires and<br>car issues thank you\",\"Stronger math and literacy<br>programs in schools.\",\"Make it more affordable for<br>working people. The people that<br>pay your taxes and salary. Fix<br>traffic issues. Stop making our<br>city look like trash by letting<br>homeless people camp<br>everywhere. Think before you<br>take away current ordices<br>without putting new rules in<br>place. Rail!!!! Park and<br>rides!!! Stop leaving oak hill<br>out of transportation plans.<br>Know who you represent, what<br>they want\/need and not just<br>what you think would be good.\",\"FIX JOB AND HOUSING ISSUES.\",\"The housing situation. We have<br>a decent income, and cannot<br>find a house close to town that<br>is reasonable for our commutes.<br>Housing cost is insanely<br>expensive, even with a<br>comfortable income.\",\"IMPROVE TRANSPORTATION, NOT THE<br>SCOOTERS!\",\"MAKE SINGLE FAMILY HOMES<br>AFFORDABLE AND RAISE THE<br>WORKING WAGE IN AUSTIN SO THAT<br>WE CAN KEEP UP WITH YOUR<br>GROWING COST! MAKE AUSTIN<br>BETTER NOT JUST FOR YOU BUT FOR<br>THE OTHER INDIVIDUALS WHOM ARE<br>LIVING HERE AS WELL. BE HONEST<br>AND SUPPORTIVE OF MAKING THE<br>QUALITY OF LIFE HERE GREAT!!!!\",\"CREATE HOMELESS FACILITIES LIKE<br>THE ONES LOCATED ON BEN WHITE<br>IN ALL DISTRICTS ASAP.\",\"Do something about the homeless<br>situation. Stop so much<br>building and polluting our<br>waterways.\",\"Focus on making it less<br>expensive to live here. Stop<br>focusing on all these stupid<br>subjects like street renames<br>and such that do NOTHING to<br>improve life here but instead<br>cost the City and businesses<br>money to adjust.\",\"Too much change is not a good<br>thing.\",\"BE EMPATHETIC TOWARDS OTHER<br>PEOPLE THAT ARE NOT AS LUCKY AS<br>YOU. LIFT PEOPLE UP-HELP FEED<br>AND GIVE A CHANCE TO OTHERS.<br>THERE WERE NO QUESTIONS<br>REGARDING HOMELESSNESS, WHICH<br>IS A BIG ISSUE\",\"Austin will lose tourists and<br>new residents if something is<br>not done about the homeless<br>crisis.\",\"Please realize that you are<br>destroying a Texas community.<br>We are not San Francisco<br>California. Please take care of<br>the residents of your community<br>and not make us a bacon for<br>immigrants to come here and<br>sleep in our parks. Please<br>realize that we residents are<br>not your bank and do not have<br>unlimited funds for you to give<br>away.\",\"WE CANNOT LET THE HOMELESS RUIN<br>THE QUALITY OF LIFE AND BEAUTY<br>OF AUSTIN. YOU HAVE TO CREATE A<br>REALISTIC SOLUTION OTHERWISE<br>MORE HOMELESS COME TO AUSTIN\",\"We need more police and<br>enforcement of traffic laws\",\"Unity belongs EVERYWHERE!\",\"IMPROVED MASS TRANSIT\",\"TRAFFIC IS RUINING AUSTIN'S<br>QUALITY OF LIFE.\",\"Build a city\/county wide metro<br>rail system, please, the one<br>line is not enough, and please<br>link it to the airport. Thank<br>you!\",\"PRESERVE OUR HISTORY SO THAT<br>FUTURE GENERATIONS HAVE THE<br>OPPORTUNITIES TO LEARN FORM IT<br>RATHER THAN BOWING TO ONE<br>ETHNIC GROUPS WISHES.\",\"RE-THINK THE SCOOTERS ON OUR<br>STREETS.\",\"Solve or lessen the problem of<br>homelessness\",\"Please re-think and work with<br>the police in regards to the<br>camping ordice.\",\"My same concern. Growth has<br>caused this city to be<br>unusable. No fun. As a retired<br>person (although I'm a member<br>of the Travis Co. Historical<br>Commission) I basically just<br>don't do anything unless forced<br>to because of traffic, parking<br>and crowds. It's just no fun to<br>have to deal with the problems.<br>THIS at a time when the cost to<br>live here has gone up, up, up<br>due to property tax.\",\"The traffic! The city is the<br>number 1 growing city in the US<br>for the 8th straight year<br>according to Forbes magazine.<br>We cannot stop the growth. Time<br>to embrace it. Build highways<br>and roads that allow traffic to<br>flow. Enough of the terrible<br>design of an on-ramp flowing<br>into an off-ramp and then the<br>lane ends. Or the access roads<br>that require you to merge over<br>three lanes after an exit to<br>make a right turn at the<br>street. The design of the<br>highways is terrible.\",\"How do we allocate some of the<br>costs for running the City to<br>Federal, State and County<br>entities rather than burden<br>non-exempt property owners with<br>higher taxes & fees?\",\"Improve traffic flow in the<br>city and reduce taxes\",\"We don't effect change for our<br>homeless residents by removing<br>an ordice. We have an out of<br>control homelessness epidemic<br>in our city. What are we doing<br>to truly get people off the<br>streets? What are we doing to<br>transition people into safe<br>housing? Assist with addiction<br>recovery? With mental health<br>services? I'm so disappointed<br>that the best our city has come<br>up with is to simply<br>decriminalize sleeping on the<br>streets. I'm concerned that<br>this band aid method is only<br>going to serve to attract the<br>criminal transients to Austin<br>and put us all at risk.\",\"RUN THE HOMELESS OUT OF AUSTIN,<br>BUILD ROADS AND HIGHWAYS, A<br>REAL LOOP. DO NOT CLOSE OLD SAN<br>ANTONIO RD.\",\"SUSTAINABILITY OF CITY\",\"MORE FREE PARKING DOWNTOWN FOR<br>PARKS AND REC\",\"HOMELESS\",\"Stop giving tax incentives to<br>businesses for coming here! We<br>have a lot to offer and should<br>not need to do this. More<br>importantly, we need the tax<br>revenue from these businesses.<br>It's not fair to burden<br>citizens, who may be facing<br>gentrification that forces them<br>out of town, with high taxes<br>and while giving rich companies<br>a free ride for years. In a<br>city growing like we are and<br>with a low unemployment rate,<br>they don't bring us enough<br>benefit to make that a winning<br>deal for us if they aren't<br>paying their share of taxes.\",\"We need to preserve our inner<br>city neighborhoods and provide<br>more\/better affordable housing<br>options.\",\"Reduce the traffic congestion.\",\"STOP WASTING MONEY and help the<br>people not yourself and your<br>friends.\",\"Fix the traffic mess!!!\",\"The city needs to focus on<br>traffic solutions that will<br>improve the quality of life for<br>all citizens.\",\"Keep up the good work in a<br>growing, dynamic city with a<br>complex population.\",\"Please address the homeless<br>situation. I want to help but<br>I'm not sure how. Volunteering<br>to hand out meals, etc. doesn't<br>seem like enough. It is the<br>homeless that create the<br>largest fear for me to go<br>downtown, especially in the<br>evenings, but in some areas<br>(7th\/Neches) I don't even feel<br>safe during the day (sadly, as<br>I'm sure many of the residents<br>do either). I know this is a<br>very tall request and I'm happy<br>to join conversations to weigh<br>in ideas, but I do think this<br>is a problem we must address<br>quickly for everyone.\",\"NEIGHBORHOOD HAS NO SIDEWALKS,<br>DRAINAGE FOR RAIN OR STOP<br>LIGHTS\",\"TRAFFIC IS MAKING ME CONSIDER<br>MOVING.\",\"ONLY AFFORDABLE FOR THE UPPER<br>MIDDLE CLASS\",\"ADDRESS THE EXORBITANT PROPERTY<br>TAX SITUATION.\",\"CLEAN UP THE CITY, TRASH<br>EVERYWHERE, SLOW DOWN GROWTH.\",\"SLOW DOWN DEVELOPMENT FOR<br>QUALITY OF LIFE!!\",\"WE NEED GREEN, 21ST CENTURY<br>PUBLIC TRANSIT PLAN\",\"TRANSPORTATION NIGHTMARE\",\"HELP HOMELESS SITUATION, IT<br>MAKES ME FEEL VERY UNSAFE.\",\"REMEMBER TO HELP THE HELPLESS.\",\"Homeless people. I suggest you<br>take the facilities city owns<br>already to move these folks<br>into safety. EX: Home Depot<br>facility at St. Johns. It would<br>make a great camp ground.\",\"welcome the homeless to live in<br>his yard.\",\"I WISH I HAD BUS STOP BACK AT<br>LEDESMA AND LOTT. I USED TO<br>RIDE THE BUS TO WORK.\",\"MORE PEOPLE MOVING HERE IS NOT<br>A POSITIVE.\",\"HELP THE HOMELESS, CLEAN UP<br>DOWNTOWN\",\"WE NEED LIGHT RAIL, BUSES ARE<br>UNRELIABLE AND TAKE TOO LONG.\",\"Cease efforts to allow camping<br>in public places. Your current<br>efforts to end homelessness<br>will fail. If people want to<br>work they can find jobs.\",\"Please try to get traffic<br>moving! Less street lights and<br>more highway lanes, especially<br>at the \\\"Y\\\" intersection. Too<br>many people and no means to<br>travel efficiently.\",\"Do what's right, not what's<br>popular and trendy.\",\"THE MAYOR SHOULD NOT DO WHAT IS<br>POPULAR, BUT WHAT IS BEST FOR<br>ALL.\",\"HIRE MORE POLICE.INSTITUTE AN<br>AGGRESSIVE CAMPAIGN ON TRAFFIC<br>VIOLATIONS. DRIVERS ARE<br>BREAKING LAWS ALL OVER THE CITY<br>AND THERE IS VIRTUALLY NO<br>CONSEQUENCE FOR THEIR ACTIONS.\",\"SO EXTREMELY DISAPPOINTED IN<br>LOCATION OF HOMELESS SHELTERS\",\"Traffic\",\"HOUSING OPTIONS AND DIVERSE<br>TRANSPORTATION GO HAND-IN-HAND.<br>WE'D LOVE TO DROP DOWN TO ONLY<br>ONE CAR BUT WE CAN'T DO IT WITH<br>THE CITY'S TRANSPORTATION<br>INFRASTRUCTURE.\",\"I DONT FEEL CONNECTED WITH<br>AUSTIN.MY COUNCIL PERSON HAD A<br>SATELLITE OFFICE ON ANDERSON<br>MILL RD-DIDN'T REALLY LIKE HIM<br>BUT I DROPPED IN TO TALKE TO<br>HIM 2-3 TIMES. I LIKED THAT HE<br>WAS CLOSE. THAT'S GONE NOW.\",\"30 YEARS AGO I WOULD HAVE<br>PLEADED WITH THEM NOT TO TURN<br>AUSTIN INTO A HOUSTON\/DALLAS<br>TYPE OF MEGA COMMUNITY. IT'S<br>TOO LATE NOW TO DO ANYTHING<br>EXCEPT ATTEMPT TO MANAGE THE<br>HUGE RANGE OF ISSUES DUE TO<br>GROWTH AT ALL COSTS. GOOD LUCK<br>TO THEM.\",\"Please get out of downtown<br>Austin so you can better<br>understand how real Austinites<br>live when it comes to mobility,<br>congestion, affordability and<br>the condition of roads and<br>other city-owned property (such<br>as medians, etc.). I'd<br>encourage the mayor and council<br>as a whole to take rotating<br>\\\"district field trips\\\" where<br>they visit a different city<br>council district and really<br>drive around to check it out<br>and also talk to residents.<br>Even with city council<br>districts, there's an<br>overwhelming sense that our<br>elected city officials are<br>elitists. No one more so than<br>Mayor Adler, who sometimes<br>seems not to live in the real<br>world.\",\"Stop the inflation of real<br>estate prices. It's not about<br>supply and demand. These prices<br>are driven by greed.\",\"Awful people who work in code<br>enforcement. They are truly<br>terrible\",\"CHANGING THE ZONING CODE IS NOT<br>BEST LEFT TO STAFF MEMBERS\",\"WOULD LIKE TO SEE HISTORIC<br>NEIGHBORHOODS SAFE FROM<br>DEVELOPMENT.\",\"PLAN FOR GROWTH, DON'T JUST<br>LISTEN TO SMALL GROUPS, MAKE<br>THIS CITY AFFORDABLE\",\"THE NEW ORDINANCE ALLOWING<br>CAMPING ON THE STREETS IS A<br>DISASTER, GET OUT OF YOUR IVORY<br>TOWER AND ADDRESS THE ISSUE<br>LIKE A REAL LEADER.\",\"Reduce the influx of those<br>trying to change the culture of<br>our city. This is no longer the<br>Austin I chose to live in. When<br>I no longer need to work<br>full-time, I will probably move<br>out of Austin. It costs too<br>much to live here when our<br>cool, weird vibe is dying so<br>rapidly.\",\"1. QUIT PROMOTING BIKE LANES.<br>BIKES DO NOT COVER THE MOBILITY<br>PROBLEMS.2. QUIT TRYING TO TURN<br>SINGLE FAMILY RESIDENTIAL<br>NEIGHBORHOODS INTO FOURPLEXES,<br>ETC. CITY SHOULD NOT TAKE<br>POSITIONS THAT WILL DESTROY<br>HOME VALUES 3. DON'T USE<br>CODENEXT AS A SOCIAL<br>ENGINEERING TOOL.\",\"PLEASE STOP DIVIDING LOTS IS<br>AUSTIN'S CENTRAL<br>NEIGHBORHOODS.LOWER TAX RATES<br>FOR LONG TERM HOMEOWNERS (LOT<br>YEARS) OR SWITCH TO INCOME TAX\",\"CLEAN UP THE HOMELESSNESS AND<br>PANHANDLING; PREVENT DEATHS AND<br>INJURIES--ENFORCE NO<br>TEXTING\/TALKING WHILE DRIVING\",\"SELL THE UTILITY!\",\"PUBLIC TRANSPORTATION\",\"Please don't chase trying to be<br>like LA, Seattle, Portland or<br>other progressive cities. The<br>recent homeless ordice is an<br>example of misguided<br>government. You only have to<br>look at those cities to see<br>what Austin will become. We<br>have enjoyed living here and<br>raising a family and it would<br>be a shame to leave due to<br>lawlessness by government<br>(Freedom City is a good example<br>of a city government not<br>following laws).\",\"Listen to the people, not the<br>ones lining your pocketbook.\",\"Please attempt to maintain the<br>uniqueness of Austin. This<br>might include affordable<br>housing for artists and<br>musicians and other folks who<br>may not have a high income.<br>Please try to keep property<br>taxes down. Please find a way<br>to alleviate some of traffic.\",\"QUIT PAYING LIP SERVICE TO<br>AFFORDABLE HOUSING, MOBILITY<br>ISSUES AND CARING GOVERNMENT<br>AND ACTUALLY GET SOME STUFF<br>DONE.\",\"Keep the history and legacy of<br>Austin that made people want to<br>come now.\",\"INABILITY TO PLAN HAS NOW<br>MANIFESTED IN BAD COMMUTES,<br>ROADS, AND PROPERTY TAXES OUT<br>OF CONTROL.\",\"STOP ASSUMING PEOPLE WANT TO<br>WALK OR BIKE IN 80-100 DEGREE<br>HEAT AND ARRIVE ALL SWEATY TO<br>WORK OR SCHOOL\",\"Taxes, fees associated city<br>services are too high.\",\"GET RID OF ELECTRIC SCOOTERS!\",\"START FIGHTING FOR THE<br>TAXPAYERS NOT THE TAKERS.\",\"Clean up the streets so that<br>people aren't sleeping or<br>living in the streets or pan<br>handling on the corners.\",\"I wish I could stay here when I<br>retire, but the taxes are too<br>high.\",\"Reign in the developers. They<br>are greedy and not interested<br>in building community.\",\"PLEASE TREAT THE CAMPING<br>PROBLEM LIKE AN ADDICTION<br>PROBLEM, NOT A HOMELESS<br>PROBLEM.\",\"BETTER ALTERNATIVE PUBLIC<br>TRANSIT\",\"INFRASTRUCTURE\",\"We need to quit emulating the<br>city of Seattle\",\"Enforce illegal immigration and<br>stop allowing building permits<br>with no road infrastructure?\",\"STOP THE RAPID GROWTH\",\"Please be forward-looking! Do<br>not build 20th century<br>solutions to 21st century<br>problems. Continue innovating<br>to attract the best and<br>brightest.\",\"Fix the homeless and<br>affordability problem without<br>making the working class pay<br>for it. More reliable public<br>transportation.\",\"RESCIND THE HOMELESS\/URBAN<br>CAMPING ORDINANCE AND STOP<br>EXEMPTING CITY LEADERS FROM THE<br>ORDINANCES. LET THE HOMELESS<br>CAMP AT CITY HALL.\",\"FIX THE CITY, DON'T WORRY ABOUT<br>200,000 ILLEGALS SURGING AT THE<br>BORDER.\",\"The majority of residents do<br>not live downtown. Most obvious<br>efforts go to support downtown<br>and tourists.\",\"HOMELESS PROBLEM, BIKE LANES,<br>SANCTUARY CITY POLICIES,<br>FORCING ALL THE LGBTQ CRAP ON<br>US!\",\"Stop with uncontrolled growth<br>for sake of tax money. Stop<br>turning Austin into California!<br>East Austin is no longer the<br>Austin I loved.\",\"YOU ARE MAKING A BIG MISTAKE<br>RELAXING WHAT DRUG AND ALCOHOL<br>ORDINANCE PROTECTION WE HAD.<br>TENTS ARE NOT COMPASSIONATE.<br>RETURNING THESE FOLKS BACK INTO<br>PRODUCTIVE CITIZENS IS.\",\"Will you please step down and<br>admit your failures. You have<br>destroyed the city.\",\"Lets get control of the<br>homeless population by<br>providing mental health<br>evaluations and quality health<br>care. Mobile Loaves and Fishes<br>along with Community First<br>Village has a great concept and<br>I hope to see more developments<br>like this moving forward.\",\"MAKE RENT MORE AFFORDABLE.\",\"Lower property taxes.\",\"Please fix the traffic.\",\"Treat the City of Austin<br>residents BETTER than you do<br>big business. STOP giving tax<br>breaks and utility discounts to<br>business and end existing<br>relationships. Pass the savings<br>on to residential property tax<br>payors.\",\"Please make more affordable<br>housing available.\",\"GIVE APD THE FUNDING TO HIRE<br>200+ MORE OFFICERS. THIS CITY<br>IS GROWING QUICKLY AND THE APD<br>HAS NOT GROWN AT ALL IN MANY<br>YEARS. ADDING 4-8 MORE OFFICERS<br>IS NOT GOING TO HELP.\",\"FIX TRAFFIC, GET VAGRANTS OFF<br>CITY PROPERTY\",\"housing affordability is a huge<br>issue\",\"Poor budgets and poor<br>management\",\"The property tax and the<br>utilities need to be lowered.<br>Retired people can no longer<br>afford to live here. All you<br>care about is bringing in<br>people from other places. This<br>city is to crowded as it is.\",\"traffic is terrible. If I was<br>starting a business, I'd do it<br>in Georgetown or Hutto\",\"Hard to pick one. Your<br>leadership on the homeless<br>issue is completely off base<br>for the vast majority of the<br>community. Move them out of<br>sight\",\"CREATE A SENIOR DISCOUNT<br>PROGRAM FOR RENTAL PROPERTIES\",\"Build bridges.\",\"Keep working in traffic flow.<br>Keep the gangs out of Austin!\",\"Light rail. At an affordable<br>cost for what the citizens<br>get-- which is why it did not<br>pass when it was on the ballot.<br>It was too expensive for one<br>line that went no where\",\"Quit promoting only high paying<br>business growth.\",\"I am very concerned with<br>affordability of housing. Many<br>people are underpaid overall<br>and have to live with many<br>others to meet rents. People in<br>service jobs are left with<br>little resources but to live<br>way outside the city limits.\",\"We need public<br>transportation-like a<br>subway-now! Also, invest in<br>roads, transportation is our<br>biggest issue.\",\"Focus on what is important to<br>people who live and work in<br>Austin quality of life afforded<br>to us by the US Constitution<br>and the Bill of Rights. Austin<br>will never return to what it<br>was once, but can be even<br>better.\",\"PROPERTY TAXES<br>!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-<br>!!!!!!!!!!!!!!!!!!!!!!!!!!!!!-<br>!!!!!!!!!!!!\",\"LIBERAL POLICIES HAVE RUINED<br>AUSTIN JUST LIKE CITIES IN<br>CALIFORNIA. COMMON SENSE AND<br>FISCAL RESPONSIBILITY DO NOT<br>CANCEL OUT COMPASSION. AUSTIN<br>OF OLD IS DYING.\",\"There should be more light rail<br>transportation ; detour the<br>freight train line outside<br>Austin.\",\"Stop trying to make beautiful<br>Austin into Portland, Seattle,<br>and San Francisco. Those cities<br>are now awful! Define a new and<br>better reality. Make them want<br>to become Austin. Not the other<br>way around.\",\"SMALLER CLASS SIZES IN LOW<br>INCOME SCHOOLS WOULD BE GREAT.\",\"Lower\/abolish property taxes.<br>Stay out of social policy<br>legislation. No more incentives<br>for Global Tech. Improve roads<br>and no more bike lanes.\",\"Keep Spencer doing his job.\",\"PUBLIC TRANSPORTATION NEEDS<br>MAJOR IMPROVEMENT.\",\"Do everything in your power to<br>enable the SERVICE workers in<br>Austin a decent chance at<br>living in the City. I'm one<br>myself. We are getting priced<br>out and, as a result, we are<br>contributing to the traffic<br>problems getting into town to<br>do all service jobs all the<br>more wealthy people need.<br>Thanks!\",\"Go green. We must stop<br>unsustainable growth. So YOU<br>must stop letting developers<br>set the agenda.\",\"try not to react in a knee-jerk<br>fashion there are always folks<br>who love to stir the pot of<br>controversy they should be<br>ignored at lest 75% of the time\",\"Homelessness and the trash<br>around our city is awful.<br>Everywhere you look you see<br>trash on the side of the roads<br>or people sleeping, camping,<br>using the restroom. We need to<br>take back our city.\",\"more large parks outside<br>downtown\",\"Address the homeless<br>population\/problem now! The<br>citizens cannot be the ones to<br>solve the problem the city is<br>unwilling.\",\"Follow the desires of your<br>constituents and quit faking<br>transparency.\",\"Deal with our traffic problems<br>in an effective manner. Help<br>homeless people with<br>healthcare, job training and<br>compassion, but DO NOT let them<br>sleep, camp or loiter in public<br>places. Manage or electric and<br>water systems and bring down<br>our costs.\",\"With the experienced growth<br>explosion and forecasted<br>continued and aggressive growth<br>to the city, road<br>infrastructure is one of the<br>most critical items of<br>importance to the city.<br>Affordability and confining<br>cost of living run close<br>seconds.\",\"Keep city vibrant, develop<br>connection to outdoor spaces\",\"Mayor and city council needs to<br>start serving the average<br>citizen, not the homeless, not<br>the immigrants,\",\"Stop Street people from being<br>victims on the street. Homeless<br>shelters that give hope, food,<br>and a different answer to Life<br>I voted for you Do not let the<br>home less situation define You<br>Solve this issue in a kind way.<br>Please get them off the streets<br>and give them Hope. I was<br>homeless for one year in 1970<br>and if I had stayed on the<br>streets I would not be here<br>today.\",\"Tolerance toward homeless is in<br>total disregard to residents<br>who actually invest in city\",\"Do not allow development to<br>take or tax me out of my home.\",\"Austin in no longer where I<br>want to live. I am 4th<br>generation and plan to leave in<br>next year. It is too crowded,<br>too expensive and no longer<br>unique. Crime increasing.\",\"Stand up to the developers.\",\"LACK OF PUBLIC TRANSIT IN<br>AUSTIN IS BAD FOR A CITY THAT<br>HAS THIS AMOUNT OF GROWTH<br>TRAFFIC. TOOL ROADS ARE NOT A<br>SOLUTION FOR TRAFFIC ISSUES.\",\"AFFORDABILITY IS A BIG PROBLEM.<br>PUBLIC TRANSPORTATION IS<br>LACKING.\",\"Fix the homeless problem. Our<br>overpasses, streets and wooded<br>areas are an embarrassment.\",\"Provide the major services.<br>Stop imposing taxes and<br>regulations.\",\"The overall cost of living is<br>getting out of control. The<br>traffic is challenging and<br>affects quality of life.\",\"Quit bringing development and<br>homeless into this City unless<br>infrastructure is improved to<br>handle the masses without<br>raises our taxes.\",\"Get the homeless people off the<br>public streets - put them all<br>in various parks downtown with<br>a fence and provide sanitary<br>facilities they need. the<br>streets and curbs are dirty<br>enough as it is.\",\"Take care of camping under Ben<br>White. Move to Adlers<br>neighborhood.\",\"I'M REALLY WORRIED ABOUT OUR<br>LONG TERM TRANSPORTATION PLANS<br>AS THE CITY GROWS ESPECIALLY IN<br>AUSTIN.\",\"STOP MAKING TRAFFIC WORSE AND<br>LOWER TAXES.\",\"Cost of living unreasonable.\",\"PLEASE FIND A SOLUTION TO<br>HOMELESSNESS IN THE CITY. I<br>DON'T WANT TO LIVE IN A PLACE<br>LIKE SF OR OREGON.\",\"Invest in families livability<br>in the city limits. The heat<br>and flash of the great things<br>happening in Austin cannot<br>completely replace a city as a<br>viable place to live and work<br>for families.\",\"Do not allow the homeless to<br>camp out anywhere they want to.\",\"Quit worrying about \\\"touchy<br>feely\\\" crap and get traffic<br>figured out. Make life<br>affordable for anyone willing<br>to work. Speak louder!!!!\",\"Fix the homeless problem!\",\"Taxes for property and homes<br>have gone up so much that I<br>cannot afford to retire in<br>Austin\",\"USE HOTEL TAX FOR METRO RAIL<br>FROM UT DOWNTOWN TO AIRPORT.\",\"Public transportation seems<br>like it is aimed at NW area,<br>but not the south part of the<br>city. More dialog between city<br>officials and residents. Like<br>meeting with police at<br>substations.\",\"STOP GOING ROGUE WITH LIBERAL<br>AGENDAS IN DIRECT CONFLICT WITH<br>THE STATE.\",\"ADDRESS HOMELESS CAMPING LIMIT<br>WHERE THEY CAMP ADDRESS TRAFFIC<br>COMMUTE COST OF TOLL WAYS IN<br>PARK TIMES TOO HIGH.\",\"city council is losing touch<br>with the residents and focus on<br>trying to please everyone,<br>including those that don't<br>really live here. I am happy to<br>help the homeless, but in many<br>cases these individuals chose<br>that lifestyle and want to live<br>that way. No camping in public<br>for anyone ever.\",\"WATER AFFORDABILITY<br>TRANSPORTATION NEED TO CATCH UP<br>TO ARTS AND ENTERTAINMENT.\",\"GROWING WAY TOO FAST DOESN'T<br>SEEM WE CAN REALLY HANDLE ALL<br>THESE PEOPLE. WE NEED TO<br>IMPROVE SCHOOLS.\",\"REDUCE COST TO HOMEOWNERS,<br>REDUCE HOMELESS LOITERING.\",\"Focus on getting traffic moving<br>in a timely manner.\",\"He is a great person.\",\"STRIVE FOR MORE GREEN SPACE<br>MASS TRANSIT AND RESERVE YOUR<br>DECISION TO LET HOMELESS CAMP<br>ANYWHERE.\",\"PLEASE STOP ENCOURAGING<br>DEVELOPERS WITH TAX BREAKS.\",\"I AM MOVING OUT OF THE CITY<br>BECAUSE IT IS GETTING DIRTY,<br>THE POLICIES, THE PEOPLE AND<br>TENTS UNDER BRIDGES, TRAFFIC<br>AND HARASSMENT OF BEGGARS AT<br>EVERY CORNER.\",\"Why bother? I'm a taxpaying<br>citizen, my opinions are of no<br>interest\",\"ENFORCE NO TEXTING AND TALKING<br>WHILE DRIVING ORDINANCE. I FEEL<br>VERY UNSAFE ON THE STREETS<br>DRIVING WITH MY BABY IN THE CAR<br>BECAUSE OF THE AMOUNT OF BAD<br>DRIVERS.\",\"MAKE HOUSING AFFORDABLE\",\"CLEAR DOWNTOWN OF HOMELESS,<br>MOVE THE SALVATION ARMY AND<br>OTHER SHELTERS TO OTHER AREAS.\",\"FAIR PROPERTY TAX INCREASES.<br>MINE HAVE GONE UP 300% IN 6<br>YEARS.\",\"VERY DISAPPOINTED IN THE CITY<br>COUNCIL'S DECISION TO LIFT THE<br>ORDINANCES CONCERNING<br>CAMPING\/NO SIT NO LIE AND THE<br>HOMELESS SITUATION. I WORK<br>DOWNTOWN AT A SMALL BUSINESS<br>AND SEE TOURISTS HARASSED AS<br>WELL AS BUSINESS OWNERS. TREAT<br>SMALL BUSINESS OWNERS WITH MORE<br>RESPECT CONSIDERING THEY ARE<br>THE LIFE BLOOD OF THE CITY.\",\"DO NOT PUT NEW ARCH FACILITY<br>CLOSE TO SCHOOL OR<br>NEIGHBORHOOD.\",\"PLEASE TAKE A PAUSE ON<br>DEVELOPMENT. PROVIDE A RAIL<br>SYSTEM TO SOUTH AUSTIN RATHER<br>THAN MORE BUSES.\",\"Disagree with the last homeless<br>issue that passed.\",\"THE CITIES IS FOCUSED ON<br>BECOMING A BIG CITY AND YOU ARE<br>IGNORING THE ELDERLY AND POOR.<br>I AM 71 AND WILL SOON HAVE TO<br>LEAVE MY HOME OF 47 YEARS<br>BECAUSE I NO LONGER CAN AFFORD<br>TO LIVE IN IT. SLOW DOWN BEFORE<br>YOU RUIN OUR CITY.\",\"AS A NEW RESIDENT OF AUSTIN I<br>FEEL THERE ARE MAY ADD ON FEES<br>WITH UTILITIES. QUALITY OF<br>URGENT CARE IS POOR.\",\"The inability to find the right<br>department for my flood<br>problems in my neighborhood!<br>Everyone we speak to agrees we<br>have a big problem, but they<br>are not able to help.\",\"MAKE WATER A PRIORITY.\",\"THERE IS A REAL NEED TO<br>PRESERVE HISTORIC NEIGHBORHOODS<br>IN AUSTIN. DO NOT DESTROY<br>HISTORIC NEIGHBORHOODS IN THE<br>NAME OF AFFORDABLE HOUSING.\",\"Lower property taxes.\",\"PLEASE TAKE CARE OF THESE<br>HURTING PEOPLE. SERVE THE<br>HOMELESS. REGULATE GROWTH.\",\"Please fix the traffic.\",\"THE HOMELESS ISSUE AND TRAFFIC<br>ARE OUT OF CONTROL. STOP<br>ALLOWING PEOPLE TO CAMP<br>EVERYWHERE AND PROVIDE MORE<br>SERVICES FOR TRASH PICK UP FOR<br>THE HOMELESS, MENTAL HEALTH<br>SERVICES, AND JOB AND DRUG<br>ADDICTION SERVICES.\",\"STOP WITH ALL OF THE DO GOOD<br>PROJECTS AND FIX THE REAL<br>ISSUES. THE CITY MUST STOP OUR<br>HOMELESS ISSUE. HOMELESS CAMPS<br>WILL STOP TOURISM AND HURT THIS<br>CITY.\",\"HOMELESS IN AUSTIN NEEDS TO BE<br>FIXED. END HOMELESS CAMPS. THEY<br>ARE PEOPLE WHO NEED SUBSTANCE<br>ABUSE HELP FIX IT.\",\"I fear Austin will turn into<br>another Seattle, and I don't<br>want that for my city. An<br>overpriced, overcrowded,<br>homogeneous city of tech<br>workers doesn't sound like my<br>cup of tea.\",\"REDUCE TAXES\",\"Traffic is a problem\",\"Make Austin a nice place to<br>live for families again where<br>we can feel safe and can enjoy<br>the amenities the city has to<br>offer in peace. People come<br>here for the natural beauty,<br>music, friendliness, quality of<br>life and prior to now, safety.<br>Crime has gone up in our area<br>from 20 years ago. Please learn<br>from San Francisco and Portland<br>and don't ruin the city.\",\"Fix our waste water bill<br>....they need to put a Y in for<br>pool water and yard sprinkler<br>system.\",\"DO SOMETHING ABOUT THE TRAFFIC\",\"Residents first, maintain our<br>community culture, don't make<br>us like every other failing<br>city.\",\"Stop telling people to move<br>here, you say lots of jobs and<br>plenty of housing ... tell the<br>truth, lots of jobs in the<br>restaurant industry and then<br>tell everyone a 1 bedroom<br>apartment cost $ 1,200.00 a<br>month\",\"I am quite concerned that<br>planning reflects to booming<br>growth of Austin. Where will<br>these people live? Improvements<br>in traffic flow both current<br>and future.\",\"Work on traffic pollution, it<br>is very unpleasant.\",\"Make parking less expensive<br>downtown and provide more free<br>parking opportunities for<br>working musicians who have made<br>this town the Live Music<br>Capitol Of The World.\",\"Take care of the homeless, but<br>not the current way you have<br>chosen.\",\"Please address traffic and<br>housing affordability for<br>middle class\",\"Be fair to the military widows<br>AO Taxes City had not bin fair<br>on it\",\"Stop your socialist agenda.<br>Work for ALL the people and not<br>just the vocal minority.\",\"It's unrealistic to expect that<br>we can stop (or even slow)<br>growth significantly, so let's<br>focus on managing it to the<br>greatest extent possible<br>through policies that improve<br>density of housing, improve<br>traffic infrastructure and<br>flow, improve public<br>transportation options and<br>maintain the \\\"culture\\\" of<br>Austin that currently only<br>exists in myth.\",\"You need to listen to the<br>Republicans.\",\"Kick out all homeless unless<br>they want rehabilitation and<br>get a job. Outlaw camping as it<br>is now. Let police arrest them.<br>Send them packing on a bus one<br>way ticket. I called the mayor<br>and left messages, nobody will<br>call me back! Sad mayor!!!\",\"Do something about the homeless<br>now before it gets out of hand.\",\"Get the police on the roads and<br>enforce traffic laws.\",\"CONTINUE TO GROW AND THRIVE.\",\"I'd like there to be more<br>accountability to the people of<br>Austin when there is an issue.<br>I'd like an audit to improve<br>the process of how to address<br>issues since my four attempts<br>were all aborted, me concluding<br>the complaint process exists in<br>name only and is designed to<br>protect the city from its<br>residents.\",\"Put more effort into expanding<br>rail service, such as lines<br>into south Austin and to the<br>airport.\",\"HOMELESS CAMPS NEED REMOVED<br>FROM WOODED AREAS NEAR TRAILS<br>AND THE ARCH NEEDS RELOCATED.\",\"REDUCE PUBLIC TRANSIT TIME\",\"Stop trying to implement<br>Progressive ideas which are<br>taken from failed societies! We<br>are not a country of diversity<br>but rather an assimilation into<br>the American Values under the<br>Constitution of the United<br>States.\",\"Do something constructive about<br>the homeless issue and mental<br>health services. Those two are<br>related.\",\"Look at cities such as Houston<br>and Dallas for guidance on<br>homeless solutions, NOT to San<br>Francisco, Seattle and Portland\",\"Stop letting the homeless trash<br>our city.\",\"The residential taxes are<br>killing me. Recently divorced I<br>WILL have to move out of Austin<br>when I retire. The taxes I pay<br>on my home are unsustainable. I<br>live be very frugally and while<br>I realized I am single living<br>in a family home my taxes were<br>very high and my house was over<br>assessed for the past 5 years.<br>This year somehow someone must<br>have caught it! My 1800 sq.<br>foot house was assessed at<br>$100K more than other houses<br>that are 2500 sq. ft houses on<br>my street. Finally, this year<br>my house seems more in line<br>with my neighborhood. I would<br>love a refund for all of the<br>money I overpaid in taxes and<br>the lies told to me at the tax<br>office. The homeless problem is<br>absolutely ridiculous. I<br>recently visited Seattle. We<br>are starting to look like that.<br>Not good I would like to see<br>the city provide designated<br>spaces for camping. Loaves and<br>fishes is one great example for<br>homeless people to move forward<br>and get help while helping<br>themselves. I believe public<br>camping in Austin will really<br>hurt the tourism industry in<br>Austin.\",\"Please work toward getting our<br>schools the funding they need<br>to provide adequate education,<br>services, & trained educators<br>to our students\",\"Change your position regarding<br>homeless. The citizens of<br>Austin should NOT be<br>responsible for them; they are<br>invaders. Try to remove them<br>from the City rather than serve<br>them.\",\"Please consider the poor and<br>working poor. Too much is given<br>to the rich in this city.\",\"Affordable housing. We make<br>over $80,000\/year. Where's my<br>starter home? I'm willing to<br>rent until my father passes<br>(hopefully that's not soon) and<br>I inherit his home, but you<br>need to do me a favor and cap<br>rent. These apartment<br>communities say that they<br>charge based on supply and<br>demand, yet 1\/3+ of their units<br>sit empty. What's the scam?<br>$1,150+ for a one bedroom and<br>$1,850 for a two bedroom is not<br>just.\",\"Please try to do something<br>about the property taxes and<br>the impact of the California<br>influx growth on our landmark<br>businesses that have been part<br>of the history of Austin.<br>Seeing places like Hills have<br>to close is heart breaking and<br>just changes the feeling of the<br>city. We can't Keep Austin<br>weird anymore and that's<br>saddening... our quirky<br>small-town big-city is gone.<br>There's a lot of good things<br>still here... save them!<br>Support the small \/local<br>businesses with decisions that<br>don't force them out!\",\"Listen and represent the hard<br>working tax paying citizens of<br>Austin. We are tired of the<br>excessive tax burden and cost<br>of living in the City. It is<br>forcing long term home owning<br>residents such as myself to<br>move and leave the city limits.<br>We can no longer afford to live<br>here. It's very sad. You seem<br>to care more about the homeless<br>and being a sanctuary city than<br>about the citizens paying all<br>the taxes. We are drowning in<br>excessively high costs of<br>living (housing, water,<br>utilities). We get no break or<br>appreciation. HELP!\",\"Stop spending on all the fringe<br>programs. Start concentrating<br>on essential services. Stop<br>trying to be a liberal haven.<br>Stop trying to be California.\",\"Great job handling such massive<br>growth.\",\"Fix Traffic\",\"HOMELESSNESS\",\"Please slow the growth to allow<br>for better planning\",\"RESIGN!!!!!!!!!!!!!!!!!!!!!!!-<br>!!!!\",\"Accountability for city<br>employees should be reviewed.<br>Seems like some higher ranking<br>employees are provided greater<br>leniency than their<br>subordinates. Also, MCS ruling<br>are often questionable.\",\"I am concerned with rising tax<br>rates especially as I near<br>retirement. I also have<br>concerns over the recent<br>camping ordice in the city. We<br>recently passed a tax increase<br>to assist with homelessness.<br>Maybe it was not enough to<br>address the problem but with<br>the camping ordice the city is<br>likely to attract far more<br>homeless citizens than can be<br>provided for. Also I really<br>dislike bike lanes!\",\"You are too liberal. Austin did<br>not become a great city with<br>people like you running things!\",\"Quit making low or no tax deals<br>w\/ big companies. Austin is an<br>attractive place for business<br>any way. These businesses will<br>come w\/out these deals.\",\"BRING MORE BIOTECH TO AUSTIN\",\"QUIT BEING SUCH A BLEEDING<br>HEART\",\"SPENDING MILLIONS ON A WALKWAY<br>BRIDGE IS NOT WELL SPENT.\",\"Don't allow public camping on<br>public spaces Unless it's on<br>the sidewalk in front of city<br>hall or the mayors residence\",\"Traffic is the only thing I am<br>concerned about that needs<br>immediate attention. I am also<br>concerned about crime, but I<br>think our police chief is<br>working on this and heading in<br>the right direction.\",\"Affordable housing and better<br>public transportation is<br>needed.\",\"Don't try to be the 'ideal<br>city'....just focus on what<br>made Austin a great place. Fun,<br>open inclusion, weirdness,<br>convenience of getting around,<br>safety.\",\"Take care of infrastructure;<br>focus on IH35.\",\"rethink homeless being able to<br>camp on public property\",\"Create a program to<br>significantly lower taxes for<br>long term residents and<br>families passing those<br>residents to other family<br>members. This would allow for<br>established residents to keep<br>their homes while allocating<br>the higher taxes to those who<br>want to move to the city.\",\"Spend more time doing your<br>elected job and less time<br>political posturing on national<br>issues that City personnel<br>should be doing on the or<br>personal time- MAYOR ADLER\",\"Make the basic city services<br>your priority.\",\"Austin is one of the most<br>extreme liberal cities I've<br>ever lived in. It's ridiculous<br>how much government caters to<br>liberals and refuses to<br>consider the views of<br>conservatives. The mayor needs<br>to be replaced immediately<br>because of his policies.\",\"Gentrification, exaggerated<br>property values and the<br>subsequent taxes and costs of<br>living are causing many of the<br>people and businesses, that<br>have given Austin it's<br>character, to move out.\",\"Please don turn Austin into<br>Seattle, San Francisco or Los<br>Angeles\",\"Get back to being a Texan and<br>not a Californian. Pay less<br>attention to people moving here<br>and the revenue they will bring<br>and more to the citizens who<br>made Austin a great place to<br>live. High taxes here are<br>driving our citizen heroes out<br>of town, along with the iconic<br>restaurants and small<br>businesses, while large<br>developer buddies are busy<br>tearing down what's been good<br>for a long time. If the Mayor<br>is so interested in helping the<br>homeless, how about letting<br>them camp on the front lawn at<br>his home. The recent changes<br>are insane. Maybe he should<br>move to California, so we can<br>get a reasoned Texan in that<br>position.\",\"Get the homeless litter blight<br>cleaned up! This is enabling,<br>not helping the people.\",\"You don't have a mandate to do<br>what you want to do. Even<br>though you got re-elected,<br>there are a lot of us that<br>don't like the job that you are<br>doing. You should try to serve<br>everyone with some common sense<br>approaches. You are helping the<br>few and hurting the many.\",\"PLEASE STOP BRINGING IN SHADY<br>DEVELOPERS-LIKE DAVID<br>WALLACE-TO MAKE DEVELOPMENT<br>DECISIONS. THE CITY IS GREAT!<br>STOP PUSHING MUSICIANS AND<br>ARTISTS OUT! (LOW INCOME)<br>PEOPLE MOVE HERE FOR ART AND<br>MUSIC-WE CAN'T LOSE IT.\",\"PLEASE PROTECT THE LOWER MIDDLE<br>CLASS AND POOR FROM THE EFFECTS<br>OF RAPID GENTRIFICATION. SOON<br>AUSTIN MAY LOOK LIKE SEATTLE.\",\"THE CURBS AND GUTTER NEED TO BE<br>PROPERLY MAINTAINED. YOU NEED<br>TO LOOK AT LOWERING PROPERTY<br>TAXES FOR RETIREES\",\"DON'T GIVE IN TO PRESSURE FROM<br>BOTTOM LINE FEEDING CRIMINALS\/<br>EXPOSE ABUSES OF POWER. DON'T<br>WASTE MONEY ON STUPID STUFF. BE<br>SOMEONE WE ARE PROUD OF TO NAME<br>AS OUR MAYOR.\",\"Too liberal\",\"REDUCE TAXES, DON'T RAISE THEM!<br>Austin residents are getting<br>priced out of living here.\",\"Help the homeless.\",\"Offer tax incentives for native<br>Austinites. It's important for<br>our community to have born and<br>raised citizens remain in this<br>community to help preserve what<br>makes Austin so great.\",\"Housing & Transportation\",\"Austin needs true affordable<br>housing options. Stop<br>gentrifying east Austin, slow<br>or stop the ridiculous<br>multi-use developments, do not<br>raze affordable student housing<br>east of I-35 for another<br>ridiculous giant development,<br>and find ways to allow older<br>Austinites on fixed incomes to<br>stay in their homes. Greed is<br>RUINING our city.\",\"Absolutely disappointed in the<br>irresponsible decision to allow<br>the homeless to camp and run<br>rampant throughout the City.\",\"I love it here. I don't care<br>about jobs and industry as much<br>as I do quality of life. I'm<br>glad you didn't court Amazon. I<br>miss the days when it was a<br>place for government employees,<br>aimless graduates, artists, and<br>natives. I value diversity and<br>everyone feeling safe and<br>welcome. I value diverse jobs<br>in areas that also pay the<br>bills. I think this discomfort<br>is happening everywhere and I<br>don't know what y'all can do<br>about it. No one has a good map<br>on growing and no one wants to<br>have the problems San Francisco<br>and Seattle have. I know you're<br>making the best choices you can<br>with the information you have<br>and I hope the advice is good<br>advice regarding affordability<br>and housing. So far I don't see<br>more housing make it more<br>affordable. I just see more<br>unaffordable housing. When we<br>have our 5% (not much) of units<br>be affordable, do they remain<br>affordable or can you then sell<br>at market? City values aside,<br>it's as though the economy does<br>not want you here if you're<br>poor.\",\"Transition to homes for<br>homeless on the street\",\"Traffic congestion, affordable<br>housing, and addressing the<br>rapidly rising homeless<br>population are top concerns and<br>I know these are some of your<br>top priorities as well.<br>Allowing the open camping is<br>causing safety issues, and<br>litter issues. There is a<br>routine homeless camp behind my<br>home for years. Previously we<br>have been able to clean out<br>these camps to try to keep this<br>water runoff critical area<br>clear. I am worried about the<br>effects of flooding (due to<br>trash clogged creeks) and where<br>this litter (including used<br>needles) will run into. My<br>cousin was assaulted before<br>sunset downtown after leaving<br>dinner over not handing over<br>his phone to a homeless man. I<br>don't vote against ballot<br>initiatives to aid the homeless<br>population. I think these types<br>of initiatives would benefit<br>from better awareness<br>campaigns. The new rules<br>allowing them to camp and trash<br>the city and waterways is not a<br>good option. I know we can't<br>help those that don't want to<br>be helped and there are no<br>perfect answers for all but we<br>have to have better options.\",\"Property taxes are ridiculously<br>high.\",\"Need to improve traffic flow\",\"My heart is broken by your<br>choices of growth, encouraging<br>more than 1-2 tech companies to<br>come here has destroyed the<br>fabric of this very unique<br>town. Also allowing the<br>homeless ordice to change prior<br>to having a solution was so<br>incredibly short sides and not<br>what the people wanted makes<br>us mistrust your intent.\",\"Fix the traffic problem\",\"More high quality museums and<br>cultural centers\",\"Mr. Mayor, while I'm sure your<br>intentions are good,<br>authorizing and endorsing<br>homeless camps is bad policy,<br>and is not any kind of<br>acceptable solution to the<br>city's homeless problem. It is<br>an abdication of<br>responsibility, both to the<br>individuals living in such<br>conditions, and to the<br>communities you serve, which<br>deserve to be kept both safe<br>and pleasant. The nearby<br>greenbelt area (Country Club<br>Greenbelt), which should be a<br>community jewel, is instead<br>overrun with homeless<br>encampments, and now, the city<br>and parks officials who<br>formerly worked with our<br>community association to<br>(humanely) remove and clean up<br>homeless encampments say there<br>is nothing they can do, because<br>of the change in city policy.<br>The city is spending tens of<br>millions to build paths from<br>the area to Ladybird Lake;<br>meantime, we can't get the city<br>to remove mountains of trash,<br>dangerous needles, and tent<br>cities from the greenbelt and<br>its paths and waterways. Most<br>of the well-intentioned but<br>misguided policies the city has<br>adopted to deal with the<br>homeless problem are eerily<br>similar to the failed policies<br>of California and the Pacific<br>Northwest, which area of the<br>country we left for Austin,<br>wrongly thinking that Texans<br>had better common sense. You<br>should expect the same bad<br>results. I have heard the Mayor<br>say that he wants the city's<br>homeless policies to be a model<br>for other cities, to which I<br>say, \\\"What policies?\\\" The city<br>is building a trivial amount of<br>beds, slowly, and at great<br>cost. The few facilities you<br>have in place are grossly<br>inadequate and unsafe. You need<br>to partner with the private<br>sector and let them build<br>larger facilities, faster and<br>cheaper than the city can,<br>without all the red tape, aka<br>San Diego tent breaks, which<br>I'm sure you've heard of. I<br>realize there are no easy<br>answers to these questions, but<br>the city is moving in the wrong<br>direction of endorsing<br>community blighting encampments<br>rather than addressing the<br>homeless issue in any kind of<br>effective way. Recognize that<br>when the only community input<br>you seek on these homeless<br>issues is 1-3 minute snippets<br>at endless city council<br>meetings, you are hearing from<br>the extreme left, and not the<br>regular citizens who must work<br>during these marathon meetings,<br>but who live and work in these<br>communities, hold a very<br>different point of view, and<br>suffer the consequences of<br>these misguided policies.<br>Unfortunately, a political<br>environment has been created<br>whereby any citizen who doesn't<br>concur with the extreme left on<br>issues of this nature, is<br>treated with extreme disrespect<br>in city forums, and, sadly, the<br>Austin city council members<br>tolerate it. That is not<br>democracy. We all are<br>legitimate voices in this city<br>and ought to be able to work<br>respectfully with one another<br>towards solutions on<br>homelessness and everything<br>else this great city needs.\",\"Deal with the traffic. Create<br>effective public transportation<br>options. Address the political<br>\/ religious hatred which<br>infects Texas and Austin by<br>virtue of being in Texas.\",\"TOTAL WASTE TO SPEND 3 MILLION<br>DOLLARS ON CODE CHANGES. QUIT<br>SPENDING MY MONEY ON LEGAL<br>CHALLENGES TO PROTECT ILLEGAL<br>IMMIGRANTS THAT THREATEN MY<br>SECURITY ON ROADS AND HOME.<br>MOVE TO PORTLAND. JUST<br>SOMEWHERE ELSE.\",\"Stop wasting tax payer money on<br>his ridiculous initiatives that<br>only hurt the citizens of this<br>city.\",\"Number 1 would be the traffic.<br>We have more bike lanes than<br>people who use them. Everyone<br>walks are bikes occasionally<br>but it seems the city is<br>forcing this. We all can't live<br>across the street from our work<br>like the mayor.\",\"ALL EMPLOYEES SHOULD BE PAID A<br>LIVING WAGE, BUSINESS SHOULD<br>PAY THEIR FAIR SHARE OF TAXES.\",\"My family and I love it hear,<br>but are worried that the lack<br>of planning for Growth is going<br>to significantly degrade the<br>awesome city we have.\",\"FIND SOLUTIONS FOR HOMELESSNESS\",\"Born and raised here. I love<br>it! But I fear I will have to<br>move somewhere else when I<br>retire, will not be able to<br>afford it. Property taxes keep<br>going up. Traffic has not been<br>planned for at all!\",\"Be prudent stewards of tax<br>dollars.\",\"Fund the parks department.<br>Create new parks and pools. We<br>need more parks space. Do not<br>shut Zilker down during the<br>best weather of the year for<br>ACL.\",\"HELP THE HOMELESS ANOTHER WAY\",\"RECONSIDER THAT DENSITY OF<br>HOUSING MAY NOT BE WHAT IS THE<br>BEST TO INCREASE AFFORDABILITY.\",\"The city HAS to get the housing<br>affordability under control<br>especially for those new in the<br>job force and those on fixed<br>income(retirement).\",\"Stop raising taxes our money is<br>just being sent to other<br>counties. Spend the money<br>wisely as if it was coming out<br>of your own bank account. Stop<br>taking trips, now days we have<br>conference calls and even video<br>conferences. Long-term home<br>owners need to have your<br>respect instead disregard. We<br>have paid to own homes, paid<br>taxes, and been long-time<br>members of this community and<br>it seems like in a rush to get<br>more \\\"affordable\\\" housing we<br>are being forced out by rising<br>taxes, rising property values<br>which means paying even more in<br>taxes, and no visible<br>improvements for most of our<br>main streets. South Austin<br>residents have more difficulty<br>going North of the river on<br>same old streets with more<br>traffic and new bike lanes will<br>not resolve that issue!\",\"Focus on fixing the homeless<br>problem, and STOP allowing the<br>tent city to grow, before it<br>completely destroys the<br>downtown Austin area.\",\"Fix your property tax issue,<br>you have plenty of new people<br>moving to Austin daily, you<br>don't need to gauge your<br>residents. Deal with the<br>homeless, shame on you for<br>putting the problem on everyone<br>else, you wanted the job, now<br>do the job. If one child is<br>harmed because a homeless<br>individual was on school<br>property you should be held<br>criminally responsible.\",\"BETTER ROAD AND BICYCLE<br>INFRASTRUCTURE AND BETTER<br>TRANSIT OPTIONS.\",\"Pay as much attention to &<br>demonstrate fairness to small &<br>medium sized business as to the<br>large companies & entities.<br>Major problem!\",\"Stop homeless camping, you are<br>only creating more problems\",\"Focus on current residents<br>rather than trying to bring<br>more people in or encourage<br>more tourism.\",\"Austin is a great city but the<br>homeless are getting aggressive<br>to the point of stopping me<br>inside library and businesses<br>asking me for money.\",\"Re instate homeless camping<br>ordice\",\"The permit process for home<br>owners should be easy and user<br>friendly. To me the permitting<br>process is a tool of<br>gentrification and taxation. I<br>don't disagree with it. But I<br>think it should be looked at<br>and refined. The homelessness<br>situation has been perpetuated<br>by the COA and providing more<br>services will not help. Private<br>funding should direct the<br>efforts the City makes for<br>this.\",\"Do not cater to the homeless<br>who do not support but only<br>take away from our beautiful<br>city. Support the workers and<br>majority of Austinites who make<br>this city special.\",\"Do a better job at providing<br>faster emergency care.\",\"Secret deals and negotiations<br>are unacceptable. I'm thinking<br>of soccer here ..\",\"Fix our out of control tax<br>increases. 10% increase per<br>year for last 10 years. Really?\",\"Take a close look at your<br>priorities for Austin and do<br>not try to attack every issue<br>at the same time at the expense<br>of resolving any of them!\",\"Lower taxes\",\"Fix something, anything, please\",\"I know I am very fortunate. I<br>live in one of the safest,<br>well-kept zip codes in this<br>city. I make a good living, and<br>I am blessed. I am very<br>concerned about growth and the<br>resulting impact on our<br>citizens, resources, and<br>quality of life. Why are we<br>still giving companies like<br>Apple a 100% property tax<br>rebate and other incentives?<br>While there are obviously some<br>benefits to locals from adding<br>these giants, the reality is a<br>large percentage of the jobs<br>they create are not being<br>filled by locals. With > 150<br>people \/ day moving here, are<br>we really making things better<br>for the people of Austin?\",\"Represent me and focus on LOCAL<br>issues, not national politics.<br>Work on solving Austin's issues<br>and keep politics out of it.\",\"House the homeless!\",\"Lower property tax. Fix traffic<br>now\",\"Affordable housing!\",\"Please make businesses pay<br>their fair share of property<br>taxes.\",\"Slow growth and attend to our<br>infrastructure. Don't build<br>more when your infrastructure<br>is deteriorating.\",\"Look into Austin's major pain<br>points - traffic, affordable<br>housing and property tax.\",\"Stop encouraging the homeless<br>to move to Austin\",\"Work on homelessness and<br>begging on City streets\",\"Spend more time addressing<br>middle class livability issues.\",\"Help the homeless\",\"Used to be proud of Austin and<br>tour visiting friends around.<br>Now it's just a crowded nasty<br>city.\",\"Get homeless out of down town\",\"focus on mass transit, roads<br>and quality of life for<br>Taxpayers -- do not focus on<br>homeless--we do more that MOST<br>cities and we can now focus on<br>other concerns with our limited<br>tax dollars. Get the light rail<br>to run to UT and the airport so<br>we can get cars off the road\",\"I have worked with persons<br>experiencing homelessness and<br>would like to encourage the<br>city to continue its efforts to<br>address these people's needs.\",\"Solutions are needed for the<br>traffic and homeless population<br>problems\",\"Need to handle the homeless<br>population issues differently\",\"Please, focus on the quality of<br>life here, tolerating excessive<br>homelessness doesn't promote<br>safety.\",\"Please let's not turn into San<br>Jose.\",\"Lower property taxes.\",\"Please make an effort to stay<br>politically centered. Our city<br>council has such a strong bias<br>to left-leaning agendas, it<br>seems to get in the way of good<br>effective policy.\",\"fix the homeless situation.\",\"More aggressively fund the<br>Police, resort the confidence<br>of sexual assault victims, make<br>our parks a place people want<br>to spend time\",\"Stop GIVING AWAY my tax dollars<br>and start using them more<br>efficiently!!\",\"Investigate 311.\",\"Move from reactive leadership<br>to proactive leadership that is<br>data-driven, strategic, and<br>mission\/vision-driven. This<br>city is on the brink of losing<br>what made it so special to<br>those who were born and raised<br>here.\",\"TOO MANY PANHANDLERS.\",\"Please don't let Austin go the<br>way of San Francisco\",\"I would suggest that the focus<br>of the city should be on<br>helping maintain and improve<br>what we have now. It seems that<br>too many issues are being<br>discussed and then decisions<br>made without determining the<br>ramifications of it, such as<br>with the law allowing loitering<br>on public land. We should leave<br>laws such as these alone for<br>now and work on enforcing the<br>current laws. We need more<br>police presence so that our<br>citizens feel safe in their own<br>neighborhoods. Once this is<br>complete and satisfactory, then<br>we can work on the other<br>issues.\",\"Manage this city on the budget<br>allocated annually, cut out the<br>programs which produce nothing<br>- like dancing garbage trucks<br>(yes taxpayer dollars went to<br>fund this!), and stop<br>increasing city fees. Know that<br>we do NOT want more bike lanes,<br>fewer driving lanes, or<br>frivolous spending of our tax<br>dollars.\",\"Cut taxes\",\"We need to make this city<br>affordable for everyone,<br>including the low income and<br>middle class. It is currently<br>only affordable for the upper<br>middle class and wealthy. We<br>need to take a stand against<br>property taxes.\",\"Fix the traffic and roads.<br>Sounds like a whiner, but it is<br>something that affects us<br>multiple times per day.\",\"Please be fair to Austin<br>residents & not drastically<br>hike up property taxes...many<br>of us can't afford this & it<br>would put a huge strain on our<br>families.\",\"Provide better services to<br>maintain our medians and<br>roadways. City looks trashy and<br>unkempt.\",\"stop being a pawn of<br>developers- protect the trees<br>of Austin.\",\"Start making this city a<br>desirable and affordable place<br>to live again by addressing<br>some of barriers to that (such<br>as traffic, property taxes and<br>homelessness\/vagrancy).\",\"Please find a better solution<br>for homeless situation.<br>Allowing them to sleep and take<br>up residency on public streets<br>is not the answer and is not<br>safe for them or for citizens<br>of Austin or visitors.\",\"Overall, things are good in<br>Austin, but transportation is<br>the number one problem that<br>needs to be fixed, both roads<br>and public transportation<br>options.\",\"Get rid of the Vagrants !!! 1)<br>STOP all pan handling. No more<br>begging on the corners. You can<br>grant special privileges w\/ a<br>permit. 2) STOP allowing anyone<br>from being able to sleep on the<br>streets. Give property Tax<br>relief to Old Austin Businesses<br>to help they stay afloat to<br>preserve what little is left of<br>Old Austin. Give property tax<br>relief to people that have<br>owned their home for 10+ years<br>before this growth occurred. I<br>just don't understand how it is<br>fair that us Old Austinites are<br>having to endure high property<br>taxes for something we had no<br>part. Austin Management allowed<br>the city to grow as much as it<br>did. In my opinion they should<br>have one foot on the brakes for<br>the past 5 years, but they did<br>not. I feel like we as Old<br>Austin original are getting<br>penalized while the developers<br>out there are raping our once<br>beautiful and fun city.\",\"Reverse your public camping<br>decision and clean up all the<br>trash the homeless have left in<br>our public areas\",\"Stop allowing developers to<br>build in our city. We will not<br>enough water in the future, our<br>traffic will only get worse,<br>and the infrastructure will<br>suffer if this growth is<br>encouraged.\",\"Our neighborhood - Travis<br>Country - needs options to be<br>able to leave the neighborhood<br>without using personal vehicles<br>by Capitol Metro and by<br>sidewalks and safe roads to<br>walk to nearby businesses.\",\"Please find a solution for the<br>homeless camping and<br>panhandling before we look like<br>Seattle.\",\"STOP all policies that only<br>increase the clogging of<br>traffic-bike lanes used only by<br>minuscule per cent, humping of<br>streets everywhere (why not<br>hump Mopac. ), bringing in<br>traffic-cloggers like MLS,<br>bigger convention centers,<br>ghastly projects like THE<br>GROVE, and inviting throngs to<br>come to Austin for the freebies<br>sleep where you want ,<br>panhandle where you want, load<br>up on free food, clothes,<br>health care. If you want to<br>come here for all the freebies,<br>do twenty hours a week of<br>community service\",\"Build a IH35 overpass over<br>Downtown !\",\"REZONING 78711 FOR AUSTIN ISD.\",\"PLEASE TAKE A LOOK AT HOMELESS<br>ORDINANCE.\",\"Horrible traffic which will<br>never be rectified\",\"Preserving our diversity is<br>important to our city.<br>Gentrification has robbed us of<br>so much color and culture.\",\"Please fix the traffic issues.<br>Taxes in Central Austin are<br>skyrocketing. Those of us that<br>live here will be forced to<br>sell our homes, and move to the<br>suburbs.\",\"the homeless thing is a<br>disaster. as a kid when every<br>other person was a hippie we<br>never had anything as ugly or<br>ridiculous as this\",\"There is a limit on the amount<br>of taxes that residents can and<br>will be capable of paying.<br>Because of the City's<br>continuing high property tax<br>rates, and its politically<br>correct, progressive electric<br>and water rate structures,<br>young folks and retirees are<br>forced to sell their homes and<br>move out of the City.<br>Fortunately, there are near-by<br>alternatives with better living<br>conditions!\",\"Solve the homeless problem\",\"My comments above on the<br>homeless issues.\",\"Please figure out a way for<br>single income people making<br>less than $70k\/year to live by<br>themselves.\",\"nothing is good\",\"The homeless crisis is ruining<br>our city and the city's actions<br>have made residents<br>distrustful. The lack of<br>transparency is scary. Our<br>distrust is warranted given the<br>example of the Arch. Our<br>vibrant downtown is becoming a<br>place people are scared to go.<br>Please listen to the taxpayers.\",\"Even if I pay off my home at<br>retirement, my property taxes<br>are so high I will be forced<br>out of my home when I have a<br>fixed income - only the very<br>wealthy can own a home here.\",\"Taxes and cost of living in<br>Austin too high.\",\"Please improve traffic<br>congestion...\",\"No more big business tax<br>exemptions!!\",\"Stop ADP from giving out<br>frivolous traffic citations and<br>put more time into actually<br>helping people.\",\"The homeless population has not<br>only become an overwhelming<br>public health issue, it has<br>also made the city-wide<br>panhandling, not only<br>intrusive, but uncomfortable.<br>I've lived here my whole life<br>and I no longer go anywhere<br>alone or unarmed. I feel the<br>lack of regulation in zoning<br>and permitted allowances for<br>the homeless population has<br>gotten out of control making<br>the rural parts of the city<br>intolerable and unbearable.\",\"As a public school teacher, I<br>will not be able to afford to<br>live in Austin if my property<br>taxes are raised any further.<br>Thank you.\",\"Do something about reducing<br>property taxes!!\",\"Get rid of tent city,<br>revitalize 6th street corridor<br>(Broadway in Nashville as<br>example)\",\"More emphasis on the<br>under-served population rather<br>than the privileged.\",\"STOP TRYING TO INCREASE URBAN<br>DENSITY.\",\"Cost of living | property taxes<br>needs to be addressed. Stop<br>letting California money<br>dictate.\",\"We need more police officers.\",\"Restart the sit and lie ordice\",\"Really needs to find a solution<br>to help the homeless, as it is<br>out of control. There is a<br>homeless person on every corner<br>asking for help. Need to stop<br>allowing them to camp anywhere<br>they want. The city needs to<br>start fixing and repairing the<br>sewage and drainage, and this<br>cost needs to be passed on to<br>all new building and<br>construction instead of the<br>current homeowners.\",\"I am concerned about the<br>homeless families and very<br>concerned about the military<br>who come back and become<br>homeless, and unable to find a<br>job\",\"Lower property taxes.\",\"IF YOU KEEP REWARDING BAD<br>BEHAVIOR AND GIVING HAND OUTS,<br>YOU WILL GET MORE OF IT.\",\"YOUR DUTY IS NOT TO APPEASE THE<br>VOCAL MINORITY, BUT THE CONTENT<br>MAJORITY. FOCUS ON WEALTH<br>CREATION, NOT REGISTRATION.<br>HELP US GROW SO WE CAN BE MORE<br>GENEROUS.\",\"CONTINUE TO IMPROVE AUTOMOBILE<br>ROAD SYSTEM\",\"MAYOR ADLER HAS A GOOD COMMAND<br>OF HIS POST, ATTEMPTS TO BE<br>FAIR AND TRANSPARENT.\",\"PRESERVE OLD AUSTIN, SMALL<br>BUSINESSES AND RESTAURANTS ARE<br>BEING FORCED TO CLOSE DUE TO<br>TAXES.\",\"BECOMING A CITY OF HAVE AND<br>HAVE NOTS\",\"RESIGN\",\"YOUR LESSENING LAWS AND<br>SUPPORTING THE HOMELESS WILL<br>ONLY BRING MORE HERE.\",\"CONTINUE POSITIVE WORK TO HELP<br>HOMELESS\",\"TREAT ALL PEOPLE FAIRLY,<br>AFFORDABLE HOUSING\",\"WE NEED A RENOVATED CODE.\",\"TRANSPORTATION INFRASTRUCTURE<br>THAT PROVIDES ALTERNATIVES TO<br>CAR OWNERSHIP HAS A HIGH COST<br>BUT HIGH REWARD.\",\"QUIT LETTING CITY EMPLOYEES GET<br>AWAY WITH UNETHICAL BEHAVIOR.\",\"THE GROVE WAS A MAJOR MISS BY<br>THE CITY. BUY LAND FOR PARKS.\",\"BUILD MORE ROADS\",\"LOOK AFTER LEAST FORTUNATE\",\"FOCUS ON PROVIDING SERVICES TO<br>THE HOMELESS.\",\"HOMELESS\",\"EXPAND LIGHT RAIL SERVICE\",\"STOP TURNING ROADS INTO TOLL<br>ROADS. ROADS WERE INSTALLED AND<br>REPAIRED USING TAX DOLLARS. I<br>SHOULDN'T BE CHARGED AGAIN TO<br>USE THEM\",\"fix our roads\",\"PUT RESOURCES NORTHEAST.\",\"TRAFFIC CONGESTION,<br>HOMELESSNESS\",\"KEEP UP GOOD WORK\",\"CODE ENFORCEMENT IS ROUGH\",\"SOME SEGMENTS OF SOCIETY GET<br>MORE ATTENTION, RESPECT ALL<br>BELIEFS. HEAR AND RESPECT ALL<br>VOICES.\",\"MANAGE GROWTH-DON'T HIDE FROM<br>IT\",\"GET AN EFFECTIVE BUS SYSTEM<br>BEFORE LIGHT RAIL, AND MAKE<br>SURE THE RAIL GOES WHERE PEOPLE<br>GO.\",\"TAKE CLIMATE EMERGENCY<br>SERIOUSLY.\",\"LOWER PROPERTY TAXES AND COST<br>OF LIVING HERE.\",\"REDUCING RENT SHOULD BE #1<br>PRIORITY. A WHOLE PAYCHECK<br>SHOULD NOT GO TO HOUSING.\",\"GET RID OF THE TRAFFIC PROBLEM,<br>CONTROL IMMIGRATION, COMPLY<br>WITH THE LAW.\",\"LET'S CATCH UP WITH THE GROWTH<br>BEFORE WE EXPAND.\",\"Affordable housing\",\"Less gentrification.\",\"CLEAN UP HOMELESS TRASH, KEEP<br>CHILDREN IN NEIGHBORHOOD<br>SCHOOLS\",\"PROPERTY TAX SHOULD NOT GO UP 8<br>PERCENT A YEAR, EVERY SINGLE<br>YEAR.\",\"LACK OF VIABLE OPTIONS FOR<br>CHILDCARE\",\"Traffic\",\"Affordable housing\",\"DO MORE TO ENCOURAGE AND<br>FACILITATE TRANSPORTATION.\",\"Do not allow homeless to pitch<br>tents downtown. We are looking<br>like California.\",\"RETURN OLDER NEIGHBORHOODS<br>INTEGRITY. ALLOW INFILL WITHOUT<br>TEAR DOWNS.\",\"Spread density to areas outside<br>the central city. Send some of<br>that density to other areas.\",\"Please fix I-35, and fix\/expand<br>the light rail.\",\"Get the homeless-situation<br>under control! W\/o blowing tax<br>dollars\",\"A LOT OF NEIGHBORHOODS ARE NOT<br>SAFE.\",\"REDUCE TRAFFIC CONGESTION\",\"Fix the highway congestion.<br>Figure it out!\",\"As a white(elderly) woman, I am<br>terrified of our police<br>department. Can you imagine how<br>a person of color feels?\",\"Plan for greater urban density<br>and more public transportation.\",\"Stop giving big companies tax<br>breaks. They need to help with<br>the roads and schools before<br>they build. Austin is growing<br>too fast! Watch the documentary<br>\\\"Seattle is dying\\\" and learn<br>from them.\",\"I love Austin and love living<br>here. The only concern is the<br>amount of traffic.\",\"Better public transportation<br>please!\",\"REDUCE PROPERTY TAXES, STOP<br>REDUNDANT SERVICES, REDUCE THE<br>CITY'S CONTROL AND MANDATE OVER<br>PERSONAL CHOICES.\",\"Homelessness is a disaster. Get<br>them off the street.\",\"TRAFFIC\/PUBLIC TRANSIT\",\"INCREASE FOCUS ON MENTAL HEALTH<br>AND EDUCATION SERVICES.\",\"Traffic Traffic\",\"More and more frequent public<br>transportation, make it free.<br>get one person cars off road.<br>stop building toll roads\",\"I DO NOT CRIMINALIZE THE<br>HOMELESS BUT DO NOT BELIEVE<br>THEY SHOULD BE ALLOWED TO CAMP<br>AND PANHANDLE ON CITY PROPERTY.\",\"master plan the city growth.<br>don't just let it happen. it<br>wont become the city that it<br>could be without it. expand<br>metro rail\",\"PLEASE DON'T SCREW OVER OUR OLD<br>NEIGHBORHOODS WITH THE NEXT<br>ATTEMPT AT A CODE REWRITE.\",\"The homeless problem is<br>overwhelming for everyone. We<br>MUST find solutions!\",\"Find a way to keep Austin<br>affordable or we will all be<br>moving to the suburbs.\",\"WE NEED TO SUPPORT THE PUBLIC<br>SCHOOL SYSTEM.\",\"Make Taco Tuesday a city law!\",\"Please reverse course in making<br>us a sanctuary city. Enforce<br>the law\",\"fix traffic congestion\",\"More rail options. move off<br>leash dog option on east side.<br>faster buses, more diversity in<br>jobs\",\"WE NEED IMPROVED MASS TRANSIT<br>AND BIKE LANES. PERHAPS<br>BUILDING SKY WAYS DOWNTOWN<br>WOULD REMOVE FOOT TRAFFIC AND<br>ALLOW FOR MORE FLUID BUS<br>ROUTES.\",\"Need solution for homeless<br>problem.\",\"Get serious about shredding car<br>dependence. Enforce traffic<br>laws. Invest more in other<br>modes. Land use that is based<br>on walking and public transit.\",\"Why are city buses so empty?<br>who really used the expensive<br>downtown library. Be more<br>conservative\",\"Make developers and large<br>corporations pay their fair<br>share to support Austin.\",\"Taxpayer rights should be<br>considered. We do not want to<br>go the way of San Francisco or<br>Seattle in terms of the<br>homeless situation.\",\"Need better transportation<br>planning. Street lighting is<br>also very important. How can an<br>HOA have control over city<br>street lighting?\",\"WE HAVE MAJOR TRANSPORTATION<br>ISSUES. WE NEED ROADS AND LANES<br>ADDED FOR CARS. AS MUCH AS WE<br>WOULD LOVE TO HAVE AS TRAIN<br>THAT PICKS US UP AT OUR DOOR.\",\"Homelessness is an issue.<br>Sidewalk camping is bad. This<br>must stop\",\"LET'S GET SERIOUS ABOUT SOLVING<br>THE HOMELESS PROBLEM.\",\"INVEST IN INFRASTRUCTURE WHICH<br>SERVES AS THE BACKBONE OF A<br>STRONG COMMUNITY AND ECONOMIC<br>POWERHOUSE. TRANSPORTATION<br>NETWORK IN AUSTIN NEEDS<br>IMPROVEMENTS.\",\"WE NEED A NATIONAL ID TO ALLOW<br>COORDINATION AT ALL HEALTH<br>HUMAN SERVICES HOUSING WELFARE<br>WORK FARE,VOTING ETC.\",\"APPRECIATE YOU'RE HARD WORK.<br>YOU DO A GOOD JOB OF WORKING<br>WITH CITY COUNCIL RESIDENTS AND<br>BUSINESSES.\",\"Reduce property taxes.\",\"Housing prices.\",\"Preserve and protect the human<br>rights of women, LGBTQ. and<br>minorities.\",\"THE BIGGEST IMPROVEMENT TO<br>AUSTIN IS THE NEW BIKE LANES<br>KEEP THAT UP AND ALSO WE NEED<br>THE LIGHT RAIL.\",\"QUALITY OF LIFE FOR RESIDENTS<br>BEFORE BUSINESSES COMING TO<br>TOWN.\",\"TOO EXPENSIVE, HOMELESSNESS IS<br>GETTING OUT OF CONTROL.\",\"Take out bonds, we need mass<br>transit!\",\"The city of Austin is an<br>incredible place to live but,<br>more needs to be done to<br>protect the character of the<br>city.\",\"CONVINCE MORE EMPLOYEES TO TELE<br>WORK TO GET DRIVERS OFF THE<br>ROADS.\",\"WE ARE GENTRIFYING MORE AND<br>MORE AND OVERPOPULATED.<br>HOMELESS SITUATION IS OUT OF<br>CONTROL, TRASH ALONG BEN WHIT<br>IS RIDICULOUS.\",\"THE FABRIC OF AUSTIN IS<br>UNRAVELING.\",\"CONTINUE TO IMPROVE NON-CAR<br>TRANSIT OPTIONS.\",\"HOUSING COSTS ARE OUT OF<br>CONTROL. IN MY WORKING CLASS<br>NEIGHBORHOOD, 800 SQ FT HOMES<br>ARE BEING REPLACED WITH<br>BEHEMOTHS LISTED AT 650,000.\",\"THE CITY NEEDS INCREASED<br>DENSITY AND TRAINS, NOT ROADS.\",\"Slow down development. The city<br>cannot keep up with the current<br>rate of growth without<br>negatively impacting Austin's<br>culture and quality of life.\",\"Utility rates, property taxes<br>and transportation need the<br>most attention.\",\"Abandon CodeNext-it is not<br>fair. Lower property taxes.\",\"Make housing more affordable<br>for first time home buyers.<br>Work on schools.\",\"PLEASE KEEP WORKING ON MAJOR<br>ROADWAYS TURN LANES EXPANDED<br>LANES BRIDGES OVERPASSES KEEP<br>US MOVING.\",\"City needs to adopt a master<br>development plan focused on<br>increasing density with fewer<br>height and setback restrictions<br>and with limited neighborhood<br>influence\/control, in the<br>neighborhoods around downtown.\",\"Solve the homeless issue. Do<br>not let them camp, shelter in<br>place anywhere. Enforce the<br>laws not by eliminating-unsafe<br>conditions.\",\"NO MORE TOLL ROADS\",\"I FILL REALLY PROUD TO LIVE IN<br>TEXAS FIRST FREEDOM CITY AND<br>HOPE AUSTIN CONTINUES TO BE<br>GUIDED BY THOSE CITY COUNCIL<br>RESOLUTIONS AND TO BE<br>RESPONSIVE TO FEEDBACK.\",\"Engage and listen to the people<br>more.\",\"THE HOMELESS ARE SETTING UP<br>TENTS AND LITTERING UP OUR<br>PUBLIC PLACES.\",\"GIVE PRIORITY TO PUBLIC SAFETY<br>AND TRAFFIC MANAGEMENT.\",\"Affordable housing for us. We<br>would like to be first time<br>home buyers but it is<br>difficult. Affordable housing<br>with good schools.\",\"Quit giving away revenue<br>generating property, let<br>business pay for their share of<br>the use off the. City. Stop<br>running a human rights org. Run<br>the. City instead.\",\"Infrastructure and Austin<br>energy improvements.\",\"The number of homeless has<br>increased drastically, and more<br>tent cities are publicly<br>seen(Hwy 290 at South 1st<br>Street as an example. Austin is<br>becoming unsafe to live in.\",\"Improve traffic flow.\",\"Fix Traffic\",\"Not happy that Austin is a<br>sanctuary city or with the<br>direction he is going regarding<br>the homeless.\",\"Better customer service with<br>Austin utilities.\",\"Please be a leader and not a<br>manager.\",\"It seems to be getting too<br>expensive\",\"Change city code to make<br>housing more affordable\",\"KEEP IT WEIRD, INCLUSIVE, AND<br>DIVERSE. WE ARE IN A HUGE TECH<br>BUBBLE, WHAT WILL HAPPEN WHEN<br>WE HAVE THOUSANDS OF TECH<br>WORKERS LAID OFF?\",\"THANK YOU FOR SUPPORTING SOCCER\",\"FOCUS ON GETTING SERVICE RIGHT<br>THE FIRST TIME\",\"Please show the those people<br>have lived in the Austin area<br>for much of their lives that<br>you care as much, if not more,<br>for their lives and well-being<br>than potential newcomers from<br>out of state. Get a handle<br>these property taxes.\",\"Diversify the economy beyond<br>tech and stop the<br>gentrification by technology<br>companies and their wealthy<br>relocated employees. Honorable<br>mention : We need a Major<br>crackdown on panhandling that<br>occurs on corners and in the<br>roadway ; it is dangerous,<br>causing accidents and<br>obstructing traffic flow.\",\"I love this city, but there's a<br>lot of work to do\",\"Give the support needed to APD<br>to help them do this most<br>difficult job. They are too<br>shorthanded and need to have<br>the additional Officers<br>approved to be at full staff<br>for a city the size of Austin.<br>They also need support to<br>repair their main headquarters.\",\"Y'all are doing great! Please<br>keep trying on progressive<br>issues and local control of<br>issues, like the one-use<br>plastic bag ban and Sick Leave<br>benefits requirement. Your<br>efforts are seen and<br>appreciated. People still<br>sometimes use re-useable bags<br>even if not mandatory, and that<br>happened because the City of<br>Austin had banned the one-use<br>bags, for as long as the State<br>allowed it...\",\"Solve the traffic issues\",\"Let's give out tents and let<br>the homeless live in your<br>neighborhood Mr. Adler.\",\"fix the roads and traffic\",\"Easier and Cheaper process with<br>small NON Developer projects<br>for City Residents doing small<br>residential changes.\",\"I have invested in solar power<br>for my home, and, on average,<br>produce slightly more than I<br>use. I would like to be able to<br>use that credit to pay for<br>other city utility services<br>(water, wastewater, etc.).\",\"tackle the homeless problem. It<br>can make Austin, unattractive<br>and unlivable. end pan handling<br>and provide more services and<br>housing for the homeless.\",\"Reduce property taxes.\",\"Expand the roads if you can.<br>Services are doing great.\",\"Do something about the homeless<br>living on our streets and under<br>bridges!!!!!!!!!!!!!\",\"Too many questions and I have<br>got to get to bed. Didn't<br>realize how long this would<br>take. This questions is kind of<br>a joke.\",\"I would like to have more<br>reasonable property taxes and<br>more public transportation<br>options.\",\"I WOULD LIKE TO SEE SERVICES<br>FOR THE POOR BUNDLED IN ONE<br>LOCATION FOR THOSE WITH NO<br>MONEY AND DEPENDENT ON THE BUS<br>SYSTEM: GETTING YOUR ID, MENTAL<br>HEALTH CARE, FREE FOOD, JOB<br>TRAINING INFO, HEALTH<br>CARE-THESE ARE SPREAD OUT ALL<br>OVER AUSTIN\",\"PLEASE MAKE TRAFFIC BETTER\",\"City pools should open earlier<br>and close later in the year.<br>Make possession of marijuana a<br>civil offense\",\"ANY EFFORT TO ADDRESS HOUSING<br>AND TRANSPORTATION IS A MUST TO<br>PRESERVE QUALITY OF LIFE.\",\"Try Harder\",\"Improve the traffic situation\",\"More help for the homeless,<br>build tiny homes and give them<br>away. Better mental health and<br>addiction services for<br>homeless.\",\"There is a LOT of good in this<br>city and corporations and<br>developers make a lot of money<br>here - they can afford to<br>contribute a bit more than they<br>do to make sure that Austin is<br>for all, not just the wealthy.\",\"I love this city. I was born<br>here. I think our leaders over<br>spend and make bad decisions<br>about the way our tax dollars<br>are used. I would hope that<br>budget wastefulness could be<br>addressed and some of the<br>burden could be taken off the<br>shoulders of property owners in<br>this city. Things could be<br>addressed in a more modest way.<br>Or maybe I should rent out my<br>house and go live in that super<br>nice REI tent (complete<br>w\/mountain bikes) under the<br>Airport\/I35 overpass. This is<br>ok? Really?\",\"Please retain the weird old<br>timey Austin , and support the<br>creative class through<br>innovative policies and<br>subsidized housing. They are<br>the a primary reason tourists<br>come.\",\"Provide the citizens with<br>better options to commute<br>to\/from work and expand the<br>bike path and trail system.\",\"I would like to know if there<br>is a plan for the homeless?\",\"The mayor Needs to broker a<br>deal between Milestone and the<br>Four Points area before the<br>city council approves<br>ridiculous SF6 rezoning at the<br>end of a residential street<br>(Milky Way) that will endanger<br>lives with fire issues (think<br>Steiner Ranch Fire). It needs<br>to follow subdivision rules set<br>by city of Austin but Milestone<br>is circumventing the set<br>subdivision rules. Need them<br>enforced- Thanks!\",\"I believe in political<br>correctness, but I feel that<br>the mayor and council should be<br>more focused on the majority of<br>our citizens.\",\"Fix property taxes so people<br>don't lose is heir homes to<br>gentrification.\",\"Please get these north freeways<br>working from north to south so<br>that traffic flows and there is<br>no backup. I think there should<br>be speed limit on the freeways<br>for people not driving fast<br>enough. Some other cities have<br>a speed limit that if going to<br>slow you get a ticket. 40 miles<br>is the limit that people should<br>not go under. These people<br>going 30 miles an hour is not<br>safe.\",\"Allowing the homeless camps was<br>a mistake. You should have had<br>a better plan or response<br>before implementation.\",\"WHERE IS THE HOMELESS<br>POPULATION PLAN?\",\"COST OF HOUSING IS<br>UNSUSTAINABLE, TERRIBLE<br>COMMUTER TRAFFIC\",\"FIX AFFORDABLE HOUSING\",\"HOMELESS POPULATION IS SCARY TO<br>RESIDENTS. MANY ARE AGGRESSIVE<br>AND ON DRUGS.\",\"THE POLICE ARE BULLIES.\",\"IT IS EXTREMELY DIFFICULT FOR A<br>PAIR OF TEACHERS TO RAISE A<br>FAMILY AND LIVE NEAR PLACES OF<br>WORK IN AUSTIN.\",\"THERE IS NO BOHEMIAN SECTION OF<br>AUSTIN, IT MAKES ME SAD.\",\"INSTITUTE HOV LANES RATHER THAN<br>TOLL ROADS LIKE PHOENIX AND<br>SEATTLE.\",\"I love living here! But please<br>fix the traffic and the<br>potholes.\",\"Add trains on more routes\",\"Slow down the amount of<br>industry coming to Austin to<br>help save our resources\",\"I am proud to be a resident of<br>Austin. There may be areas that<br>need improvement but I feel our<br>city is always looking to<br>improve.\",\"DO NOT MAKE THE SAME MISTAKES<br>OF SAN FRANCISCO LOS ANGELES<br>AND NEW YORK CITY REGARDING<br>HOMELESS POPULATION AND<br>ENCAMPMENTS. RESERVE RECENT<br>CHANGES MADE BY CITY COUNCIL<br>REGARDING HOMELESS ORDINANCES.\",\"KEEP ON KEEPING ON\",\"As a lifetime educator, I find<br>it incredibly difficult to<br>afford to live in Austin.<br>Property taxes are ridiculous!\",\"Transportation plans for<br>multi-modal integrated options.<br>Homeless-I know the mayor is<br>looking to find a solution.\",\"Please make it a priority to<br>keep Austin no kill\",\"The brushy pick-up is a<br>valuable service to DIY<br>homeowners who need to clear<br>out vegetation in their yards.<br>Thank you for providing this<br>service!\",\"MY YEARLY INCOME IS 53,000.IT<br>IS NOT GOING UP MUCH. PLEASE,<br>STOP RAISING PROPERTY TAXES FOR<br>PEOPLE THAT MAKE LESS THAN<br>80,000 A YEAR.\",\"BETTER CUSTOMER SERVICE WITH<br>TEXAS GAS. GAS WAS SETUP AT APT<br>ON MOVE LIKE REQUESTED AND<br>APPOINTMENT FOR FOLLOWING SETUP<br>WERE NOT FULFILLED BY<br>COMPANY-TOOK 1 WEEK FOR SETUP\",\"Disgusting to see the number of<br>tents under bridges\",\"PROVIDE HOUSING FOR MUSICIANS\",\"AFFORDABLE HOUSING AND<br>AFFORDABLE MENTAL HEALTH CARE.\",\"I WANT TO BE ABLE TO PARK A<br>BOAT IN MY DRIVEWAY OR A<br>TRAILER FOR WORK.\",\"crack down on homeless. radical<br>traffic changes, ban single<br>person cars. clean up litter<br>and trash.\",\"I WISH I FELT MORE CONNECTED\",\"Come up with some reasonable<br>solution for the homeless and<br>less fortunate ASAP. Quit<br>talking it to death\",\"RAISE TAXES ON PEOPLE THAT MAKE<br>MORE THAN 120 K A YEAR.\",\"Be transparent in all dealings<br>and decisions. You work for the<br>taxpayers.\",\"THE COST OFBIKE LANES IS<br>EXCESSIVE RELATIVE TO COST. I<br>USE THE LANE AND THERE IS VERY<br>LITTLE TRAFFIC ON THEM.\",\"LAND AND TRANSPORTATION DO NOT<br>SUPPORT GROWTH. IT WAS NEVER<br>MEANT TO BE A BIG CITY.\",\"LONG TERM PLANNING FOR<br>HIGHWAYS, ENERGY AND<br>CONSERVATION PROGRAMS,<br>RECYCLING WEEK.\",\"BUILD THE RAIL SYSTEM TO THE<br>AIRPORT.\",\"WORK ON RELIEVING TRAFFIC WOES<br>NOW IT WILL ONLY GET WORSE WITH<br>OUR RISING POPULATION.\",\"Stop the new homeless camping!\",\"I think current mayor and<br>council are doing a great job.\",\"FIX UP OUR ROADS AND CLEAN<br>AFTER MAJOR CONSTRUCTION.\",\"STAND STRONG AGAINST STATE'S<br>ENCROACHING ON LOCAL CONTROL.\",\"HIGHER CULTURE FOR OVER 50'S.\",\"I am overwhelmed by the amount<br>of panhandling, vagrancy and<br>homelessness in Austin. I<br>believe there is a place for<br>everyone in Austin. When<br>expectations are set for<br>behavior and opportunities are<br>aligned with appropriate<br>community services (housing,<br>mental health, job mentorship)<br>only then can you truly move<br>forward in creating a cultural<br>and socioeconomic inclusive<br>environment that is the<br>hallmark of any great city.<br>When families and the community<br>at large no longer feels safe<br>visiting the cultural center of<br>the city, that community begins<br>to die from the inside out -<br>with people seeking safer and<br>cheaper neighborhoods in an<br>increasingly distant ring<br>around the city center,<br>building farther and farther<br>away with each new housing<br>opportunity. There is a visible<br>disconnect between<br>understanding what the problems<br>are that create this suburban<br>flight and how to appropriately<br>address the challenges with<br>thoughtful, long term,<br>sustainable solutions.\",\"I would like to see the city<br>orient much more of it's<br>activities, particularly in<br>planning and economic<br>development, around equity and,<br>in so doing, articulate a clear<br>notion of equity that will<br>guide decision making.\",\"Cap the property tax rate for<br>seniors (over 65) at rate when<br>they reached 65.\",\"LISTEN MORE TO CITY TECHNICAL<br>STAFF, LESS TO NEIGHBORHOOD<br>ASSOCIATIONS.\",\"Reduce the homeless population\",\"PROPERTY TAXES TOO HIGH\",\"DO NOT USE TAX MONEY TO PAY FOR<br>AFFORDABLE HOUSING.\",\"FIX 1-35 DOWNTOWN\",\"KEEP IMPROVING AISD.\",\"The home less should not be<br>allowed to live along streets<br>or in parks.\",\"Stop catering to minorities<br>such as the homeless etc. and<br>focus on the needs of the<br>community as a whole. We are<br>the ones that put you there, so<br>represent us.\",\"More affordable housing\",\"Bury I-35\",\"MADE US PROUD WHEN HE<br>INTRODUCED MAYOR PETE. HIS<br>SPEECH WAS AWESOME.\",\"I have already written the<br>mayor about my major problem.<br>We have an aggressive homeless<br>person staying in my<br>neighborhood who is threatening<br>senior citizens, gays and<br>children and we are unable to<br>get him removed.\",\"CLEAN UP THE MONTOPOLIS<br>NEIGHBORHOOD.\",\"IT HAS BECOME IMPOSSIBLE UNLESS<br>ONE IS QUITE WELL OFF<br>FINANCIALLY. I HAVE LIVED IN<br>AUSTIN FOR OVER 40 YEARS-ALL MY<br>ADULT LIFE- BUT WILL SOON LEAVE<br>AS I CAN NEVER HOPE TO RETIRE<br>HERE. SAD\",\"DIVERSITY; TRANSPORTATION;<br>AFFORDABLE HOUSING\",\"WE NEED MORE INFRASTRUCTURE FOR<br>TRANSPORTATION SERVICES DUE TO<br>THE OVERGROWTH IN POPULATION\",\"TAXES ARE TOO HIGH\",\"Expand your vision in<br>supporting conservative<br>business growth and limit<br>reaction to liberal causes of<br>few.\",\"Help people with taxes that<br>earn less than 50,000 a year\",\"Fix the traffic\",\"AUSTIN DID NOT PLAN FOR TRAFFIC\",\"HOMELESS SITUATION IS<br>DESTROYING OUR CITY. MAYOR<br>ADLER HAS RUINED MY CITY.\",\"GET RID OF SCOOTERS.\",\"Quit giving tax breaks and fee<br>waivers to companies to entice<br>them to move to Austin.\",\"Focus on core services like<br>streets, parks, libraries, and<br>utilities. Please stop focusing<br>on non-core services like child<br>care, food, and housing. The<br>city spends too much time on<br>dialog and civic engagement,<br>residents have already told you<br>what we want, please stop<br>asking and start doing.\",\"OFFER MORE AND COMPREHENSIVE<br>BUS SERVICES THROUGHOUT<br>NEIGHBORHOODS\",\"RECENT CHANGES REGARDING THE<br>HOMELESS POPULATION WILL<br>GREATLY AFFECT THE BUSINESSES<br>IN A NEGATIVE WAY.\",\"your doing a poor job start<br>with getting read of all<br>deadbolts that drain owner city\",\"we need to crack down on the<br>homeless pan handling bums or<br>we're gonna turn into san<br>francisco\",\"The overall level of safety is<br>appreciated. I wish the growth<br>was better planned. It is sad<br>to have buildings taking over<br>shopping areas and recreational<br>areas.\",\"We need more housing and better<br>transportation ASAP!\",\"HOMELESS NEED A COMPREHENSIVE<br>PLAN. PUBLIC CAMPING IS A BAD<br>IDEA.\",\"Mopac still sucks - too many<br>people moving here- plan for<br>more growth\",\"Please get rid of the scooters!<br>Please change the law back to<br>keep homeless off the<br>sidewalks. They need their own<br>place to live.\",\"Continue to march in the same<br>path. Don't give in to moneyed<br>interests at states or national<br>level.\",\"do not be dismissive of<br>opinions you do not personally<br>agree with. Your job is to<br>serve all citizens.\",\"would love if Austin could get<br>a rail system that linked the<br>city and the airport\",\"We need to be aware of the<br>impact of development on the<br>city. City is not taking<br>advantage of the fact that<br>people want to live and work<br>here. We need to say no to<br>luxury apartments and demand<br>more affordable housing units.\",\"WE need a plan to ensure<br>facilities keep up with the<br>speed at which we are growing.<br>Traffic is unbearable.\",\"Affordability is key (in<br>Housing, Transportation,<br>healthcare and essential city<br>services)\",\"Deal with the homeless<br>situation.\",\"Improve lighting in residential<br>areas around UT Austin\",\"Code next was a disaster. Do<br>not destroy old neighborhoods<br>by increasing density\",\"Traffic\",\"Rethink the homeless camping<br>ordice. We really don't need to<br>become another Seattle.\",\"VERY UNHAPPY WITH THE GROWTH<br>DEVELOPMENT OF AUSTIN. TOO<br>EXPENSIVE AND POOR PLANNING FOR<br>GROWTH.\",\"WHY TAXED OUT OF MY OWN HOME?\",\"code enforcement should be VERY<br>responsive to residents<br>concerns.\",\"HELP WITH TRAFFIC, REPLACE 29TH<br>ST.\",\"Traffic is a problem\",\"PUT SPEED BUMPS ON MY STREET<br>COPPERFIELD DR 78753\",\"FOCUS EFFORTS AWAY FROM<br>TERRYTOWN, FIX PUBLIC ROADS,<br>AND PLEASE CUT IT OUT WITH THE<br>TOLL ROADS.\",\"CITY WIDE WALK\",\"Please continue to improve bike<br>lanes so we can commute safely<br>and keep our cars at home.\",\"The homeless situation and the<br>ordices. Transparency and real<br>communication with citizens.<br>Austin is a swamp now. Hate it<br>that I have homeless people<br>surrounding my home. You will<br>go down as the worst mayor. You<br>are an idiot.\",\"I would love to see a light<br>rail system from Southwest<br>Austin to Downtown (actually<br>throughout the city.)\",\"Quit giving tax breaks to large<br>corporations who move here.<br>Companies that want to move<br>here will do so without the tax<br>breaks and those that don't<br>shouldn't move here. It's a<br>disservice to residents to tell<br>them there's a COA budget<br>downfall (meaning closing pools<br>and decreasing other city<br>services) while at the same<br>time giving out tax breaks to<br>billion-dollar corporations.\",\"More parks\/pools\/bike lanes\/rec<br>programs in SW Austin!\",\"BE MORE THOUGHTFUL WITH ROAD<br>AND TRAFFIC CONTROL.\",\"FIX I 35. SCHOOL ZONES NEED<br>MORE POLICING.\",\"MOST CONCERNED WITH BEING ABLE<br>TO STAY IN MY HOME OF 40 YEARS.\",\"Traffic improvement.\",\"The way they handled the<br>homeless camping ordice was<br>awful - pretty sneaky\",\"BE SURE ALL COA IT SYSTEMS ARE<br>PREPARED TO DEAL WITH<br>RANSOMWARE AND OTHER CYBER<br>THREATS. I AM CONCERNED THAT<br>COA IS NOT NOW. CONSIDER<br>RE-ORGANIZING THE SECURITY<br>GROUPS AND ALL COA IT SERVICES<br>TO STRENGTHEN IT SECURITY. COA<br>LACKS A SECURITY OPERATOR<br>CENTER.\",\"Wish we had better public<br>transportation, metrorail would<br>access other parts of town\",\"Figure out transportation<br>options for getting to and from<br>the airport, work and home.<br>Sitting in hours of traffic<br>everyday is soul crushing.\",\"QUIT SPENDING SO MUCH MONEY AND<br>TAXING US TO DEATH. YOU COWER<br>TO EVERY MINORITY AND HAVE<br>SPECIAL PROGRAMS FOR JUST A<br>FEW.\",\"IT IS GETTING TOO EXPENSIVE TO<br>LIVE IN AUSTIN, QUALITY OF LIFE<br>HAS DECLINED.\",\"Do SOMETHING about the<br>homeless, public camping, etc.<br>Austin is well on its way to<br>becoming the next LA or San<br>Francisco!\",\"clean up the homeless situation\",\"Since you will not change, do<br>not run again.\",\"Get the homeless off the<br>street. Give the drug addicts<br>rehab. Any old or disabled,<br>provide housing.\",\"You have a thankless job and I<br>believe you are trying. State,<br>national and local politics and<br>the influence of big money,<br>however, seem to be thwarting<br>many good efforts. I see the<br>bureaucracy of the city, as an<br>organization, being pretty<br>dysfunctional. Fiefdoms exist<br>and many Department managers<br>and leaders seem to be closed<br>to meaningful change. I believe<br>that your performance<br>management systems are<br>ineffective and HR is driven<br>more by fear of lawsuits than<br>by common sense.\",\"tone of the civic conversation<br>in Austin has deteriorated; I<br>hear more negative comments<br>about the city than in the<br>past; my personal interaction<br>with city government less<br>satisfactory - less<br>transparency, difficult to get<br>the information you want vs<br>prepared presentations that<br>city wants to provide\",\"let social services and private<br>sector deal with the homeless.<br>take back control of public<br>spaces and streets eliminate<br>street solicitation get them<br>out of the intersections.<br>homeless are here because of<br>all the freebees. Last week we<br>had visitors from out of the<br>city and all of there comments<br>were that they could not fathom<br>allowing the homeless to camp<br>under the bridges and the vast<br>amount of panhandling.\",\"Public transport and planned,<br>sustainable, affordable growth<br>are the most important issues.\",\"Public transportation is<br>horribly insufficient. My<br>neighborhood sidewalks are<br>falling apart, causing injury<br>to joggers. Not enough<br>lighting. To many car and house<br>break ins since building bridge<br>over little Walnut Creek. Crime<br>is up and another low income<br>housing development is being<br>built in our neighborhood<br>against residents' wishes. This<br>will be the second one in the<br>last few years. Homeless people<br>camping everywhere, makes it<br>dangerous.\",\"Way too many tolls, we will<br>eventually have to pay to get<br>in & out of Austin. No more<br>tolls. Traffic issues as the<br>city grows\",\"find a place for the homeless<br>people to live, ban pan<br>handling and camping in public<br>areas\",\"STOP TURNING AUSTIN INTO<br>CALIFORNIA! Let Austin<br>represent Texas. Erase Keep<br>Austin Weird and change it to<br>what it should have been. Keep<br>Austin Cool\",\"Gun control and background<br>checks\",\"Thanks for caring about the<br>homeless. Have sanitation<br>services clear the garbage that<br>accumulates around the camp<br>sites.\",\"Work on the homeless problem.\",\"Save our historic neighborhoods<br>from overdevelopment\",\"PLEASE CONSIDER MORE STATE<br>FUNDED RECOVERY CENTERS\",\"Please get a hold on the<br>traffic issues and road rage<br>drivers. I'm frightened at<br>times just driving down the<br>road due to other drivers<br>running me off the road,<br>driving erratically and<br>threatening me. It's scary!\",\"Please lower property taxes.<br>Austin is not affordable to<br>honest, hard working citizens.<br>The cost of living is too high.<br>We do not need social programs<br>or special projects. Focus on<br>the infrastructure and public<br>safety.\",\"Homeless and transient<br>population. It is becoming an<br>immense burden on the City of<br>Austin. I have safety concerns.\",\"Don't let the growth of Austin<br>(and the big investment<br>dollars) ruin the spirit of<br>Austin\",\"I love the City, but I wish<br>people would stop moving here.<br>We do not have the<br>infrastructure to support this<br>level of growth, nor is it<br>pleasant to go to<br>events\/shows\/etc. with such<br>large crowds. I'm saddened that<br>so many local businesses<br>(Austin \\\"institutions\\\") are<br>closing due to rent that is too<br>high, or worse, being pushed<br>out by residential apartments<br>or condo complexes.\",\"How do we make housing<br>affordable again?\",\"Watch how the city is growing<br>and keep around places that<br>make Austin what it is. Keep<br>rent affordable for those of us<br>who live and work and are from<br>this city so we don't have to<br>move away and provide services<br>that are also affordable. Also<br>keep it clean and safe.\",\"Help people over businesses<br>with tax breaks for properties.<br>Build more train lines.\",\"Would like to see clean up and<br>the homeless helped, especially<br>at the intersection of Highway<br>35 and US Highway 183 E<br>Anderson Lane. Thank you.\",\"Something needs to be done<br>about the traffic. Our roadways<br>are not equipped to deal with<br>current (and future) traffic<br>loads. It feels like the<br>traffic situation is being<br>created as nothing seems to be<br>happening to relieve the<br>overflow. An extra Toll lane on<br>MoPac? More toll roads? These<br>aren't solving the problem.<br>Additionally, something should<br>be done about blatant traffic<br>light \/ stop sign violations.<br>Daily, I see at least 6 cars<br>blow through the left turn stop<br>light (Northbound Dessau to<br>Westbound Parmer) at every<br>exchange, once was even a fire<br>truck (2 cars followed after<br>it). On 2-lane roads that I<br>take to avoid heavy traffic on<br>my way to work, folks blow<br>through stop signs and pass on<br>double yellow lines<br>consistently. It's frightening.\",\"Traffic is Terrible... Toll<br>Roads are not the Answer...<br>Electric, Water and Sewer Rates<br>need Auditing. If you want to<br>have individual homes reduce<br>water usage\/waste why does<br>Austin take an average of the<br>neighborhood??? I barely use<br>any water in my house and pay<br>for my neighbors usage....\",\"Overall, I enjoy my quality of<br>life in Austin and think it's a<br>great place to call home. I do<br>wish there were some things I<br>could address and would love to<br>be considered for a committee<br>to help change those things.\",\"A living wage for all,<br>affordable health care, keep<br>the streets and common areas<br>clean on east Riverside, this<br>is a well traveled route into<br>Austin from the airport and is<br>one of the first areas our<br>guests see, let's give them a<br>good first impression of<br>A-town.\",\"Property taxes are insane and<br>really hard to afford\",\"Match city growth with<br>infrastructure developments\",\"Please value the needs of the<br>residents, especially middle<br>class and lower income<br>residents, over the affluent<br>and business interests. They<br>can purchase what they need,<br>whether it's private pools,<br>gates, taking Uber all the<br>time, belonging to a country<br>club, etc.. The lower and<br>middle income folks need access<br>to amenities and enrichment to<br>be provided by the city, and to<br>keep a sense of a healthy place<br>to raise a family, we need to<br>preserve affordable home<br>ownership as at least an<br>option.\",\"Easiest solution to traffic is<br>getting folks off the street at<br>the same time so please<br>continue to encourage business<br>and govt. to allow flex<br>schedules, work from home, etc.\",\"If you want the citizens to<br>speak to you, make time to<br>listen even if you have to<br>schedule several days to do so.<br>We make time to speak up on<br>things that are important to<br>us.\",\"Austin cannot sustain it's<br>growth including but limited to<br>inadequate roads, water table,<br>downtown and other cultural<br>area parking and generally<br>overcrowded which is driving<br>out music culture and being<br>un-affordable.\",\"LOWER THE ELECTRIC RATES.\",\"Stop trying to make Austin like<br>Portland or any other city. You<br>should be trying to serve<br>current residents rather that<br>the needs of future prospective<br>residents.\",\"Please control rent prices<br>somehow. I love my<br>neighborhood, but will be<br>priced out of it soon. I would<br>like to be able to live alone<br>as a single woman in my 30s,<br>but am doomed to have roommates<br>forever, even though I have a<br>steady job making more money<br>than I've ever made before. I<br>work hard, I contribute to my<br>community, and I deserve to be<br>able to afford to live in this<br>neighborhood in a rented<br>apartment or house. I'm not<br>asking to live in west lake<br>here. Just the east side.\",\"Great city, but it's sprawling<br>- get rid of the cars and<br>provide pedestrian-friendly<br>environments, improve public<br>transportation.\",\"Lower our property taxes!\",\"Housing affordability. Traffic<br>congestion.\",\"Do your best.\",\"Stop the rise of big government<br>encroaching on individuals.<br>Also, don't run again.\",\"Stop growing areas without road<br>capacity.\",\"Please stop trying to turn<br>Austin into a city in<br>California. Haven't you seen<br>the mess that places like San<br>Francisco and San Diego have in<br>their downtown's?\",\"Don't be wasteful. Quit<br>spending money with no<br>accountability and pretend it's<br>your own money from your bank<br>account that you're spending.<br>Focus on where you are going to<br>put all the people moving here<br>and they will be able to travel<br>on our highways.\",\"Need for high-quality,<br>affordable housing.\",\"PLEASE make urban light rail a<br>reality - we CANNOT rely on<br>CapMetro to decide alone. They<br>are SLOW to adapt. They can't<br>even take CC's at vending<br>machines for Metro-rail. Geez!\",\"FIX THE TERRIBLE TRAFFIC. NEED<br>AFFORDABLE HOUSING. YEARLY TAX<br>HIKES ARE MAKING QUALITY OF<br>LIFE UNSUSTAINABLE.\",\"Thank you for all you do for<br>ALL of Austin's citizens. Your<br>thoughtfulness as Mayor is<br>unparalleled and with more<br>council members that operate<br>like you our city could truly<br>flourish in a responsible and<br>equitable way.\",\"Lower taxes cut social<br>programs, increase<br>transportation\/roads.\",\"Don't let the NIMBYs stop us<br>from having nice things like<br>public transit (light rail),<br>better connected bike and<br>pedestrian systems, and a land<br>development code that supports<br>dense, affordable housing!\",\"We really need better, faster,<br>more reliable public<br>transportation!\",\"housing rates to high\",\"We need to focus on<br>transportation improvements in<br>Austin--which would have<br>downstream effects in<br>affordability, cleanliness,<br>etc. of the city.\",\"IMPROVE TRAFFIC FLOW AROUND<br>TOWN AND ON HIGHWAYS.\",\"Fix the traffic issues on<br>Mopac. Plan for the future not<br>the present. When you plan for<br>the road improvement, plan for<br>what the population will be not<br>what it currently is. It always<br>seems the city is out of date.\",\"Concentrate on providing all 9f<br>Austin with upgrades and<br>maintenance of roads, not just<br>downtown. It seems that more<br>and more of my tax dollars go<br>to improving downtown while we<br>have potholes growing ever<br>bigger in south Austin. Share<br>the wealth man!\",\"Please, for the love of god,<br>ban people from owning roosters<br>within city limits. Chickens<br>are fine, but roosters are the<br>worst.\",\"Please help public school<br>teachers afford to live in the<br>city where they teach. Thank<br>you.\",\"housing affordability needs to<br>be addressed and fixed if<br>Austin is to be a viable city\",\"Put together a mass transit<br>program that makes sense. A<br>light rail system should have<br>routes where the people are,<br>not where we think they will be<br>in 10-15 years. We need<br>immediate relief. That is why<br>these proposals keep getting<br>voted down. Other options<br>should be considered, it's too<br>late and expensive to tunnel<br>for subway, too disruptive to<br>lay rail down on already busy<br>streets. I have been long a<br>proponent of sky link or<br>monorail downtown transforming<br>to in ground track outside of<br>city center. These routes<br>should take pressure off Lamar,<br>Riverside, Mopac, Cesar<br>Chavez\/Fifth Streets, South<br>First, downtown parking needs,<br>and should service the<br>University, the Zilker Park<br>area and capitol complex.\",\"HOMELESS DOWNTOWN ARE IS A<br>PROBLEM. MOVE THE HOMELESS FROM<br>DOWNTOWN.\",\"Possible parking affordability<br>downtown with longer hours.<br>Most street parking is only for<br>3 hours, if you have to work 8<br>hour and have to move your car<br>and find another spot to park<br>because you are not to just<br>feed the meter is very<br>stressful! Most parking garages<br>have a waiting list for monthly<br>parking. Traffic light are to<br>long!!!!! Guadalupe, Congress,<br>1st street is pure torture.\",\"Stop recommending that Austin<br>become a sanctuary city and go<br>back to the Liberal Ivy League<br>area where you came from. In<br>other words, get the hell out<br>of Dodge!\",\"Make our roads safer. Constant<br>traffic accidents, people<br>speeding and running Stop signs<br>even at schools. Living in the<br>NW boundary (Canyon Creek) is<br>no excuse for lack of service<br>such as traffic enforcement.\",\"Need more highway lanes on I-35<br>and Mopac. The toll on Mopac is<br>a joke! Its mostly for out of<br>towners like from RR or<br>Dripping Springs not internal<br>Austin residence. Someone<br>should be fired for not also<br>adding another free lane on<br>Mopac. It already need<br>additional work to support the<br>traffic.\",\"Please slow growth - we are not<br>effectively the size the city<br>is now. Give it time for the<br>services, road system and<br>transportation options to catch<br>up. We do not need a pro Soccer<br>team or bigger entertainment<br>venues, raceways, stadiums. We<br>NEED affordable housing.\",\"Please make all departments<br>more transparent. It is really<br>difficult to get anything done<br>in this city\",\"Permitting process needs work<br>to make it more timely and<br>improve communication.\",\"lower cost of housing and mass<br>transit needed\",\"Please partner with regional<br>municipalities and move forward<br>with the comprehensive light<br>rail\/commuter rail plan that<br>already exists. Let's not<br>continue being the city that's<br>30 years behind in<br>transportation infrastructure.<br>Busses aren't the solution.\",\"Really listen to what the<br>people in all areas of Austin<br>and all backgrounds would like<br>to see for future of Austin\",\"Property Taxes too high. Going<br>to move out of Austin within<br>the next 3 yrs. Homeless all<br>over the Highways making Tent<br>homes and Trash everywhere.<br>Yard Maintenance for our Public<br>Schools... JUST MOW !\",\"Respect the central and east<br>Austin neighborhoods, restrict<br>demolition to uninhabitable<br>buildings and restrict<br>replacement of houses to<br>maximum of two residences per<br>lot and a height of two<br>stories. Preserve parking<br>requirements in order to keep<br>neighborhood streets accessible<br>to emergency vehicles and<br>walkers.\",\"Please improve public<br>transportation so that it is<br>obviously better than sitting<br>in traffic jams.\",\"Please strive to facilitate the<br>process for low and middle<br>income housing and support all<br>efforts for a decent minimum<br>wage, reliable public<br>transportation, affordable<br>child care and early childhood<br>education. Healthy adults are<br>most productive and satisfied<br>citizens when they can put a<br>roof over children's heads and<br>decent food on the table. Since<br>a significant number of adults<br>in this city are NOT MENTALLY<br>HEALTHY, please support<br>adequate mental health services<br>to help us to get there. MOST<br>NOTABLE TOPIC MISSING FROM THIS<br>SURVEY: Homelessness.\",\"Stop wasting $ on social<br>programs and affordable<br>housing.\",\"My utility bills and property<br>taxes are forcing me to sell my<br>house. Too expensive. Also,<br>traffic is a nightmare.<br>Otherwise, Austin is great.\",\"Express lanes on MoPac for<br>South Austin\",\"Stay out of politics such as<br>immigration issues, quit<br>claiming you care about social<br>issues like affordable housing<br>while continuing to allow<br>unaffordable housing to be<br>built downtown so you can<br>collect massive amounts of tax<br>dollars to abuse. If one lives<br>outside the 5 mile radius of<br>downtown, you and the council<br>members don't give a damn about<br>except for their property tax!<br>A 4.1 billion dollar budget is<br>obscene.\",\"Need to better manage the<br>homeless problem.\",\"SW Austin needs more swimming<br>facilities and ways for to get<br>around on a bike.\",\"You are making it impossible<br>for elderly to live in this<br>city. We can't continue to pay<br>your increasing taxes. Why not<br>make every third street for<br>buses and bikes as older people<br>can't walk to bus stops 3<br>blocks away and the roads are<br>horrible to drive on.\",\"Reduce housing taxes.\",\"Take care of the City of Austin<br>business instead of all your<br>national political agenda.\",\"Stop giving tax breaks for<br>companies, and sports teams to<br>move here.\",\"please clean up the streets and<br>sidewalks downtown\",\"Bike lanes are not the answer<br>in theory it sounds great but<br>they are not. There is no way<br>the city can control housing<br>cost that would make a<br>significant impact.\",\"Make sure that the basic needs<br>and necessities of the city and<br>its residents are provided and<br>maintained before spending tax<br>dollars on other things or in<br>other areas that may not be so<br>important. Listen to the people<br>of Austin. You were elected by<br>the people of Austin to serve<br>the people of Austin\",\"Improve diversity efforts<br>(start with affordable housing<br>options)\",\"Tap the breaks on the tax and<br>fee increases. I understand we<br>have to grow but let's<br>prioritize policies and<br>spending a little better. Did<br>we NEED composting? I don't use<br>compost, why do I have to pay<br>for a bin? Am I going to leave<br>Austin because of it, no; but<br>every camel can only take so<br>much straw.\",\"My concerns would be about<br>traffic and the rapid<br>destruction of homes for<br>expensive modern blocks....\",\"Please put bicycle lanes in the<br>Quail Hollow area, such as<br>Braker Lane. Please make<br>pedestrian crosswalks across<br>Braker, Lamar, Metric, etc., so<br>it will be safer to cross.\",\"The employees at City of Austin<br>Tax office need education on<br>customer service. I know the<br>job isn't fun, but when dealing<br>with people they should be kind<br>and empathetic as much as<br>possible. I only saw one person<br>smile the 2 times I was there<br>last month. One manager (Monica<br>Blackwell) treated me like I<br>was no better then the dirt<br>under her shoe when I asked her<br>a question about a policy. Only<br>one person there (another<br>manager) treated me like a<br>human being. He was able to<br>convey bad news without<br>treating me like an idiot on a<br>conveyor line. Classes for City<br>of Austin employees to teach<br>them how to treat people would<br>be an excellent idea.\",\"Please take care of basic<br>services first - utilities,<br>street maintenance, mowing,<br>facilities and park<br>maintenance. Don't waste<br>taxpayers money on travel, etc.\",\"get a new mayor\",\"Get a handle on water and<br>electric billing practices. We<br>get three or four amended bill<br>a month. Why?\",\"Get off left of the daily and<br>be more neutral in political<br>approach. Quit squandering our<br>tax dollars trying to fix<br>things that are not basic<br>public service.\",\"City future planning needs to<br>improve dramatically. Property<br>taxes are single handed lily<br>going to ruin residential and<br>commercial businesses.\",\"Better mass transport. FLOOD<br>control - new flood plane maps<br>should NOT move people into<br>flood planes. Mitigation should<br>fix flooding.\",\"Stop being afraid of these<br>people. They may protest<br>everything but they believe in<br>nothing. Stand your ground and<br>do what's right for everyone<br>not just the people that lie,<br>cheat, and try to bully you<br>into submission.\",\"Provide permanent housing for<br>homeless, especially disabled<br>in any way, along with<br>permanent access to social<br>services near their home,<br>perhaps through mini-house<br>neighborhoods.\",\"Right now I'm REALLY mad at Cap<br>Metro. The bus ran me off the<br>road four months ago and they<br>don't care. We need a<br>City-owned transit system with<br>profits going toward<br>improvement. In general, I am<br>horrified at the flight of the<br>poor (Black and Hispanic)<br>families from Austin. I grew up<br>in segregated Austin, and we're<br>STILL segregated, and becoming<br>more so. Shame, shame, shame.\",\"Better job opportunities for<br>new residents of Austin.\",\"Affordability and<br>transportation\",\"Lower property taxes or a cap<br>because the property values are<br>skyrocketing. Taxes go up every<br>month.\",\"The City Council spends too<br>much.\",\"Build more rail systems around<br>the city.\",\"Don't let the haters get you<br>down, Steve.\",\"Make the downtown area safer.<br>We have too many homeless<br>people downtown and in Austin.<br>I use to work downtown(until<br>2017) and walked on the<br>sidewalks and around the lake<br>and many times I did not feel<br>safe. I had homeless guys<br>follow me several times or yell<br>at me. I do feel sorry for<br>anyone that is homeless but it<br>needs to be cleaned up.\",\"Please improve the traffic flow<br>issues.\",\"Pay attention to our emergency<br>services and personnel, respect<br>them, and support them. Get the<br>police a contract, build the<br>fire stations we need, raise<br>their wages. The city manager<br>could take a pay cut to help<br>that out. One thing I'd like to<br>ASK the mayor is how many of<br>the city council, or Mayor<br>himself, ever rides the bus? or<br>rides a bike? I often wonder,<br>especially when they advocate<br>riding the bus or biking to<br>work and spend so much time<br>trying to get people out of<br>cars and onto other transport.<br>As I noted in a previous<br>answer, I do ride the bus<br>almost daily (and love the<br>Rapid) but it is not practical<br>for many to bus into work or to<br>errands. I also like the Cap<br>Metro services for those<br>elderly or handicapped who<br>can't walk to bus stops.\",\"Please decrease property taxes!\",\"Homelessness is a real<br>issue\/problem that needs to be<br>addressed.\",\"Provide value to the taxpayer<br>by keeping the city safe and<br>clean. Thank you for bringing<br>an MLS team to Austin and<br>hopefully you will consider<br>other major sports teams as<br>well in the future.\",\"I wish the City still felt<br>welcoming to it's residents.\",\"Austin needs a well planned<br>efficient mass transit system<br>other than buses to accommodate<br>the huge increase in<br>population.\",\"Because of its costly<br>inefficiency, the Planning and<br>Zoning Department needs to be<br>audited immediately. Raising<br>fees is NOT the answer and goes<br>completely against the Mayor's<br>expressed desire for<br>affordability. Hiring capable<br>people is the answer. Clearly,<br>Austin would benefit from<br>contracting with large<br>engineering firms who would be<br>more efficiently. Private<br>companies have a vested<br>interest in providing fast,<br>quality service. City<br>bureaucracies are notoriously<br>slow and inefficient, and their<br>dissatisfied customers can<br>either like it or lump it.\",\"Please do all you can to<br>improve, keep strong, the<br>relationship between law<br>enforcement and our minority<br>communities - make changes to<br>protect those who live in our<br>older, but now sought for<br>property - do not tax these<br>people OUT of our city!!!\",\"do something to improve public<br>transportation\",\"I encourage density and<br>avoiding sprawl but I don't see<br>the infrastructure or strategy<br>to support it. The bus route<br>changes actually turned out<br>worse for me and I stopped<br>riding the bus, the<br>construction doesn't seem to be<br>strategic and there are<br>multiple buildings being built<br>on one stretch of road leading<br>me to drive through one<br>construction site after another<br>- it doesn't feel like a<br>pleasant city to live in when<br>you feel like you live in a<br>construction site... It feels<br>like buildings are evaluated<br>case by case without thinking<br>about other things that are<br>going on in the neighborhood. A<br>very large condo building (300+<br>units) is going up right where<br>a bus stop USED to be - and now<br>the new bus stop is a 10-12min<br>walk away. I imagine residents<br>may have used that bus stop if<br>it had stayed there...\",\"hold people responsible for<br>their areas of responsibility.<br>if they fail to meet<br>expectations, there should be<br>financial penalties,<br>suspensions or loss of<br>employment.\",\"Enforce rules against<br>aggressive panhandlers. I have<br>written Mayor Adler about this<br>two times and did not receive a<br>reply.\",\"Stick to the core services ,<br>issues and cease unauthorized<br>pursuit of too many issues that<br>should not be involved. balance<br>the budget as the state of<br>Texas must do without raising<br>fees and taxes. Runs the city<br>finances and issues as I do my<br>own business and family not<br>pursuing pipe dreams and<br>misguided issues.\",\"More garbage pick up at my<br>apartment. Keep avenue g pool<br>open during summer. Reduce<br>driving speed and crossing of<br>all lanes in short order. More<br>pedestrian awareness. Less<br>accidents especially avoidable<br>ones, which almost all<br>accidents are.\",\"I LOVE our new library<br>downtown, and I LOVE that the<br>city picks up my compost! Two<br>great things from the city in<br>the past year!!! I hope the<br>city can continue to stay true<br>to our character with no<br>plastic bags polluting our<br>water, no driving with cell<br>phones, and with our police<br>force keeping trust with<br>undocumented residents!! I hope<br>Bull Creek can be cleaned up so<br>I can swim there with my kids<br>again carefree!\",\"SIDEWALKS AND STREETS ARE<br>SOMETHING CITY SHOULD PROVIDE.\",\"Fix roads, be transparent,<br>control spending, pay down bond<br>obligations, think like this is<br>a town who is 35 and needs to<br>stop acting like a 23 year with<br>his parents diners club card.\",\"Develop a comprehensive plan to<br>govern the City. Why do we let<br>the City staffers determine how<br>this city is run? Let's elect a<br>Mayor who has a personality!\",\"Lower Energy costs. Because<br>Austin is a giving community<br>there are more homeless here.<br>Better management of the<br>homeless population. Move ARCH<br>facilities from downtown<br>location.\",\"Maintain basic services and<br>quit wasting time on issues you<br>have no authority.\",\"Will someone have to die before<br>we regulate scooters downtown?\",\"Traffic signal system could be<br>much better (i.e., automated to<br>respond to congestion in<br>certain directions, but less<br>congestion in others, etc. . .<br>. respond to the vehicle<br>numbers at intersections and on<br>streets . . . that technology<br>is available).\",\"I am interested in having lots<br>of really great future<br>neighbors and friends here in<br>Austin. In order for that to<br>happen we need to focus on our<br>schools. I know the city shies<br>away from dealing with AISD but<br>we may need to start a<br>conversation soon. Our special<br>education aids that work<br>directly with all of our<br>mentally and physically<br>impaired children make less per<br>hour than our lifeguards at our<br>city pools. Neither of which<br>are a living wage. Teachers are<br>paid less than retail store<br>managers. By ignoring this<br>problem we are screwing<br>ourselves in the long run. We<br>have to take the brunt of<br>making ends meet off of<br>teachers and aids plates so<br>they may focus all of their<br>efforts on guiding our future<br>residents to be the best<br>citizens they can be. AISD<br>seems broken to me right now<br>and we need to fix it quickly!<br>Thanks for letting me get my<br>two cents out! Forever in love<br>with the ATX, Melissa Bowman\",\"Please don't Dallas my Austin.<br>Plan for more affordable<br>housing.\",\"I wish living in Austin were<br>more affordable so that my<br>children could live here. They<br>couldn't qualify for a home in<br>Austin but were able to qualify<br>and purchase a great size home<br>in Ft. Worth.\",\"One thing I didn't see<br>reflected in the survey is<br>public education, which is one<br>of the most important things to<br>me as a parent and one of the<br>things that sets Austin apart<br>from the rest of the state. Our<br>schools are amazing and should<br>continue to be a priority. Even<br>with the challenges related to<br>declining enrollment and the<br>mismatch between where students<br>and schools are located, I<br>believe and hope we can<br>continue to provide the best<br>possible education to our kids.<br>Beyond that, I hope Austin will<br>continue to be a diverse,<br>welcoming, thriving,<br>progressive city. We are<br>already a positive example for<br>the rest of Texas in many ways,<br>but there is much work to do<br>related to affordability,<br>transportation, expanded<br>opportunities for all, and<br>integration (or at least<br>connectivity between citizens<br>and neighbors). Austin always<br>has been and I hope will remain<br>the best city in Texas!\",\"We need more affordable housing<br>right now we have my daughter<br>and her family living with us<br>because they can't afford<br>housing. Also improve<br>disability services and<br>independent living and job<br>services for disabled.\",\"Look for private funding for<br>public transportation. Open<br>traffic calming program back<br>up. Put more taxes on<br>development not residents\",\"Hi, Mr. Mayor, I pay thousands<br>in property taxes yet don't<br>feel safe here at 3116 Corbin<br>Lane. Crime is up and criminals<br>abound. Look at the abundance<br>of tagging here in South<br>Austin. My family has our home<br>in a trust for me, a gift from<br>my late Mother. If not, we<br>could not afford to live here.<br>We love the police a whole lot.<br>Councilman Renteria helped me<br>get fencing from the Union<br>Pacific RR -- $100k - 1500<br>square feet - running from<br>Bannister Lane to Oltorf, since<br>rocks were being thrown into<br>our home. It's a scary world<br>with scary times. I applaud all<br>you do for us and have always<br>been a supporter. Yet, I do<br>feel as though more needs to be<br>done. Homeless camps by the<br>Gillis Park are scary. Folks<br>carrying weapons and making<br>public drug deals, in the park.<br>Why don't you let homeowners<br>designate a portion of their<br>property taxes to the school<br>their kiddo attends? My<br>eight-year-old attends Dawson<br>Elementary School. I ought to<br>be able to designate a portion<br>of my property taxes to her<br>school. Sorry for my rambling<br>thoughts (smile). Happy<br>weekending, Mayor. ~ Tricia<br>Potyka and Miss Nevada\",\"I understand that it is hard to<br>retrofit streets to accommodate<br>bikes. I believe the Texas heat<br>makes biking to work<br>uncomfortable. Stop taking my<br>road space for bikes. Overall I<br>am very happy to live in<br>Austin, good thing I was born<br>here, I certainly could not<br>afford to move here.\",\"Better quality of living for<br>all people!!!\",\"start doing some well thought<br>out long term planning\",\"Please help make our roads less<br>congested. Thank you!\",\"Austin has beautiful natural<br>resources. To help the citizens<br>enjoy the outdoors the city<br>should control the mosquito<br>population. Each household is<br>taking it upon themselves to<br>curb the population. As a<br>result each household is<br>spraying many different<br>chemicals into the air with<br>little to no results. There's<br>got to be a better way.\",\"Stop being so liberal. We<br>should not be competing with<br>San Francisco. My daughter<br>lives there, but grew up in<br>Austin. No sanctuary city,<br>please. I took the time to<br>answer your survey, then you<br>ask for personal information at<br>the end. I don't know who<br>access to this stuff. Very<br>disconcerting.\",\"I love this city. I am very<br>dissatisfied with the ems<br>responders that attended to me<br>attitude. I am concerned about<br>affordability as I enter<br>retirement. Thank you mayor<br>Adler for your support of f<br>fairness to all. I appreciate<br>you.\",\"Taxes and traffic are<br>horrendous\",\"It may be time to stop the<br>rapid growth until the area has<br>an infrastructure plan for<br>current and near term<br>population. The city is large<br>enough that there is a serious<br>lack of non-laughable public<br>transportation, especially for<br>people living south.\",\"Home and housing affordability.<br>Traffic and public<br>transportation. Needs to be<br>more transparent that city is<br>trying to do better. Code NEXT<br>is a joke.\",\"The exponential increase in the<br>housing taxes for the city of<br>Austin homeowners is simply<br>unrealistic. I am paying<br>mortgage here in housing tax<br>than I used to pay in rent.<br>This is not affordable living.<br>I thought I would be saving<br>money when I bought my home and<br>now that is just not the case.\",\"Set up a special Internal<br>Affairs division composed of<br>retired veterans with honors in<br>combat and conduct, to field<br>COMPLAINTS about police,<br>deputies, politicians, clergy,<br>etc. and provide the public<br>with competent oversight<br>recourse if this division fails<br>them. Recourse MUST enable the<br>public to then make a permanent<br>RECORD with the Governor's<br>Office at own volition, NEVER<br>BLOCKED in any way by Internal<br>Affairs, and the record must<br>come up for review by a grand<br>jury for prospect of<br>prosecution by an independent<br>prosecutor..\",\"Too much focus on proving low<br>income services. Put social<br>services and affordable housing<br>away from downtown where there<br>is reasonable grocery stores or<br>transportation.\",\"Promote city growth, but<br>preserve unique culture and<br>historic aspects of Austin as<br>well as parks and recreation.<br>Plan for traffic\/city mobility.<br>Get ahead of it. Find mass<br>transit solutions for central<br>Austin (elevated trains, light<br>rail) and commuter rails<br>between Austin and Houston,<br>Dallas and San Antonio.\",\"build roads, quit pushing empty<br>busses and bikes.\",\"Help with traffic\",\"Change the billing system of<br>Austin energy to allow for more<br>time between receiving the bill<br>and having to pay it. And<br>flexible payment schedules.\",\"Better metro rail<br>transportation\",\"Cost of living is outrageously<br>high while city maintenance and<br>services are low.\",\"Think further ahead. Plan for<br>what my children and their<br>children will experience as<br>adults should they choose to<br>stay here.\",\"Would like more transportation<br>options besides bus connecting<br>downtown to the rest of the<br>city\",\"TRAFFIC CONGESTION. TAXES AND<br>AFFORDABLE HOUSING\",\"I would tell Mayor Adler that I<br>appreciate his support for the<br>\\\"Freedom City\\\" initiative.\",\"Keep working on traffic<br>congestion and homeless support\",\"Making changes to the<br>efficiency of the planning and<br>zoning department might help<br>(not solve) the cost of housing<br>in Austin. Taxes must be<br>reduced and with more people to<br>spread the costs to it should<br>be achievable. Although there<br>are advantages to creating more<br>downtown for visitors who help<br>economy, those of us in the<br>remainder of the city feel as<br>though we finance it. Further<br>expansion of downtown needs a<br>transparent plan of repayment<br>from the people using it.\",\"Work on traffic congestion and<br>the timing of lights. Work on<br>affordable housing.\",\"The quality of the streets,<br>street lights, and sidewalks<br>are very poor unless you live<br>in very rich areas of town. I<br>am able to drive outside of my<br>neighborhood to access nicer<br>parts of town which is a pain<br>but I can do it. For many of<br>the neighborhood children, that<br>is not possible and they simply<br>don't play outside. Please,<br>please fix the quality of those<br>three things in areas like<br>mine.\",\"Safety in the neighborhoods\",\"STOP favoring developers over<br>citizens! Density is not the<br>answer to affordability as this<br>is dismissive of people's<br>quality of life earning less<br>than $65K to force them to live<br>in 450 sq. feet or 60-90<br>minutes away (one way). l The<br>city has become economically<br>segregated with expensive<br>transportation costs and there<br>is no protection for long-time<br>homeowners to retire here. The<br>Mayor seems to champion<br>policies that work for him and<br>others in his socio-economic<br>status while enriching real<br>estate professionals at the<br>cost of us people earning less<br>than $65K per year ... my<br>quality of life is OK but I<br>cannot travel, I cannot go out<br>to eat at a restaurant that is<br>more than $10, and I cannot<br>afford to attend activities in<br>our public park that are more<br>than $5. Large commercial<br>businesses should pay their<br>fair share of property taxes<br>and SHOULD NOT get incentives<br>like tax breaks.\",\"Telephone staff should be<br>friendly and knowledgeable in<br>order to help customers. If<br>they don't know the answer,<br>find someone who does; transfer<br>the customer but give them the<br>direct dial # should the<br>connection be lost. Excellent<br>telephone etiquette will<br>introduce the City of Austin to<br>new and existing citizens and a<br>friendly voice goes a long way<br>towards good relations.\",\"I'm a Realtor and driving<br>around Austin is difficult. I<br>find myself stuck in traffic<br>more and more. I understand<br>that we have had a huge influx<br>of people, but there should<br>have been a plan in place for<br>how to handle it. Turning road<br>lanes into bike lanes is NOT<br>the answer. Expecting people to<br>somehow get to their metro stop<br>that doesn't have parking and<br>is too far to ride a bike is<br>ridiculous. I live in Great<br>Hills. My Metro stop is at<br>Kramer. Many people who live<br>near me, work downtown and<br>would be willing to take the<br>Metro if there were a way to<br>easily get there-or have a<br>place to park their car.\",\"areas needing improvement:<br>traffic congestion; homeless<br>services\",\"Traffic flow is a real problem\",\"Water cost is out of control,<br>TOO High\",\"The east side needs more<br>attention to its parks, pools,<br>sidewalks, and roads.\",\"Coyotes are A MENACE.\",\"WORK WITH SURROUNDING CITIES\",\"TRANSPORTATION THRU THE CITY IS<br>DIFFICULT.\",\"PLEASE CONTINUE TO SUPPORT<br>AUSTIN PUBLIC SCHOOLS AND THE<br>ARTS.\",\"Plan for growth and traffic.\",\"I WOULD LIKE TO OWN A HOME ONE<br>DAY. NOT CERTAIN IF WE WILL BE<br>ABLE TO AFFORD IT HERE.\",\"RAPIDLY GROWING SENIORS NEED<br>VISIBILITY WITH SERVICES,<br>ESPECIAL THE LGBT CITIZENS.\",\"please continue to seriously<br>consider the environment when<br>planning for Austin's future.<br>more green spaces and more<br>policies that incentives both<br>residential and commercial,<br>recycling and conservation of<br>natural resources. thank you\",\"MORE EFFICIENT WAYS OF DEALING<br>WITH THE RAPID GROWTH, FREEWAY<br>EXPANSION? TRAFFIC ON LAMAR<br>MOST TIMES OF DAY IS MORE<br>CONGESTED THAN NECESSARY DUE TO<br>CONSTRUCTION.\",\"I ENJOY THE 10 ZONES IN AUSTIN.<br>COUNCIL PERSON IS VERY<br>ATTENTIVE TO ISSUES . ANN<br>KITCHENS RESPONDED IN A PROMPT<br>MANNER.\",\"BALANCE DEVELOPMENT WITH<br>ATTENTION TO TRAFFIC. MAKE MORE<br>LIGHTS SMARTER. CITYWIDE<br>COMPOSTING NEEDED. WE NEED<br>LIGHT RAIL.\",\"I 35 IS A MESS. NEED BUS<br>SERVICE IN ONION CREEK\",\"FIX TRANSPORTATION SYSTEM.<br>REDUCING SPENDING ON SCHOOLS.<br>REMOVE THE HOMELESS. FINE<br>LITTERERS. PROMOTE ANI-<br>LITTERING.\",\"YOU ARE LOSING THE CULTURE OF<br>AUSTIN BECAUSE OF<br>GENTRIFICATION.\",\"THE MAIN ARTERIES SHOULD BE<br>REPAIRED IN SOUTH AUSTIN. WE<br>NEED COMMUNITY SOLUTIONS FOR<br>THE HOMELESS POPULATION AS IT<br>RAPIDLY GROWS BEYOND CONTROL.\",\"REDUCE POPULATION GROWTH RATE,<br>TOO MUCH TRAFFIC\",\"PLEASE BE REALISTIC WITH TAX<br>DOLLARS. THINK ABOUT WHAT IS<br>REALLY NEEDED. SELLING PUBLIC<br>LANDS IS NOT A GOOD THING.\",\"Transit, transit, transit!<br>Additionally, cars don't like<br>to give the right of way to<br>walkers, joggers, or bikers<br>(even if they have the<br>pedestrian light). It's bad. I<br>could literally keep a journal<br>of close calls.\",\"The longer real estate in<br>Austin remains like this, the<br>more likely Austin will become<br>a city that loses its soul.<br>Even for a household with our<br>income, buying a property seems<br>unattainable and rent isn't too<br>far behind.\",\"I need to be educated on my<br>city and how I can serve Where<br>would I go for a good general<br>orientation?\",\"Sidewalks are very important<br>for the inner city\/downtown.\",\"Affordable housing, Austin is<br>turning into a town where you<br>have to be a millionaire to<br>have a good quality life.<br>Access to health services.\",\"Get downtown traffic moving.\",\"There are not enough affordable<br>senior living facilities.\",\"The amount of construction on<br>both high volume roads and<br>residential is horrible. The<br>new pavement shoots pebbles<br>everywhere.\",\"Fix the traffic on Mopac, 290,<br>& 360. Less lights and bike<br>Lanes, more car Lanes. Add<br>public transit along all of 360<br>and turn it into a freeway. Add<br>public transit South of<br>Slaughter Lane between Mopac<br>and 35. Finish the 45 toll road<br>to 35 in South Austin.<br>Transportation is so far behind<br>here. Please continue to focus<br>on getting us caught up.<br>Beneficial light rail route<br>options would be nice.\",\"PROMOTE DIVERSITY AND MAKE ALL<br>AREAS OF AUSTIN SAFE.\",\"GET TAXES UNDER CONTROL. WHERE<br>IS ALL THE MONEY GOING?\",\"Be fair to ALL constituents.<br>Austin is NOT California.\",\"Traffic is the 4th worst in the<br>country, it needs professional<br>services on how to manage. The<br>soccer stadium needs to be<br>built outside of the city.\",\"Support creative public<br>transportation.\",\"Make the permitting process for<br>construction more efficient.\",\"TRAFFIC PLANNING, MORE LIGHT<br>RAIL WOULD BE HELPFUL\",\"DECISION MAKING AND PLANNING IN<br>THE CITY HAS BECOME TOO SHORT<br>SIGHTED. NEED A FAR SIGHTED<br>VISION TO PRESERVE WHAT STILL<br>SPECIAL ABOUT THIS CITY.\",\"TOO MUCH TIME AND MONEY SPENT<br>TO SATISFY MINORITY NEEDS. MORE<br>EFFORT SHOULD GO TO MAJORITY<br>NEEDS, TRAFFIC, GROWTH<br>MANAGEMENT.\",\"I think for those of us living<br>here for a long time, it feels<br>like the new, the money, the<br>growth, the change are all more<br>important to any type of<br>preservation of our city and<br>its ability to run smoothly or<br>well. Growth is good and<br>inevitable, but growth without<br>regard to how it will be<br>managed in an appropriate way<br>is not. Rising property taxes<br>and affordability of housing is<br>terrifying. I would never be<br>able to qualify for a house<br>today in the city I have been<br>in for 17 years. I don't want<br>to be pushed out but as my kids<br>grow up and my income doesn't<br>go up, I may be forced to<br>leave. Then what? I am a white<br>middle class person and grieve<br>over those we have pushed out<br>downtown in situations more<br>dire than my own.\",\"East West thoroughfare. It's<br>about time some home owner's<br>did the right thing & quit<br>complaining or stopping what<br>makes sense. We are going to<br>grow so plan for it! Quit<br>paying corporations. The soccer<br>field out at triangle area off<br>183 was a Trump-like fiasco of<br>money or common sense. The<br>codes are so hard to follow, so<br>serpentine in trying to find -<br>what, which, how, where in<br>which neighborhood, garage set<br>backs so that now we have so<br>many carports & no garages?<br>trees, Good grief, common<br>sense.\",\"Accessing Mopac from SW Parkway<br>can take 5 min or 40 min<br>depending on time of day.<br>BOTTLE NECKING and timing of<br>lights\",\"MORE COMPETITION FOR UTILITIES.\",\"Keep up the good work on<br>cleanliness.\",\"I left Houston for a better<br>quality of life, and to one day<br>raise a family here. Cost of<br>living and transportation<br>issues make it seem less<br>possible here.\",\"Practical train system\",\"We need roads.\",\"Fix zoning\",\"Make housing more affordable.\",\"Traffic is the biggest issue.<br>Fix it or at least address it!\",\"coa has been behind the curve<br>on the roadway system for<br>years, please visit other<br>cities that have more efficient<br>roads to try and stay ahead of<br>the problem\",\"Make the city cleaner. Send the<br>homeless to areas where they<br>are off the freeway and roads.\",\"property tax are killing me,<br>bought my house $25000\/year now<br>$12,500 year, not to provide me<br>services but to subsidize<br>everyone else, water, electric<br>costs are outrageous, city govt<br>only represents tax many<br>consumer\/never tax payer\",\"1. EAST AUSTIN RESIDENTS SHOULD<br>NOT BE DRIVEN OUT OF THEIR<br>COMMUNITY. 2. LIGHTS NEED TO BE<br>INSTALLED - IT IS TOO DANGEROUS<br>TO BE ALONE IF YOU ARE A<br>RUNNER.\",\"QUIT SPONSORING IRRESPONSIBLE<br>LIFESTYLES.\",\"no mention of AISD? very<br>concerned on environmental long<br>term impacts of our city,<br>increasing impervious cover<br>unnecessary ways, creating<br>lifestyles dependent to high<br>emissions, laws against grey<br>water to minimize<br>water\/wastewater\",\"MAYOR AND COUNCIL ARE VERY<br>IDEALISTIC, NOT REALISTIC. THEY<br>DO NOT UNDERSTAND PEOPLE WHO<br>WORK FOR A LIVING. BIKES ARE<br>NOT A REASONABLE MODE OF<br>TRANSPORTATION FOR MOST PEOPLE.\",\"WE NEED TO DEAL WITH THE<br>TRAFFIC.\",\"need to establish rent control\",\"WHY DO YOU ALLOW DEVELOPERS<br>LIKE THE ONES ON BULL CREEK TO<br>MISLEAD THE PUBLIC ON WHAT THEY<br>PLAN TO DO? TRAFFIC ON BULL<br>CREEK WILL BE ATROCIOUS AND IT<br>IS A MAJOR COMMUTE ROUTE. WHY<br>DO YOU SUBSIDIZE DEVELOPMENTS<br>LIKE THE DOMAIN AND THEN<br>COMPLAIN WHEN THEY BEGIN TO<br>TAKE AWAY BUSINESS DOWNTOWN?<br>AUSTIN FEELS LIKE IT IS RUN BY<br>CLOWNS.\",\"WE NEED TO FIX THE HOMELESS<br>PROBLEM.\",\"CITY SERVICES ARE IMPRESSIVE<br>GIVEN AUSTINS' EXPLOSIVE GROWTH<br>BUT LACK OF SUFFICIENT<br>AFFORDABLE HOUSING IS BECOMING<br>MORE OF AN ISSUE.\",\"AUSTIN IS SLOWLY BECOMING A<br>CITY I DO NOT RECOGNIZE.\",\"FIX TRAFFIC CONGESTION<br>INFRASTRUCTURE CANNOT KEEP PACE<br>WITH THE AMOUNT OF PEOPLE<br>MOVING HERE. FIX 360 CONGESTION<br>ASAP.\",\"Stop uncontrolled growth,<br>improve traffic light timing<br>and traffic flow.\",\"PANHANDLING SPOTS FOR TRANSIENT<br>PEOPLE ALSO RESEARCH BLVD 183<br>HWY BETWEEN N LAMAR BLVD AND<br>I-35 HWY.\",\"YOU SEEM TO BE DOING A GOOD<br>JOB. ESPECIALLY COMPARED TO THE<br>REST OF TEXAS. PLEASE WORK ON<br>PUBLIC TRANSIT.\",\"FIX THE TRAFFIC PROBLEM, PUBLIC<br>TRANSPORTATION. QUALITY OF<br>ROADS. TIMING OF LIGHTS. SPEED<br>OF CONSTRUCTION PROJECTS.\",\"Please work to improve public<br>transportation and improve bike<br>safety on public streets.<br>Sidewalks would be great!<br>Faster permitting and<br>inspections-Please!\",\"More wide reaching public<br>transport please! This will<br>allow young people greater<br>independence without having to<br>have a car, therefore<br>increasing safety too! If there<br>were buses that took me out and<br>to work, I would rarely drive<br>my car.\",\"The affordability of housing<br>needs to go down. It's very<br>expensive to live here. I make<br>a decent wage, but when you<br>support other people, it's<br>still not enough to buy your<br>own home. Houses in my<br>neighborhood used to cost<br>$175,000 when I first moved<br>here, now they are upwards of<br>$300,000. I hope to own a home<br>soon, but at this rate I will<br>probably keep renting.\",\"bring safety to montopolis<br>improve crime rate for most<br>crime rate area in Austin\",\"Affordable housing to buy.\",\"I wouldn't live anywhere else<br>in Texas, but we really need to<br>do something about mobility in<br>the south. I know it's coming<br>but after 17 years I'm starting<br>to lose hope I'll see it in my<br>lifetime. Sidewalks would be<br>nice and if it's not too much<br>to ask for, please don't make<br>the road smaller to put one in<br>on one side of the street, I'd<br>rather go without if that's the<br>case, with all the big trucks<br>in this city the streets are<br>tight enough already. Thank<br>you,\",\"We need a comprehensive<br>plan\/vision for managing the<br>growth of this city!\",\"Mental health is real, our<br>facilities are substandard and<br>are not recommended by local<br>professionals, and someone<br>needs to be accountable. These<br>people need real help, not just<br>a band aide and to end up on<br>the streets.\",\"URBAN DENSITY DOESN'T WORK IF<br>THE TRANSPORTATION<br>INFRASTRUCTURE CANNOT SUPPORT<br>IT.\",\"many lower income people who<br>have been a major part of the<br>Austin culture service<br>industry, artists, musicians<br>are moving away I seem to get a<br>going away party every week, it<br>will only be a matter of time<br>before Austin will only be the<br>technology companies we gave<br>incentives to but no character\",\"I am happy to live in such a<br>culturally diverse and<br>stimulating city. We need more<br>affordable housing and a fully<br>staffed police\/fire\/EMS<br>service. In retirement I will<br>be forced to move to find<br>better resources to housing and<br>safety.\",\"BE TRANSPARENT\",\"The City and council is making<br>it too expensive to live here.<br>I am not just talking about<br>housing. Forcing small<br>businesses to pay for<br>sick-leave, they will have to<br>raise prices to compensate for<br>this, passing the cost on to<br>us-the consumers.\",\"The homeless \\\"population\\\" is a<br>real problem on my street. I<br>live on Rundberg and they are<br>aggressive.\",\"KEEP AUSTIN GOING\",\"THE 3 THINGS THAT ARE MOST<br>IMPORTANT TO AUSTIN'S VIALITY<br>ARE TRANSPORTATION ENVIRONMENT<br>AND EQUITY\",\"Lack of mass transit for the<br>masses. Making Austin<br>affordable for the masses(food,<br>housing, healthcare, city<br>utilities, re-distribution of<br>wealth.\",\"I THINK OVERALL THE CITY IS<br>DOING A GOOD JOB.\",\"CONCENTRATE ON PEOPLE THAT DO<br>NOT RIDE BIKES, AS WELL AS<br>SENIOR CITIZENS.\",\"BE TRANSPARENT. THIS COULD<br>START WITH AN AUDIT OF CODE<br>NEXT CONTRACT. IT IS A SCANDAL<br>THAT THE CITY PAID SO MUCH. WHY<br>DID THE COUNCIL OR SOMEONE NOT<br>DO DUE DILIGENCE. THE ENERGY<br>EFFICIENCY AND LANDSCAPING<br>MATERIALS AVAILABLE FROM THE<br>CITY ARE THE BEST I HAVE EVER<br>SEEN.\",\"Cost of living is too much!<br>Food, rent, the traffic - all<br>the things we spend extra money<br>and time doing that prevent us<br>from enjoying life. I shouldn't<br>have to work 2 jobs and 75<br>hours a week so I can spend 2<br>hours a day with my kid because<br>this city has gotten so darn<br>expensive. It wasn't like this<br>when I moved here. It's only<br>getting worse and the rich,<br>out-of-towners who are just now<br>moving here are the one's<br>causing the inflation of<br>everything here including tofu!<br>It's ridiculous. The city is<br>pretentious and not the city I<br>feel in love with. The only<br>\\\"weird\\\" thing about Austin is<br>that a 1 bedroom apartment is<br>over $1200\/month.\",\"TRAFFIC improvements\",\"Figure out the traffic before<br>we keep inviting business and<br>more people here to live.\",\"GREW UP IN AUSTIN AND NEVER<br>HAVE I SEEN A CITY GO FROM<br>BEAUTIFUL TO A CITY COVERED IN<br>TRASH LAND OVERGROWN COMMON<br>AREAS, THE RIDE FROM THE<br>AIRPORT SAYS IT ALL, I HAVE<br>BEEN TO MANY BIG CITIES<br>INCLUDING A RECENT TRIP TO<br>WASHINGTON DC THEY SEEM TO TAKE<br>MORE PRIDE IN KEEPING THEIR<br>CITY CLEAN. FIRST THING I<br>NOTICED IS THE RIDE FROM THE<br>AIRPORT WHAT A HORRIBLE FIRST<br>IMPRESSION WE ARE GIVING WHEN<br>DID IT BECOME OKAY FOR THE<br>PEOPLE HERE TO LIVE IN SUCH<br>DIRTY CITY\",\"QUIT WASTING RESOURCES ON FAR<br>LEFT POLICIES, SANCTUARY CITY,<br>LAWSUITS AGAIN ICE AND THINGS<br>SUCH AS CODENEXT.\",\"Work better with TxDOT to<br>improve major roads. ALSO get<br>Government (State, Local,<br>County) to begin real telework<br>programs.\",\"Property taxes are outrageous.\",\"Concentrate on doing a great<br>job at basic services.\",\"I'm really worried about<br>affordable housing and<br>preserving African American<br>neighborhoods\/diversity.\",\"Keep Austin clean, affordable,<br>and weird.\",\"Austin traffic and<br>transportation options are<br>stopping us from becoming a<br>world class city. Please help!<br>Ok 2 things, please do<br>everything you can to keep<br>Austin's art and music scene<br>alive despite how expensive the<br>city is becoming.\",\"The quality of life in this<br>city SUCKS! In case you missed<br>it before, I am an Austin<br>native. This actually used to<br>be a nice place to live - years<br>ago - but city administration<br>has been so piss poor that<br>there has been no master plan<br>to keep this a nice place to<br>live. The developers own this<br>city, and me an my fellow<br>citizens have to pay for all<br>the crap that they build with<br>my tax dollars. The condition<br>of the roads is awful, traffic<br>is awful. I hate it<br>here...........but I do have a<br>plan to get out, and I will.<br>Don't ever give anyone in city<br>administration a raise - they<br>don't deserve it. You do an<br>awful job and should be<br>ashamed.\",\"FIX THE PUBLIC SWIMMING POOLS!\",\"Austin is a miserable excuse<br>for a city. Everyone was asleep<br>at the switch until the<br>1990s...no planning, no effort<br>to see the future...and we were<br>caught with our pants down for<br>transportation and other<br>infrastructure. Then the 90s<br>came and greed\/growth exceeded<br>all else. Still no effort to<br>improve<br>transportation\/infrastructure<br>and the era of Will Wynn saw us<br>give away the farm even more to<br>developers. Now we're<br>overcrowded and everything that<br>was special about Austin -<br>everything you've been selling<br>to the outside world for 30<br>years is trashed. You can't go<br>to Zilker Park anymore because<br>it's been sold to special<br>events most weekends of the<br>year. And when you do go you<br>have to pay to get in, pay to<br>park. You can't go to the green<br>belts or trails because they're<br>just too crowded. Music is<br>dying a rapid death because you<br>put all the stinking condos<br>downtown and decided the clubs<br>were too loud, then the<br>inflated land values doomed the<br>nightclubs, and our ridiculous<br>cost of living has further<br>doomed the musicians. \\\"Live<br>Music Capitol of the World\\\" is<br>not just a joke, it's a<br>downright lie. City government<br>is directly responsible for<br>destroying the music scene. And<br>Code Compliance, Jesus, find<br>that news report about Code<br>Compliance showing up at that<br>guy's house, in force, in<br>kevlar vests, with cops in tow,<br>all because he built a shed too<br>close to the property line. And<br>that insane response the city<br>had to that poor schmuck who<br>dug tunnels under his house.<br>That's what Austin has become -<br>taxes, ordinances, intrusion<br>and suppression.\",\"We don't want that stupid<br>soccer team!\",\"Need to be more inclusive of<br>all races. The divide and lack<br>or racial diversity is painful<br>in Austin. Also, traffic SUCKS!\",\"Please work to make Austin<br>affordable!!\",\"Please finds ways to improve<br>public transit later at night,<br>and\/or loosen regulations on<br>neighborhood bars and<br>restaurants to serve alcohol,<br>as it's created a culture where<br>meeting for drinks is usually<br>centralized in a few, highly<br>populated areas, with few<br>reasonable transit options<br>available to avoid drunk<br>driving.\",\"Homeless people sleeping on the<br>streets and underpasses.\",\"GIVE RETIRED RESIDENTS MORE<br>FINANCIAL BREAKS.\",\"More public transportation<br>options from north Austin<br>towards UT\/downtown, please.\",\"I FEEL THERE SHOULD BE MORE<br>SERVICES ALL AROUND THE CITY<br>FOR HOMELESS PEOPLE.\",\"Publish the city budget, be<br>honest, and do not hide<br>anything.\",\"Improve the transportation<br>infrastructure and find a way<br>to lessen the property tax on<br>people who feel like they are<br>funding everything.\",\"TAXING OWNERS OUT OF THEIR<br>HOMES TO RELOCATE OR BE<br>HOMELESS.\",\"More red line rail stops and<br>bus routes that intersect with<br>stops are crucial.\",\"RE-THINK STARTING A LETTER<br>UNDER MY LEADERSHIP\",\"Slow down new development and<br>new residents.\",\"The soccer thing should have<br>been at Burger Stadium.\",\"Stop the panhandlers, it's not<br>safe.\",\"Less focus on growth and<br>bringing in new businesses.<br>Stick to a reasonable budget.<br>Improve infrastructure for<br>vehicles.\",\"I grew up in Austin, I still<br>love Austin (and am proud to be<br>a resident), just starting to<br>worry about affordability and<br>traffic. I know how difficult<br>these are to address, so any<br>efforts are appreciated. Better<br>public transportation is a good<br>start!\",\"Don't punish supervisors just<br>because they didn't spend ALL<br>the money they budgeted in the<br>FY. The comment I was told was,<br>Since you didn't use it you<br>don't need it all so I'm<br>cutting your budget.\",\"THANK YOU FOR YOUR PUBLIC<br>SERVICES YOU HAVE A DIFFICULT<br>JOB. PLEASE CUT PROPERTY TAX<br>RATES AND ANNUAL REVENUE GROWTH<br>TO THE EFFECTIVE RATE.\",\"The city is much larger than<br>the vocal residents of Hyde<br>Park. Growth should not be<br>scary, but it will be if small,<br>moneyed residents are able to<br>curb it at every turn. Go<br>Austin FC! Don't let the<br>council defeat the stadium<br>initiative.\",\"Invest more in our teachers and<br>education system in Austin.\",\"Cost of living is higher than<br>most salaries. It degrades the<br>quality of life.\",\"Improvement in the way regular<br>transit staff treat disabled<br>people.\",\"Quit raising taxes every year.\",\"Lower taxes and improve<br>traffic. Stop taking turn lanes<br>and turning them into bicycle<br>lanes.\",\"PLEASE DON'T RAISE PROPERTY<br>TAXES BECAUSE WHEN I CAN AFFORD<br>TO BUY A HOUSE I DON'T WANT<br>HIGH TAXES.\",\"Let the people vote when you<br>plan to change the quality of<br>their lives. No behind the door<br>deals!\",\"With the influx of people<br>moving here, we need to make<br>sure drivers are being SAFE!<br>You have to wait 20 seconds<br>before going through an<br>intersection to let all the red<br>light runners through (my<br>previous daily commute - 290 W<br>and William Cannon<br>intersection). Let's enforce<br>the rules we have in place.\",\"IT SEEMS THE CITY'S ATTENTION<br>IS FOCUSED ON THE HAVE'S WELL<br>OFF AND THE HAVE NOT'S LOW<br>INCOME.\",\"Fix the transportation issues<br>now, not 6 years from now.<br>Projects and process takes too<br>long. See prior comments.\",\"Get a mobile office and travel<br>the city. They could be exposed<br>to real time problems while<br>continuing to work with digital<br>communication. This would speed<br>up solutions.\",\"Make 35 underground.\",\"AUSTIN IS BECOMING A BORING AND<br>HAND TECH CITY.\",\"Love this city!\",\"Consider neighborhoods and<br>communicate with neighbors when<br>developers build. Our street is<br>so old, it cannot handle the<br>volume of traffic now.\",\"PLEASE! STOP RAISING PROPERTY<br>TAXES! I can't hold on much<br>longer.\",\"RECYCLE WEEKLY\",\"Build more roads and hire more<br>police.\",\"People making less money should<br>be able to buy homes in the<br>city.\",\"Rename I-35, from 290 to Ben<br>White, Willie Nelson Hwy. It<br>would add charm to that stretch<br>of highway. Then the city could<br>run an add campaign called<br>\\\"Spending' time with Willie!,<br>so then people would think it<br>is cool to get stuck in<br>traffic! Rename lower deck to<br>\\\"Outlaw Country Dive\\\". Rename<br>upper deck \\\"Stevie Ray Way\\\".<br>You are Welcome! I love my city<br>and all the city employees.<br>Keep up the great work!\",\"We need a better code process.\",\"THE BIGGEST CHALLENGE FACING<br>AUSTIN ACCOMMODATING GROWTH.<br>DEVELOPMENT CODES MUST ALLOW<br>FOR URBAN DEVELOPMENT.\",\"Please improve Mass Transit. We<br>need access to the rail on the<br>east side. We do not have any<br>at this time.\",\"QUICKER DSD PERMIT REVIEWS AND<br>MORE CITY INSPECTIONS.\",\"PLEASE TRY TO DO WHAT IS RIGHT<br>FOR THE CITY CONSIDERING AS<br>MANY VARIABLES AS POSSIBLE AND<br>OVER ALL FAIRNESS OF THE<br>DECISION.\",\"Austin is too socialistic. Too<br>concerned with giving things<br>away. Property taxes are too<br>high.\",\"Please address the<br>affordability of living in<br>Austin.\",\"(1) Lanes for scooters. (2)<br>Expand rail system (time and<br>location) and more affordable.<br>(3) City does not accessible<br>handicap spots, maintenance for<br>wheelchairs. (4) Rent is<br>excessive.\",\"Mental health training for<br>police.\",\"FOCUS ON FUNCTIONS CITY EXISTS<br>TO PROVIDE.\",\"Keep Austin safe. Don't let our<br>city be another San Francisco<br>or Portland.\",\"Provide more aggressive traffic<br>calming on Scenic Brook Drive<br>in Oak Hill. The existent speed<br>bumps are insufficient. Stop<br>cut through traffic. Children,<br>walkers, animals, and bicycles<br>are put at risk.\",\"PLEASE CLOSE THE AUSTIN REC<br>CENTER TO THE HOMELESS AND<br>THOSE WHO DO NOT PAY FOR<br>PROGRAMS. PLEASE DISCONTINUE<br>THE PRACTICE OF ALLOWING PUBLIC<br>SHOWER HOURS AT REC CENTER.<br>PLEASE CREATE AND ENFORCE A NO<br>LOITERING LAW AT CITY<br>FACILITIES. I DO NOT FEEL SAFE<br>AND I AM LOSING CUSTOMERS<br>BECAUSE OF THIS ISSUE.\",\"STOP THE BUSES FROM WAITING<br>BLOCKING THE ROAD TO PICK UP<br>AND DROP OFF RIDERS OR TO GET<br>BACK ON SCHEDULE.\",\"ENCOURAGE BUSINESSES REBATES OR<br>SUBSIDY TO WORK FROM HOME.\",\"LACK OF EQUALITY REGARDING<br>HISTORY AND ETHNIC GROUP<br>HISTORY, GIVING IN TO PRESSURE<br>TO JUST EITHER GET THEM OFF<br>YOUR BACK OR LOOKING TOWARD<br>VOTES .\",\"AUSTIN NEEDS TO CONTINUE TO<br>BALANCE GROWTH WITH THE QUALITY<br>OF LIFE AND RESOURCES, AS WELL<br>AS WITH ITS ABILITY TO RETAIN<br>ITS CHARACTER.\",\"STOP RAISING TAXES. PAY<br>ATTENTION T OUSE. GET THEM TO<br>REVISE ROBIN HOOD, IT IS<br>KILLING TRAVIS COUNTY.\",\"WE NEED TO DO A BETTER JOB OF<br>SUPPORTING THE HISTORICAL<br>RESIDENTS OF EAST AUSTIN.\",\"Traffic.\",\"PLEASE FIND WAYS TO ENSURE THE<br>CITY IS AFFORDABLE FOR THOSE<br>WHO HAVE LIVED HERE THE LONGEST<br>TO STAY AND MAINTAIN THEIR<br>LIFESTYLES. FURTHER SCRUTINY OF<br>HOUSING DEVELOPMENT COMPANIES<br>AND PROJECTS AND MORE<br>RESTRICTIONS ON THE HOUSING<br>OPTIONS THEY CREATE IS<br>ESSENTIAL.\",\"PLEASE CONTINUE EFFORTS TO<br>DECREASE PROPERTY TAXES.\",\"Consider the future and if<br>people will be able to afford<br>to live here.\",\"FOCUS ON BASIC RESPONSIBILITIES<br>OF GOV'T, NOT ADVANCING SOCIAL<br>AGENDAS. TREAT ALL FAIRLY<br>WITHOUT VILLIFYING SEGMENTS OF<br>THE POPULATION. FOR EXAMPLE:<br>POLITICAL GRANDSTANDING BY ANN<br>QUNCINA INTENT NOT TO ATTEND<br>VETERANS DAY PARADE WAS<br>CLASSLESS.\",\"START TO SOLVE THE<br>TRANSPORTATION PROBLEM-WORKING<br>HIGHWAYS OR ADDING OVERPASSES<br>AT CHOKE POINTS WON'T<br>ACCOMPLISH A SOLUTION.\",\"Get rent under control.\",\"Do not meddle in the affairs of<br>other cities, and do away with<br>your sanctuary city status.\",\"Get property taxes under<br>control.\",\"IMPROVE TRAFFIC AND REDUCE<br>TAXES.\",\"Please approve the police<br>contract favorable to the<br>stresses the police face. .\",\"NO to sanctuary city!!!\",\"Quit raising property taxes.\",\"There is a high to homeless<br>assistance in South-East<br>Austin. Large homeless camps<br>under overpasses and on every<br>street corner bring down<br>property value and deter<br>tourism.\",\"Build soccer stadium at McKala<br>Place.\",\"Stop incentivizing growth and<br>density. Put Code Next through<br>the shredder. Get rid of<br>parking meters being installed<br>off trails by Austin High.\",\"Stop putting planters in the<br>middle of the street. Trying to<br>make people get out of their<br>cars and walk and ride a<br>bicycle really doesn't work in<br>Texas and besides Texans love<br>their trucks!\",\"Reduce city taxes!!!\",\"Stop\/limit building of \\\"luxury\\\"<br>apartments\/condos\/homes - focus<br>more on safe, stable, clean<br>structures that the middle<br>class can afford that aren't in<br>Kyle or Buda. A two bedroom<br>home is not affordable when it<br>costs $300,000 plus. Tech is<br>great, but you need blue collar<br>and other occupations to<br>maintain the infrastructure of<br>the city. Those occupations are<br>vital for day to day<br>operations, yet those in a<br>field where salaries are less<br>than 50-60,000 have limited<br>\\\"affordable\\\" living options<br>that don't require a long<br>commute on our overcrowded<br>roads and poor public<br>transportation system.\",\"Improve traffic flow!!!<br>Eliminate paid street parking<br>at lakes and parks.\",\"FIX HOMELESS PROBLEM\",\"He has done a great job! Is<br>accessible. Thank him for his<br>service.\",\"lower our water and wastewater<br>costs!\",\"To make city streets safer, cut<br>the speed limit to 25mph. It<br>has an oversized effect on<br>injuries and deaths. Look at<br>the stats.\",\"Police enforcement to eliminate<br>drugs traffic in 800 block of<br>Rutland Dr.\",\"We need better public<br>transportation\",\"Stop fighting the outside<br>audit. Listen to voters and<br>stop bending to the will of<br>developers. Manage the city, as<br>you were elected to do, and<br>stop opining on matters that do<br>not concern the city of Austin.\",\"The cost of living in Austin<br>and the surrounding v areas is<br>100% absurd. Beyond ridiculous.<br>I would do anything to have the<br>\\\"old Austin\\\" back.\",\"Clean up Cameron road and no to<br>code next\",\"Please make it affordable to<br>live here again.\",\"Clear up the traffic flow. Plan<br>ahead so streets don't have to<br>be torn up repeatedly. The<br>flyovers are turning Austin<br>into Chicago, and I don't<br>understand why business owners<br>aren't raising Cain with all<br>the traffic going overhead.<br>It's the same as sending all<br>the traffic on a loop around<br>the city where they don't stop<br>to shop. Austin is great if you<br>are young, love music, and have<br>money. Otherwise, it sort of<br>sucks.\",\"City of Austin bills are<br>totally outrageous.\",\"Please uphold immigration law,<br>get rid of homeless bums, make<br>room for cars not bikes and<br>reduce city government<br>tremendously. Thank you\",\"Help keep local businesses<br>thriving.\",\"we need a better bus system<br>some bus routes did not run<br>Mondays if you go to work the<br>bus routes should run all the<br>time and on Monday\",\"Stop the socialist agenda of<br>Greg Casar\",\"I believed in you until I saw<br>you and council members jumping<br>around, high fiving one another<br>after Lyft and Uber were voted<br>out. Thousands of people were<br>put out of work. SICKENING.\",\"Please put in place a green<br>energy program for residential<br>home owners to switch to 100%<br>renewable energy.\",\"Represent the Citizens of<br>Austin, not developers,<br>corporations, contractors, or<br>any other business interest. Be<br>a true civil servant and not to<br>abuse the position they<br>represent.\",\"I wish we could get some kind<br>of rail system so that our city<br>was more like other cities that<br>have chosen density as their<br>growth strategy. Also, I feel<br>like people using alternative<br>transportation like e scooters<br>should still have to follow<br>some basic traffic laws. As it<br>stands now, many people riding<br>the e scooters ride on the<br>street, on the sidewalk, and<br>wherever else they like with<br>little predictability. It makes<br>it extremely challenging not to<br>get into an accident with them<br>while I am in my car or as a<br>pedestrian.\",\"There is a lack of inclusivity<br>for transplants - people moving<br>into the area. There is a<br>feeling that the only way to<br>keep Austin weird is to keep<br>new people out. One of the<br>wonderful things about Austin<br>is its diversity. That<br>diversity only happens with new<br>people from different<br>backgrounds moving in. This<br>should be encouraged, not<br>discouraged.\",\"There are many things I have to<br>say about the City of Austin<br>but the one that most affects<br>my daily life is the quality of<br>roadways from E Riverside Dr<br>heading south. Riverside Dr is<br>in my opinion the worst road to<br>drive on. Montopolis is in dire<br>need of repaving from Grove to<br>Ben White. The sidewalks need<br>to be cleared & there are other<br>trails that need tending to,<br>not just the Lady Bird Lake<br>Hike & Bike Trail. In other<br>words, this entire area has<br>been neglected, other than by<br>contractors & developers.\",\"WORK ON THE TRAFFIC PROBLEM.\",\"Efficiency, rationality,<br>equality in use of our city<br>dollars\",\"Please invest in off road urban<br>mountain bike trails that link<br>Balcones, Gracywoods, and<br>Walnut Creek Parks. Currently,<br>there is a paved path that<br>links these parks but the<br>addition of off road urban<br>mountain bike trails would be a<br>huge economic benefit to the NW<br>Austin area as cyclists from<br>all over Austin would use this<br>trail system similar to the<br>current extensive trail system<br>of the Greenbelt and spend time<br>in local businesses in NW<br>Austin as a result. Also,<br>please link the North Walnut<br>Creek paved path to the South<br>Walnut Creek path to provide a<br>safe commuting corridor to<br>cyclists from NW Austin to East<br>and Central Austin.\",\"Audit the books . Would like to<br>see if there is any waste in<br>that 4 billion dollar budget\",\"Please do something about all<br>the homeless people around<br>Slaughter and I35.\",\"Austin has many fabulous<br>qualities but the city is<br>slowly destroying those<br>qualities by allowing<br>developers to build what they<br>want where they want. Fake<br>concern is given to the current<br>citizens to placate but then<br>the approval is given for<br>another tall building that<br>completely blocks out another<br>building and destroys real<br>estate value along with adding<br>to traffic. Even these surveys<br>won't help because the city<br>only wants to show concern.<br>They clearly do not want to<br>take responsibility for massive<br>traffic concerns by taking<br>action. The disregard shown by<br>the city is very hard to<br>fathom.\",\"Get a new job\",\"Get the darn construction jobs<br>under control & done\",\"More shopping downtown because<br>malls are over. Cap metro could<br>offer better service to school.<br>Need more flexible<br>transportation options.\",\"More night time safety<br>measurers downtown.\",\"quit worrying about state and<br>national issues and work on<br>things for Austin\",\"thanks for his hard work\",\"ACTION NEEDS TO BE TAKEN TO<br>REDUCE THE COST OF LIVING.<br>REDUCE THE INFLUENCE OF BIG<br>DEVELOPERS. AND INCREASE THE<br>AMOUNT OF POVERTY FIGHTING<br>SERVICES IN OUR CITY.\",\"this type of survey leaves a<br>lot of room for bias,<br>discrepancy and inaccuracy.\",\"Please focus on addressing<br>inequality and public<br>transportation within our city.<br>I'd love to see our city apply<br>design thinking to try and find<br>innovative ways to try and<br>address these problems in<br>Austin. Sustainability is also<br>very important to me.\",\"Building affordable is<br>gentrifying neighborhoods is a<br>good idea but still should pay<br>something. Big apartment<br>projects with cheap rent ruin<br>neighborhoods. I don't like<br>MUD's though.\",\"IMPROVE TRAFFIC\",\"GIVE YOUR PRESIDENTS AN<br>EFFECTIVE CITY WIDE LIGHT RAIL<br>SYSTEM FOR COMMUTERS. WE CANNOT<br>AFFORD TO LIVE CLOSE TO OUR<br>JOBS AND WE ARE KILLING THE<br>ENVIRONMENT.\",\"FIX OAK HILL 290\/71 TRAFFIC PUT<br>IN FREEWAY OVER PASS.\",\"I know this is a difficult<br>problem to solve, but the<br>availability of mental health<br>services to the homeless would<br>be a great win for Austin.\",\"SLOW THE GROWTH UNTIL CAN GIVE<br>THOSE ALREADY HERE A BETTER AND<br>MORE AFFORDABLE QUALITY OF<br>LIFE.\",\"Please keep expanding choices<br>in natural and healthy\/holistic<br>programs.\",\"Homeless shelter for women.<br>More cost friendly rent. More<br>cost appropriate child care.<br>More cost appropriate healthy<br>food. Affordable housing for<br>all incomes. Fix more potholes.\",\"I love the rate at which Austin<br>is growing and diversifying,<br>however, I'm always concerned<br>at how far behind road and<br>highway development is compared<br>to current population and<br>especially compared to future<br>growth populations. I feel<br>roads\/highway development is<br>always trying to catch up and<br>never done in accordance with<br>future projections for growth.\",\"Get rid of the dockless<br>scooters! More affordable<br>housing.\",\"The permitting process for<br>small businesses needs to be<br>improved to shorten the amount<br>of time required.\",\"FOCUS ON MOBILITY BECOMING<br>WORSE EACH DAY. DECISIONS MADE<br>TODAY TAKES YEARS TO DEVELOP SO<br>ADVANCED PLANNING IS CRUCIAL.\",\"Austin needs better<br>transportation methods - more<br>public transportation. Better<br>park management and cleaning.\",\"GET RID OF TAX BREAKS TO BIG<br>CORPORATIONS.\",\"traffic, population explosion<br>without infrastructure to<br>support it\",\"NEED TO INCREASE MINIMUM WAGES.\",\"We must redistribute wealth.<br>Rich get richer. No more middle<br>class.\",\"PRESERVE SMALL LOCAL<br>BUSINESSES. KEEP AUSTIN LOCAL.\",\"FOCUS ON RUNNING THE CITY WELL<br>INSTEAD OF PERIPHERAL ISSUES<br>LIKE SACTUARY CITIES, LGBT,<br>DIVISIVE ISSUES. OUR CITY IS<br>MORE THAN JUST THE WEIRD<br>RESIDENTS.\",\"support all environmental<br>responsibility development and<br>let a rail system be planned to<br>provide public transportation<br>that is clean fast and reliable<br>without continuous of the eco<br>system by continuous rail\/drip<br>more roads, there will never be<br>enough roads to support the<br>growth in Austin\",\"KEEP OPEN SPACES AND EXPAND<br>RECREATION AREAS. LOVE THE<br>CONCEPT OF TREES AND PLANTS<br>AROUND SHOPPING AREAS.\",\"OUR BUS AND LIGHT RAIL SYSTEM<br>ARE INCONVENIENT FOR MANY<br>BECAUSE OF THEIR LIMITED<br>SERVICE. EXPANDED LATE NIGHT<br>WOULD BE HELPFUL.\",\"METRO RAIL\",\"LOVE THE NEW URBANISH. LOVE<br>AUSTIN SPIRIT. KEEP STANDING UP<br>TO OUR BACKWARD STATE<br>GOVERNMENT. DON'T FORGET FLOOD<br>CONTROL.\",\"I understand the demand for the<br>cost of infrastructure and the<br>desire for improvement in<br>Austin is high but if property<br>taxes continue to increase at<br>the rate they have in the past<br>decades, will there be any of<br>the business or people left<br>that make this city great\",\"LACK OF THE COUNCIL TO<br>EFFICIENTLY ACCOMPLISH THEIR<br>JOB OF MAKING THE CITY RUN AND<br>EXPAND TIMELY TO ACCOMODATE<br>GROWTH.\",\"TRAFFIC PROBLEMS\",\"PRESERVE AUSTINS COSMIC COWBOY<br>CULTURE AND SITES\",\"Make spaces accessible to the<br>performing community. Almost<br>all accessible arts spaces have<br>shut down due to development<br>and have not reopened due to<br>prohibitive costs. This will<br>damage the culture of Austin in<br>the long term and drain much of<br>the talent to other cities.\",\"improve transportation,<br>highways, city streets, public<br>transit, don't let property tax<br>drive people from their homes\",\"HOME OWNERS SELL THEIR HOMES<br>DUE TO RISING APPRAISALS. SINCE<br>THERE IS NO STATE INCOME TAX<br>PROPERTY TAXES ARE VERY HIGH.<br>AFFORDABLE HOUSING IS TORN<br>DOWN. MILLION DOLLAR HOMES<br>BUILT ON THE LOT AND THE NEXT<br>TAX APPRAISALS MAKES OTHERS<br>HAVE TO SELL.\",\"STOP TALKING DOWN CONFEDERATE<br>STATUS THAT IS PART OF HISTORY<br>PLUS STOP REMOVING SCHOOLS THAT<br>IS ALSO PART OF HISTORY.\",\"TAXES AFFECT NEW HOME OWNERS<br>AND SMALL BUSINESS. MAKES IT<br>DIFFICULT TO STAY HERE.\",\"listen to area residents who<br>oppose TXDOT plans to put in<br>super hwys that destroy areas<br>like Oak Hill, continue your<br>efforts to make Austin a<br>sanctuary city and place which<br>is safer, cleaner, moving<br>forward instead of backwards\",\"I REALLY WISH AND WOULD LIKE TO<br>SEE THE HOMELESS GET MORE HELP.<br>WHETHER TO BE MORE SHELTERS<br>SOUP KITCHENS OR EVEN<br>RESOURCES. WE HAVE SUCH A HIGH<br>POPULATION AND NOBODY TO GUIDE<br>THEM AND HELP THEM.\",\"the city seems to be trending<br>towards being a place where<br>only the affluent are welcomed<br>and their desires are given<br>priority over the desires and<br>needs of the less affluent<br>citizens\",\"Better management of the<br>homeless population. Either<br>redirect where they choose to<br>be, or reduce the population<br>through more restrictions on<br>camps and panhandling<br>locations.\",\"public safety needs to be<br>priority with the growth Austin<br>has experienced APD need<br>resources. The code enforcement<br>dept needs to take a page out<br>of the dallas handbook to get a<br>handle on the slum lords here.<br>one family owns 200 plus<br>properties in Austin and their<br>are slumlords, there are<br>terrible housing conditions and<br>trash which lead to more crime<br>but code has no bite, they need<br>to be empowered\",\"The state recapture tax system<br>is going to send people packing<br>- Austin ISD = -50% plus $<br>State. Let's get a rail system<br>like Denver or Amsterdam.\",\"Improve traffic on major<br>highways such as 360, MoPac,<br>I-35, Ben White.\",\"Keep Austin affordable for a<br>broad income demographic.\",\"GET CONTROL OF THE HOMELESS<br>POPULATION. THEY ARE AGGRESSIVE<br>AND FEEL OBLIGATION TO ABIDE BY<br>CITY LAWS.\",\"we need more affordable high<br>density housing\",\"protected bike lanes on all<br>major N-S or -W routes<br>congress, s 1st, cesar Chavez,<br>MLK, slaughter, anderson to<br>name a few\",\"Please have more affordable<br>housing options in areas w\/good<br>schools. The housing<br>affordability in Austin is<br>terrible!\",\"WE NEED BETTER PUBLIC<br>TRANSPORTATION. MAYBE THE BUSES<br>WOULD BE USED MORE IF THERE<br>SHADE AT THE STOPS,BUT ITS TOO<br>HOT MOST OF THE YEAR TO WANT TO<br>TAKE THE BUS OVER DRIVING.\",\"Mass transit. Light rail -<br>invest as soon and as much as<br>possible. Traffic is reaching<br>the point of choking the<br>city\/metro area and impacting<br>quality of life.\",\"I WOULD SUGGEST NOT SPENING<br>MONEY ONADDING BIKE LANES WHERE<br>THE COMMUNITY IS NOT SAFE<br>ENOUGH OR NOT WILLING TO BIKE,<br>LANES HAVE BEEN TAKEN AWAY IN<br>SOME AREAS TO SIT EMPTY FOR A<br>BIKE LANE THAT NO ON USES\",\"QUIT VIEWING THE CITIZENS<br>POCKETS AS UNLIMITED AND A WAY<br>TO FUND ALL KINDS OF PET<br>PROJECTS THAT BENEFIT ONLY A<br>SMALL PART OF THE POPULATION.\",\"I WISH WE COULD END HOMELESS<br>PROVIDE MORE MENTAL SUPPORT AND<br>PAY OUR TEACHERS MORE.\",\"my top concerns at traffic and<br>affordability otherwise I think<br>Austin is a great place to<br>live, work and raise a family\",\"WE ARE WONDERFUL AND POPULAR<br>USE THE MONEY TO PRESERVE<br>WILDLIFE AND HABITAT AND CLEAN<br>WATER\",\"Expand Metro Rail to places<br>people need to go - the airport<br>& UT.\",\"BUS SERVICES ON EAST BEN WHITE.\",\"I'm part of a community that<br>continues to struggle within<br>the Austin of the present, why<br>are there no questions about<br>the arts as they relate to city<br>support which is poor also no<br>questions about dog parks non<br>north of river and east of I35\",\"Reducing traffic on main<br>streets through Austin, making<br>it easier to get through town<br>without the highways, which<br>also suck.\",\"UN MANGED GROWTH HS MADE AUSTIN<br>LESS ATTRACTIVE OVER THE YEARS.<br>TO THE POINT I LOOK FORWARD TO<br>LEAVING WHEN I RETIRE.\",\"Austin needs more lower income<br>housing, more affordable<br>housing, lower property taxes,<br>better roads, transportation<br>and mass transit, improve<br>safety on UT campus, address<br>homeless and expand homeless<br>shelters\",\"HIRE SOMEONE THAT DEALS WITH<br>TRAFFIC MANAGEMENT. PLEASE<br>CONSIDER THE OPINIONS THE ONES<br>THAT LIVE AND PAY TAXES IN<br>AUSTIN ONCE IN A WHILE.\",\"It is a disgrace that most<br>teachers, police, firefighters<br>and state employees cannot<br>afford to live here. We<br>desperately need transit in all<br>areas. Traffic is way too<br>congested and dangerous.\",\"DIVERSITY IS ESSENTIAL TO OUR<br>COMMUNITY. STOP PUSHING PEOPLE<br>OUT. AND MAKE AFFORDABLE<br>HOUSING CHILDCARE AND PUBLIC<br>TRANSPORTATION AVAILABLE TO<br>ALL.\",\"Reduce the awkward amount of<br>panhandlers w\/more police<br>enforcement of street corners.\",\"Austin is a great city, please<br>don't compromise the city\",\"Clean up the downtown scene and<br>build more highways.\",\"Get a plan to improve I-35<br>please!\",\"we are notice Texans lived in<br>comal county 1990-2000 moved to<br>new Mexico in 1999 to escape<br>the explosive growth in Austin,<br>return in 2012 experienced a<br>horrendous culture chock coming<br>back to live in Austin, sherr<br>number of vehicles and rude<br>drivers made us believe Austin<br>only focuses on services and<br>desires of the young. drivers<br>gave us offense gestures in<br>traffic and seemed to have the<br>attitude that they were<br>entitled and no one else<br>mattered\",\"Build a state of the art public<br>transportation system that does<br>not depend on cars. (Example -<br>System Base D on Heathrow<br>Airport London) Make it one<br>that will work for the city in<br>50 years, not what we needed<br>last year.\",\"I LOVE THAT WE ARE A NO KILL<br>CITY. I LOVE THE LIBRARY<br>SYSTEM. WE NEED TO PUT MORE<br>MONEY IN OUR PARKS AND<br>IMPROVING PUBLIC<br>TRANSPORTATION. MY FAMILY BIKES<br>A LOT AND THE NEW TRAILS ARE<br>HELPING US GET AROUND SAFELY<br>BUT WE NEED MORE.\",\"more affordable housing in nice<br>areas for low income senior<br>citizens and better traffic<br>flow\",\"Don't make a bunch of<br>concessions to attract Amazon<br>HQZ!\",\"better min wage, paid sick<br>days, tuition assistance, could<br>be improved but I am glad I<br>moved here\",\"WE NEED MORE AFFORDABLE CITY<br>WITH DIVERSITY.\",\"we need to plan for global<br>climate change, water and<br>energy programs must be robust\",\"Large companies are hiring<br>young people at wages that<br>don't reflect the cost of<br>living. It would be nice to<br>encourage them to find a<br>balance that would ensure their<br>employees could live in areas<br>that offer a reasonable commute<br>to their work.\",\"I REALLY LOVE THE CITY HOWEVER<br>I FEEL THE ARCH CENTER SHOULD<br>BE MOVED OUT OF DOWNTOWN.\",\"deal with the homeless<br>population, stop enabling pan<br>handling, other cities don't<br>allow panhandling and over<br>night camping and they don't<br>attract a population of people<br>completely dependent of city<br>resources, homeless should be a<br>temporary status but Austin has<br>allowed it to become a way of<br>life it is shameful and in<br>humane\",\"Stop taxing us out of the city!\",\"Traffic is poor.\",\"do something about the public<br>schools, the teachers can't<br>control the students anymore<br>because of political excuses\",\"RENT UNAFFORDABLE\",\"LOWER TAXES. MY TAXES HAVE<br>TRIPLED SINCE 2003\",\"Lobby the state to fix Robin<br>Hood. It is killing AISD and<br>families are leaving the<br>district, because property<br>taxes are too high.\",\"NEED EV CHARGING STATIONS\",\"I WOULD LIKE TO SEE MORE<br>SUPPORT SYSTEMS IN PLACE FOR<br>THE HOMELESS, AND STRONGER<br>ENFORCEMENT TO KEEP THEM OFF<br>THE STREET, INSTEAD SOMEWHERE<br>SAFE WHERE THEY CAN GET WHAT<br>THEY NEED.\",\"please assist homeowners and<br>single persons please review<br>facts and history, please help<br>better our neighborhoods, lease<br>let the $500\/mo. I pay in taxes<br>help me, I can't take on<br>everything alone\",\"Lower property tax on all<br>residential and rental<br>property. Higher (taxes) on<br>commercial property.\",\"stop taxing us out of homes\",\"Austin needs to get traffic and<br>affordable housing for regular<br>people under control if they<br>want to keep building and<br>growing the economy. Otherwise<br>it will just become another US<br>city with no character,<br>diversity, or distinction.\",\"Middle class people with child<br>care getting priced out of<br>Austin due to property taxes.<br>It shouldn't cost this much to<br>run a city, as other towns with<br>much less expensive houses are<br>able to do it. This is not a<br>livable city unless a person is<br>upper middle class or has no<br>children.\",\"Austin needs to push through<br>its progressive agenda to deal<br>with growth and transformation<br>to a large city. It can't be<br>held back by naysayers and<br>people scared of change. Do<br>what is best for Austin and<br>ignore those people and<br>(overreaction) by state and<br>national governments.\",\"Fix traffic problems. Fix<br>poorly timed lights. Cut out<br>racist behavior of<br>police\/government!\",\"Thank you! For all my<br>complaining, this really is a<br>great city.\",\"I feel like Austin's library<br>system is a wonderful resource<br>for residents. We have to work<br>on a systematic, realistic play<br>to renovate our dying<br>neighborhood pools.\",\"Property taxes are killing our<br>family. Income can't keep up!\",\"City of Austin staff morale is<br>not good.\",\"The cost of living in Austin<br>now outpaces the value. The<br>taxes, utilities, etc. have us<br>planning to leave. So<br>regrettable. But this is no<br>longer affordable or pleasant<br>for the 60-plus retirees!<br>You've run us out!\",\"Austin's rapid growth is not<br>slowing down. We need to make<br>changes like expanding public<br>transportation to match this<br>growth!\",\"Encourage people to live and<br>work in the same area. This<br>could greatly reduce traffic<br>congestion, reduce emissions.<br>Encourage healthy alternatives<br>for mobility (walking, bikes,<br>etc.). Encourage businesses to<br>hire employees living in same<br>area.\",\"Transportation needs to<br>improve.\",\"Transportation and traffic.\",\"Expand 3-1-1 and give them<br>power to be customer service<br>for all citizen questions.\",\"Please lower our property<br>taxes. I can barely afford to<br>live in Austin. Thank you.\",\"Think long term about the<br>infrastructure of the city and<br>how to move the growing numbers<br>of folks around town while<br>minimizing traffic.<br>Affordability is becoming an<br>issue, especially for housing<br>and taxes.\",\"WORK ON TRAFFIC-AFFORDABLE<br>HOUSING AND ACCESSIBILITY TO<br>RESOURCES FOR MINORITIES\",\"PLAN FOR THE FUTURE AND<br>SUSTAINABLE GROWTH. STOP<br>FOCUSING ON EXCLUSIVE SERVICES<br>LIKE TOLL ROAD EXPANSION AND<br>INSTEAD, PUSH FOR PROGRAMS WITH<br>THE LARGEST BENEFIT FOR THE<br>MOST PEOPLE IN THE FUTURE, LIKE<br>A SUBWAY SYSTEM AND<br>CITY-SPONSORED DISTRIBUTED<br>SOLAR AND ELECTRIC VEHICLE<br>NETWORK.\",\"HOUSING FOR RETIRED THAT WANT<br>TO STAY IN AUSTIN-TRAFFIC<br>CONCERNS--PROGRAMS FOR OUR<br>HOMELESS COMMUNITY\",\"I WOULD LIKE TO SEE THE LIGHT<br>RAIL EXTENDED TO ABIA AND COTA<br>BEFORE EXTENDING TO OTHER<br>AREAS. WITH ALL RADIATING OUT<br>OF A LARGER DOWNTOWN HUB.<br>RUNNING LIGHT RAIL ALL DAYS &<br>LATER INTO THE EVENING HOURS.\",\"FOCUS FIRST ON CORE CITY<br>SERVICES, THEN WORK ON CULTURAL<br>SOCIAL ISSUES. ALL ARE<br>IMPORTANT BUT A WELL<br>FUNCTIONING CITY LENDS ITSELF<br>TO FURTHER IMPROVEMENTS IN<br>QUALITY OF LIFE.\",\"THE PROBLEMS\/CRIME IN EAST<br>AUSTIN. I FEEL FOR THE FAMILIES<br>THAT MUST LIVE THERE. IT MUST<br>CREATE SCARY NIGHTS\",\"PLEASE CONSIDER THE<br>OVERDEVELOPMENT IN SOUTH AND<br>EAST AUSTIN. A GREAT DEAL OF<br>THE CULTURE AND FEEL OF THE<br>CITY THAT I MOVED HERE FOR IS<br>RAPIDLY DISAPPEARING.\",\"ENCOURAGE MORE HIGH QUALITY<br>CHILDCARE IN TOWN\",\"DO SOMETHING EFFECTIVE ABOUT<br>THE TRANSIENTS THAT ARE RUINING<br>AREAS AROUND DOWNTOWN &<br>SLAUGHTER LANE\/I-35 AREAS. IT<br>IS DISGRACEFUL. PROHIBIT PAN<br>HANDLING AND LIVING UNDER<br>BRIDGES. OPEN AN EFFECTIVE<br>PATHWAY (HOUSING FOR HOMELESS)<br>STOP RAISING PROPERTY TAXES FOR<br>HOMEOWNERS & ALLOWING<br>BUSINESSES TO CONTINUE GETTING<br>TAX BREAKS.\",\"DO SOMETHING ABOUT THE TAXES ON<br>HOMES. IF NOT, YOU WILL HAVE A<br>CITY WITH NO RESIDENTS.\",\"TRAFFIC & INFRASTRUCTURE<br>IMPROVEMENT FOR RESIDENTS,<br>WORKERS AND ENHANCING<br>ATTRACTIVENESS FOR NEW<br>BUSINESSES AND TECHNOLOGY<br>GROUPS.\",\"HELP MORE WITH SMALL BUSINESSES<br>(HELPING TO MAKE PERMITTING<br>MORE EASY AND TRANSPARENT); TOO<br>EXPENSIVE PERMITTING AND TIME<br>CONSUMING, WHICH LEADS TO MORE<br>FAILED OR NEVER EVEN STARTED<br>BUSINESSES\",\"We need to tackle homelessness<br>we don't feel safe. No more<br>panhandling or camps in our<br>through fares. This has to stop<br>we are fed up and considering<br>moving.\",\"Continue to focus on mass<br>transit and renewable energy as<br>well as affordability.\",\"Improve public transportation<br>as in faster and more options.<br>Would help everyone as keeps<br>roads clear less traffic and<br>pollution. Acc is wonderful<br>system that is a key driver of<br>jobs in Austin.\",\"Study large cities like Atlanta<br>and widen and build more roads.<br>Traffic is awful. Lights need<br>to be timed better. Lower<br>property taxes and tax<br>visitors, like Florida. Tax<br>hotels, rental cars, etc.\",\"Stop raising property taxes.\",\"South 1st street between<br>Stassney Lane and WM Cannon<br>Drive is worn out.\",\"Funding to help homeless get<br>jobs & care & send pamphlets<br>out how to help and what<br>resources are available for<br>them.\",\"Don't destroy modest single<br>family neighborhoods. Putting<br>rental properties in too many<br>backyards will drive out<br>established citizens.\",\"Traffic lights should be timed.<br>Safety.\",\"Improve I35\",\"Increase tolls on large<br>vehicles & parking fees on<br>large trucks. Keep on energy<br>conservation increase buses and<br>use of carpools.\",\"Let's not price out our east<br>Austin families through<br>gentrification because of<br>property taxes.\",\"Focus budget on infrastructure<br>and less on diversity programs.\",\"Help get rid of Robin Hood law<br>for education.\",\"Need to lookout for low income<br>residents don't push them out<br>as they have value too.\",\"Develop more affordable housing<br>and access to healthcare for<br>those on Medicaid.\",\"Invest in public transportation<br>and increase number of city<br>council districts.\",\"City should be thinking longer<br>term for infrastructure.\",\"Cost of living and housing<br>buying or renting is too high.\",\"Don't let the state legislature<br>bully Austin.\",\"Improve roads for cars.\",\"Rewrite zoning codes. Mass<br>transit.\",\"PARTNER WITH STATE TO CAP<br>PROPERTY TAX INCREASES.<br>PROPERTY TAXES ARE THE DRIVER<br>FOR LOW INCOME FAMILY<br>DISPLACEMENT.\",\"Overgrowth, cost of housing\",\"BETTER TRAFFIC LAW ENFORCEMENT<br>NEEDED. PRICE CITY UTILITY<br>SERVICES TO BENEFIT THOSE ON A<br>FIXED INCOME. COST OF LIVING IS<br>HIGH\",\"FIX TRAFFIC PROBLEMS\",\"Help traffic problem!\",\"TRAFFIC AND AFFORDABILITY ARE<br>MY TWO BIGGEST CONCERNS FOR THE<br>FUTURE. I LOVE MY CITY AND WANT<br>TO STAY HERE.\",\"Take the electric scooters off<br>of the sidewalks downtown!<br>Especially on 6th street. I<br>have been almost hit or run<br>over while walking!\",\"Affordable senior living.\",\"Low\/moderate income housing is<br>a major problem. People are<br>being taxed out of their homes.\",\"I really love the \\\"vibe\\\" of<br>Austin, welcoming and<br>accepting, outdoorsy and<br>active, health and<br>environmentally conscious.<br>Austin is creative, innovative,<br>and weird in the best way, but,<br>I do hope the city can improve<br>upon the traffic and housing<br>issues.\",\"Things have changed a little<br>too much since 2004. Safety is<br>a big issue now that I have a<br>child. My friends cannot afford<br>to live here anymore, I may<br>join them soon. Daycare is<br>12,000 a year on average for<br>once child.\",\"If my husband hadn't bought<br>this house in 1993, there is<br>not way we could afford to live<br>in Central Austin. As an<br>employee of AISD, the majority<br>of my colleagues (in my<br>department) live in<br>Pflugerville, Round Rock, and<br>other suburbs. There must be<br>housing stock in the City for<br>EVERYONE. Economic diversity<br>and cultural diversity are<br>evaporating here.\",\"The toll roads are ridiculous.<br>Housing is on the rise. Unless<br>you are on assistance,<br>childcare is $1,100 a month and<br>going up.\",\"KEEP IT UP SUPORT MLS\",\"Traffic congestion must be<br>solved.\",\"More work on walk-ability<br>outside of CBD.\",\"Bike lanes are absurd.\",\"Work on traffic delays. I like<br>our mayor.\",\"STOP WASTING MONEY ON WELFARE<br>AND SOCIAL PRGRAMS. MAKE AUSTIN<br>MORE OF A FREE MARKET TO<br>ATTRACT MORE BUSINESS. ALSO<br>SUPPORT OUR POLICE\/FIRE\/EMS.\",\"I love living in Austin.\",\"KEEP THE PARKS\/GREEN SPACES<br>GREAT.\",\"DON'T WORRY ABOUT BEING<br>POLITICALLY CORRECT. THERE ARE<br>MORE IMPORTANT THINGS THAT NEED<br>ADDRESSING.\",\"ENFORCE THE LAWS OF THIS<br>COUNTRY. DO NOT CATER TO<br>ILLEGALS WHO DO NOT CONTRIBUTE\",\"FOCUS ON CITY SERVICES, NOT ON<br>DEMOCRATIC SOCIALIST ISSUES\",\"I really want Austin and Travis<br>County doing everything to stop<br>child abductions, molestation<br>and murder.\",\"WE ARE ATTORNEYS WHO MOVED TO<br>DOWNTOWN AUSTIN, LIVE IN A<br>CONDO. HOMELESS ISSUE IS<br>CAUSING US TO RETHINK THOSE<br>CHOICES. OUR LEASE ENDS IN<br>2021. WE WILL MOVE OUT OF<br>DOWNTOWN BECAUSE OF THE<br>HOMELESS. WHY DOES AUSTIN NOT<br>VALUE US?\",\"PLEASE TAKE ACTION TO FIX<br>TRAFFIC AT THE Y JUNCTION OF<br>290 AND 71.\",\"More bike lanes and better bus<br>rates please.\",\"Address the traffic issues. I<br>have to use MoPac to get to<br>work and the commute is<br>horrible. Added to that,<br>enforce the hands free rule. I<br>see multiple people each day<br>using their phones, reading a<br>newspaper, etc.\",\"We need to spend out tax money<br>on essential services first and<br>get those up to par before<br>funding other programs.\",\"IMPROVE TRAFFIC AND KEEP THE<br>POLICE ON A VERY SHORT LEASH.\",\"More of an effort to preserve<br>local businesses that are<br>pushed out by sky rocketing<br>rent, and also the residents.\",\"I WOULD APPRECIATE EXPANDED<br>LATE NIGHT BUS SERVICE BETWEEN<br>DOWNTOWN AND NORTHWEST AUSTIN.<br>BY THIS, SERVICE RUNNING LATER<br>THAN 11 PM.\",\"OUTLAW HOMELESS AT EVERY CORNER\",\"Keep the parks (specifically<br>Zilker) for people of the city<br>and if there are festivals,<br>keep them as short as possible<br>to not stop the people from<br>being able to use their parks.<br>Lastly, don't add parking<br>meters to parks to compensate<br>for damage done by festivals<br>that already take our parks<br>temporarily away from us.\",\"Traffic and affordability\",\"Please help the city build more<br>housing types for all type of<br>people in all neighborhoods.\",\"ENCOURAGE THE CITY TO DO MORE<br>TO ADDRESS THE RACISM\",\"More affordable housing in<br>reach of low income people.\",\"we need better parking options<br>for the wonderful events we<br>have here in Austin and<br>community places like ziller<br>and barton springs\",\"WOULD LIKE TO SEE IMPROVED<br>INFRASTRUCTURE FOR BIKES AND<br>PEDESTRIANS.\",\"VERY HAPPY WITH COMPOSTING AND<br>RECYCLING PROGRAM. VERY UNHAPPY<br>WITH TRANSPORTATION AND NOT<br>ENOUGH PROGRAMS FOR THE<br>HOMELESS\",\"Fix the homeless problem.\",\"NEED GREEN SPACE.<br>TRANSPORTATION NEEDED. ADD TO<br>PARK SYSTEM.\",\"LOWER WATER COST.\",\"(1) Help the homeless. (2)<br>Implement anti-bullying in<br>schools!\",\"(1) Affordable housing. (2)<br>Complete transportation plan.<br>(3) Annual audits of City<br>Departments.\",\"Streamline the development and<br>permitting process for<br>remodeling one family<br>residences. It is too<br>cumbersome, expensive and time<br>consuming, the requirements for<br>submission require costly<br>hiring of architects, etc. I'm<br>all for protecting mature<br>trees, but the level of<br>scrutiny and regulation is<br>excessive and seems conflicts<br>between what a family's needs<br>are for their home and existing<br>trees are settled always in<br>favor of trees.\",\"PLEASE focus on our city, not<br>national issues where you have<br>no direct affect. You were<br>elected to run OUR city, not<br>our state nor country.\",\"Cost of housing!!!\",\"Please keep our pools open and<br>help with the traffic and<br>crime.\",\"Improving city streets is<br>essential for transportation<br>for the vast majority of Austin<br>citizens and for public safety.<br>Police, fire and EMS need<br>street maintenance and traffic<br>flow to provide public safety<br>services efficiently. Stop<br>obstructing traffic flow and<br>reducing traffic capacity. Very<br>few citizens actually use bike<br>lanes. We all have to drive<br>cars!\",\"Traffic is the thing that most<br>affects my quality of life in<br>Austin. We desperately need<br>better mass transit,<br>specifically train\/light rail.<br>Another less expensive fix<br>would be to properly time the<br>freaking traffic lights!\",\"More bike lanes. More public<br>transit. Less cars.\",\"As a member of Austin Homeless<br>Committee, I see many positive<br>things being dealt with, many<br>good ideas being discussed and<br>hopefully put into action. Even<br>though there are still<br>problems, at least they are<br>being done slowly than none<br>done at all.\",\"Traffic.\",\"The police need to learn how to<br>direct traffic during major<br>events! Like ACL and SXSW!<br>Instead of just standing around<br>and looking at people in need<br>!!!\",\"Make it affordable to live here<br>and get to work on time.\",\"We need more public<br>transportation options.\",\"Keep pushing for mandatory paid<br>sick leave for all employees.\",\"Utilize<br>research\/grants\/volunteers all<br>hands on deck for support of<br>mental health of Austin folks.<br>Don't just study it get some<br>helpful therapies going.\",\"Property taxes are rising at an<br>alarming rate! Every year. When<br>will it level out? This is our<br>greatest concern as residents<br>of Austin.\",\"Have time to have neighborhood<br>mtgs and get to know the<br>residents. Thank you are doing<br>a great job.\",\"Be wary of trying to be too<br>much like California. This may<br>be Austin but it is still<br>Texas.\",\"Please fix my curb it cost me<br>3k in repairs when meter burst.<br>Better buses\/routes and a train<br>to airport.\",\"KEEP GREEN AREAS IN AUSTIN IS<br>IMPORTANT THEY ARE BUILDING TOO<br>MUCH. EDUCATION CODE AT SCHOOLS<br>ARE TOO LOW.\",\"Most people state that Austin<br>is one of the greatest cities<br>on earth and that is not true.<br>Far from being a leading city<br>so have the ambition to make<br>Austin a leading world capital<br>and brand it as such. Stop<br>thinking small. Change the<br>sister cities program to<br>include great cities worldwide.\",\"STOP RAISING MY PROPERTY TAXES!<br>REPLACE PROPERTY TAXES WITH<br>INCOME BASED TAX.\",\"help the low income into nicer<br>homes or apts instead of the<br>dangerous places they put<br>people, get rid of the arch<br>downtown and move it, clean<br>things up\",\"Make city programs accessible.<br>Would like to know what<br>learning, training and<br>activities are offered by the<br>city of within the library.\",\"Stop trying to make Austin into<br>New York, Chicago or San<br>Francisco, with policies<br>pushing urban density and mass<br>transit. The reason those<br>places have mass transit is<br>that their core predates the<br>auto and it was too expensive<br>to retrofit. Texans like the<br>independence and freedom of the<br>auto, and wide-open spaces (At<br>least in the burbs). Let it be.<br>Use taxes for more auto lanes.<br>(Also support telecommuting.)\",\"More lighting on streets\/parks<br>@ night. Lower homeless<br>population as I don't feel safe<br>downtown because of excessive<br>homeless. Parks in my<br>neighborhood are not safe.\",\"CONTINUE TO BUILD<br>INFRASTRUCTURE TO ENSURE CITY<br>STAYS PREPARED FOR GROWTH.<br>FOCUS ON IMPROVING SCHOOL<br>SYSTEM IN ALL AREAS OF THE<br>CITY.\",\"Lower overall government<br>spending on lower priority<br>issues in order to focus more<br>on growth factors before it is<br>too late.\",\"PLEASE DO MORE TO CLEAN UP THE<br>CITY AS A WHOLE BUT ESPECIALLY<br>CONCENTRATE IN THE RUTLAND<br>LAMAR AND RUNDBERG RESIDENTIAL<br>AREAS. SUPER TIRED OF TRASH AND<br>JUNKY CARS.\",\"build the infrastructure\",\"NEW BETTER BIKE LANES AND DO<br>NOT CHARGE TO PARK AT TOWN<br>LAKE.\",\"It will only add to a lot of<br>tax dollars.\",\"Focus on alt. transportation,<br>city beautification, education<br>and safety.\",\"focus on transportation like<br>roads and traffic lights.\",\"WE HAVE HUGH HOMELESSNESS<br>PROBLEM AND I WOULD LIKE TO SEE<br>MORE EFFORTS TO SERVE THIS<br>POPULATION.\",\"my family and I are able to<br>live comfortably in Austin,<br>please provide housing that<br>everyone who wants to live in<br>Austin can afford and be<br>comfortable with and lets take<br>better care of mental health<br>issues more services not less\",\"PRESERVE LAKE FRONT AND GREEN<br>SPACE WHAT'S LEFT OF IT. LIKE<br>CHICAGO HAS DONE WHILE STILL<br>HAVING EXCELLENT PUBLIC<br>TRANSPORTATION INCLUDING<br>TRAINS.\",\"transportation is ridiculous<br>and housing prices are absurd\",\"Truly address the road\/traffic<br>issue in Austin. 360, 620, I-35<br>and East-West limited access<br>must be fixed.\",\"Affordability needs fixed to<br>keep us from turning into San<br>Francisco-and they at least<br>have good public<br>transportation.\",\"Infrastructure, HOV lanes,<br>train schedule and routes (need<br>more and increase the times in<br>which the trains run especially<br>on weekends).\",\"PROPERTY TAXES ARE TOO HIGH, WE<br>CAN'T AFFORD ANY DEALS FOR BU<br>SINESS BRINGING JOBS TO AUSTIN,<br>IF PEOPLE HAVE TO DRIVER FOR<br>HOURS TO WORK THOSE JOBS OR THE<br>FOLKS WHO SELL THEM SANDWICHES<br>AND CLEAN THEIR OFFICES AND<br>WORK WITHIN LIBRARIES AND TEACH<br>THEIR KIDS. PUBLIC<br>TRANSPORTATION IS POOF\",\"work on parking\/traffic and<br>access to affordable<br>healthcare, move the arc<br>downtown, the homeless are<br>overtaking downtown in that<br>area, I don't feel safe enough<br>to go east of congress at night<br>anymore\",\"Clean up your streets from<br>homeless people. Clean up<br>highways from trash (really<br>looks bad). More state troopers<br>on the highways.\",\"INVEST IN PUBLIC<br>TRANSPORTATION.\",\"MAYOR ADLER IS DOING A GOOD JOB<br>AS MAYOR OF AUSTIN. HE SEEMS TO<br>HAVE THE BEST FOR AUSTIN AT<br>HEART. KEEP ON KEEPING ON.\",\"Prioritize large road project<br>and connect the airport to<br>downtown without having to go<br>through a traffic light.\",\"A practical, area-wide 24\/7<br>light rail system, please.\",\"TRANSPORTATION NEEDS TO BE AT<br>THE TOP OF THE AGENDA. BETTER<br>MAIN ROAD NETWORKS.\",\"Affordable housing for low<br>income families.\",\"ALTERNATIVE TRANSPORTATION<br>IMPROVEMENT\",\"Austin needs a new police<br>contract that is favorable to<br>the fire officers of the<br>department. No more delays!\",\"INCREASE IN THEFT IS UPSETTING.<br>WE WILL HAVE TO LOOK AT MOVING<br>EVENTUALLY DUE TO UNSAVORY<br>ACTIVITY AND POOR RATINGS AT<br>THE SCHOOL\",\"THERE WERE FLAWS WITH CODE NEXT<br>THAT FAVORED DEVELOPERS BUT<br>OVERALL WE NEED TO MAKE IT<br>POSSIBLE FOR MORE PEOPLE TO<br>LIVE AND WORK IN AUSTIN, THIS<br>MEANS INCREASED DENSITY AND<br>IMPROVED PUBLIC TRANSPORTATION\",\"BEAUTIFUL CITY WISH IT WAS A<br>BIT EASIER TO GET AROUND.\",\"QUIT CATERING TO DEVELOPERS.\",\"KEEP AUSTIN DIVERSE BY<br>SUPPORTING GOOD PUBLIC PROGRAMS<br>AND REGULATIONS.\",\"MAKE HOUSING MORE AFFORDABLE.\",\"Traffic - get rid of \\\"funnel\\\"<br>roads. i.e. 4 lanes go to 2<br>thus creating traffic. Get a<br>\\\"real\\\" light rail - a raised<br>system like a monorail could go<br>down major roadways, use<br>shopping parking lots and you<br>get people to their work and<br>shopping and play. Monorails<br>are quiet.\",\"I HOPE THE CITY DOES FOCUS ON<br>PRESERVING HISTORY AND MAKING<br>THE CITY ACCESSIBLE AND<br>AFFORDABLE FOR ALL .\",\"taxes are out of control\",\"we need lower price housing<br>within the city\",\"Austin should be easier and<br>safe to bike around in parmer<br>lane is very close to my house<br>and the speed limit is 60 which<br>I find too high it's not safe<br>to bike there next to the cars,<br>the bike lane needs to be<br>separated I would really like<br>to be able to bike to my son's<br>school, grocery stores,<br>playgrounds etc.\",\"Safety, growth, and traffic are<br>#1. Then we need to focus on<br>education, culture, fairness,<br>equity, conservation of our<br>resources. I do feel those of<br>us in zip codes such as 78726<br>feel left out of city<br>priorities and decisions<br>regularly.\",\"BICYCLES DO NOT MIX WELL WITH<br>AUTOS.\",\"GROWTH NEEDS TO BE THOUGHTFULLY<br>MANAGED. TRANSPORTATION ISSUES<br>AND AFFORDABLE HOUSING\",\"Find a way to get people moving<br>around our city.\",\"please stop promoting \\\"wants\\\"<br>new library that raise taxes<br>and lets spend tax money on<br>needs\",\"WE ARE BEING SQUEEZED OUT BY<br>GROWTH THAT IS DRIVING UP THE<br>COST OF LIVING. WE SEE LITTLE<br>VALUE BUT TAXES GO UP.\",\"RESPOND TO 311\",\"traffic sucks\",\"Your city will ruin itself big<br>time if you do not address its<br>transportation or affordability<br>issues (you seem to be at least<br>trying w\/the latter).\",\"PLEASE LOOK INTO ABOVE OR BELOW<br>GROUND TRAIN SYSTEMS.\",\"TRAFFIC CONCERNS AND NEED FOR<br>MASS TRANSIT.\",\"he is doing a great job\",\"How will Austin move residents<br>of high density housing being<br>built today? The roadways are<br>clogged all day. The wildlife<br>has been displaced and lost<br>food\/shelter.\",\"QUIT BEING SO LIBERAL TO GRAB<br>NATIONAL ATTENTION. IF YOU BID<br>ON THE WALL, YOU CAN'T BID ON A<br>COA PROJECT. IF YOU HELPED<br>DETAIN CHILDREN AT THE BORDER,<br>YOU CAN'T WORK FOR COA.\",\"City growth rates have made<br>taxes and cost of home buying<br>unaffordable to most people<br>that were born and raised in<br>Austin. It is very sad because<br>we are losing the people that<br>shaped ATX to be such a great<br>city to live in. Now we are<br>just becoming like all the<br>other large cities in Texas.<br>Overrun with homeless, violent,<br>and expensive.\",\"Bus system to anywhere other<br>than downtown is insufficient<br>for a city this size. Need<br>frequency and accessibility.\",\"please help keep the cost of<br>living low in Austin\",\"QUALITY OF LIFE IS BEING<br>DEGRADED\",\"FIX THE TRAFFIC PROBLEM\",\"PROVIDE MORE AFFORDABLE HOUSING\",\"Stop trying to be SOMEBODY,<br>just do your job and provide<br>police, fire and good road<br>repair. Insist that if a person<br>is driving without a license or<br>insurance, impound their<br>vehicle.\",\"CONTROL GROWTH TO PRESERVE<br>CHARACTER AND QUALITY OF LIFE<br>FOR ALL\",\"We are losing Austin, Texas<br>trying to make it like other<br>cities. Taking the streets from<br>vehicles and giving it non<br>taxable bikers. This not<br>helping traffic at all! The<br>school taxes may be high but<br>our schools are crumbling and<br>nothing is being done about it.<br>School administration is making<br>a fortune, not teachers. And<br>schools are being torn down,<br>not repaired.\",\"I love Austin\",\"to update transportation<br>infrastructure to keep up with<br>new residents influx\",\"control growth\",\"PLEASE SOLVE THE MASSIVE<br>HOMELESSNESS PROBLEM AT 290 AND<br>MANCHACA- IT IS CAUSING HUGE<br>SAFETY CONCERNS IN THE<br>NEIGHBORHOOD.\",\"its getting too survive in<br>Austin, I plan on moving soon<br>because I cant afford it<br>anymore\",\"My friends and I regularly use<br>the pools and parks and trails.<br>I understand the need for<br>revenue, but resent having<br>parking meters around Zilker<br>Park\/Greenbelt access and Hike<br>and Bike access at Lady Bird<br>Lake. The meters at Zilker<br>don't until 8:00 am, but those<br>of us who start runs or hikes<br>on greenbelt like to start<br>earlier. We are regular users.<br>I would like the city to<br>consider having discounted<br>parking pass for those who<br>frequent the parks and trails.\",\"FIX AFFORDABLE HOUSING IN THIS<br>CITY BEFORE IT BECOMES DALLAS\",\"PLEASE PROMOTE AUTOMATIC REMOTE<br>READING FOR WATER\/WASTEWATER<br>READING. REDUCE OVERALL EXCESS<br>LIGHTING TO REDUCE LIGHT<br>POLLUTION AND LOWER COST OF<br>ELECTRICAL PRODUCTION FOR<br>PUBLIC BUILDINGS.\",\"MAJOR PERCENT OF CITY MONIES<br>SHOULD BE GOING TO ROADS, NOT<br>BICYCLES OR BIKE LANES. VEHICLE<br>TRAFFIC TAKES MINIMUM OF 1 HOUR<br>PER DAY--WE WILL BE LEAVING<br>AUSTIN EVENTUALLY BECAUSE OF<br>TRAFFIC.\",\"We have loved Austin. We<br>embrace change and growth. But<br>is the current trends continue,<br>we will move to a state with an<br>income tax, rather than a<br>poorly-managed property tax<br>system and Robin Hood funding<br>of schools.\",\"Please stop trying to be so<br>\\\"progressive\\\". Leave people<br>alone. It is NOT your job to<br>instantly focus on \\\"helping<br>people\\\". Your job is to provide<br>police\/fire\/EMS, roads,<br>parking, etc. THAT'S ALL.\",\"REDUCE TAXES (ESPECIALLY AS IT<br>RELATES TO CITY'S EFFORTS TO<br>PROVIDE LOWCOST HOUSING; I DO<br>NOT AGREE THAT THIS IS A CITY<br>RESPONSIBILITY)\",\"I WAS BORN HERE-WOULD LIKE TO<br>DIE HERE-SCARED I WON'T BE ABLE<br>TO AFFORD TO.\",\"TRAFFIC SHOULD BE NUMBER 1\",\"Traffic law enforcement and<br>street maintenance.\",\"A GROWING NUMBER OF AUSTIN<br>RESIDENTS THAT HAVE LIVED AND<br>WORKED IN AUSTIN FOR DECADES,<br>ARE RETIRED. THEY STILL HAVE<br>THE EXPERIENCES AND TRAINING TO<br>ASSIST IN FACILITIES, HEALTH<br>CARE, EDUCATION,BUT ARE NOT<br>BEING UTILIZED. LOOK FOR WAYS<br>TO ENGAGE THIS LOST HUMAN<br>RESOURCE.\",\"Affordability, affordability,<br>affordability! We have to keep<br>housing affordable for<br>EVERYONE!\",\"Traffic is this city's worst<br>problem. All resources should<br>be tuned to that problem. Light<br>rail, signage, traffic lights,<br>garbage collection, police,<br>everything!\",\"PLEASE DO SOMETHING TO GET<br>PANHANDLERS OFF THE STREET.<br>PLEASE KEEP HOMELESS FROM<br>SLEEPING IN PUBLIC.\",\"I love Austin. Traffic seems to<br>be the biggest headache for me.\",\"THIS SOCCER STADIUM IDEA IS<br>TERRIBLE-AUSTIN IS NOT A GREAT<br>CITY DESPITE ITS LACK OF SPORTS<br>CULTURE, RATHER BECAUSE OF ITS<br>LACK OF SPORTS CULTURE. IN NO<br>WAY DOES THIS SERVE THE MEMBERS<br>OF OUR COMMUNITY. FOCUS INSTEAD<br>ON ZONING IMPROVEMENTS AND<br>TRAFFIC ALLEVIATION.\",\"HOUSING PRICE INCREASES ARE A<br>MAJOR CONCERN FOR OTHER<br>STUDENTS AND ME. RENTING A<br>1BDRM APARTMENT NEAR CAMPUS IS<br>BECOMING DIFFICULT ON A<br>GRADUATE STIPEND.\",\"DEAR MAYOR OF AUSTIN: LETS KEEP<br>GROWING AND TRY TO MAKE AUSTIN<br>A SMART CITY. LET'S UPGRADE OUR<br>TRAILS\/BIKE LANES\",\"GROWTH DOES NOT PAY FOR ITSELF.<br>QUIT RECRUITING AND PAYING<br>INCENTIVES TO RELOCATE HERE.<br>ITS DONE ON THE BACKS OF AND TO<br>THE DETRIMENT OF CURRENT<br>RESIDENTS.\",\"IMPROVE THE FACILITIES WE<br>HAVE-STREETS, PARKS, SIDEWALK<br>AND STOP UNFETTERED BUILDING<br>AND INTRODUCTION OF MORE UNSAFE<br>MODES OF TRAVEL DOWNTOWN. COME<br>TAKE A LOOK AT THE MESS CALLED<br>RAINEY NEIGHBORHOOD\",\"LOWER PROPERTY TAXES\",\"I have a great concern I will<br>be priced out of living in<br>Austin. I love it here. It is<br>disappointing and sad.\",\"With drought conditions and no<br>new roads, why are new<br>sub-divisions, high rises,<br>etc., being given permits?<br>There was only one city council<br>member who looked at the whole<br>picture\/situation and tried to<br>make some sense with the ever<br>growing population.\",\"KEEP UP THE GOOD WORK\",\"City of Austin is one of the<br>best cities that I have been<br>in.\",\"TO HELP MENTAL HEALTH PEOPLE<br>GET SSI, HOUSING AND FOOD\",\"WE REALLY NEED TO IMPROVE THE<br>HOMELESS SITUATION,<br>PARTICULARLY IN THE DOWNTOWN<br>AREA AND EAST AUSTIN. BESIDES<br>BECOMING A SAFETY ISSUE, I HAVE<br>SEVERAL VISITORS TO AUSTIN<br>COMMENT ABOUT SEEING HOMELESS<br>ENCAMPMENTS WHICH NEGATIVELY<br>IMPACTS THE VIEW OF OUR CITY.\",\"IMPROVE PUBLIC TRANSPORTATION\",\"LOVE THE CITY OF AUSTIN. KEEP<br>THE CULTURE AND OPPORTUNITIES.<br>ONLY REAL CHARGES WOULD BE TO<br>IMPROVE TRAFFIC FLOW AND MAYBE<br>ADD SOME BIKE LANES DOWNTOWN.\",\"DON'T CONTINUE YOUR DESTRUCTION<br>OF AUSTIN BY RUNNING OUT THE<br>MUSIC VENUES AND RESTAURANTS.\",\"Taxes are too high so when<br>making the budgets that should<br>be considered.\",\"More diligence in sustainable<br>growth. No more large<br>developments without needed<br>infrastructure improvements at<br>the same time. Thanks for this<br>survey.\",\"Keep our city progressive<br>socially, economically,<br>politically, culturally,<br>environmentally etc. Our future<br>lies not in some bigoted idea<br>we need to make our nation &<br>cities great. Build a new<br>future not idealize a<br>fabricated past.\",\"We need other revenue for<br>schools. Affordability of<br>everything jeopardizes the<br>people that helped Austin get<br>to this point. Education,<br>traffic are main concerns.\",\"Housing affordability & traffic<br>need fixed. If San Antonio can<br>do so can we.\",\"more effort to provide housing<br>to residents displaced by<br>gentrification\",\"continue to assist with helping<br>with traffic congestion, help<br>for financial disadvantage to<br>get affordable housing, help<br>prevent homeless\",\"need more affordable housing<br>and more public transportation<br>to ensure diverse and<br>successful population\",\"ENFORCEING CITY CODES, TRIM<br>TREES THAT PROTRUDE ACROSS<br>STREETS, FIX POTHOLES, STOP<br>WTIH ALL THE LARGE APT BLDGS<br>ESPECIALLY INNEIGHBORHOODS,<br>SLOW DOWN JUST A LITTLE\",\"Please see my response<br>regarding the redevelopment of<br>existing neighborhoods that is<br>altering the character of the<br>area. Some of us are being<br>priced out of our longtime<br>homes by soaring home<br>valuations and the resulting<br>taxes, in addition to losing<br>some of the feel of the area<br>that brought us here in the<br>first place. My long-term plan<br>had been to live out my<br>retirement years in Austin, but<br>over the past year have been<br>rethinking this.\",\"stop bldg. for more people and<br>start providing infrastructure<br>first, preserve the charm and<br>spirit of Austin (too late)<br>rather than slash and build<br>into a horrendous every city,<br>alternated effective<br>transportation esp. for low<br>income\",\"this is a magical city to live<br>in, I hope Austin can keep the<br>things that make it unique<br>intact as it continues to grow.<br>we also need to admit we are<br>growing and scale our<br>infrastructure accordingly\",\"it seems city council have<br>problems making decision and<br>spends too much money on<br>studies and research\",\"better the train system more<br>affordable children activities,<br>more opportunities to take<br>advantage of the culture and<br>museums in Austin but adding<br>more free days for the<br>residents and keep Austin the<br>music capital, protect what<br>makes Austin . Austin is great,<br>over pricing goo families will<br>not keep families based here,<br>we relocated to Austin from<br>Chicago and our paying more and<br>getting less and Chicago at<br>least had more trains to<br>accommodate and more children<br>programs\",\"STUDENT HOUSING IS BAD.<br>AMENITIES MAKE PRICES HIGHER. I<br>LIKE THE EFFORTS IN GETTING US<br>OPPORTUNITIES TO VOTE AND BE<br>HEARD\",\"KEEP UP THE GREAT WORK BUT PLAN<br>AHEAD FOR GROWTH.\",\"NEIGHBORHOOD PRESERVATION AND<br>AFFORDABLE HOUSING\",\"SMALL BUSINESS OWNER, YOU MUST<br>WORK WITH US. LAND BAG<br>ORDINANCE AND ORGANIC DIVERSION<br>REQUIREMENTS ARE VERY DEVISIVE\",\"Stop the republicans\",\"SERVE RESIDENTS OVER WEALTHY<br>DEVELOPERS.\",\"IMPROVE HOUSING, GET HOMELESS<br>OFF THE STREET.\",\"I LOVE THE APD AND 311 APPS.<br>APPRECIATE THE CITY'S EFFORTS<br>TO PAY ATTENTION TO THE NEEDS .\",\"CITY SHOULD STRIVE TO LOWER THE<br>TAX BURDEN ON ALL FAMILIES.<br>FOCUS ON PUBLIC SAFETY, UTILITY<br>AND SANITATION, NOT ON<br>AMENITIES.\",\"There needs to be a fundamental<br>change on how we view the<br>infrastructure of Austin in<br>terms of housing!<br>Transportation, particularly<br>transportation. We need a major<br>shift\/change in public<br>transportation.\",\"BETTER UPDATING ON ZONING CAN<br>ONLY HELP AUSTIN\",\"TOO MUCH EMPHASIS ON RACES\",\"KEEP ENCOURAGING DIVERSITY.\",\"Keep the focus on making it<br>pedestrian, bike and outdoor<br>friendly. The changes are<br>happening and it's wonderful.\",\"AUSTIN HAS A LOT OF JOBS AND A<br>GREAT UNIVERSITY. TRAFFIC IS<br>BAD. NEED TO FIX THE ROADS.\",\"we need to clean up the city .<br>Austin used to be a beautiful<br>city , the roads are littered<br>the city is ugly. under 6th and<br>35, 1st and 35, almost every<br>major intersection there is a<br>trash problem\",\"All aspects of homeless<br>situation needs to be fixed.\",\"First, thank you for doing a<br>great job for the citizens of<br>Austin and standing up for the<br>dreamers and undocumented<br>residents. Second, please do<br>more to address the traffic<br>concerns. Add elevated<br>monorails downtown or<br>something. If we just keep<br>trying to fix what we have,<br>we'll always be trying to play<br>catch up to the flood of people<br>moving here daily.\",\"Keep promises that were<br>publicly stated during an<br>election.\",\"Fix the Traffic lights in this<br>town they cause massive<br>congestion by not being timed<br>well\",\"We must have affordable<br>housing. Austin is a great<br>place to be, but we really<br>can't afford to liver here, and<br>have out small business here -<br>after we have worked so hard to<br>build our business, we still<br>aren't making a living at it<br>after more than 12 years<br>because costs go up so much.\",\"AFFORDABLE HOUSING!!! HCHDPP is<br>great, but still not enough.\",\"I love what the city is doing<br>with the trails and safe bike<br>lanes. I love the Rio Grand<br>Bike Trails and the downtown<br>library so very much. Thanks<br>for all you do.\",\"More transportation options.\",\"Homeless problem is out of<br>control, and the city's<br>proposals and approach,(more<br>money, continued sift touch)<br>aren't working. It<br>disproportionately affects a<br>single area, and it makes<br>quality of life poor, the<br>neighborhood unsafe. The<br>approach and tone must change.\",\"MORE PUBLIC TRANSPORTATION<br>PLEASE! TRAINS ARE GREAT! EVERY<br>THRIVING CITY HAS THEM! (I'm<br>from Chicago and grew up<br>there).\",\"Housing affordability is a real<br>problem for middle income folks<br>and much too much for low<br>income housing and not enough<br>for market rate housing.\",\"We need to get light rail<br>expansion. Maybe instead of a<br>large plan, do small additions.\",\"Remember you serve the people,<br>not yourselves. Seriously.\",\"Use UT, St Ed's to problem<br>solve City growth and<br>sustainability issues. Great<br>master and doctoral thesis!\",\"Plan for more cars on the<br>highway during rush hour and<br>enforcement of the \\\"slower<br>traffic keep right\\\" laws would<br>go a long way.\",\"As Austin grows, we need to<br>ensure the city remains<br>affordable for the many<br>talented smart young people who<br>move here for school.\",\"Please don't allow Austin ISD<br>to kick churches out of it's<br>facilities. What about<br>religious freedom? Austin<br>should be accepting of ALL<br>views including those of us who<br>choose to follow Jesus Christ.<br>Please don't persecute<br>Christians for our beliefs as<br>the city \\\"includes\\\" everyone<br>else.\",\"HOUSING AFFODABILITY\",\"Our garbage and recycling bins<br>are confusing and unorganized<br>since we are a complex with<br>multiple dwellings and only<br>have bins, such as brown bins<br>recycling signs but do not<br>clarify if are waste or<br>recycling. We only have one<br>blue recycling bin, but five<br>garbage. Our street is<br>frequently covered in glass.<br>BUILD AFFORDABLE LOW INCOME<br>HOUSING.\",\"Please expand the metro rail<br>network sough - this would help<br>with the insane traffic.\",\"I am leaving Austin because it<br>is too crowded, traffic bad and<br>cost of living is too high.\",\"We feel the stress of everyday<br>living in this city where we<br>are considering moving out of<br>the state. We can't walk\/ride<br>bikes in neighborhood without<br>fear of being hit by speeding<br>cars, especially those that cut<br>through to avoid traffic. It<br>takes me ONE HOUR to drive 5<br>miles to pick up my kids from<br>school. It's no longer worth<br>living here because it steals<br>time from family and joy. FIX<br>THE TRAFFIC!!! Thanks.\",\"I would really love a rail<br>system expansion to include<br>South\/Southwest Austin to<br>downtown Austin. It would<br>decrease air pollution,<br>alleviate many traffic<br>issues\/parking needs downtown,<br>and add convenience to<br>attending Austin events.\",\"Keep Austin Weird and improve<br>transportation options and keep<br>up the good work on economy and<br>quality of life.\",\"MORE ROADS THAT TRAFFIC CAN<br>FLOW AND NOT SIT IN TRAFFIC<br>BUMPER TO BUMPER.\",\"Traffic solutions, keeping<br>parks beautiful and preserved,<br>making Austin a safe place.\",\"Could we please do something<br>about traffic. Mopac toll is a<br>joke, I 35 is a joke. But if I<br>could see and talk to him at<br>all it would be about all of<br>the relevant issues.\",\"Please work on affordable<br>housing as the increasing costs<br>are driving many talented,<br>creative people who are the<br>heartbeat of Austin to live<br>elsewhere.\",\"I know we are doing what we can<br>do and it's no revelation but<br>we have to keep a focus on<br>infrastructure and<br>accommodating all these people<br>moving here and the population<br>growth. I think it's issue #1.\",\"Fix the traffic problems. Let<br>us vote if another Toll is<br>being planned. I want a say in<br>this. It is unfair to all of us<br>not to be able to say we want<br>it or are willing to vote on a<br>bond election for improving<br>highways.\",\"Remove deed restrictions on<br>housing. It's discrimination.\",\"Stop being a sanctuary city. It<br>is driving up the cost of<br>housing and cost of living.<br>Supply vs demand. The more<br>demand we have the more cost<br>goes up. The more people we<br>have the more the cost goes up.<br>If we have people that are<br>illegally here it raises the<br>cost of those of us here. We<br>don't have another county to go<br>to.\",\"The east side needs lots of<br>improvement to it's<br>infrastructure, roads,<br>sidewalks, etc., as well as<br>basic services like banks and<br>pharmacies. Things have gotten<br>a little better, but mostly as<br>a result of gentrification and<br>work still needs to be done in<br>areas that haven't been deemed<br>\\\"desirable\\\" by developers.\",\"Please deal with the homeless<br>population by engaging multiple<br>agencies (mental health, drug<br>rehabilitation, police).\",\"The city's priorities mostly<br>askew. Big issue like security<br>- like NO police union contract<br>for years and are mostly<br>ignored. Problems with Fire<br>Department and EMS not<br>addressed in timely way.\",\"Please continue to support<br>teachers and public education.\",\"Let's try and keep the<br>classics, while also<br>accommodating new growth,<br>(restaurants, businesses,<br>etc.). Also, take all the time<br>and resources you need to fix<br>traffic\/construction around<br>here.\",\"I am terrified to drive daily<br>on what I consider to be some<br>of the most dangerous roads in<br>the city - 620 & 2222. The<br>number of lives lost on these<br>roads in any given year is<br>tragic. I baffles me that<br>people thought it wise to allow<br>inexperienced high school<br>drivers to enter and exit their<br>high school at the top of the<br>dangerous 222 hill! The idea of<br>teaching my future children to<br>drive these roads is<br>frightening, The loss of life<br>is truly uncalled for.\",\"Traffic solutions by the city<br>have been TOO SLOW.\",\"Please take care of Austin<br>residents and leave immigration<br>stuff to the state.\",\"Some members of the transient<br>population scare my friends and<br>family.\",\"Our area still does not have<br>composting containers\/bags for<br>weekly pick up! I used a<br>composter (turn by hand) for<br>years, but can no longer do<br>that. So, PLEASE get service to<br>my area! Off 2222 W on<br>Westslope Drive and surrounding<br>area!\",\"I'm moving away because this<br>really isn't a great place to<br>live. It is sad because Austin<br>has so much to offer, but it is<br>choked off by the city's<br>incompetence towards growth<br>planning. If you can't even<br>surface streets correctly, how<br>can people trust the city to do<br>anything else?\",\"Need more Police or improved<br>response time and follow up<br>after accidents.\",\"Sad at the lack of job<br>opportunities for college grads<br>like me. I had to live with my<br>parents for four years after<br>college because of this. I am a<br>teacher married to an Austin<br>native currently stationed in<br>Iraq and we can hardly afford<br>to buy a home.\",\"Stop densification. Help<br>citizens not businesses.\",\"Music being played inside cars<br>should not be heard of felt<br>outside of them.\",\"Help us stay in our homes in<br>our neighborhoods. Help<br>developers develop outside the<br>city core, or adhere to<br>neighborhood-friendly<br>limitations inside the city<br>core. So many of us long-timers<br>have devoted so many volunteer<br>hours to help protect our<br>neighborhoods, that we've<br>helped to transform into safe,<br>desirable places to live, only<br>to see our efforts bypassed by<br>determined developers who have<br>the resources to ignore them.<br>I've given up volunteering and<br>fighting after 10 passionate<br>years because it feels<br>ultimately like lost effort. We<br>need a council that values what<br>has been crafted by community<br>over many years. This does not<br>have to be antithetical to<br>fair, responsible<br>neighborhood-friendly<br>development.\",\"I am concerned about the lack<br>of affordable housing, the<br>gentrification of downtown and<br>east Austin. The cost of<br>housing increasing so much.<br>Thank you.\",\"Homeless are out of control.<br>Every corner, tent cities and<br>under bridges. Traffic lights<br>downtown seem designed to stop<br>you at every single light.\",\"Use tax dollars for<br>improvements for ALL, for<br>example roads, traffic pattern,<br>services, and then for cultural<br>\\\"needs\\\".\",\"Eliminate marketing parking<br>space requirements?\",\"The tar and gravel repaving<br>system (is poor). Makes a mess.<br>Makes the road surface rough.<br>The leftover gravel sits in<br>gutters forever. I know it's<br>probably cheap, but I hate it.\",\"Austin will grow! Prioritize<br>development and roadways.\",\"Do not keep borrowing (no bonds<br>please). Balance you budget.\",\"hwy and road improvement, help<br>the elderly with solar and<br>electric bills for low income<br>and elderly, arrest people<br>breaking traffic laws and<br>driving reckless\",\"That the mix of races and<br>ethnic backgrounds is being<br>replaced by white upper to<br>upper middle class population<br>(of which I am a member),<br>replacing diversity due to<br>increased housing costs and<br>lack of housing for lower<br>middle and low income families.\",\"Traffic needs to be dealt with<br>soon!\",\"Better police department<br>protocols and fair enforcement<br>needed. Neighborhood policing<br>needs improvement.\",\"housing prices inflation is<br>pushing my less fortunate<br>neighbors out of the area\",\"EDUCATION IS THE FOUNDATION OF<br>SOCIAL MOBILITY, IN ORDER TO<br>GIVE CITIZENS THE MOST<br>OPPORTUNITY WE MUST FOCUS ON<br>ATTRACTING TOP TALENT TO OUR<br>SCHOOL SYSTEMS. HIGHER SALARIES<br>AND HIGHER SELECTION CRITERIA<br>WILL MAKE SURE THAT AUSTIN<br>CONTINUES TO BE A DESIREABLE<br>PLACE TO LIVE\",\"please put more money and<br>support into public transit<br>options, especially frequency<br>of can metro buses\",\"equality in service provision<br>for all neighbors\",\"need to focus on basic services<br>and safety and not get involve<br>and spend so much time and<br>money on championing political<br>and social issues\",\"great police dept, law<br>enforcement and spencer crook<br>welcome to Austin\",\"PROPERTY TAXES ARE BEING USED<br>AS A TOOL TO MORPH CITY<br>DEMOGRAPHICS, APPRAISALS OF<br>PROPERTY ARE EXAGGERATED AND NO<br>ONE (BANKS, DEVELOPERS, EVEN<br>THE CITY) WILL DO ANYTHING TO<br>REIGN INREALISTIC PROPERTY<br>VALUES, UNPLANNED GROWTH DUE TO<br>CITY SUBMISSIVENESS TO COPORATE<br>DEVELOPMENT HAS ILLED AUSTIN.<br>THE CITY OFFERS NO TAX<br>INCENTIVES FOR ACUTALLY LIVING<br>INTHE CITY, THIS LEADS TO REAL<br>ESTATE SPECULATION ANDPROPERTY<br>OWNED BY ABESTEES INVESTORS<br>HAVING THE SAME POWER AS CITY<br>CITIZENS\",\"make the city safer for lgbt,<br>women, ethnic minorities\",\"traffic,\",\"property taxes and housing cost<br>have risen far too fast, my<br>property taxes are 6 times what<br>they were 10 yrs. ago, have<br>double again in just the last<br>few years\",\"when something wrong with<br>water, have military or other<br>organization go out to the<br>neighborhoods and give out<br>cases of water to each<br>person\/family\",\"don't let people buy multiple<br>properties only to Airbnb them,<br>and expand affordable housing\",\"to reduce traffic congestion<br>they city should explore<br>corporate incentives to promote<br>work from home employees a<br>certain number of days per week\",\"I would like to see urban rural<br>expanded, bike lanes expanded,<br>I love Austin, we just need to<br>focus on congestion, relief<br>from traffic, overall the city<br>does a good job managing change<br>with such rapid growth\",\"please carefully develop a<br>comprehensive plan for growth<br>that preserves historic<br>buildings, neighborhoods, and<br>Austin's unique character\",\"Stop building expensive condos<br>and focus on low income<br>housing.\",\"To repave South first street<br>and have bulk trash pickup more<br>often\",\"We are the biggest city in the<br>nation - BY FAR - that only has<br>one single freeway that runs<br>the entire length of the city<br>at 3+ free lanes the entire<br>time.\",\"Teachers struggle here. I know<br>more and more teachers who have<br>plans to leave the<br>district\/career because of a<br>multitude of factors. Help our<br>younger generation and invest<br>in them and things for them.<br>Teachers should be planning to<br>better their career not<br>planning to leave it. We need<br>to and could invest more in our<br>young children.\",\"Discourage more growth, at<br>least until the City catches<br>up.\",\"Please put more trans and<br>recycling bins in parks!\",\"Critical access, quality and<br>dependability of affordable<br>childcare\",\"Protect Barton Springs.\",\"I grew up here and I am<br>disappointed in how the money<br>grab is all that seems to<br>matter anymore. Affordable<br>homes for the people who work<br>here!\",\"Please improve the quality of<br>the light rail lines! It could<br>do so much more to alleviate<br>congestion and pollution, but<br>it doesn't go anywhere people<br>need to go.\",\"Please plan for the massive<br>influx of people moving to the<br>city. Please increase the<br>capacity of the convention<br>center and let's make that area<br>safe for our visitors. As an<br>event manager who plans a<br>convention there every year, we<br>want to keep people coming and<br>spending money in the city.\",\"Enhance affordability and<br>ensure a diverse, healthy<br>population.\",\"Fix traffic\",\"Land and communal spaces in and<br>around District 1 and the<br>Cameron Road\/183 area<br>desperately need improvements.<br>Two new schools recently opened<br>near there, and there is not a<br>safe way for families to walk<br>or bike to the school, creating<br>greater traffic challenges in<br>an already congested area.\",\"Do your actual job instead of<br>focusing on fairness,<br>diversity, illegals, etc. Make<br>this city livable and let<br>individuals decide how to live.<br>You aren't God.\",\"Improve schools and<br>affordability of the city!\",\"Please do something for<br>property-owning residents! We<br>are paying for this non-stop<br>party and we get nothing for<br>our money. Your focus is on<br>tourists and businesses. These<br>policies have made the city<br>unlivable. The only reason we<br>are here is our jobs. We are<br>looking for another city when<br>we retire. This city is<br>unsustainable. The only reason<br>it has made it this far is<br>because people move here<br>because they hear it is cool.<br>They move here, spend mom and<br>dad's money on high rent and<br>booze, go broke and then move<br>back home. The next day, they<br>are replaced by two others<br>waiting to get their spot. This<br>is the city that you built. And<br>why did you pay for a Kansas<br>company to do this survey? UT<br>could have done it and you<br>would keep the money in this<br>town. Typical.\",\"How can citizens get involved?\",\"Transportation and affordable<br>housing are huge issues. Please<br>keep up the good work with<br>environmental\/sustainability<br>initiatives and code<br>enforcement. It could and<br>should be easier for small<br>businesses to build\/expand.<br>It's so dollar-only big brick<br>and mortar. Chain stores can<br>afford it.\",\"Please make mobility around<br>this city by personal vehicle<br>more workable for those of us<br>whose work makes us need to use<br>our personal vehicle. As a home<br>health RN, I can't use public<br>transportation to get around<br>Travis county as well as North<br>to Liberty Hill and South to<br>Kyle and San Marcos. The<br>biggest blockade is always<br>AUSTIN.\",\"Work closely with your<br>emergency services departments<br>(police\/fire). Protect these<br>men\/women with fair\/equal pay<br>and benefits. Austin relies on<br>these services heavily and<br>needs the happiest and<br>well-kept police department,<br>fire department, etc. in the<br>state.\",\"Lower property taxes!\",\"We must build a mass transit<br>network and rezone for<br>high-density, mixed-use<br>development along transit<br>corridors. Buses that get stuck<br>in traffic are not a solution.<br>People will only vote to fund a<br>train if the path makes sense.<br>North Lamar to South Congress,<br>not Highland to East Riverside.\",\"The toll roads don't help<br>traffic.\",\"Get over your political career<br>b.s. and serve our community or<br>quit.\",\"Instead of building more high<br>rises, how about filling the<br>vacant buildings scattered<br>about the city. There are so<br>many struggling starving<br>unemployed people like myself\",\"WE NEED TO FIX THE ROADS.\",\"The role of government is to<br>use force to protect individual<br>rights. Please stick to<br>military, police and the<br>courts. You are ruining our<br>lives and stealing our income.<br>The first thing you can do to<br>better Austin is leave<br>businesses alone. Get out of<br>the economy. Let home\/apartment<br>developers build.\",\"Bad Traffic makes me stay in my<br>area.\",\"Austin a good place to work but<br>the housing is very expensive.<br>I don't drive a car so public<br>transportation is essential. I<br>don't have a lot of options as<br>to where I can buy a house<br>within my budget and also has<br>public transportation.\",\"Please invest in public rail<br>system. This city desperately<br>needs it to pull cars off the<br>streets.\",\"Stop sending property tax<br>dollars to robinhood districts<br>if other city's areas doing the<br>same.\",\"Need RADICAL changes in energy<br>conservation and \\\"green\\\" energy<br>in public properties and<br>businesses; be the example the<br>rest of America can follow in<br>DRASTIC energy changes before<br>it is too late!!!\",\"Overall affordability is<br>crucial - taxes, electric and<br>water service.\",\"I think you're selling the city<br>out to tech companies rather<br>than truly investing in<br>families.\",\"Slow development down! And find<br>our soul in the rubbish.\",\"COST OF LIVING IN AUSTIN IS TOO<br>HIGH. I DON'T KNOW IF IN THE<br>NEXT YEAR I WILL NOT BE ABLE TO<br>PAY MY PROPERTY TAXES.\",\"IMPROVE PUBLIC<br>TRANSPORTATION\/LIGHT RAIL<br>SYSTEM\",\"TRAFFIC IS REALLY GETTING<br>CONGESTED. YET WE NEED A CAR TO<br>GET TO MEDICAL SERVICES. I HAVE<br>VOTED FOR EVERY NEW<br>TRANSPORTATION BOND. I HOPE THE<br>CITY CAN FIND THE RIGHT<br>SOLUTION.\",\"TOO MANY RESIDENTIAL STREETS<br>ARE DARK. MORE BETTER STREET<br>LIGHTING NEEDED.\",\"Many are angry that you wasted<br>our tax dollars by flushing<br>Code Next. Fix the Land<br>Development Code. Give the<br>community a voting voice for<br>all rules\/regulations in the<br>land development code. Repeal<br>pointless\/ineffective land<br>development codes.\",\"PUT GROWTH AND QUALITY OF LIFE<br>1ST.\",\"Stop handing out million dollar<br>settlements to everyone that<br>sues the city and don't be so<br>hard on police for doing there<br>job.\",\"Solve traffic problems\",\"Less traffic please\",\"CONTINUE WITH RECOMMENDATIONS<br>OF THE INSTITUTIONAL RACISM<br>TASK FORCE. AFFORDABLE<br>HOUSING-END SEGREGATION.\",\"ENJOY THE CITY,BUT HOPE PUBLIC<br>TRANSPORT INCLUDED TO THE SOUTH<br>OF THE CITY.\",\"reduce the fees for elect\/water<br>make the bills less hard to<br>read, simpler the better\",\"get metro rail running 24\/ 7<br>w\/more routes airport, south<br>Austin, build public<br>transportation b\/w Austin and<br>s\/a,\",\"AUSTIN NEEDS AFFORDABLE HOUSING<br>AND BETTER INFRASTRUCTURE.\",\"Affordability is a huge<br>problem. We need to take<br>measure to 1. Raise minimum<br>wage, 2. Secure affordable<br>housing, 3. Apply rent control<br>for residents so they are not<br>displaced.\",\"The idea of using Gondolas to<br>get around town sounds crazy,<br>but it is viable and cheap.\",\"CREATE A TASK FORCE TO ADDRESS<br>POLICE'S GENERALLY HEAVY HANDED<br>ATTITUDE TOWARD PUBLIC.\",\"CONTROL PROPERTY TAX! WE WILL<br>BE FORCED TO MOVE IN 5 YEARS IF<br>THE TAX RATE CONTINUES.\",\"More bike lanes.\",\"BETTER COMMUNICATION WITH<br>RESIDENTS OUT SIDE OF DOWNTOWN.\",\"Keep city affordable. May not<br>be able to live here in a few<br>years.\",\"Education and mobility! We know<br>it's not easy but please keep<br>at it.\",\"Improve infrastructure.\",\"Very disappointed on the amount<br>of money spent on social<br>programs.\",\"his main person does not return<br>phone calls\",\"We need big change. The rail<br>line was a start, but it needs<br>to be bigger. We need<br>infrastructure. People that own<br>their property should never be<br>at risk of losing it because of<br>taxes.\",\"Transportation! Fix it now! You<br>know it sucks!\",\"KEEP AUSTIN WEIRD WERE LOOSING<br>OUR WEIRD FACTOR SLOWLY BUT<br>SURELY.\",\"help find my husband a good av<br>audio visual job here locally\",\"need real solution to the<br>traffic problems, plan for<br>growth by looking at the impact<br>it will have on the roads,<br>pedestrians accessibility and<br>the neighborhoods before<br>starting a new project, let<br>neighborhoods vote on what can<br>be built in their own<br>neighborhood, look for ways to<br>lower the cost of living for<br>families who want to stay in<br>Austin\",\"traffic, Austin is losing its<br>heart, all the things that make<br>Austin are being priced out<br>either from real estate, high<br>taxes, or new development while<br>recognized about the money in<br>their own pocket than retaining<br>Austin's unique culture and<br>make it an affordable place to<br>live, if I didn't own my own<br>home I wouldn't be able to<br>afford rent as a single person<br>anymore and I make decent money<br>that fact deeply saddens me for<br>Austin's future\",\"better transportation. more<br>museum\/cultural centers\",\"need to balance rapid growth<br>w\/affordability ease of use<br>costs\",\"Keep Austin roadsides and<br>sidewalks along with yards<br>clean of clutter and debris.<br>Get broken down vehicles out of<br>yards. Get code enforcement out<br>doing a better job.\",\"thank you for your engagement<br>of residents in making<br>decisions thank you for making<br>Austin a great place to live\",\"DONT KEEP TRYING SO HARD TO<br>MAKE AUSTIN WEIRD, YOUR VISION<br>AND VALUES ARE NOT ACCEPTED BY<br>SILENT MAJORITY OF AUSTIN<br>PEOPLE, RETIRED PEOPLE CAN NOT<br>AFAFORD ALL THE INCREASE COST<br>OF LIVING IN YOUR AUSTIN\",\"PLEASE HELP MENTAL HEALH<br>SERVICES AND SENIOR SERVICES\",\"MORE TRAIN\/RAIL\",\"Advocate for people with<br>disabilities and affordable<br>housing for all\",\"There are too many things. I<br>cannot think of one. Only that<br>I am a baby boomer and I feel<br>forgotten by my home town. I<br>was born and raised here. I<br>feel like I am being pushed out<br>if my home because of cos to<br>live here.\",\"Too much construction and other<br>hindrances to traffic flow.\",\"Too many of the city's agencies<br>are ethnically biased.\",\"Ensure that all citizens,<br>regardless of race\/ethnicity,<br>gender, gender identity feel<br>protected and respected by our<br>police services.\",\"no more tax incentives to large<br>companies. help seniors with<br>property taxes!\",\"Growth is good but stop tearing<br>down the things that make<br>Austin a unique and cool place<br>to live.\",\"Stop spending so much money my<br>taxes is about to equal more<br>then my monthly house payment\",\"Thank you for your hard work.<br>What can we do about traffic<br>and rising costs of services<br>and taxes?\",\"We need much less<br>government(allow people to be<br>more responsible for<br>themselves)\",\"Help fix school financing to<br>lower taxes. Sound more angry<br>sometimes. Too nice when pissed<br>of\",\"Focus on better traffic<br>patterns between city, county<br>and state roads. IE, 620<br>corridor does not flow well<br>from Lakeway to Round Rock.\",\"Affordable housing and not just<br>for low income but for middle<br>class or single people\",\"Please keep our parks! We need<br>more off-leash areas for our<br>dogs that need exercise. Austin<br>needs to reevaluate the<br>growth!!!\",\"I appreciate your work under<br>difficult circumstances. It's a<br>fine city but work must be done<br>to grow the diversity of the<br>city, to build on the<br>opportunities here, expanding<br>learning to develop solutions<br>to the issues of an urban<br>community.\",\"Speed time getting a build it<br>replacement permit!\",\"I appreciate the work that<br>keeps our roads drivable and<br>safe. However, I would like the<br>city to provide information<br>proactively regarding road work<br>that changes traffic patterns,<br>I have searched the city<br>website for this information,<br>called and emailed and received<br>no response. It would be nice<br>to know ahead of time when<br>there are road work closures<br>that will affect my commute.<br>The city does an excellent job<br>of informing us of events that<br>will cause road closures, so<br>thank you for that.\",\"Leadership isn't done by<br>consensus\",\"LCRA did a great job during the<br>flooding.\",\"Transit and zoning for<br>mixed-income density are the<br>major issues I want the office<br>of Mayor to support.\",\"NEED TO FIX CITY WEBSITE.\",\"Create affordable housing.<br>Don't raise property tax for<br>long time residents in east<br>Austin.\",\"Something drastic needs to be<br>done to improve traffic. It is<br>intolerable.\",\"Austin needs to get in front of<br>the growth instead of acting on<br>a reactionary basis, traffic,<br>homelessness, affordability and<br>sustainability forward thinking\",\"IMPROVE IH 35 TRAFFIC\",\"IF YOU WERE A TWO-PARENT<br>HOUSEHOLD MAKING 100K WITH TWO<br>KIDS, HOW COULD YOU AFFORD TO<br>LIVE IN THE CITY? PLEASE DO A<br>HOUSEHOLD BUDGET BREAKDOWN AND<br>COMPARE TO SURROUNDING CITIES.\",\"We DESPERATELY need better\/more<br>expansive public transit<br>options NOT only would this<br>rectify the lack of affordable,<br>quality housing within a<br>commutable distance (because<br>people could live further<br>outside the downtown area), but<br>if would reduce traffic<br>congestion. A railway or the<br>proposed gondola project would<br>be great for Austin!\",\"Traffic and homeless.\",\"GET NEW REPS TO TALK ABOUT<br>LOWER INCOME NEEDS\",\"Build better infrastructure for<br>pedestrians to access city<br>core.\",\"STOP LETTING PEOPLE PARK AND<br>BLOCK SIDEWALKS. WHOEVER DOES<br>IT, SHOULD BE TICKETED.\",\"Cleaner parks with more updated<br>equipment. Recycling pick up<br>every week (not every other<br>week). Education\/school<br>improvements.\",\"Improve permitting construction<br>process. Also, I do want to<br>note that I appreciate Mayor<br>Adler's leadership.\",\"REDUCE DENSITY WITHIN THE CITY<br>SO YOU DON'T BREAK THE<br>INFRASTRUCTURE MORE. THIS CITY<br>ISN'T BUILT FOR THIS DENSITY.<br>NEW DEVELOPMENTS ON THE<br>OUTSKIRTS OF TOWN NEED TO MAKE<br>UP FOR THIS. DUPLEXES AND APTS<br>IN THE CENTER OF TOWN ARE NOT<br>HELPING THIS.\",\"Affordability - housing\",\"I love Austin but the traffic<br>problem significantly impacts<br>my quality of life.\",\"THAT FURTHER GROWTH\/DEVELOPMENT<br>ON THE PERIPHERY OF THE CITY<br>SHOULD BE DONE IN A WAY THAT<br>CREATES NEIGHBORHOODS WHICH ARE<br>WALKABLE AND MIXED-USE, IN<br>WHICH A SENSE OF COMMUNITY CAN<br>MORE EASILY BE CULTIVATED AND<br>OLDER ADULTS CAN AGE IN<br>PLACE.-ALSO, THANKS TO THE<br>MAYOR FOR HIS CALM, DELIBERATE,<br>RATIONALE STYLE OF GOVERNANCE.<br>HE SETS A GOOD EXAMPLE.\",\"Reduce traffic and take better<br>care of the street maintenance.\",\"Schools were not mentioned in<br>the survey! This is the<br>important thing to parents. I<br>am currently selling my house<br>to move into a better school<br>district.\",\"Improve wages for educators and<br>provide reasonable expectations<br>for jobs. Provide funding for<br>students suffering from<br>social\/emotional needs.\",\"Please do more to protect the<br>artist community. Please<br>provide housing opportunities<br>and health care for those who<br>put Austin on the map.\",\"Affordable housing for low<br>income and middle class.\",\"Affordable housing and transit<br>are most important issues.\",\"Address the homeless situation<br>ASAP. Pay more attention to<br>other areas of Austin besides<br>the business\/downtown areas.\",\"THANK YOU FOR HELPING AUSTIN<br>BEONE OF THE MOST DESIRABLE<br>PLACES TO OLIVE, BEAUTIFUL<br>FREENSPACES, AND A WELCOMING<br>CULTURE\",\"I love the City, but the<br>overcrowding is making it less<br>enjoyable. This town was a<br>place for artists, musicians<br>and people trying to express<br>themselves. It has lost some of<br>that magic-people can't afford<br>to be artists here any more.\",\"Cost of living is too high. We<br>are losing artist and musicians<br>that use to make the City<br>special.\",\"No soccer stadium.\",\"Please continue to maintain and<br>approve bike infrastructure.\",\"I LOVE THIS CITY BUT AM<br>CONCERNED ABOUT THE<br>AFFORDABILITY IN THE FUTURE.\",\"DISCOURAGE FOSSIL FUELS\",\"Reduce property taxes.\",\"HELP US CLEAN UP OUR<br>NEIGHBORHOOD AND FEEL SAFE<br>AGAIN.\",\"Homeless issue is getting out<br>of hand and trashing our city.<br>They should be required to keep<br>areas clean. Housing prices for<br>middle class should be more<br>affordable.\",\"Provide cultural events. The<br>COA does not plan events geared<br>towards minority involvement.\",\"Please help with traffic<br>problems. I ride a bike to work<br>(with no bike lane) and it's<br>dangerous.\",\"During Mayor Adler's term I've<br>personally experienced my<br>property taxes increase to a<br>sum of 46%. How is this<br>affordable, much less,<br>sustainable? In addition, I've<br>experienced the City's Code<br>Enforcement and Energy<br>divisions aggressive and<br>inequitable enforcement of city<br>codes\/fees, price rates, rules<br>and or regulations of life-time<br>east Austin residents. All<br>under the under the guise of<br>\\\"enforcement\\\" and or \\\"safety\\\",<br>yet the division's gestapo like<br>tactics are not used of newly<br>approved city council<br>residential\/commercial building<br>contractors, permits or new<br>comers\/residents to the<br>neighborhood.\",\"Get rid of the toll roads. Why<br>did we have to get rid of the<br>Montopolis Fly over?\",\"STOP BUILDING --NEED MORE<br>ROADS, LESS PEOPLE-STOP<br>THINKING ABOUT YOUR<br>WALLET--MAKE AUSTIN BEAUTIFUL<br>AGAIN.\",\"leave montopolis alone\",\"To do a better job of taking of<br>people who have spent their<br>lives as Austin residents.\",\"Income based city fees.\",\"LIKE HE READS THIS... ACTUALLY<br>FIX THE HOMELESS PROBLEM<br>INSTEAD OF CONSTANT LIP<br>SERVICE!!! THAT MEANS MAKE IT<br>ILLEGAL TO SQUAT.\",\"figure out a system for the<br>homeless situation, have<br>cheaper taxes for home owners<br>who have lived here all their<br>lives,\",\"Quit pandering to the special<br>interest groups. Do what is<br>right for Austin - all of<br>Austin - not just the ones who<br>scream the loudest.\",\"Stop allowing the homeless<br>situation to tear this city<br>apart.\",\"GET A FULL AUDIT OD ALL CITY<br>FUNDS AND PROGRAMS.\",\"FIND A WAY TO COMBAT PROPERTY<br>TAX ON A MASSIVE SCALE.\",\"LOWER ENERGY BILLS\/TAXES ON<br>HOME.\",\"Not that anyone is going to<br>read this, but I'm severely<br>disappointed in Austin as a<br>whole, It is basically<br>Nashville or Denver now, which<br>is sad. We sold out to<br>Marriott, Hilton developers.\",\"Seniors deserve more incentives<br>to stay in Austin. Discount on<br>electrical and water services.<br>After 65, we pay less for<br>taxes, but no other incentives.<br>I use lees water and<br>electricity than families.\",\"TO HELP WITH RISING HOUSING<br>COST CRACK DOWN ON MISUSE OF<br>SHORT TERM RENTAL IE. AIR BNB<br>AND GENTRIFICATION THE CITY OF<br>DC JUST HAD A SHORT TERM RENTAL<br>BILL PROPOSED THAT COULD ALSO<br>HELP US WITH RENT COST\",\"LIGHT RAIL AND BUSES NOT GREAT.<br>NEED ELEVATED RAIL.\",\"Stream line the permitting<br>process to build a new home.\",\"WE ARE LOSING OUR GREEN SPACES.\",\"Austin is a wonderful place to<br>live and I consider myself<br>lucky to be here. There is room<br>for improvement -<br>affordable\/moderate rentals and<br>home ownership opportunities<br>must be a priority as well as<br>improving traffic. Long term<br>residents are losing faith in<br>City Government as inequities<br>are not addressed.\",\"Focus on handling growth:<br>traffic\/housing\/expanding<br>services to growing areas\",\"Austin is not representing<br>itself as a capital city.<br>Embassies are in Houston. Big<br>businesses are going to Dallas<br>and Houston. Why not Austin?\",\"Get out of the way, you can't<br>be everything to everybody so<br>quit trying. AND, get rid of<br>the homeless instead of<br>inviting them in by giving them<br>they're needs. Identify the<br>truly needy and concentrate on<br>those few.\",\"He is doing a great job.<br>Setting planning for growth,<br>transportation and mobility<br>together is an excellent<br>approach.\",\"THE CITY IS GROWING FASTER THAN<br>IT CAN HANDLE. THE LIMIT WILL<br>BE REACHED, THEN WHAT? THE<br>RESIDENTS ARE MOVING OUT IF<br>THEY CAN TO AVOID PAYING THE<br>HIGH PROPERTY TAXES AND TRAFFIC\",\"PLEASE PAY EQUAL ATTENTION TO<br>PEOPLE RESIDING IN AREAS<br>DISTANT FROM THE DOWNTOWN<br>AREAS. DON'T LET US DEPEND ON<br>NEIGHBORING CITIES CLOSE TO US<br>TO PROVIDE CONVENIENCES FOR<br>WHICH WE ARE TAXED BY THE CITY<br>OF AUSTIN. GIVE US CLOSER<br>POOLS, LIBRARIES, PARKS, ETC.<br>THANK YOU\",\"TAXES ARE HIGH, TRAFFIC SUCKS.\",\"THE CITY OF AUSTIN IS NOT A<br>GOOD PLACE TO WORK. DO<br>SOMETHING ABOUT THE CORRUPT<br>MANAGERS THAT ARE HIRING AT THE<br>CITY.\",\"I FEEL BAD FOR THE HOMELESS<br>TOO, BUT WE CANNOT JUST ALLOW<br>UNSIGHTLY CAMPS AROUND AUSTIN.<br>IT WILL ATTRACT CRIME AND<br>LAWLESSNESS LIKE NEW YORK.\",\"Affordable housing\",\"ROADS NEED TO BE BETTER\",\"ANSWER YOUR PHONE\",\"WORK ON MAKING AUSTIN AN<br>AFFORDABLE PLACE TO RETIRE AND<br>ALLOW RETIREES TO STAY IN THEIR<br>HOMES.\",\"police response is terrible.<br>usually no show\",\"Traffic is getting harder.<br>People need to slow down.<br>Unsafe.\",\"We need designated camping<br>areas for the homeless so there<br>are toilets and showers . They<br>could get plugged into services<br>more effectively.\",\"GOOD PLACE TO LIVE. USED TO BE<br>GREAT NOW JUST GOOD BECAUSE OF<br>EXPENSIVE COST OF LIVING AND<br>TRAFFIC CONGESTION.\",\"Please fulfill public works<br>tickets fairly!!! I feel<br>discriminated against. There is<br>no other reason I can see for<br>why my neighbor's same issue<br>was fixed and not mine.\",\"PROPERTY TAXES ARE OUT OF<br>CONTROL, I NEED RELIEF!!!\",\"AUSTIN NEEDS TO REMAIN<br>AFFORDABLE TO LIVE FOR ALL<br>PEOPLE. WE CAN'T BECOME ANOTHER<br>SAN FRANCISCO.\",\"Improve roads, install<br>intelligent lights in major<br>intersections. Add subways and<br>overpasses to reduce traffic<br>congestion. Work with the State<br>of Texas.\",\"Communicate with the public on<br>how to protest\/exercise our<br>rights about zoning and<br>development(we don't need a<br>domain on riverside).\",\"Improve Schools\",\"focus on traffic, it is<br>horrible for everyone\",\"Bring down our property taxes -<br>that is a huge burden on<br>retirees.\",\"Process fingerprints and cut<br>down on property crime. It's<br>the same people and we give<br>them two years to do it before<br>we ID them.\",\"Please be strategic on the<br>growth of the city, promoting<br>economic attractiveness of our<br>city but also plan to support<br>such growth. Let's follow<br>Singapore's example of a well<br>planned and successful city.\",\"Austin is already a \\\"desirable\\\"<br>place to live, work to make it<br>an \\\"affordable\\\" place to live<br>through multiple approaches.\",\"CITY COUNCIL SHOULD BE WORKING<br>TO HELP IMPROVE THE LIVES OF<br>PEOPLE, THERE SHOULD NOT BE<br>SPECIAL INTEREST FOR ANY<br>GROUPS.\",\"Traffic is a problem\",\"Medicare and Medicaid support<br>to vision, dental and ears\",\"base your decisions on evidence<br>based research and plan<br>accordingly\",\"INCREASE EMPLOYEE WAGES\",\"WHY ARE YOU NOT USING THE HOME<br>DEPOT FACILITY TO WORK UP A<br>PROGRAM FOR THE HOMELESS?? STAY<br>OUT OF THE \\\"HOUSING\\\" BUSINESS,<br>ALLOW FREEDOM TO DEVELOPERS,<br>PROPERTY OWNERS TO BE IN CHARGE<br>OF THEIR PROPERTIES. ELIMINATE<br>50% ON YOUR \\\"COMMISSIONS\\\"<br>REDUCE THE NUMBERS ON THE<br>REMAINING COMMITTEES, TIME<br>LIMITS TO COUNCIL MEETINGS,<br>EVEN IF ISSUES HAVE TO DRAG ON<br>- INACTION CAN BE A WONDERFUL<br>BENEFIT. CONSOLIDATE CODE<br>ENFORCEMENT INTO THE<br>PERMITTING\/INSPECTION<br>DEPARTMENTS. REDUCE COSTS!!!<br>REDUCE DEBT!!! ALLOW OUR<br>NEIGHBORHOODS TO GENERATE THEIR<br>OWN MARKETS AND CHARACTER.\",\"I think that creating better<br>public transportation is the<br>only way to help ease the<br>traffic concerns in Austin.\",\"I think the city's attitude to<br>a lot of issues with livability<br>is: \\\"housing prices, and<br>therefore your net worth, are<br>increasing, so we are doing ok<br>and you are doing ok.\\\" If I am<br>correct, the problem is that<br>the individual or family tax<br>burden increases in kind, and<br>the only way to realize this<br>value increase is to sell the<br>home and move out of Austin.\",\"Lower property tax and increase<br>public schools\",\"Lower the property taxes.\",\"Stop making plans for your<br>future career in Democratic<br>politics and run the darn city.<br>Oh, and fire Cronk. He's gonna<br>ruin this town.\",\"We need affordable housing and<br>water rates\",\"Please let police remove<br>homeless from street. Austin<br>was a beautiful, clean and safe<br>city until recently. Homeless<br>live on street made Austin<br>unsafe and dirty,.\",\"Appropriately fund the Police<br>Department so that Austin, the<br>11th largest city in the US,<br>meets a national standard for<br>law enforcement.\",\"No tax rebate or subsidy to for<br>profit corporations.\",\"Reduce traffic congestion on<br>the roads\",\"HOUSING AFFORDABILITY AND<br>PROPERTY TAXES TOO HIGH\",\"WORK WITH CAP METRO TO EXPAND<br>LIGHT RAIL\",\"THANK YOU FOR DOING A GOOD JOB<br>AS MAYOR. YOU SEEM REASONABLE<br>AND FAIR.\",\"WE NEED TO SOMEHOW GET THE<br>HOMELESS CAMPS SHUT DOWN, MORE<br>AFFORDABLE HOUSING AND MENTAL<br>HEALTH CARE.\",\"Keep working to maintain<br>independence from the state.<br>Expand the light rail system.\",\"Do something about traffic\",\"SLOW DOWN AND MANAGE GROWTH.<br>WORK ON TRAFFIC FIRST.\",\"WE NEED MASS TRANSIT ALONG I<br>35. GOOD CITY PLANNERS KNOW<br>THAT MORE ROADS EQUAL MORE<br>CARS, NOT LESS TRAFFIC.\",\"LONG TERM TRANSIT VISION\",\"INVEST IN SOLAR ENERGY\",\"Plan for growth without the<br>heavy tax burden\",\"STICK TO YOUR GUNS ON<br>HOMELESSNESS.\",\"Property tax and water cost are<br>too high\",\"Stop being a sanctuary city.<br>This is disgraceful to our laws<br>and our law enforcement<br>officers.\",\"PLEASE GET US OUT OF CONTRACT<br>WITH FAYETTE COAL POWER PLANT.\",\"Ban declawing!\",\"TAKE CARE OF THE HOMELESS<br>PROBLEM, REDUCE TAXES.\",\"Improve public transportation.\",\"Keep Austin Weird\",\"GREAT JOB ON PUTTING AUSTIN ON<br>THE BEST CITY TO LIVE IN THE<br>USA!\",\"TRAFFIC AT 620 AND 2222 NEEDS<br>IMPROVED\",\"WE SEE THE MAYOR IS DOING HIS<br>BEST TO IMPROVE AUSTIN AND MAKE<br>AUSTIN THE BEST PLACE TO LIVE.<br>WE APPRECIATE THAT VERY MUCH.<br>GOOD JOB MAYOR!!\",\"PUBLIC TRANSIT IS CRUCIAL TO<br>GROWTH OF CITY.\",\"Work on the quality of drinking<br>water. Reduce the water and<br>electric bills.\",\"Deregulation in electric<br>service providers. Better<br>rebates for solar power at<br>residence. Better rain water<br>harvesting programs. Better<br>cultural exchange with those<br>from India.\",\"BETTER MASS TRANSIT\",\"ENSURE AUSTIN REMAINS A BULWARK<br>AGAINST WHITE CHRISTIAN<br>NATIONALISM, EVEN WHILE THE<br>CITY IS INCREASINGLY SURROUNDED<br>AND PRESSURED BY IT'S INSIDIOUS<br>PROPONENTS.\",\"It is difficult to find a list<br>of parks with Pavilions.\",\"Biggest issue is taxes, which<br>is really a State issue.<br>Related to school taxes, which<br>the Mayor has little say.\",\"Salary adjustments for cost of<br>living in Austin.\",\"Something as simple as timing<br>traffic lights better, could<br>easily reduce congestion in a<br>big way. It doesn't all need to<br>be new road construction. Also,<br>trimming trees that cover<br>street signs would be very<br>helpful.\",\"To better enforce traffic laws<br>with respect to aggressive and<br>dangerous drivers. And hire<br>ethical and honest people!\",\"TRAFFIC, WE NEED AN ELECTRIC<br>SHUTTLE SYSTEM.\",\"Traffic and property tax, both<br>need fixing.\",\"Recreation centers are<br>concentrated in Central Austin.<br>Most of them are not accessible<br>by North West Austin community.<br>We need a new recreation center<br>for indoor sports in North West<br>Austin.\",\"Traffic and noise from<br>construction\",\"Please resign and let someone<br>else run the city. In fact the<br>same goes to at least several<br>of the city council members. If<br>you want to get involved in<br>national politics, please run<br>for another elected office.<br>There are many problems facing<br>a growing city like Austin. We<br>need a mayor who has undivided<br>attention to make Austin a<br>better place to live. We need<br>more roads (not bike lanes),<br>larger police force, and more<br>affordable housing. It's not<br>very complicated if you focus<br>on the right problem.\",\"Please approve new development<br>and also keep the beauty of the<br>city with the best quality of<br>life for people. Everything is<br>bigger in Texas, we can expand<br>our downtown wider and taller<br>at the same time. I know<br>traffic is a growing problem,<br>people who work in tech can<br>help to solve this with a new<br>design. We can also help<br>identify the cause for slow<br>moving traffic. We can use our<br>homeless population to keep<br>city and lakes clean, thus<br>helping each other. Thank you.\",\"better public transportation\",\"HEARD THERE WOULD BE CHANGES TO<br>IMPROVE CROSSINGS AT 360.CAM WE<br>DO SOONER?\",\"FOCUS ON IMPROVING QUALITY OF<br>LIFE FOR LOW INCOME AND<br>DISENFRANCHISED RESIDENTS. HELP<br>THOSE WHO HAVE BEEN IGNORED FOR<br>DECADES.\",\"REMOVE THE UPPERDECK ALONG I 35<br>DOWNTOWN, PUT THE ROAD<br>UNDERGROUND. CONNECT EAST AND<br>WEST DOWNTOWN AUSTIN. THINK BIG<br>FOR THE FUTURE. DO IT NOW.\",\"public transportation<br>development, more bus\/train<br>lanes, frequency\",\"LOWER OUR TAXES AND STOP<br>WASTING OUR MONEY\",\"I would like to thank the Mayor<br>for trying to solve the traffic<br>issue on Mopac and 183 (towards<br>airport). We should have if not<br>already started planning to see<br>more growth of Austin as a city<br>and make sure that housing\/rent<br>is still affordable for all.\",\"find a way to keep property<br>taxes low - we see a lot of our<br>neighbors having to move away<br>because their property taxes<br>have risen too much, too<br>quickly in the last few years<br>and the trend is continuing\",\"Need to improve transportation\",\"Establish reliable mass transit<br>system - preferably not on<br>street level (e.g. subway,<br>monorail) - that connects east,<br>south, and north Austin. Austin<br>is too dense to continue to<br>have unreliable bus system that<br>only exacerbates the traffic<br>problem. Establishing better<br>transit system would encourage<br>less personally owned vehicles<br>on the road too.\",\"Police availability and<br>response.\",\"Good work on keeping Austin<br>friendly!\",\"Support initiative for Lyft.\",\"move the homeless shelter out<br>of the prime real estate in<br>downtown Austin. make people<br>pay a fine if they give money<br>to pan handlers in street<br>intersections! this is<br>dangerous because it causes car<br>accidents. I have witnessed<br>this myself.\",\"Transport all these bums to a<br>different city and get our<br>transportation highway issue<br>fixed. One lane off and on<br>ramps - are you crazy? Your<br>toll road Texas tag needs to<br>encompass ALL the toll roads in<br>Texas. It is so confusing to<br>get toll road bills from two<br>different companies. Forget the<br>toll roads and make legit<br>highway alternatives to I-35.<br>One traffic accident on I-35<br>causes congestion for miles.<br>See if you can have a<br>helicopter lift the two wrecked<br>cars off the highway so traffic<br>can resume back to normal<br>quicker. Make an emergency<br>traffic lane gate that opens<br>only for EMS and police so that<br>they can get to the traffic<br>accident quicker and tow the<br>cars off into the emergency<br>lane.\",\"PERHAPS JOB FINDING PROGRAMS.<br>OR INCREASE MINIMUM WAGE.\",\"Thank you for improving Parque<br>Zaragoza.\",\"CODENEXT HAD A GOOD END GOAL.<br>ALLOW DENSIFICATION TO TAKE<br>PLACE TO COMBAT THE<br>AFFORDABILITY ISSUE. THE<br>MISSING INGREDIENT IS PLACE<br>BASED DESIGN. THE DESIGN<br>PROFESSIONALS INVOLVED NEED A<br>STRONG VOICE AS POLICY MAKERS<br>AND SHOULD BE ADVOCATES FOR THE<br>COMMUNITY. ALSO, PASS THE GREEN<br>LINE PLEASE.\",\"Quit trying to provide things<br>to people at the expense of<br>others. Anything worth having<br>is worth working for. You think<br>if we give it to them they will<br>work up to keep it, they invest<br>nothing and have nothing to<br>lose. You spend others money<br>very liberally, why not spend<br>your own?\",\"lower the property tax , water<br>n electric fee\",\"CITY GOLF COURSES SHOULD BE<br>OPEN TO ALL PUBLIC.\",\"LIVING IN CLOSE PROXIMITY OF<br>TRANSPORTATION FOR THE WORKING<br>CLASS IS IMPERATIVE TO THE<br>FUTURE SUCCESS OF THE CITY.\",\"NEED BETTER HIGHWAYS EXPANSION<br>OF GROWTH AND REDUCE CRIME.\",\"Need lower property taxes (for<br>homes and autos) for low income<br>of less than $20,000 annually\",\"Focus on the taxpayer. We need<br>a solid infrastructure, a<br>healthy and safe environment.<br>Follow Federal and State laws.<br>Quit making Texas a California.<br>Lower taxes and make a balanced<br>budget.\",\"Why is soccer stadium more<br>important than housing and why<br>do I have to pay taxes and they<br>don't?\",\"Road planning\",\"Waited 6 hours at DPS to renew<br>drivers license. Actual work<br>took 5 minutes. How is this<br>considered acceptable?\",\"I FEEL CITY AND POLICE DEPT<br>SHOULD TAKE MORE STEPS TO STOP<br>THE GUN VIOLENCE.\",\"Traffic is getting worse, even<br>with all efforts being made.\",\"Please deal with<br>homeless\/druggie problem.\",\"IMPROVE TRAFFIC\",\"NOT SURE WHAT THE CITY IS DOING<br>MOST OF THE TIME, WHICH IS WHY<br>I ANSWERED DK FOR A LOT OF<br>THIS. MAYBE MORE INFO WOULD BE<br>GOOD\",\"Police training on how to talk<br>to people, also learn the<br>codes. Better service to<br>civilians.\",\"Please improve the sidewalks to<br>Lakeline Mall - along 620<br>please! Thanks!\",\"Lower the cost of living.\",\"Keep up the good work!\",\"Please invest in large scale<br>solar energy or provide large<br>companies with incentives to<br>promote solar energy . It is a<br>free and constant resource for<br>Texas with no hazardous by<br>products to the environment.\",\"PLEASE IMPROVE TRAFFIC AND<br>TRANSPORTATION.\",\"IT WOULD BE VERY BENEFICIAL IF<br>WE HAD A BETTER TRANSIT SYSTEM<br>SUCH AS A TRAIN. I THINK IT<br>WOULD HELP REDUCE TRAFFIC.\",\"Lower the property tax.\",\"I THINK IMPROVEMENTS AT THE<br>AIRPORT AND TRAFFIC AROUND THE<br>CITY WOULD HELP TAKE OVER CITY<br>TO THE NEXT LEVEL.\",\"Fix traffic\",\"Good job overall! Pay more<br>attention to the road<br>conditions and traffic issues.\",\"THE SEAL COAT IN MY<br>NEIGHBORHOOD IS VERY POOR<br>QUALITY.\",\"We need to accelerate the<br>approved timeline of licensing<br>and permitting for a new<br>business. There are too many<br>homeless people living under<br>the freeways and sleeping in<br>front of small local<br>businesses.\",\"growth in infrastructure<br>project should match with the<br>growth in city economy while it<br>is important to bring more<br>business tot he city to<br>generate more revenue, it is<br>equally important to focus on<br>the quality of life in the city<br>as well. traffic, climbing rate<br>and property value will<br>eventually push people away and<br>make Austin the worst place to<br>live and work\",\"expand available events venues<br>outside of downtown and\/or<br>create better traffic flow and<br>parking downtown\",\"When is the traffic going to<br>get better?? What are the plans<br>in regards to better traffic?\",\"Initiate programs that will<br>help lower property taxes.<br>Every initiative the city taxes<br>increases property taxes. Be<br>innovative.\",\"Make Austin more affordable to<br>live in. Taxes are running<br>ahead of inflation & income<br>growth.\",\"Transportation system needs a<br>new plan otherwise big<br>companies can't come here.\",\"hope you can come up with a<br>solution to improve traffic on<br>290 at Y in oak hill and reduce<br>speed limit on FM1826\",\"MAKE PARKING ESIER<br>DOWNTOWN\/SURROUNDING AREAS,<br>ENSURE HWY CONSTRUCTION MEETS<br>DEADLINES ON TIME\",\"NEED TO DO BETTER, NEED TO PUT<br>IN THE WORK, PEOPLE ARE GOING<br>TO HATE YOU CAN'T PLEASE<br>EVERYONG BUT YOU HAVE TO POWER<br>THROUHG AND DO WHAT IS FOR THE<br>CITY AND ITS PEPOPLE, THEY<br>ELECTED YOU, YOU ARE IN A<br>POSITION OF POWER,YOU NEED TO<br>GIVE US AND CAN DO THAT BY<br>FIXING TRAFFIC AND CONGESTION<br>AND POLLUTION AND MAKING AUSTIN<br>MORE SUSTAINABLE, DON'T GET<br>COMPLACENT OR LAZY\",\"LETS GREATLY IMPROVE AUSTINS<br>PUBLIC TRANSPORT\",\"WE NEED TO DO BETTER ON<br>SPENDING TAX DOLLARS WISELY FOR<br>A RELIABLE PUBLIC<br>TRANSPORTATION SYSTEM\/RAIL.<br>NEED TO PLAN FOR THE<br>ACCELERATED GROWTH NOW.\",\"VERY EXPENSIVE PLACE TO LIVE.<br>COMMUTE TIMES ARE VERY LONG.\",\"Keep building out the bike lane<br>network (segregated on<br>major\/busy roads).\",\"More bike lanes, especially in<br>East Austin. Lots of people are<br>riding out there and the area<br>is under new development. And<br>keep up the great work, thank<br>you!\",\"Traffic issue\",\"Making public transport more<br>efficient (with respect to<br>connection and time).\",\"Lower costs for retired<br>residents.\",\"Stop toll roads and build<br>rails.\",\"Make downtown area walking<br>only. Divert more money into<br>hike bike trail. Assist<br>homeless.\",\"I WOULD LIKE TO SEE MORE BIKE<br>LANES.\",\"Tackle the cleanliness of all<br>the pockets in East Austin<br>w\/areas between IH-35 and<br>Pleasant Valley. Will really<br>help develop East side and the<br>level of safety and security<br>status it can be. (e.g. like<br>\\\"tipping point\\\" and the article<br>about NYC subway cops and<br>crime). Thanks!\",\"AFFORDABLE HOUSING, CENTRAL IS<br>A MAJOR ISSUE. BUT IF THEY<br>COULD GET MORE COPS TO GIVE<br>TRAFFIC TICKETS, IT WOULD HELP<br>SO MUCH-YOU SHOULD LOOK INTO<br>THAT\",\"Stop growing if the city can't<br>handle it!!!!\",\"CHARGE PEOLE TO MOVE HERE AND<br>STAY HERE FOR THE FIRST YEAR\",\"MAKE YOUR GROWTH A CONSIDERATE<br>ONE. GREED CONTINUES TO PUSH<br>CITIZENS OUT OF THE CITY.<br>INCLUDING CITIZENS WITH DEGREES<br>AND PROFESSIONS. PROVIDE HELP<br>TO THOSE THAT HAVE LITTLE.<br>REDUCE FEES TO THOSE WHO<br>CONSUME LESS WATER AND<br>ELECTRICITY; CONSIDER ONES'<br>INCOME TO BE FAIR WITH TAX HOME<br>RAISES\",\"Traffic\",\"Stop building and ruining<br>Austin.\",\"Improve the infrastructure for<br>continued growth of our city,<br>especially for traffic. Listen<br>to the citizens on the options<br>we prefer.\",\"Make the budget smaller. Do<br>more with less. When money is<br>tight in our house, we spend<br>less. We are taxed to the gills<br>and the City ALWAYS say MORE!<br>But you spend it on things that<br>are not important. Build your<br>base. The Family. The tax<br>payer!! We own homes and have<br>stable jobs. We pay our taxes.<br>Work for us, not those people<br>who cry the loudest.\",\"We need 3000 Permanent<br>Supportive Housing vouchers and<br>SW staff to support them.<br>Please.\",\"Make commute easier - time the<br>lights, construction is ok but<br>it is at the inconvenience of<br>commute - common sense to reset<br>or time the lights. We can<br>learn from Houston or Dallas -<br>very well timed lights.\",\"FIX OUR DAMNED TRAFFIC PROBLEM!\",\"Forget light rail. Consider<br>Gondolas, aerial, not water.\",\"Respect the residents and their<br>needs instead of looking out of<br>the city for more hair brained<br>ideas for making Austin<br>anything more than it is<br>already.\",\"Focus on traffic flow, think<br>about roundabouts and traffic<br>light engineering for the<br>timing.\",\"keep Austin lovely, not<br>exploding\",\"Traffic- lack of roads, shut<br>the gates to Austin, stop<br>building.\",\"See my comments on homeless<br>strategy... don't model after<br>what LA or San Francisco are<br>doing. Get off the anything for<br>bike lanes kick. Focus on<br>public safety, traffic, and<br>roads.\",\"TOO MANY PEOPLE, NOT ENOUGH<br>ROADS OR AFFORDABLE HOUSING FOR<br>THOSE THAT WANT TO WORK.\",\"FIX TRAFFIC AND WATER<br>COST\/USAGE.\",\"FOCUS ON ROADS, TRAFFIC, PUBLIC<br>SAFETY, KEEP TAXES LOW, STOP<br>GIVING OVER OUR TAX DOLLARS.\",\"MORE OPTIONS FOR ELDERLY TO<br>PARTICIPATE IN COMMUNITY.\",\"It is so sad to see long time<br>local business disappearing. We<br>loved Austin because it was<br>unique, and used to have the<br>feeling of a small town with<br>the advantages of a big city.<br>Now, it is just another city in<br>Texas with gas stations, banks<br>and Walgreen's on every corner<br>of every rd. So sad to see<br>Austin go down that rd!\",\"IMPROVE TROUBLED NEIGHBORHOODS\",\"STOP BUILDING ON EVERY CORNER.<br>AUSTIN IS LOST IN CONGESTION<br>AND APARTMENT BUILDINGS. AUSTIN<br>IS NO MORE!\",\"Make housing affordable!!!!\",\"MAKE AUSTIN AFFORDABLE AND<br>FOCUS ON MOBILITY.\",\"AUSTIN IS BECOMING<br>UNAFFORDABLE, HELP US FIND A<br>WAY TO STAY HERE.\",\"Don't let Austin turn into<br>Seattle as far as homeless<br>problem in their city.\",\"LOWER TAXES, STOP INFLATION\",\"Stop lying to his constituents<br>and allow an audit of the city.\",\"LOWER THE COST OF HOUSING AND<br>BRING IN MORE HIGHER PAYING<br>JOBS\",\"MIDDLE CLASS FAMILIES SHOULD BE<br>YOUR PRIORITY, ADDRESS<br>HOMELESSNESS. GET THE CITY<br>COUNCIL IN CHECK.\",\"INFRASTRUCTURE\/ROAD<br>DEVELOPMENT, PROPERTY TAX TOO<br>HIGH\",\"Stop gentrification. Preserve<br>Austin's identity as a diverse,<br>welcoming and weird place.<br>Protect long standing<br>businesses. Stop selling out<br>the established working class,<br>some who's families have been<br>in our neighborhoods for<br>generations, for the sake of<br>expanding condos.\",\"Do not let big business,<br>extremely wealth people and the<br>state dictate what is done for<br>Austin. Listen to the people<br>who live and work hard to make<br>Austin a place they want to<br>continue to afford to live in.\",\"See previous comment\",\"Traffic fixation\",\"I appreciate the work he is<br>doing. I appreciate what he<br>does and his involvement with<br>all races. Please reverse the<br>tent ordice.\",\"Please make Austin a more<br>affordable place to live ! I<br>love Austin , I am a teacher<br>and a homeowner but I do not<br>know if I'll be a le to afford<br>to retire here because of the<br>property taxes going up every<br>year .... please help the<br>teachers â™¥ï¸\",\"Eliminate tax subsidies to<br>incoming corporations that do<br>not hire long time residents\",\"HOMELESS SITUATION SLEEPING ON<br>SIDEWALKS AND UNDER BRIDGES.<br>HOW CAN YOU IMPROVE THIS SHAME<br>ON YOU MAYOR.\",\"We need to address the homeless<br>problem and the traffic issues.<br>Austin's traffic is becoming a<br>real burden on its citizens and<br>the lack of public<br>transportation and lack of<br>density will both make<br>traveling across the city too<br>burdensome, time-consuming.<br>This will not only affect<br>quality of living but also be<br>bad for business. Please let's<br>come up with incentives for the<br>private sector to support the<br>city in making public<br>transportation a priority.\",\"In spite of its tremendous<br>growth spurt, Austin continues<br>to be a beautiful and enticing<br>city. Would never live anywhere<br>else but I am worried of the<br>cost of living and the taxes<br>since I getting to the point<br>where I will be on a fixed<br>income.\",\"More roads and shopping centers<br>east of IH 35.\",\"ELIMINATE ALL TOLL ROADS\",\"Availability of services for<br>low income families.\",\"PROPERTY TAX ARE HIGH AND<br>UNABLE TO FIX MY HOME INVESTORS<br>ARE BUYING OUR HOMES DUE TO TAX<br>CLIMBING.\",\"STOP WASTING MONEY. REDUCE<br>PROPERTY TAX AND MAKE AUSTIN<br>AFFORDABLE.\",\"OUR CITY GOVERNMENT IS NOT<br>TRANSPARENT, THERE ARE BACK<br>DOOR DEALINGS.\",\"We don't need a soccer stadium.\",\"Homeless off the street and in<br>city run drug facilities and<br>hospitals\",\"Stop wasting taxpayer monies on<br>trips to find out how are<br>cities & other areas are<br>dealing with issues. Use your<br>staff to come up with solutions<br>that work for the City i.e. be<br>innovative, a leader & not a<br>follower. Use technology to<br>explore the solutions to issues<br>instead of trying solutions for<br>other areas that may not work<br>here. Shape the box.\",\"I would like to see community<br>police. It may be old school<br>but trust in government starts<br>at what should be the most<br>visible.\",\"Inviting the homeless to camp<br>in Austin is a terrible idea.<br>We don't want Austin to become<br>San Francisco.\",\"Please stop letting those big<br>companies infiltrate downtown<br>and inside the 15min bubble,<br>our city cant handle all those<br>extra people they bring in for<br>jobs (their families, the<br>traffic, the roads, the taxes,<br>the parking, the rent) This is<br>the best city and we want to<br>keep it that way by not pushing<br>out the locals that have made<br>it that way!\",\"subway system...doesn't impede<br>traffic\",\"HELP THE HOMELESS GET JOBS OFF<br>THE STREET, GET HOMES.\",\"Homelessness is a travesty and<br>makes me feel unsafe at lights<br>and certain areas of Austin.\",\"Improve transportation by<br>building better roads and<br>highways without them being<br>toll roads. We pay for the<br>bonds & taxes to build roads<br>and then we have to pay more to<br>use them? We can not afford to<br>use the new roads and highways<br>if you make them all Toll<br>Roads. This will not fix the<br>transportation problem. AND<br>please do not raise taxes for<br>Home Owners, it puts a lot of<br>pressure and we can not afford<br>to live in our own homes. You<br>want to fix all the budget<br>problems by having homeowners<br>pay for it. That is why most of<br>my co-workers live in Bastrop,<br>Round Rock, or Kyle.\",\"School and teacher, child care<br>teachers pay\",\"Truly value minorities as<br>equals without using their<br>income as a measure for their<br>worth. Focus on improving the<br>quality of life for your low<br>income minority<br>(black\/brown\/immigrant,<br>disabled, senior) residents<br>before trying to increase the<br>growth of the city; which<br>negatively impacts those<br>residents by widening the<br>income inequality gap.<br>Increasing efforts to invest<br>more in social services for<br>lower income residents allows<br>them to get the adequate<br>resources they would otherwise<br>be unable to access, and<br>potentially keeping them in a<br>cycle of poverty\/debt.\",\"Thank you for your service\",\"Homeless problem, maybe find or<br>create simple jobs like mowing<br>the empty lots or picking up<br>trash.\",\"You are not the mayor of<br>California. Californians are<br>not your constituents, we are.<br>We are being forced to move out<br>of the city because it is no<br>longer affordable. Hispanic and<br>African American neighborhoods<br>are being gentrified everyday<br>and nothing is being done to<br>help the long-time residents<br>that are being forced out of<br>their homes. And because they<br>are poor and minorities, you<br>don't seem to care about it.\",\"We need solutions to the high<br>cost of living. They (the mayor<br>and council) need to do more<br>for the working class. Instead<br>of worrying about attracting<br>more condo developers. Many of<br>us born and raised here in<br>Austin are hanging on by<br>threads to afford our hometown.<br>That's not right. They mayor<br>and council are allowing the<br>people and local businesses<br>that made austin special<br>beautiful and unique vanish .<br>They mayor and council have all<br>shown they have sold our city<br>out for the all mighty dollar.<br>And most importantly the mayor<br>has made our city a disgusting<br>filthy and unsafe place by<br>allowing the homeless to<br>overtake our formerly beautiful<br>city.\",\"Cost of housing is ridiculously<br>high. Build an other bridge<br>across town lake to East of<br>IH35.\",\"PLEASE help the homeless.<br>decisions in this \\\"situation\\\"<br>will be hard and<br>distasteful.... But People will<br>start leaving... and go<br>somewhere else....\",\"Taxes and housing do something<br>stop just talking\",\"You need to get on the ball<br>with all these changes, keep us<br>informed and updated.\",\"Please do something to reduce<br>the number of homeless people<br>on each intersection. They<br>don't seem to be needy if<br>people provide them with living<br>conditions or material means to<br>survive under bridges to smoke<br>and drink. Thank you.\",\"Get rid of the dumbest rule :<br>camping allowed pretty much<br>anywhere! NO ENFORCEMENT so it<br>has become DANGEROUS! We are<br>FED UP WITH IT!! You claim it<br>has not caused more homeless<br>people but you are wrong! My<br>neighborhood has become a giant<br>camping ground full of trash,<br>junk, aggressive homeless<br>thieves!!\",\"control homelessness. It's<br>creating a feeling of<br>uneasiness for communities and<br>also creating a safety concern<br>for Austin and the people who<br>want to visit us.\",\"TAXES ARE TOO HIGH\",\"Too many bike lanes. I do not<br>like those posts being placed<br>on the streets in order to make<br>more bike lanes. My<br>understanding that is that you<br>have a council member and since<br>he rides bikes pretty much of<br>what he says happens. Well, I<br>do not like what it is doing to<br>the streets, all of those posts<br>and the narrow streets are<br>making it difficult to maneuver<br>around pedestrians\/children.<br>The cyclist are now riding two<br>or three abreast making it even<br>more dangerous, please, no more<br>bike lanes in our neighborhood.\",\"STOP THE GENTRIFICATION ON<br>RIVERSIDE and overall Austin\",\"Help the homeless so we can<br>keep Austin clean. Everywhere<br>you look there's trash. In all<br>of my 67 years in Austin I've<br>never seen such filth.\",\"LACK OF DIVERSITY AND CITY<br>SEGREGATION\",\"Get a F****** clue on the<br>homeless situation in Austin.<br>Do not try to solve the problem<br>punishing tax payers and<br>homeowners of this city. Stop<br>this camping thing, and enforce<br>some laws. Our city looks like<br>S*** now.\",\"To please help the Elder with<br>Taxes so we do not have to<br>leave our Homes Thank you\",\"Stop the homeless from being<br>everywhere. My daughter was<br>almost walked to in a CVS\",\"RECENT ORDINANCE ALLOWING<br>HOMELESS TO CAMP IN FRONT OF<br>BUSINESS ENTRANCES AND ANY<br>SIDEWALK IS AWFUL. DEVELOP A<br>BETTER PLAN.\",\"GROWTH MUST STOP, HELP OLD<br>AUSTINITES TO HAVE THEIR HOME.\",\"I PAY $17 FOR DRAINAGE EVERY<br>MONTH, RIDICULOUS!\",\"THE RISING COSTS OF LIVING ARE<br>PUSHING OUT SOME OF AUSTIN'S<br>BEST RESIDENTS-FAMILIES WITH<br>CHILDREN,PEOPLE OF COLOR, THE<br>ELDERLY AND THE DISABLED.I<br>CONSIDER MYSELF SUCCESSFUL AND<br>FINANCIALLY STABLE BUT I DON'T<br>SEE MYSELF ABLE TO AFFORD<br>LIVING HERE IN THE FUTURE IF<br>THINGS PROGRESS THE WAY THEY<br>ARE NOW.\",\"To add more freeways to this<br>never-ending city growth for<br>easy pathways and less car<br>crashes, no bike lanes!\",\"Make Austin's housing<br>affordable, quit giving tax<br>breaks and try to solve the<br>traffic problem.\",\"AUSTIN POLICE DEPT NEEDS TO<br>VISIT THIS NEIGHBORHOOD MORE<br>FREQUENTLY DAY AND NIGHT.\",\"PLAN FOR MORE PEOPLE HOUSING<br>ROADS\",\"Please decrease the number of<br>homeless people littering our<br>city!\",\"I wish I didn't think to<br>myself, \\\"I liked Austin a lot<br>more in the 1980's\\\", so often.<br>Some things have improved, but<br>many have worsened. I realize<br>much is inevitable due to urban<br>growth, but many cities across<br>the globe have maintained their<br>unique cultures despite their<br>growth...I hope Austin can do<br>it too.\",\"Cheaper rent for single mothers\",\"STOP GIVING TAX BREAKS TO<br>CORPORATIONS, IT IS A RANSOM<br>THAT THE WORKERS HAVE TO PAY.\",\"REMEMBER AUSTIN HAS ALWAYS BEEN<br>A FRIENDLY CITY.\",\"I AGREE WITH THE CITY'S<br>POSITION ON THE NEED FOR<br>RESIDENTIAL DENSITY IN THE<br>URBAN CORE. PROVIDING MORE<br>DENSE AND VARIED HOUSING IS<br>IMPORTANT FOR AFFORDABILITY.\",\"We need real transportation<br>options, not just more lip<br>service and endless studies<br>that do not achieve<br>implementation.\",\"COST OF LIVING TO MATCH RATE OF<br>PAY\",\"HOMELESS IS A PROBLEM IN THE<br>CITY. TRASH IS EVERYWHERE,<br>THERE SHOULD BE DESIGNATED<br>AREAS FOR THEM TO CAMP.\",\"Please check into the traffic<br>flow in growing neighborhoods.\",\"Affordable housing and traffic<br>enforcement\",\"Thank you for asking for your<br>community's feedback!\",\"WE ARE NOT PREPARED FOR INFLUX<br>OF HUMANS\",\"To have access to better<br>education costs and quality<br>affordable child after school<br>programs.\",\"Make APD work.\",\"I AM VERY CONCERNED ABOUT THE<br>HOMELESS PEOPLE IN OUR CITY\",\"STOP TELLING PEOPLE AUSTIN IS A<br>PLACE TO LIVE\",\"BETTER AND MORE CITY<br>PLANNING-MAKE MORE DENSE-BETTER<br>COMMUNICATION BETWEEN 311 AND<br>OTHER DEPARTMENTS\",\"Make more conservation and<br>sustainability efforts.\",\"Please continue to address<br>city's infrastructure in<br>dealing with population growth.\",\"Mayor, I appreciate the desire<br>to house the homeless, I think<br>that is something that we need<br>to do. However, I also feel<br>that the residence in the north<br>east sector of town keep<br>getting overlooked. In the<br>areas of police protection,<br>maintece of city property such<br>as the sidewalks and<br>maintaining the areas adjacent<br>to main streets, lighting, and<br>Timely response from 311 and<br>911 calls. Often our neighbors<br>have been broken into, our<br>mailboxes have been broken<br>into, our cars have been broken<br>into, and somehow no one ever<br>gets caught. I have no choice<br>but to ask myself how does the<br>treatment residents in my<br>neighborhood compare to the<br>treatment of residence in more<br>affluent neighborhoods.<br>Respectfully yours, Maria Elsa<br>Rodriguez, 36-year resident at<br>Copperfield subdivision\",\"TRASH AND RECYCLING BINS IN<br>HEAVILY POPULATED HOMELESS<br>AREAS.\",\"KEEP AUSTIN FRIENDLY AND<br>BEAUTIFUL\",\"INVEST MORE RESOURCES IN THE<br>RUNDBERG AREA.\",\"LOWER PROPERTY TAXES,<br>AFFORDABLE HEALTH CARE AND<br>DENTAL.\",\"SAFETY! POLICE NEED TO TAKE<br>ACTION IN CAR ROBBERIES, NOT<br>JUST COME AND MAKE A REPORT.\",\"Affordable housing\",\"CONTROL PROPERTY TAXES\",\"Better schools programs\",\"the businesses that supply tax<br>revenue to Austin's coffers<br>deserve better attention than<br>they have been given in regards<br>to helping them maintain a<br>business friendly environment<br>when it comes to homeless<br>loitering in and around their<br>premises.\",\"To ensure people all across<br>this city are treated equally.<br>I live in Southeast Austin near<br>William Cannon and McKinney<br>Falls Parkway and have made at<br>least two requests to 311 over<br>the past year to have my street<br>repaired and the request has<br>been ignored. I house sat for a<br>friend last week that lives<br>near Mopac and 32nd St. and<br>called 311 requesting a pothole<br>in the street to be repaired<br>around 11:45 AM. When I arrived<br>back at her house at 5:00 PM<br>that VERY SAME DAY, that<br>pothole and a couple of others<br>were repaired.\",\"Make sure that the camping<br>everywhere in the streets<br>ordice is revalued. Downtown is<br>turning into an unhospitable<br>street jungle full of<br>unemployed, drug users that<br>create waste and are unsafe to<br>the other citizens paying the<br>taxes. Stop talking about<br>affordable housing and actually<br>create some. Developers will<br>not create anything affordable<br>since there is not incentive to<br>sell cheaper houses when you<br>can build and sell million<br>dollar mansions.\",\"I love Austin been here all my<br>life. I am disappointed how we<br>are handling the homeless<br>population.\",\"Sir, can you please do<br>something about the driving<br>test. I feel like it's out of<br>date and many people young to<br>old should be tested in a<br>better way.\",\"New homeless ordice is a<br>nuisance and an eyesore to our<br>great city.\",\"Get rid of the tent city plan.\",\"Traffic is the #1 problem and<br>the lack of roads\/highways. I<br>live in Barton Hills and it is<br>impossible to park downtown. I<br>love Austin but it has become<br>difficult to live here.\",\"POLICE OFFICERS SHOULD ABIDE BY<br>TRAFFIC LAWS JUST LIKE<br>CIVILIANS.\",\"Please work to keep the cost of<br>living in Austin affordable.\",\"Affordable housing\",\"KEEP WORKING AT IT\",\"BETTER WAY TO HELP THE HOMELESS<br>OTHER THAN CAMPING ALL OVER\",\"IMPROVE FLOW OF TRAFFIC\",\"More affordable housing\",\"Homelessness. Move them to an<br>outside location. Learn how to<br>deal with them but do no expect<br>the citizens to deal with them<br>since some do not care to be<br>helped. Some enjoy their life..<br>Hey no taxes.\",\"Stop adding more FTEs to both<br>general fund and enterprise<br>departments. Focus on<br>departments operating<br>efficiently rather than giving<br>them additional FTEs. Also,<br>tell the truth about<br>homelessness in the media and<br>how many of them are bused here<br>from other cities\/communities.<br>Ask the big tech firms to pitch<br>in and help address the<br>homelessness issue ficially to<br>build community such as<br>Community First Village.\",\"Give it's city employees a<br>bigger pay raise. as inflation<br>continues to increase our pay<br>checks are not.\",\"Make available transportation<br>options in Northeast Austin,<br>Harris Branch Parkway.\",\"Need public transportation<br>options in the Harris Branch<br>Parkway area.\",\"ADDRESS TRAFFIC. POLICE ARE<br>VERY RUDE. HIGH HOME PRICES AND<br>RENT.\",\"Try to foresee planning on<br>travel throughout the city<br>versus building first. Its<br>because of the Rapid growth<br>there isn't anywhere to reach<br>your destination . Also maybe<br>if possible look at a Truck<br>route using 130 so traffic on<br>35 won't be so bad like<br>starting out at Sun City and<br>come out in Buda , San Marcos<br>and pose fines on 18 wheeler's<br>caught in city . But discount<br>rates for them to use 130 .\",\"Life should not be so expensive<br>so parent don't have to work<br>both full time to be able to<br>nearly live a normal life.\",\"Please slow down the growth of<br>Austin to allow the residents<br>and the citizens to adjust and<br>grow with the city. Please do<br>not allow the people who made<br>Austin a great place to live<br>and work in be driven out. One<br>example is Beau. He is a great<br>example of what makes Austin<br>amazing, and what is wrong with<br>how Austin is handling it's<br>citizens.\",\"You need to find a way to make<br>the city a more affordable<br>place to live, especially for<br>hard-working, middle class<br>citizens.\",\"Continue to do what's in the<br>best interest of the residents<br>of this city, and state. If<br>you're a Texan, you know what I<br>mean.\",\"1. Taxes 2. Loss of driving<br>lanes to bicycles\",\"Your affordable housing isn't<br>working. You are only catering<br>to the ones who can afford the<br>fancy expensive apartments and<br>homes. what about us plain<br>working folk, we cant hardly<br>afford the rents in Austin<br>anymore. Too bad you didn't<br>remember us when you are doing<br>your \\\"gentrification\\\" thing.\",\"Housing\",\"Lower prices on homes\",\"Make traffic better.\",\"I will tell him to stop the<br>patching work on the major<br>highways, that make the traffic<br>worse, and come out with a<br>realistic solution to the<br>traffic problem. The city has<br>all these plans to grow and<br>attract more business to the<br>city, but obviously we don't<br>have the roads to support it.\",\"We Need to make home buying in<br>Austin way more affordable!!\",\"Pick up aggressive dogs in the<br>neighborhood before they bite<br>somebody\",\"Homeless situation in Downtown<br>is hideous and needs to be<br>addressed urgently. They do<br>need to be removed from<br>Downtown.\",\"Deal with the traffic - it<br>looks bad, it tastes bad and it<br>is unhealthy and not safe.<br>Every day it's like a free for<br>all on I 35 for sure! Deal with<br>the homeless population -<br>building low cost\/affordable<br>homes isn't the only way -<br>clean up their \\\"villages\\\", cite<br>them for infringing on the<br>roadway, etc. It's gone beyond<br>ridiculous and is unhealthy,<br>unsafe and in the areas where<br>the homeless congregate - you<br>are really losing some of the<br>aura of why folks want to live<br>in Austin - because visitors,<br>etc. see city that is<br>deteriorating and not being<br>kept up. Sorry that's two - but<br>both need to be said.\",\"More lighting at night on<br>highway 71 heading toward Bee<br>Caves.\",\"Please try to do more on<br>affordable housing. Too many<br>people can't afford to live<br>here anymore. We can't all work<br>for Facebook and Google, making<br>$100,00\/year. Say not to<br>Amazon.\",\"Support the arts with the<br>creation of new and accessible<br>performance venues. Work with<br>AISD to support policies that<br>benefit public schools and<br>teachers.\",\"Education for all children<br>regardless. Education for<br>adults so they may have a<br>better life.\",\"Improve traffic flow.\",\"Improve traffic congestion!\",\"Keep Austin Affordable. Do not<br>recycle your people out of<br>Austin to round rock or other<br>urban cities out of Austin.\",\"Quit raising taxes & utilities.<br>You keep forcing older people<br>to have to move out of their<br>homes because they can't afford<br>to live in their life long<br>homes!!!\",\"Please listen to the people of<br>Austin with their concerns<br>about safety , and support them<br>in their efforts to protect<br>Their children and private<br>properties. I'm really<br>concerned about what I'm<br>seeing. Let's truly lead by<br>example by supporting the<br>little guys as well as the big<br>guys in matters of growth,<br>development , in all areas<br>including education, safety ,<br>health but most importantly<br>community support and guidance.<br>People start to panic when they<br>reach out for help and have no<br>where to turn, it's actually<br>very dangerous because it leads<br>to mental health issues( man<br>that flew his private plane<br>into IRS office off Mopac a few<br>years ago,) that's desperation<br>And feeling lost. If you build<br>it , they will come, but are<br>you really prepared Austin, or<br>just pretending? Lots of growth<br>too quickly and we need the<br>right people leading us into<br>the future, our lives are in<br>your hands....\",\"As Mayor you are doing an<br>amazing job with this city.<br>Keep up the good work. It can<br>be a tough job but I feel safe<br>with you managing this city.<br>Thank you.\",\"Affordable housing and traffic<br>on 35\",\"Fire employees Tameka Saldana<br>and Cassidy Villegan, who<br>falsifies timesheets with the<br>stamp of approval from Tamela<br>Saldana\",\"Concentrate on Austin's<br>problems and not the national<br>problems.\",\"Lower the taxes on our utility<br>bill that would help out. Thank<br>you\",\"I grew up on the east-side of<br>Austin. I love that Austin is<br>evolving, growing and has a ton<br>of opportunity but we have to<br>stop displacing families that<br>have been here for generations.<br>I've watched as the generation<br>before me is forced to move to<br>the suburbs and lose<br>connections with lifelong<br>friends and neighbors and<br>access to this incredible city<br>and all it has to offer. There<br>has to be some way we can allow<br>families to stay in their homes<br>and co-exist with new<br>neighbors. If there is way to<br>sort of \\\"grandfather\\\" in<br>property tax rates to residents<br>that have lived in a house for<br>a certain number of years it<br>may help the problem of<br>gentrification. The people<br>moving in love authentic<br>culture and food but also force<br>out (probably unknowingly) the<br>people who that culture belongs<br>to. Let's keep Austin welcoming<br>for EVERYONE, not just for the<br>new residents, but our native<br>ones too.\",\"Fixes residential streets that<br>need it! Waste of money fixing<br>South Congress and Otltort. Be<br>concerned to all people living<br>pay check to pay check. STOP<br>giving incentives to large<br>corporate businesses by<br>allowing them NOT to pay taxes<br>while longtime residents are<br>loosing their home due to high<br>taxes on property and school<br>taxes, etc. Disabled people's<br>taxes continue to increase too<br>much. What can be done about<br>that?\",\"Give landlords credit for<br>renting affordable housing. My<br>rentals do not make me a<br>profit. I eat into my savings<br>to pay my taxes.\",\"Keep promoting a progressive<br>agenda.\",\"*To fine construction companies<br>that do not finish jobs they<br>have signed contracts to finish<br>in a timely manner. * To<br>demolish the monstrosity of the<br>unfinished apartments behind<br>the H-E-B on McCallen Pass and<br>Tech Ridge... near the Gold's<br>Gym. The drywall is peeling and<br>ghostly. A costly project that<br>was started and never finished<br>leaving a mess and mold...could<br>be very hazardous to the public<br>in the area...get some money<br>back there and fine the<br>abandoning companies.\",\"Work to reduce Public Safety<br>costs (reduce APD, AFD, etc.)\",\"Lower rent or higher pay to be<br>able to live and work in<br>Austin. Moving out of Austin<br>makes it hard for single<br>parents to find affordable<br>trustworthy daycare\/after<br>school care with extended hours<br>with Austin traffic these days.\",\"Please fix our streets and stop<br>spending money on useless items<br>(courthouse, bike lanes, light<br>rail).\",\"We can always be improving but<br>overall Austin is a great place<br>to live.\",\"Troy Gay is unethical and<br>should probably be in jail for<br>how he handled the DNA<br>(non-issue). He's going to<br>destroy what is left of the<br>police department.\",\"So many homeless people at all<br>traffic lights and all around<br>the city, never have seen any<br>sign of concern for this huge<br>situation in this city, I don't<br>feel safe at all each time I<br>stopped at a traffic light\",\"We need light rail or mono rail<br>something new instead of buses<br>which causes some of the<br>traffic congestion. Gondolas or<br>something similar running along<br>IH35 would eliminate some<br>traffic problems and would be<br>unique to Austin!!!\",\"The electricity bill in summer<br>is just expensive\",\"Give benefits back to APD or<br>Austin is going to be another<br>Chicago crime is getting worse.<br>People are noticing it.\",\"More affordable housing. It is<br>almost impossible to be a<br>single income household with<br>multiple children.\",\"Affordable housing is becoming<br>unaffordable\",\"offer more to the residents of<br>Austin and less to the big<br>companies\",\"How are you addressing housing<br>affordability and<br>gentrification of Austin? It's<br>sad to lose the true Austinites<br>of this city due to more<br>wealthy out of state people.\",\"soy madre de un niÃ±o y no<br>tenemos transporte , caminar no<br>es problema para nosotros ,<br>pero en muchos lugares no se<br>encuentran aceras y los<br>conductores casi nos atropellan<br>.... tambien la gente que<br>trabaja en el sector publico<br>son muy groseros\",\"Why is property taxes so high\",\"If there was any way he or she<br>could help with getting the<br>living cost in Austin lower it<br>would help a lot of people they<br>wouldn't have to work 2 jobs<br>just to pay rent and they could<br>relax a little if they weren't<br>so worried about making sure<br>they were going to be able to<br>pay rent each month\",\"homeless\",\"Please hear us it's too<br>expensive to live here and I<br>love AUSTIN should be more<br>considerate for low income and<br>lower middle-class number one<br>concern\",\"Fix the traffic problem\",\"I'm a Democrat but I know<br>Austin mayors take care of<br>themselves for after they leave<br>off rather than do anything to<br>help ALL the people.\",\"Transportation- I-35 is so<br>congested. We need more<br>highways. Employment - I did<br>not feel safe at work. Housing:<br>we need more affordable housing<br>in Austin. However, I believe<br>that this is a great city to<br>leave.\",\"Cost of living is far too high<br>within the city and we should<br>be able to find a decent place<br>to live without sacrificing our<br>integrity and having to work<br>multiple jobs to afford it.\",\"Bring back Texas friendly and<br>Don't mess with Texas. With the<br>influx of out of state folks we<br>are not \\\"Tejas\\\"(friends) Start<br>a wave at your neighbor- Clean<br>up your act and fix the<br>homeless issue.\",\"This is a beautiful city, but a<br>lot of people are being victims<br>of gentrification and this<br>should be addressed fairly\",\"Fix the traffic and fix<br>property taxes. Stop telling<br>people you aren't raising their<br>taxes when their bill is<br>actually going up. If prop.<br>values go up then taxes go up<br>regardless of the percentage<br>being charged.\",\"Property taxes are too high and<br>traffic is getting worse every<br>day.\",\"We need light rail, we need to<br>stop the gentrification of East<br>Austin, we need to repave all<br>the major arteries (roads) that<br>come into Austin. Business will<br>be leaving once their workers<br>can't get into town.\",\"There needs to be more<br>affordable housing for those<br>who qualify for these services.\",\"The city of Austin need to go<br>back to being more affordable.<br>It used to be affordable to<br>live here, eat here, and play<br>here and now it's not. If I<br>were to rent my home out,<br>according to my realtor, I<br>could for $2800 a month and<br>that is insane to me. REALLY<br>INSANE!! After living in Austin<br>for 27 years I am actually<br>thinking about moving and<br>renting my home so that I can<br>live more comfortably and make<br>a profit from my home.\",\"HOMELESS PEOPLE ARE AGGRESSIVE<br>AND VIOLENT AT TIME,<br>ESPECIALLY7 BY I 35 AND 6TH<br>STREET. UNABLE TO EVEN WALK<br>AROUND. VERY UNSAFE.\",\"STOP PANDERING TO SPECIAL<br>INTEREST GROUPS . DEAL WITH<br>EVERYONE EQUALLY.\",\"HAVE ALL STREETS CLEANED ONCE A<br>MONTH. INCLUDE THE HIGHWAY<br>THROUGH THE ADOPT A HIGHWAY<br>PROGRAM.S HAVE SEMI TRUCKS GO<br>THRU THE TOLL WAY SO THEY PAY A<br>FEE.\",\"TELL THE MAYOR TO GET TOUGH ON<br>THE HOMELESS ISSUE.\",\"Stop focusing ONLY on downtown!<br>City run services in the<br>suburbs are falling apart.<br>Libraries and pools are<br>embarrassing and buses do not<br>even come here at all. Stop<br>getting involved with<br>controversial political areas.<br>Your personal opinion does not<br>speak for all of Austin. Focus<br>on making Austin better for<br>everyone who lives here.\",\"INCREASE PROPERTY TAXERS. MAY<br>FORCE ME TO RELOCATE WHEN I<br>RETIRE\",\"IT IS NOT NECESSARY TO OFFER<br>INCENTIVES TO LARGE<br>CORPORATIONS TO ENTICE THEM TO<br>BE HERE.\",\"Get serious about mobility.\",\"WE WOULD LOVE TO STAY IN OUR<br>HOME WHEN WE RETIRE BUT TAXES<br>ARE TOO HIGH\",\"Take bikes and scooter off of<br>the road. Less bars in our<br>neighborhoods.\",\"LOWER COST OF WATER\/WASTEWATER\",\"NEED EFFICIENT TRANSIT SERVICE.\",\"FLOW OF TRAFFIC IS TERRIBLE.<br>MOPAC IS TERRIBLE DURING RUSH<br>HOUR.\",\"city streets in Austin are<br>extremely dangerously for<br>cyclist and pedestrians,<br>drivers frequently run red<br>lights, text and drive,<br>generally a how disregard for<br>the more vulnerable road users<br>around them autism is supposed<br>to be a leader among American<br>cities. we must commit fully to<br>be a vision zero future and<br>deliver. we both ride bikes<br>everyday one death is too many<br>we can make this change as a<br>community but we have to put in<br>the work\",\"Very proud to call Austin home.\",\"I would say please do something<br>about our homeless people they<br>make our city look trashy the<br>under passes are filthy dirty<br>and are all over in every light<br>asking for money, don't feel<br>safe cause they come to your<br>window and ask for money and<br>beg even if you say no they<br>will ask you and are very<br>persistent, very unsafe don't<br>go out at night like I used to\",\"traffic\",\"Look at creating a Truck Route<br>starting out in Buda and ending<br>in Sunset City to lower traffic<br>on I-35 from 18 wheelers giving<br>discounts to use it and if<br>caught in city with a drop get<br>fine .\",\"Traffic and affordability for<br>teachers\/civil servants who<br>work in Austin.\",\"The east side should be called<br>the white east side because the<br>city has kicked the blacks and<br>Hispanics out! We cannot afford<br>to stay where we were raised!<br>We're having to sell our homes<br>in order to eat. We can't get<br>help from the government if<br>we're not from Cuba! Cuba<br>residents get more money for<br>school than if you were born<br>here!\",\"SCOOTERS ARE GETTING IN THE WAY<br>OF TRAFFIC AND PEDESTRIAN FLOW.<br>THEY SHOW NO RESPECT FOR<br>DRIVERS OR WALKERS. PUT THAT<br>MONEY TO BETTER CITY<br>TRANSPORTATION.\",\"CITY GROWTH SHOULD BE KEPT IN<br>CHECK, UNTIL WE HAVE THE<br>RESOURCES AVAILABLE, LIKE<br>ROADS, UTILITIES.\",\"Please consider what the rapid<br>growth is doing to our lower<br>income communities.<br>Preservation of communities<br>must be considered before<br>Austin becomes unrecognizable.\",\"WORK ON A SOLUTION TO<br>HOMELESSNESS. MOVE ARC FROM<br>DOWNTOWN. WORK WITH COMMUNITY<br>FIRST ON EXPANDING THEIR<br>PROGRAM.\",\"Great city to live in.\",\"WE ARE FULL, NO MORE RESIDENT<br>FROM OUT OF TEXAS PLEASE\",\"BESIDE TRAFFIC CONGESTION THE<br>OTHE THING THAT REALLY BUGS ME<br>IS HOW DIRTY OUR MAJOR HIGHWAYS<br>ALWAYS LOOK, I KNOW THAT<br>RESPONSIBILITY BELONGS TO TXDOT<br>BUT IT REFLECTS VERY BADLY ON<br>AUSTIN, PLEASE KEEP IN MIND<br>AUSTIN IS THE CAPITAL OF TEXAS<br>AND IT SHOULD BE KEPT CLEAN AND<br>IVITING FOR VISITORS AND ALL<br>PEOPLE TRAVELILNG THRU TOWN, IN<br>ADDITION THE HOMELESS CAMPING<br>OUT DOWNTOWN BY I-35 IS ANTHER<br>EYESORE FOR CITIZENS OF AUSTIN<br>AND VISTORS\",\"Property taxes are ridiculous<br>and traffic is just the worst<br>stressor ever please do<br>something about these 2 things<br>before it becomes a place where<br>everyone is stressed and<br>unhappy\",\"Fix the South Mopac traffic<br>problems\",\"Stop making Austin a bigger<br>city\",\"Lower electricity prices\",\"Please be mindful of the<br>whitewashing of labor made by<br>tech companies in the Austin<br>area - They hire people of<br>color to work at the bottom For<br>the lowest pay and then promote<br>Mostly Caucasian males to hire<br>up roles With better pay.\",\"I applied for Homestead tax<br>exemption, and have had no<br>action on the application.\",\"Improve public transportation<br>options. Austin cannot support<br>so many vehicles(personal)\",\"THE CITY IS BECOMING MORE UN<br>AFFORDABLE FOR LOW MIDDLE CLASS<br>INCOME.\",\"Traffic should be a number one<br>priority. Second is sidewalks.\",\"Regulate water charges - In my<br>neighborhood we are always in<br>fear of a water bill 800-1200<br>or more - as many of our<br>neighbors have received - for<br>no apparent reason and there is<br>no fighting it!!!\",\"Facilitate health care services<br>for the young and seniors.\",\"Build another airport like<br>Houston and DFW area.\",\"Property taxes are ridiculous.<br>We are running the people out<br>of town that made this city<br>what it is today.\",\"Make downtown safer at night.<br>Move the homeless shelters away<br>from the most expensive and<br>touristy part of Austin.\",\"Take care of escalating home<br>prices for median and low<br>income families, and traffic.\",\"Some areas speed limits should<br>be less than what they are now.\",\"Quit borrowing with Bond<br>packages. They cost the<br>taxpayer too much.\",\"Please do something about the<br>traffic light timing. It's a<br>city-wide problem that might<br>help alleviate some traffic.\",\"Affordable housing in the city<br>and higher minimum wage\",\"Focus on how we can support<br>long term residents by lowering<br>utility costs in aging houses.<br>Otherwise, we will be forced to<br>move away. It is too expensive<br>to maintain housing costs.\",\"PROPERTY TAXES ARE TOO HIGH!\",\"More affordable housing.\",\"Please help native Austinites<br>afford to buy a home in our<br>hometown.\",\"To work hard at providing<br>affordable housing for low<br>income citizens within the city<br>limits.\",\"The best way to campaign for<br>your next term is working with<br>city officials to resolve<br>homeless problem, the contract<br>with APD and many other issues<br>we have. Don't waste your time<br>going to public events and<br>taking photos with everyone.<br>Invest your time in what we<br>need and show us why you need<br>to be reelected. Work for your<br>community.\",\"Reduce taxes!\",\"Finding the homeless a place to<br>live to get them off the<br>downtown area. Keeping better<br>track of the sex offenders,<br>keeping them away from all<br>schools. Tracking down human<br>traffickers.\",\"We need to be a city that<br>allows other companies to<br>provide water, electricity,<br>garbage, etc. instead of being<br>a monopoly just one electric<br>company to choose from and one<br>water company to choose from\",\"Every single penny of taxpayer<br>money you spend on your pet<br>projects makes it more<br>difficult for the average<br>middle class family to remain<br>in Austin. Every bond...every<br>new building you have the city<br>buy for affordable<br>housing.......comes from people<br>who are financially stretched<br>to the breaking point, yet<br>don't qualify for your charity.\",\"Traffic enforcement start<br>writing tickets to bad drivers<br>it works.\",\"Stand strong against Gov.<br>Abbot! Let our city continue to<br>be governed by the rules we, as<br>residents, set.\",\"Help families by putting a cap<br>on the housing market costs. I<br>want to live in Austin longer<br>but will be unable to if I<br>cannot buy our first home here.\",\"Its not fun to pay $600 dollars<br>for electricity in the summer.<br>When the city could make a more<br>aggressive effort to provided<br>attractive incentives to switch<br>to solar energy. Specially for<br>low income families.\",\"Transportation mobility issues<br>MUST be addressed to preserve<br>quality of life.\",\"Focus on the needs of the<br>citizens of Austin, not on<br>other things like soccer<br>stadiums.\",\"lower property taxes\",\"AFFORDABLE HOUSING\",\"We need more indoor parks for<br>our kids, museums and better<br>public transportation.\",\"WE NEED LOWER TAXES FOR OWNER<br>HOME OWNERS. WE NEED BETTER<br>TRANSIT OPTIONS.\",\"WE NEED A RAIL SYSTEM\",\"please help to control the<br>influx of population, the<br>growth has been overwhelming<br>for so long now\",\"traffic sucks, fix it, don't go<br>to El Paso to look at federal<br>issues, fix your city that<br>elected you, this is not a new<br>issue, obviously toll roads<br>haven't fixed it\",\"PLEASE UPDATE THE<br>AUSTINTEXAS.GOV WEBSITE. FOR<br>EXAMPLE, DEVELOPMENT SERVICES<br>DEPT WEBSITE REQUIRES DIGGING<br>AND SEARCHING TO FIND PERMITS.\",\"HELP MIDDLE CLASS AFFORD TO<br>LIVE IN AUSTIN.\",\"I would like to meet him and<br>participate in city planning<br>programs professional\",\"BETTER RECYCLING PROGRAM. HELP<br>WITH PUBLIC TRANSPORTATION\",\"BUILD SOMETHING IN THE UGLY<br>FIELD OFF HOFFMAN LN.\",\"embrace public transportation\",\"FRUSTRATION WITH TRAFFIC AND<br>LACK OF MASS TRANSPORTATION<br>THAT DOESN'T REQUIRE OUR ROADS.<br>LIGHT RAIL OR OTHER RAIL SYSTEM<br>WOULD REMOVE CARS AND BUSES OFF<br>OUR ALREADY CONGESTED STREETS.\",\"WORK ON TRAFFIC AND QUIT<br>CHARGING FOR TOLLS. IT SHOULD<br>BE FREE.\",\"SOME EDUCATION ON LIFE TO<br>HOMELESS PERSON'S HARM<br>REDUCTION FOR PERSON'S ADDICTED<br>TO DRUGS.\",\"KEEP UP WITH THE SAFETY AND<br>CLEANLINESS STANDARDS PROVIDED<br>UNTIL NOW. THE CITY OF AUSTIN<br>IS A GREAT PLACE TO RESIDE.\",\"make west campus clean and safe<br>again\",\"I see many people who are<br>cheated by utilities ex water<br>and electricity why is it that<br>problems were rectified only<br>when the media exposed those<br>abuses, too many city offices<br>allowed to practice dishonest<br>practices\",\"keep Austin affordable\",\"simplify your process as much<br>as possible make it easy to<br>know what's going on get out of<br>your office and get out in the<br>community to talk to people and<br>visit neighborhoods\",\"Please invest in public transit<br>to make the city more<br>accessible for workers, the<br>elderly, and poor residents.\",\"better public transportation<br>and better water quality,<br>overall love ATX<br>green\/environment; incentives\",\"Control the overvaluing of<br>housing from outsiders moving<br>into Austin, making housing not<br>affordable to locals to find or<br>purchase.\",\"Preserve paid sick leave! And<br>figure out a way to stick to<br>our guns and keep plastic bags<br>at bay.\",\"The money that city of Austin<br>(is) making all around the year<br>with festivals, musicals, etc.<br>Where is (money) going or (in)<br>personal pockets?\",\"The city has a lot of<br>incredible enhancements and<br>initiatives in progress, but<br>the drastic spike in taxes,<br>cost of living and property<br>values on the East (central)<br>side of Austin do not balance<br>with the needs or the direction<br>of the collective communities.<br>While an increase in population<br>is always on the rise, we do<br>not see the extra money taken<br>from our taxes being planted<br>back into our communities, and<br>instead have higher rates of<br>transient activity, mental<br>health issues, criminal<br>activity, low income or section<br>8 housing, aggressive driving<br>in school zones, poor quality<br>of equally priced and easily<br>accessible healthy food, and<br>tobacco sales than ever before<br>and comparatively to most large<br>subsection neighborhoods (NE,<br>NC, NW, SE, etc.)\",\"THE HOMELESS POPULATION AND THE<br>BIG MESS AT THE CORNER OF FIRST<br>& WM CANNON\",\"day care and child care is too<br>high\",\"I think when owner of a<br>property for over 30 years it<br>is time for the owner to no<br>longer pay taxes on their<br>property. There is blatant<br>gentrification in Austin and<br>always has been.\",\"Austin sucks unless you are<br>rich. Wish I could move.\",\"Fix traffic\",\"Stop spending so much money<br>taxes are too high.\",\"Affordable housing in the city.<br>I am a government employee with<br>a masters degree and a job that<br>pays fairly well. It feels<br>impossible to buy a home here.<br>I worry about being able to<br>start and raise a family in<br>this city.\",\"Stop robin hood program so I am<br>not taxed out of my home. Stop<br>overpaying city employees &<br>hiring more so they can do<br>less. I feel Austin Gov't<br>crooked\/dirty too many real<br>estate developer ties.\",\"Take Austin OFF the list of<br>being called a Sanctuary<br>City!!!! Punish, deport, or<br>jail criminals, and pay cops!!<br>Please have the mayor resign.\",\"Traffic problems\",\"please improve traffic<br>congestion.\",\"I voted for, but am very<br>dissatisfied with the mayor. I<br>think he should support the<br>police department, ICE, and not<br>make this a place for<br>immigrants to hide.\",\"Do something about traffic. I<br>use to love to drive. I pray to<br>God every time I get on 620,<br>222, 183. People turf from<br>center lane to exit, they pass<br>on turning lanes, they are on<br>phones, they never leave any<br>room between cars, they do not<br>drive the speed limit. They are<br>totally hostile. This all<br>started in 2016. They shoot the<br>finger at you if you go the<br>speed limit.\",\"Keep the east-side affordable.\",\"Preserve the music community.<br>Keep the city affordable.\",\"FIX THE NORTH SOUTH TRAFFIC.<br>MORE TOLLS ARE NOT THE ANSWER.\",\"Austin is more than just<br>downtown, south Congress and<br>Westlake... you should see the<br>city as a whole and attempt to<br>fix all parts of the city. Push<br>for electric vehicles.\",\"COST OF HOUSING\",\"NO EFFORT MADE BY POLICE TO<br>FIND MY BIKE. OUR NEIGHBOR'S<br>SON GOES OUT EVERY NIGHT TO<br>STEAL, THE MOTHER ENABLES HIM.<br>WE NEED MORE POLICE PATROLS.\",\"DON'T LIVE UP TO THE REPUTATION<br>THE STATE REPUBLICANS GIVE THE<br>CITY.\",\"do something about transient<br>issue on 7th st, in downtown<br>and on street corners. clean up<br>lakes \/streams. lower property<br>taxes, discount for people with<br>no children.\",\"We need to care for the<br>homeless, less pan handling on<br>corners. House taxes are too<br>high for the elderly.<br>Affordable healthcare insurance<br>for those who have low incomes!\",\"Improve traffic flow and<br>enforce violations.\",\"Racially integrate the city.\",\"IT IS IMPERATIVE THAT MORE BE<br>DONE TO REDUCE PROPERTY TAXES.<br>TOO MANY ARE BEING FORCED OUT<br>OF THEIR HOMES.\",\"MAKE IT MORE AFFORDABLE TO LIVE<br>HERE. MAKE AUSTIN ISD SALARIES<br>COMPETITIVE. THEY ARE BELOW THE<br>AVERAGE TEACHER SALARY BY 10K\",\"NON HOMEOWNERS MAKE UP THE<br>MAJORITY OF POPULATION. DESPITE<br>NOT PAYING PROPERTY TAX, THEIR<br>VOTES CARRY THE SAME WEIGHT\",\"Lower property taxes for senior<br>citizens under $40,ooo annual<br>household income.\",\"PLEASE TRY TO FIND A WAY TO<br>MAKE IT MORE AFFORDABLE TO STAY<br>HERE.\",\"We need more small businesses<br>in N. Austin. It is becoming<br>too Dallasy, too many chains,<br>not enough culture. Not enough<br>art, no music venues.\",\"Lower taxes, and cheaper rents.<br>Also, lower electric bills.\",\"Take it easy on home valuations<br>and increasing taxes likewise.<br>Ease the traffic congestion<br>somehow. Have more police<br>patrol regularly around my<br>neighborhood instead of speed<br>traps.\",\"Improve home code: one home<br>away from mine, there has been<br>a 5 or 6 cars in the grass in<br>the front yard, and one old<br>safe in the front yard.\",\"Max hour parking for downtown<br>employees should be more fair.<br>Thank you for keeping Austin a<br>great place to live.\",\"Work on making city affordable<br>for minorities so we are not<br>pushed out of our homes by<br>white gentrifies.\",\"Process to contest taxes was<br>difficult, time consuming and<br>unfair. Feels like city is not<br>supportive.\",\"WORK ON LOWERING HEALTH<br>INSURANCE COST.\",\"Lower home taxes and stop<br>giving corporations free rides<br>when it comes to taxes.\",\"Traffic due to construction is<br>not very good.\",\"LADIES OF THE NIGHT AND DAY BE<br>KEPT OUT OF FAMILY<br>NEIGHBORHOODS. GEORGIAN STREET<br>IS NOT NICE BECAUSE OF THESE<br>LADIES AND SOMEHOW THEY KNOW<br>WHEN POLICE ARE CLOSE BY AND<br>WHEN THEY WON'T SHOW UP.\",\"TO LOWER PROPERTY COSTS TO HAVE<br>MORE AFFORDABLE HEALTH SERVICES<br>AND FOR THE POLICE FORCE TO NOT<br>ABUSE THEIR POWER.\",\"Build more freeways! Offer<br>public transportation like<br>trains, subway, street car.\",\"I wish rail fees were less and<br>more service on Sunday but I<br>don't know how to fix that...<br>the use of tolls during peak<br>are unbelievably high but I<br>know if less they would be<br>super crowded so I have not<br>suggestions I would pay<br>something extra in my taxes to<br>cover for more affordable<br>transportation and housing<br>there are so many apartments<br>and not enough homes.. kids<br>shouldn't live in Apts their<br>whole lives\",\"Wish there was a city program<br>to help mobile home owners.<br>Home repairs. Wish also the<br>city would control mobile home<br>insurance or offer other.\",\"please allow people of all<br>income brackets to experience<br>the magical city of Austin,<br>find a way to tax corporations<br>or the most financially well<br>off so others can simply live,<br>it pains me to see homeless<br>elders, I would like to see<br>innovation led by the community<br>on affordable housing supported<br>by the city\",\"AFFORDABLE HOUSING IS SO<br>EXPENSIVE. EVERYONE ONE IS POOR<br>AND WORRIED ABOUT THEIR TAXES<br>WE PAY.\",\"Traffic in Austin is a disaster<br>and so bad that I sometimes<br>consider leaving the city.\",\"roads, transportation and<br>affordability to retire and<br>live in Austin when you work<br>for non profits\",\"LIVING COSTS RENT WASTEWATER<br>TRAFFIC METRO COSTS SIDEWALKS<br>IN AREAS NOT COMPLETED IN OLDER<br>AREAS.\",\"ADDRESS TRAFFIC SITUATION\",\"more housing and land us<br>overall\",\"WHY DID YOU GUYS WAIT SO LONG<br>TO ADDRESS TRAFFIC PROBLEMS.<br>AUSTIN HAS BEEN GROWING FOR<br>MANY YEARS NOW.\",\"provide more hwys for group<br>population and traffic problems\",\"OUR CURRENT MAYOR IS DOING<br>GREAT JOB.\",\"MORE PARKS CHILDREN FRIENDLY<br>PLAY AREAS AND TRAILS.\",\"compared to annual salaries<br>rent is outrageous\",\"THERE NEEDS TO BE BETTER<br>OPTIONS FOR RISING RENT COST.<br>MOST PROFESSIONAL PEOPLE I KNOW<br>ARE UNABLE TO BUY A HOME DUE TO<br>PRICES AND IN RENT.\",\"we need too make Austin<br>affordable to live, the high<br>cost of living is driving<br>people out. Traffic congestion<br>is another issue that needs to<br>be addressed. more talk is not<br>the answer\",\"govt should be focused on<br>infrastructure. municipal<br>services and education.<br>everything cannot be fixed<br>trying to influence the market<br>to make Austin affordable can<br>only be accomplished it the<br>city allow a hog farm in terry<br>town\",\"LARGER AND MORE PARKING AREAS<br>FOR PUBLIC PARKING.\",\"The city is responsible for<br>police, fire, garbage and<br>electric. All of your other pet<br>projects are a waste of my tax<br>money and your time. Stop<br>wasting time on national<br>politics. That's not your job!<br>Control the bums!\",\"Homeless folks living\/lingering<br>in the downtown area- My car is<br>approached by someone daily,<br>Monday through Friday. I am<br>also approached while walking<br>to my workplace building in<br>downtown. I've been harassed,<br>yelled at, and belittled just<br>for ignoring them. My child had<br>the unfortunate experience of<br>being with me in the middle of<br>the day and was called very<br>nasty names by one of them.<br>I've apologized to tourists on<br>behalf of our city after<br>witnessing the same being done<br>to them. It is scary and<br>extremely sad that a city with<br>so much to offer can scare even<br>the locals away from downtown<br>some days.\",\"I love mayor adler ashe stands<br>for the same values we have,<br>more transparency form within<br>the city council\",\"Austin is too over crowded.<br>Traffic is unbelievable,<br>construction everywhere is how<br>they are trying to fix roads<br>but it is making everything<br>worse. There shouldn't be<br>traffic the majority of the day<br>every single day all year long.<br>Migration to Austin is making<br>Austin horrible to live in.<br>It's such a beautiful place<br>being ruined by over crowding.\",\"Find a way to make houses<br>affordable again. Especially<br>for young couples who have been<br>in the city a while, paid their<br>dues\/taxes and are now ready<br>for the next chapter in life.<br>Buying a home and having<br>children......\",\"Please help with traffic<br>congestion along main highways<br>and streets.\",\"I HOPE FOR MORE TRANSPARENCY<br>FROM THE CITY, BETTER<br>UTILIZATION OF TAX MONEY AND<br>PLEASE STOP RAISING PROPERTY<br>TAXES\",\"Southbound MoPac toll lane, an<br>extra lane was added, but took<br>over an existing lane. Now sure<br>the drive may be quicker if one<br>pays the toll, but it is a the<br>time expense of those who<br>didn't.\",\"Code in dove springs so many<br>cars parked all over a house<br>... makes neighborhood look bad\",\"Stop raising rent, it's getting<br>out of hand. Wish employers<br>would pay more. In order to<br>live in Austin, you have to<br>work two jobs!!!\",\"THE ADMINISTRATORS IN ALL<br>DEPARTMENTS HAVE TOO MUCH<br>POWER. THEY SLOW ALL THINGS<br>DOWN. STOP LISTENING TO NIMBY\",\"MORE AVAILABLE AND AFFORDABLE<br>PARKING\",\"FAST PUBLIC TRANSPORTATION THAT<br>WOULD ALLOW YOU TO LIVE OUTSIDE<br>THE DOWNTOWN AUSTIN WHERE ITS<br>EXPENSIVE, YET EASILY AND<br>QUICKLY COMMUTE INTO THE CITY.<br>SIMILAR TO SUBWAY IN NYC, NJ, &<br>DC. I THINK A GREAT JOB IS DONE<br>DURING ACL 7 SXSW GETTING FOLKS<br>EASILY AROUND USING PUBLIC<br>TRANSPORTATION.\",\"I live in an apartment and do<br>not use most of these services.\",\"traffic and safety\",\"WE NEED TO PLACE MORE EMPHASIS<br>ON PUBLIC TRANSPORTATION AS THE<br>CITY GROWS IS CRITICAL THAT OUR<br>PUBLIC TRANSPORTATION GROWS AS<br>WELL I FEEL LIKE WE ARE AT<br>LEAST 10 YEARS BEHIND WHEN IT<br>COMES TO PUBLIC TRANSPORTATION\",\"advance notice of street<br>repairs\",\"GET SMARTER, USE APPS\",\"BACK ROOM DEALS DO NOT SERVE<br>THIS COMMUNITY. CODE NEXT WAS<br>BAD. WE HAVE BEEN LIED TO BY<br>MAYORS AND PAST COUNCILS.\",\"HIGH COST OF PROPERTY TAXES.<br>CONCERNED OVER THE ARTICLE<br>ABOUT PARKING FEES HOURS AT<br>LADY BIRD LAKE TRAIL. THEY<br>SHOULD START LATER THAN 6:30<br>AM. SHOULD BE AT LEAST 8 AM TO<br>MATCH OTHER METERS IN THE<br>DOWNTOWN AREA OF THE CITY\",\"To have low income assistance<br>with utilities fees.\",\"GET RID OF TOLL ROADS, CHANGE<br>THEM TO CARPOOL LANES.\",\"STOP WORKING ON I 35, PUT SOME<br>STREET LIGHTS ON RR 620 S. ALSO<br>ON 2222. STOP RAISING HOME<br>TAXES.\",\"That they make respect the<br>streets of the community<br>removing from the streets<br>abandoned cars and cleanses of<br>the platforms and more presence<br>of the police patrolling at<br>night\",\"Give felons a chance to be<br>productive members of society,<br>we are human.\",\"Quit\",\"Traffic is the main concern and<br>needs to be addressed. Buses<br>cause a major backup, they need<br>to be allowed to pull over<br>without backing up traffic even<br>if the sidewalk needs to be<br>pushed back in order to<br>accommodate this, then it<br>should be done. Many other<br>cities do this.\",\"More affordable housing or part<br>of Austin primary Black and<br>Hispanic will disappear.\",\"Fix our south-side neighborhood<br>sidewalks and residential<br>streets. Our area especially,<br>Palo Blanco Lane & Teri Road,<br>78744.\",\"We have to do something about<br>the homeless population. The<br>homeless are downtown, under<br>freeway passes, living in camps<br>in the greenbelt, panhandling<br>on every corner, all over UT<br>Campus. Many seem to be on<br>drugs and are unstable and<br>aggressive. I don't feel safe<br>at night walking downtown<br>alone.\",\"Do your darn job!\",\"Traffic reduction and. Higher<br>minimum wage for Texas and less<br>taxes for home owners and more<br>available housing for low<br>income. More health care for<br>low income.\",\"Please remain committed to<br>listening to the voices of the<br>disenfranchised living within<br>this community.\",\"Train officer's police<br>department to treat people<br>better and don't be racist,<br>which I know it won't happen<br>because it is just getting<br>worse, so what's the use of<br>this paper and comments you<br>want to know.\",\"Clean up our neighborhoods or<br>crime, drugs, homeless people<br>living all over our immediate<br>area. Prostitution. Get rid of<br>all late night food trucks that<br>only keep drunks out on streets<br>at 3:00-4:00 am in the morning.<br>Crime, especially on Rundberg.<br>Enforce neighborhoods to keep<br>properties clean and decent<br>instead of dumps.\",\"I would like to have a city<br>park near my home with a<br>walking trail. Poor<br>neighborhoods rarely have a<br>park nearby.\",\"FUND PARKS BETTER. HELP OUR<br>TEACHERS WORK HARDER TO AMEND<br>RACE RELATIONS IN OUR CITY.\",\"WE NEED BETTER TRANSPORTATION.<br>A LIGHT RAIL WOULD BE NICE.\",\"I love city Austin, I think is<br>a great city... but we forgot<br>about the people who is been<br>living here forever, for new<br>California, Chicago people...\",\"Affordable housing. Better<br>planning for future. Mass<br>transit (rail system that<br>covers City wide.\",\"Austin is a very diverse city<br>and I strongly urge the mayor<br>to get to know the different<br>citizens in Austin and to<br>connect more with people that<br>are not represented in our<br>government.\",\"Fix streets on the east side,<br>handle the homeless. Please<br>thank you\",\"Changes need to be made. I will<br>be voting.\",\"Invest in housing<br>affordability\/ transportation<br>in lower income communities.\",\"Please encourage services<br>growth on east side for<br>families.\",\"Affordable housing, options to<br>live in Austin safely needed.<br>The city is growing and crime<br>is growing, too. Drivers<br>licenses (needed) for<br>undocumented people, so they<br>can learn the rules and follow<br>them.\",\"We need better sidewalks and<br>lighting in neighborhood.\",\"Affordable place to live for<br>families with disabled<br>children, or disabled adult<br>care.\",\"Keep Austin affordable!\",\"Love the city of Austin. Every<br>month, every year I've been<br>here I see efforts all over to<br>make Austin the best place to<br>live. Just wish housing could<br>be more affordable.\",\"Sanction those who blow leaves<br>and trimmings in to the street.<br>Create ways to accelerate<br>traffic flow on Lamar and<br>Airport interception.\",\"stop giving tax breaks to<br>people to move their business<br>here, they need to pay just<br>like everyone else\",\"AFFORDABLE HOUSING\",\"I have lived here all my life<br>and really seen it grow. Please<br>keep Austin from changing too<br>much.\",\"we need more affordable housing<br>and rent\",\"less people need to be moving<br>here, expand the roadways where<br>needed (I-35) and ensure that<br>African Americans and Latinos<br>offered to stay in east Austin,<br>stop the development of all<br>these awful apt complexes\",\"we don't want Austin to turn<br>into California, too many<br>homeless because the city is<br>enabling\/promoting them`\",\"Please help make Austin<br>affordable for all, not just<br>the dot com and other \\\"silicone<br>valley\\\" types. What made<br>Austin, Austin, no longer<br>exists. We need a good balance<br>of incomes in this city and it<br>is hard when the city becomes<br>expensive and unwelcoming to<br>native Austinites.\",\"Do your damndest to keep Austin<br>affordable to those hoping to<br>continue to live here. :)\",\"Help curb gentrification and<br>preserve the essence and<br>cultural\/ethnic diversity of<br>Austin neighborhoods while<br>allowing the working class<br>affordable housing.\",\"Please keep bicycles off roads<br>that are too narrow and have no<br>bike lanes. Impress upon<br>bicycle riders that they are<br>REQUIRED to follow the same<br>laws as cars if they are<br>driving in the street lanes -<br>NO RUNNING RED LIGHTS. If<br>bicycle riders don't want cars<br>to be rude to them, they need<br>to ride appropriately.\",\"Better ways to understand the<br>bus or public transportation.<br>Try to work with better service<br>or options for the homeless.<br>There are too many everywhere.<br>I was (in) city council in<br>Aguadilla, Puerto Rico. I was<br>reelected in 2016 but because<br>of a better job offer in<br>Austin, I had to move here.\",\"Let's have a citywide audit<br>just like the legislature has<br>the sunset process. Mayor, you<br>know what this is since you<br>worked at the capitol some time<br>back.\",\"Support local businesses and<br>their growth.\",\"If there could be a way to help<br>elderly and disabled with<br>financial difficulties. Helping<br>with food and utilities and<br>maybe clothing.\",\"Get street lights on Boulder in<br>78726 up to city Standards<br>please.\",\"Keep Austin from growing.<br>Affordable living\",\"stop raising our taxes\",\"Improve psychiatric and mental<br>health access and services.\",\"Control the homeless. I give to<br>organizations to help them,<br>however I do not feel like<br>getting threatened whenever I<br>walk my neighborhood for<br>exercise.\",\"Do good work and find balance.\",\"I'm really sad about what<br>Austin has become. It used to<br>feel like home. Now, it just<br>feels like a big, impersonal<br>city with not much personality,<br>and a lot of traffic (and high<br>taxes). The city that I loved<br>is gone, which makes me sad and<br>angry.\",\"lower taxes for the middle<br>class low income\",\"please consider how high the<br>property taxes are in this<br>city, they are completely<br>unaffordable Florida also has<br>no state income taxes and<br>property taxes they are much<br>more affordable also please<br>consider rent control\",\"Intersection of I 35 & W Cannon<br>Dr is taking too long to get<br>finished.\",\"Traffic it's horrible\",\"Continue to fix the roads, stop<br>adding in bike lanes where<br>people don't ride them. Stop<br>focusing on attracting tourists<br>and making Austin look, \\\"cool\\\"<br>and start focusing on the<br>people. The homeless population<br>is overwhelming. People need<br>food and to feel safe.\",\"Several family & friends now<br>live in Bastrop, Buda, Kyle,<br>Del Valle, Manor, Georgetown,<br>Taylor, Hutto and surrounding<br>areas because they have been<br>displaced due to the incredibly<br>high property taxes and costs<br>of living in Austin - what will<br>be done to keep the last of us<br>who can barely afford to stay<br>in Austin now & encourage<br>others to return?\",\"don't let old Austin die\",\"homeless situation, traffic,<br>scooters blocking handicap<br>ramps\",\"Light rail.\",\"I WOULD URGE YOU TO CREATE MORE<br>AWARENESS AROUND PUBLIC<br>TRANSPORTATION ONCE WE HAVE<br>MORE OV IT, IT CAN REDUCE<br>TRAFFIC ACCIDENTS AND DUI\/DWI<br>THE TIMELINE FOR CONSTRUCTED<br>MORE ROADS IS WAY FURTHER AWAY<br>THAN VS CREATING MORE BUS<br>ROUTES\/BIKE ROUTES\",\"AFFORDABILITY IS A MAJOR ISSUE.<br>IM A RECENT COLLEGE GRAD AND IT<br>SEEMS AS IF I WILL HAVE A HARD<br>TIME TO PURCHASE A HOME IN<br>AUSTIN OR EVEN AFFORD THE TAXES<br>IN THE FUTURE IF THEY KEEP<br>INCREASING.\",\"I am proud to be an Austinite<br>and I love the fact that Austin<br>is growing and attracting<br>people from everywhere.<br>However, as much changes as<br>I've seen in parts like Rainey<br>St and the Domain, there are<br>places in Austin that do not<br>change. I don't know why but I<br>am referring to places such as<br>low income houses and<br>apartments that look the same<br>or worse than they did 10 years<br>ago. I guess the issue is that<br>I don't see these areas<br>improving at all.\",\"High prices of housing and<br>taxes (and gentrification) are<br>robbing the city of cultural<br>diversity.\",\"More affordable housing and<br>quicker response. Higher pay<br>rates to afford living in<br>Austin.\",\"We love Austin! Let's keep it<br>beautiful, kind, and<br>environmentally friendly. Clean<br>water, clean air, and our<br>natural environments are<br>important for each citizen.\",\"WE ABSOLUTELY NEED AFFORDABLE<br>HOUSING SOLUTIONS AS SOMEONE<br>WORKING A STORGE LOT HAS BEEN<br>NOTICEABLE INCREASES THESE PAST<br>2 YRS IN NOT JUST HOMELESS BUT<br>VOLOTILE AND FRAGILE HOUSING<br>SITUATIONS LEADING TO DISPLACED<br>POOR, I MYSELF MAY BE EMPLOYED<br>UT IF THERE ISN'T ENOUGH MONEY<br>FOR PEOPLE TOLIVE OR MOVE HERE<br>THEN I'LL BE JOING IN WITH<br>THOSE ALREADY DISPLACED AS A<br>MATTER OF ECONOMIC EVENTUALLITY<br>IF MY BUSIENSS IS UNSUSTAINABLE\",\"THANK YOU FOR THE EXPERIENCE OF<br>MEETING GREAT PEOPLE DURING THE<br>BEYOND DIVERSITY TRAINING. IT<br>HELPED ME BE MORE CONNECTED TO<br>MY COMMUNITY.\",\"TAKE CARE OF ADDRESS YOUR NAZI<br>PROBLEM. I WAS CHASED OUT PEASE<br>PARK BY A GROUP OF MEN WITH<br>ALT-RIGHT SYMBOLS ON.\",\"TRAFFIC IS GETTING OUT OF<br>CONTROL! IT IS SO HARD TO GET<br>TO PLACES IN AUSTIN WITHOUT<br>GIVING YOURSELF HALF OR A FULL<br>HOUR.\",\"Traffic - get cars off the road\",\"The Homeless and Permitting<br>process in this city due to his<br>leadership has been a huge<br>failure. $8m spent on round 1<br>of re-writing the codes, now<br>overpaying for shelter that he<br>and the council members said in<br>town hall meeting \\\"We OWE the<br>homeless a home\\\" What? Why do<br>we owe them a home? Do you owe<br>me a home? Unbelievable. I<br>challenge you to put me on a<br>focus group mentioned below!<br>For the record I have huge ATX<br>following from my business<br>career and I want to and they<br>want me to be involved. Accept<br>the challenge, please!\",\"Lets rethink transportation and<br>do better to accommodate bikes<br>and scooters throughout<br>downtown. We can't double the<br>lanes in our downtown streets<br>but we could shift reliance on<br>cars to other, more efficient,<br>modes of transportation.\",\"Start using tax money for<br>improved transportation options<br>and remedies for the homeless<br>problem. The city's appeal is<br>trending down with the only<br>positives being the seasonal<br>events that are worth<br>attending.\",\"KEEP AUSTIN CLEAN AND SAFE!!\",\"Love the city but I35 is scary\",\"Keep Austin cool\",\"PROPERTY TAX IS TOO HIGH.\",\"BUILD A BIKE LANE FROM RUNDBERG<br>AND CAMERON AND LAMAR. THIS IS<br>USED BY A LOT OF PEOPLE AND IS<br>NOT SAFE.\",\"Highway improvement, ramp of 35<br>to 183 North.\",\"TRAFFIC AND CONSTRUCTION\",\"IMPROVE PUBLIC TRANSPORTATION<br>AND A BIGGER PUSH FOR GREEN<br>ENERGY AND GENERAL SERVICES\",\"PLEASE DO ANYTHING YOU CAN TO<br>EXPAND AND BUILD MASS TRANSIT<br>THROUGHTOUT THE CITY\",\"help the elderly, disabled, as<br>much as homeless, and low<br>income residents\",\"We need a new mayor.\",\"GET THE HOMELESS OFF THE<br>STREETS\",\"YOU MUST GET CONTROL OF THE<br>GENTRIFICATION IT IS RUNNING<br>OUT OF ALL THE MIDDLE CLASS<br>EDUCATORS THAT SERVE THIS CITY<br>SHOULD BE ABLE TO LIVE HERE<br>TOO.\",\"FIRE CHIEF MANLEY FROM APD.<br>RAPE KIT, RAPE CLEARANCE,<br>KILLING PEOPLE ON MENTAL HEALTH<br>CALLS, HIGHEST POLICE SHOOTINGS<br>OF TOP 15 CITIES. WARRIOR VS.<br>GUARDIAN.\",\"Please shut down motorized<br>scooters! Thank you.\",\"Slow down Unrestrained growth<br>is not progress. What is the<br>vision for the heart of Austin?\",\"THE DISTRICT DOES NOT REPRESENT<br>ME I WANT LOWER TAXES. BUT<br>MOSTLY NO HOMELESS STREET MEN<br>AND WOMEN PANHANDLING.\",\"Stop pandering to special<br>interest groups. Focus on<br>relieving traffic problems.\",\"I want a choice in all my<br>utility providers. Quit putting<br>bike lanes in. Quit spending<br>money like it's yours (it's<br>not). Quit being greedy so an<br>average person can live here. I<br>believe you believe you are<br>doing what you think is right,<br>but you are missing everything.<br>Look at who you council with,<br>represent all people, not the<br>select.\",\"When are you going to put more<br>roads (highways) in Austin to<br>improve the horrible traffic?\",\"Improving the neighborhood<br>streets and I-35 car congestion\",\"Open Windsor Park library\",\"The electric bill is too high,<br>even with assistance program.\",\"Please stop giving my tax<br>monies away for stupid projects<br>and give away programs. All my<br>years of working, I had three<br>jobs. So let everybody work for<br>their living.\",\"If people disagree with city<br>council votes on issues, let<br>them run for office (council)<br>not seek to supersede council's<br>vote and demand a referendum!<br>Also - plan in closed session<br>how to prevent state<br>legislators from passing bills<br>negating and opposing local<br>community issues i.e. minimum<br>wage and bag bans.\",\"Police department needs to step<br>up and investigate and go after<br>people who break into mailboxes<br>and cars. Also when businesses<br>are conducting shady business<br>practices they need to return<br>phone calls and investigate and<br>help with evictions. And the<br>roads need to be expanded if we<br>are going to build all these<br>apartment complexes. Incomes<br>needs to rise with increase<br>property values so people can<br>afford homes.\",\"Stop building condos where<br>there is no traffic<br>infrastructure. Stop building<br>stadiums in the middle of the<br>city. We do not need to create<br>jobs.\",\"Worry about traffic and<br>services north of north loop.\",\"Eliminate bike lanes on city<br>streets. Run them along creeks.\",\"Let's make Austin affordable<br>for any hard working single<br>person to not only survive, but<br>thrive.\",\"PLEASE RESIGN!MY FAMILY IS<br>GOING TO SELL AND MOVE OUT OF<br>AUSTIN ASAP\",\"HOUSING IS GREAT FOR LOW INCOME<br>RESIDENTS THROUGH ATC HOUSING<br>AUTHORITY.\",\"PLEASE HAVE POLICE OFFICERS<br>KINDLY TAKE ALL HOMELESS PEOPLE<br>TO A SHELTER. IT IS UNFAIR TO<br>TAXPAYERS TO ALLOW BEGGING IN<br>THE STREETS.\",\"Mr. Mayor, please resign and<br>take your left wing toady city<br>council with you. There may be<br>lots of growth in this city but<br>each day Austin becomes a more<br>unlivable than the day before.<br>I'm not sure how much more of<br>your actions and the City<br>Council's actions we can<br>endure.\",\"TRANSPARENCY\",\"DO NOT ALLOW OVER DEVELOPERS TO<br>TAKE OVER THE NEIGHBORHOODS.\",\"EDUCATION MISSES KIDS WHO ARE<br>NOT WELL SUPPORTED BY THEIR<br>FAMILIES AND ARE NOT COLLEGE<br>BOUND.\",\"STOP THE BICYCLE LANES, TOO<br>MANY BIKES.CAN'T FIX ROADS, BUT<br>WE HAVE BIKE LANES.\",\"Be more proactive and less<br>reactive\",\"I can barely afford to live<br>here and I don't make enough<br>money to save up and leave,<br>either. The city only cares<br>about the very, very rich and<br>the very, very poor. The<br>working class is struggling and<br>no one seems to care.\",\"Non polluting transportation,<br>city support for electric cars.\",\"Get a handle on the homeless &<br>illegal immigrants\",\"WE HAVE WAY TOO MANY ORDINANCES<br>ESPECIALLY FOR SMALL<br>BUSINESSES.\",\"PAY ATTENTION TO EVERY ONES<br>CONCERN\",\"Stop trying to bring in more<br>large companies. Stop giving<br>them tax breaks since so much<br>of Austin is used for state<br>services and therefore do not<br>pay any taxes. At least until<br>the city catches up with the<br>current needs. Would rather see<br>the school taxes used to pay<br>the teachers and staff instead<br>of having to spend so much<br>money on security, which is<br>also important, just more of a<br>balance. Just to say a<br>few...¦..\",\"STOP PROVING INCENTIVES TO<br>OURSIDE ENTITIES AND<br>CORPORATIONS, EAVEN WHEN THESE<br>GROUPS ARE REQUIRED TO GIVE<br>BACK TO THE COMMUNIY AFFORDABLE<br>HOUSIN, JOBS, THE PAYOFF IS<br>ALWAYS SIGNIFICANT LESS THEM<br>PROMISED, AND THESE COMPANIES<br>AND THE EMPLOYEES WHO RELOCATED<br>CLOG UP AUSTINS INFRASTRUCTURE,<br>WHICH WASN'T DESIGNED FOR\/READY<br>TO MEET THE NEEDS OF A RAPIDLY<br>GROWING POPULATION\",\"THE CITY HAS TO GET A PLAN THAT<br>WILL ADDRESS THE RAPID GROWTH<br>OF THE CITY. WE HAVE TO BE<br>AHEAD OF THE GAME NOT PLAYING<br>FROM BEHIND. IT IS NOT TOO<br>LATE!\",\"DON'T BUILD THE STADIUM ON<br>MCCALLA ARE YOU KIDDING-20,000<br>PEOPLE ON BURNET AND CUTTING<br>THROUGH MY NEIGHBORHOOD NEED<br>POLICE THERE TO KEEP MY<br>NEIGHBORHOOD SAFE.\",\"I truly don't believe he will<br>do anything for me. Too<br>concerned about being reelected<br>and stealing from the<br>taxpayers.\",\"The input\/output ratio of tax<br>money\/services is out of<br>balance. Residence of this city<br>deserve to know why and where<br>the breakdowns lie.\",\"THERE AR MANY CRAZY PEOPLE WHO<br>WANT FLOURIDE OUT OF THE<br>DRINKING WATER HERE, PLEASE SEE<br>PAST THE CRAZY AND REALIZE<br>THERE ARE RATIONAL, LOGICAL AND<br>FISCAL REASONS TO REMOVE<br>FLOURIDE FROMTHE WAT, IT IS<br>REMOVED PEOLE CAN STILL OPT-IN<br>AND THE CITY CAN GET THEM<br>FLOURIDE IN AOTHER WAYS BUT IF<br>IT REMAINS IN IT IS FORCED ON<br>EVERYONE EVEN THOSE WHO DON'T<br>WANT IT AND THOSE WITH MEDICAL<br>CONDITION FLOUROSIS REMOVE<br>FLOURIDE ITS A WASTE OF MONEY\"],\"hovertemplate\":\"<b>Text:<\/b> %{text}<br><b>Score #1<\/b>: %{x}<br><b>Score #2<\/b>: %{y}<extra><\/extra>\",\"x\":[0.7405474922437069,0.8407719587394106,0.7996939304669908,0.060143472365288816,0.9142140160562866,0.11747710846883021,0.6596013137444054,0.9777356332089362,0.7775906245014692,0.9704193872816704,0.7574744329709562,0.010404282812779189,0.3034373911658227,0.8819455604203783,0.2705317873418231,0.9118923799306089,0.18151017114640594,0.25951933498566404,0.7855887686554445,0.04039561331968547,0.0927284498474491,0.28980455916452236,0.15119297898295955,0.049036554159976556,0.30131533216063067,0.6288442892588016,0.9709132361978431,0.28316555606167,0.12797042089941735,0.07342399997423169,0.9557555010002651,0.9366002519875546,0.11515958028061757,0.9820816815302511,0.615563619627454,0.9545180996606873,0.17728587308147603,0.19772343202634762,0.5655158935492817,0.9604394573641314,0.8133201776274798,0.5931445576178586,0.8703604050825239,0.7163531318857155,0.2631337116730302,0.8325598310933174,0.9870834547692712,0.01963642530526857,0.20746650170796266,0.21844863441218687,0.039872790490726416,0.6034569288477077,0.9352334702298518,0.35895035256570995,0.46344779060042635,0.9297704156953223,0.831787291272361,0.04734744818686189,0.1137484951926167,0.11929395837244094,0.17198713822991235,0.06655547175808849,0.7658285553921497,0.9240944748439249,0.797973609753883,0.4515096407383747,0.20453185155204237,0.8651038886697768,0.37866535193666656,0.4260659727631113,0.043171287299594345,0.7179090608311086,0.4427591820611712,0.9046229109382994,0.8611258437710092,0.3298584055262457,0.12462177181250329,0.6266859126279526,0.36388055779349593,0.6521233285109141,0.27496139412760695,0.27494261300312195,0.7397881654422309,0.40037161032652885,0.9353464515141071,0.4434681005768579,0.39078017557652783,0.7397467067045688,0.8635818783611144,0.912300437868121,0.30263206598084175,0.7857455959741794,0.9694726200338133,0.815654055508878,0.38202532615188706,0.3492048941923001,0.1848624412837638,0.02400898505199257,0.3410336245026852,0.9776919065209099,0.9326825949573052,0.9769154579777782,0.1753732578928971,0.17387323263456061,0.08181121026485015,0.16245732318398542,0.30913610827617666,0.805869412841364,0.8463372480362115,0.017652416601449207,0.9796663457746447,0.1653530319148433,0.3622161183644079,0.6204685566434788,0.760926222650895,0.690339573610835,0.9318100265594652,0.1300348985395169,0.09085934580293607,0.3064569914329779,0.46662151349744524,0.1670339634207,0.7327896293847436,0.044659574749002416,0.1251827389275476,0.962299856148004,0.04088169239576879,0.061293071409640805,0.05452390844391152,0.9478095499473458,0.794994607426297,0.6365302177988889,0.8902367878917045,0.9669207163820877,0.9749906700741164,0.6382266072817078,0.14973754275011159,0.9172568700384589,0.9240018026532533,0.07177501638350503,0.1437915980643502,0.023967499637484985,0.739745043232993,0.6182958221990292,0.3308894466776066,0.049387712116270924,0.9637070345931016,0.8696072536554089,0.24314426632999173,0.5369602965588064,0.2141170832322128,0.11602213123569606,0.8725560459672542,0.2968703329831168,0.17013144764229263,0.7410617997476879,0.3978788919392202,0.01262237580747256,0.5682301425393582,0.017073062395900132,0.9369803844632004,0.9660473242652473,0.6874643994770306,0.5675293755335847,0.946291479644557,0.5179199476536216,0.9113336455676003,0.9117104973598089,0.6423098938224917,0.8479595972696123,0.6561566151405691,0.2644834219883424,0.5731341260408099,0.9792564070227261,0.1010230868953313,0.3608506458900357,0.5517297443682904,0.1501025984619929,0.6179180521641051,0.7665122742496905,0.9813137305517697,0.0477913256986394,0.1143555113507477,0.7108373721252254,0.06562421945852083,0.2823080082903962,0.5339969489646236,0.9520539446783597,0.37460922979529815,0.0364172699189244,0.82717179751739,0.8581484370014909,0.7843827327029225,0.05478720852940264,0.7516769310219509,0.7394592329367307,0.4216014789761355,0.07438116659237365,0.023113746394208302,0.13824641887303254,0.0009940643727061862,0.077389172308803,0.1774899626417902,0.2655971446766925,0.3272184430477167,0.8813094902183759,0.2850440855260565,0.8265427812717828,0.1830255216132936,0.13050498845142566,0.38171591346033523,0.3419527748854625,0.22858748568229917,0.0927614264992181,0.5338571899331047,0.1463152202358888,0.8220188161099552,0.4898426334012025,0.6813742154494425,0.8950586995259823,0.029767681856991714,0.04511241448407529,0.04166883572637246,0.8364730771453751,0.6214395706599402,0.6002487474347004,0.21871327177857894,0.9124455905507379,0.35561801830155443,0.058933049096355154,0.8597623315847488,0.8153119116535363,0.3906733634566554,0.24562879488454498,0.3791408463104785,0.29302380041509396,0.9223871916556619,0.3484606119335703,0.7529932690395681,0.6678478947338461,0.8386585889309763,0.16900774179874226,0.9660242609346664,0.8081125809592351,0.6900036833721329,0.3516153496221268,0.840447964970648,0.10197739134967629,0.9624533611045483,0.3148951818147624,0.47915925412626575,0.7751118964746214,0.829725963123713,0.24619700449150766,0.3161650943606009,0.5939858547012541,0.6075764609577667,0.28533043243475276,0.9138260891565666,0.8293954488493244,0.24636336408814657,0.2581281233223888,0.9743701997848081,0.4076563668971838,0.05159187150131846,0.44610834839664176,0.4320003131105785,0.22846083408959428,0.2828716690633256,0.1254575548688959,0.8670592130199123,0.1844233455118375,0.08668135968354876,0.238630689107401,0.7097922485101409,0.5228382186358059,0.20106353655385586,0.7089195055653289,0.9673918034370732,0.4186108436902233,0.9729158938590015,0.1597475546950989,0.866230925300536,0.056427901830639234,0.07585463933425794,0.06458372508309818,0.013478442122764141,0.967176603586065,0.027971210174391123,0.3110478117918919,0.9545180996606873,0.9447160770078968,0.0015271293826441522,0.9445203413062535,0.9317279019133122,0.29965048311744796,0.7398737397485622,0.558005611115374,0.11601364624321713,0.7012529662165063,0.18834952659617799,0.8223139519643871,0.6516260807407802,0.0025421893814717,0.3291954822646819,0.8323730864754026,0.9771364829858744,0.8631285548144849,0.9181242951744466,0.8119079722364634,0.08499940216961765,0.30582785881110125,0.06401797379635396,0.08708071618760103,0.3418457263599414,0.0901986893966373,0.19325948351944153,0.04495385886223063,0.049967586562747975,0.9682946420559305,0.03835158580451187,0.20219401727452482,0.9672811922565892,0.3044658137402417,0.26107125820005594,0.25637362261885194,0.1928554310755955,0.46330120155206805,0.9592435412602042,0.07352568717869465,0.7016950042903348,0.03254400571069436,0.06405349780663977,0.5394896378613501,0.35671982220413145,0.3000560650678143,0.5443850280567051,0.12192576892549614,0.49317228125855406,0.7943311140609663,0.045054105263682545,0.713956152371014,0.7234526959574491,0.24570569040432996,0.6934308574081358,0.15114820344154722,0.3037677140630419,0.43901175087731875,0.5791184658090471,0.6916326043952631,0.03132127612836987,0.7388422472986828,0.05879704305672671,0.36364697258743595,0.926531248240548,0.01711473835657015,0.29175445098490943,0.13833308641424807,0.1261098076432639,0.7359228870474896,0.5630693108019011,0.40356693055856435,0.0611494374601187,0.8592734421087017,0.18662565056172295,0.06911025724222672,0.4498080759577904,0.3524256347791498,0.022041276608839817,0.42784593705112395,0.9307648144611816,0.04770953066779311,0.19442366230547686,0.8716503919038193,0.8693079974878634,0.06182474553458403,0.8525240321585994,0.9807478234114946,0.8177458059872484,0.20849831003837652,0.3350181538882293,0.9729397441047594,0.6527926379541212,0.49146084232087456,0.9987802462077702,0.8091986426020671,0.849740043014212,0.8091964374544894,0.8695652466865939,0.8735621046067129,0.4204295086844377,0.9970780885835276,0.6523115645960152,0.7976712312712575,0.2942164011720945,0.942675062338534,0.19704186154889797,0.9550776443165464,0.041341846862919425,0.04052629268150908,0.0690252887430909,0.6775212434925159,0.6499643564399396,0.5168426076639653,0.16464709232876315,0.8839257780077994,0.8177310986073674,0.1560019617479969,0.5834461585971042,0.9944060660385851,0.6708444526192466,0.1377432228119873,0.7516481545207782,0.9888556970058976,0.6173562032460441,0.9513762181987884,0.07425106569287863,0.7003719329091818,0.11079115315669034,0.8276295055221556,0.14099607955770913,0.9653494180636102,0.18366882942860277,0.6714077063702213,0.9621916478695179,0.818445445650845,0.042722938701406435,0.9885959854655958,0.9606084294186752,0.7018156154954978,0.9889763541068335,0.06588451260052865,0.9915374892947649,0.9470590531445023,0.847229596277217,0.9654726754630807,0.3349334549674921,0.028975885962274003,0.6088604918137317,0.9878690350422986,0.7595080106533468,0.36990585105604257,0.6292032350163275,0.36388055779349593,0.9371223152303819,0.15636869169453127,0.8567282969980426,0.8121107745592548,0.13432439661524492,0.4615871802517515,0.2392507397040796,0.4164356033584477,0.7355681948914511,0.1398188953174399,0.20584848038981363,0.49695235900487583,0.41023339796274316,0.9732550679533449,0.017900101694570365,0.054618431053565,0.9911034956041098,0.6423045822943443,0.0370927425394161,0.8766647997435617,0.07056434938295159,0.04540480002854428,0.28999032052877566,0.9797943755153359,0.08500969048338268,0.10452261546968122,0.5000468238330031,0.497254333084329,0.22532700400520073,0.3428604126288392,0.4795172706309528,0.9023042296929255,0.061529080167900894,0.30960588565815195,0.062242692459925975,0.42548438327318333,0.9598381906536445,0.6170400985574349,0.30318394522440023,0.29742594868207095,0.5551674915150838,0.011766948137251496,0.21833589818642857,0.2877486480258299,0.5391630017530525,0.13624077932133102,0.5129986785492963,0.25141806535053196,0.7365352793968927,0.06393001411540686,0.5139377120536309,0.019241118495707185,0.40383867342545143,0.47697342834204043,0.5418132194910477,0.8675667959204925,0.40328155473482075,0.1451319175657861,0.08540396814194552,0.031695361610458654,0.08282352703287205,0.00323981235823102,0.9740053159732682,0.353333711296062,0.590248905430797,0.18296926513631576,0.5318486271209953,0.014475288463237503,0.45752767738193584,0.10493357190606,0.8468823318287025,0.35396852322106576,0.17043976041336245,0.06362536218622865,0.5241731078069326,0.6591863190876479,0.43050903336275037,0.010739721771133115,0.15251895857974052,0.44483039339501257,0.0009796950663228565,0.9530831447964444,0.1174049223414611,0.3215086416240268,0.28500470862419225,0.4929474487234891,0.8997236765200657,0.11336117300688259,0.9904333656364194,0.5491381486404252,0.893338353915085,0.9984867937144567,0.2723945296180304,0.3285564757359751,0.006286248974249649,0.04564182422437592,0.045953581875765946,0.8408036871200125,0.12503449825599355,0.6068396388755631,0.8377771143581498,0.5196634017117976,0.025421818868764746,0.5762368901097735,0.6848646373919685,0.9059978022532429,0.9535929360572715,0.8469659571851019,0.9386556733600877,0.022086376686362735,0.47584120875327807,0.633129297021557,0.08382789003185549,0.7612454853952848,0.9357252731578688,0.8839739113293692,0.08285671457784502,0.9175716314809157,0.47202269686162546,0.9428980326716326,0.28340148485128175,0.868363942548245,0.31369813118572143,0.5265288078821951,0.9625687005864565,0.967767968171619,0.9678185859329723,0.521063366788171,0.7623018356529844,0.9823859686266561,0.887561029615732,0.09534995991227166,0.07077241087085333,0.23731696685407727,0.25747746237949265,0.6014602134548613,0.511790335892669,0.6629504983445023,0.24764031062967698,0.1057343812093019,0.6398997715583031,0.5600108843057844,0.41340241403991834,0.9188419298616818,0.5197767922479808,0.5770444710963841,0.7943919688891379,0.9335854033405881,0.114432268019034,0.09093474489210987,0.7329618650447901,0.4955039582805038,0.8218965772553547,0.20113123082192788,0.2573136597331776,0.1774237869051954,0.33810929828300645,0.9979261023147199,0.1662432013282004,0.9960146402753519,0.9909040050589673,0.03441880324598473,0.21482084707236898,0.19709612086182185,0.37605275259360316,0.0023515587508980353,0.03560959444817212,0.9521712834595847,0.9466279723758392,0.07464742238743526,0.8803215805811231,0.9785940859197878,0.7064701040077187,0.6524157699581358,0.9388413743079688,0.7236629876229644,0.9081077812953924,0.24336379821462598,0.8603108552774323,0.5450787514455675,0.63209683642564,0.07853465332890146,0.29706741206248505,0.9240108101318957,0.18170825263050638,0.19953570635801038,0.9808171656286383,0.3694935336711156,0.46443658037785834,0.8160282083267854,0.10421091914126886,0.2622652157043834,0.31178892245336753,0.16530845567532085,0.05953484315849167,0.7248753946079548,0.9782917632412368,0.27286012079267863,0.4140201502841469,0.05047281197566352,0.029784721355083022,0.9165134503425296,0.6915265694549264,0.09492368453546801,0.22226527541727095,0.8823248036284608,0.043667926593892896,0.20631146316512855,0.33464495499056374,0.18816825958052016,0.9820436566512609,0.8791489201822237,0.8388194357165762,0.14068940459487675,0.935378698713721,0.445091434510402,0.44431238214366564,0.9122557924261723,0.4507186824666108,0.04170939398514975,0.17179870943218783,0.9530298643730055,0.7191905491768125,0.4341189671967402,0.6500033377282348,0.8347255902938242,0.11600606728052311,0.057241611750182414,0.609459110822339,0.7132187421201599,0.9859950963305811,0.916485676118162,0.9633215049441005,0.9612929472924547,0.9111195998923853,0.5479329685131534,0.9567819850371506,0.5519568554728284,0.500055095663329,0.26835176459847115,0.8312541594378164,0.9839173523290314,0.7653597622429127,0.2849200841465489,0.24473670421552635,0.0050004833688681305,0.7597001403391754,0.09810716942549107,0.7669394256165304,0.8117789510876334,0.28081073569959153,0.7292617475015544,0.9641504345957227,0.06015103153406539,0.8697851634457804,0.44634495622592785,0.20230876707628248,0.948390103335818,0.2320697349440041,0.004954664771975117,0.5490864784196279,0.9056662644429122,0.9750451487253797,0.5502418415734517,0.1986420762379823,0.9745520295330569,0.7188748846658146,0.429219304217782,0.6948431884977163,0.7297139935938487,0.5522342454226157,0.46210793977541575,0.08180934646754745,0.9889493201672983,0.9964373116042278,0.2897249056251878,0.2520344417297924,0.208971210248712,0.36614949689083565,0.8398400850331519,0.24611733160081795,0.2722451279994854,0.9601895057852003,0.2531286185821926,0.19258920494983583,0.09313836302071875,0.43431392563322113,0.7809253355016064,0.0003598628514878695,0.6348617283508675,0.6196944768635537,0.3540957654093942,0.6785286798332241,0.3272436410573776,0.05916662415931365,0.6314067940107112,0.7119161181216451,0.09282232262417527,0.4507186824666108,0.8990806065264805,0.009001569670687815,0.03805310267626927,0.16855251770436697,0.2457807041440815,0.08074116635540386,0.8553733985408009,0.21638343419575193,0.9912436593341409,0.36832853577889035,0.004266139509584037,0.8320684174909173,0.20297855489066158,0.7111774723139995,0.14117864381116205,0.8958895209482434,0.368837300941553,0.167465657654734,0.5940823965422208,0.4904217713243907,0.025109746904433267,0.3096093594754414,0.3175387789028112,0.22254046279224957,0.17787256087558864,0.5767813977141021,0.5105232094124211,0.06470499376507514,0.26263221687666016,0.31667246511268315,0.9235793101135242,0.9051263014807981,0.0682146973705319,0.3203537353219081,0.18597746421567848,0.9939920262218047,0.6339932630627779,0.1820458034669356,0.6281314111718792,0.330351953704301,0.23646486186130927,0.012339934929890243,0.22383666337838115,0.02336360555876703,0.9079061183477485,0.8971247700435517,0.8036375952461691,0.031073908758087965,0.5394920839230116,0.8629150865737334,0.541953044154375,0.26818604726701845,0.7084583141392178,0.044619533811793684,0.0752572520555547,0.010371220243629357,0.3886641897066405,0.6999190766794092,0.9633940353508503,0.25476956748438084,0.157768180637417,0.3902399811239511,0.4509633589797914,0.9106169550587999,0.5632119283776335,0.5550082439678572,0.029885256911358973,0.5763600007392924,0.12705651387647984,0.10200511866124508,0.5485305654644018,0.24161686536302865,0.7154133626255166,0.6332692913076727,0.7306004762276261,0.03963047197245895,0.03965164742639187,0.41409609689896687,0.7269090627543169,0.6260798824655296,0.9755766605091282,0.9708917431377418,0.9630238225790504,0.41005759063361036,0.2274644315666944,0.27737157829852344,0.5517809696196474,0.04662851987569475,0.19698585580628442,0.33020046139690024,0.5181363452818374,0.19152045074637333,0.6375228090921734,0.02809348018080977,0.6782068001635243,0.5668548297288268,0.36796402600845124,0.822888119863292,0.7393683944066446,0.05223692333321244,0.8086057836329973,0.7913221420966003,0.41947979374571354,0.7504942151248739,0.5316952121552891,0.0487940347624738,0.7196939634874873,0.5720685020792071,0.4497096907612211,0.22488450304743599,0.06903205962778979,0.7646886575142068,0.4572198491414668,0.9474677422962993,0.7230931524386764,0.224437419407175,0.980580420139065,0.40071699641100533,0.13321562253811933,0.17567656543951057,0.0812713278175661,0.9745187406812723,0.348857155594651,0.08495296004972527,0.02691442812692443,0.6609898780062498,0.7135308840447498,0.003463542065790176,0.10469409922523994,0.12228447698544956,0.1332559737970517,0.8912873881450091,0.2362891257192381,0.804074660704344,0.7880376328334422,0.031073908758087965,0.33032471385352635,0.31233365659087575,0.29837942062530215,0.3930019981307054,0.968063302054329,0.05708900393577966,0.13344948599900094,0.3018512272054611,0.2772129127704464,0.618110921573945,0.10949092758250903,0.9103897839269733,0.10197341453530771,0.5581301148654713,0.31350147923255556,0.8226978114200529,0.0055797562194154675,0.8609669331655246,0.8126597850780617,0.1613416994135035,0.12569597528122362,0.4642338400169565,0.5645781492527269,0.9829489128407953,0.22739725834300134,0.8053982639419158,0.15422918428308924,0.8957130688437351,0.5749102881470699,0.7823407490528282,0.9179312423118452,0.10370402750919595,0.07239842998277754,0.9813686669860093,0.42957403918068326,0.18201162863258075,0.35877131867986173,0.02109848222664707,0.15717186100629166,0.23219101126083536,0.7025624249477681,0.07548919355307819,0.348539764536655,0.38100909949839257,0.157788550226956,0.07435844868812767,0.2528977729123307,0.15620879751555886,0.48698045758099834,0.9350243492905489,0.06600421326256802,0.30260996972027343,0.6241718631024235,0.5641411902435665,0.9461761157454517,0.11937577767226819,0.8967294110612196,0.4078553231788219,0.9836570658966153,0.6559448414455467,0.9519737160019426,0.39751803332493146,0.036389395291994274,0.5209147190651836,0.06110576340887288,0.3980512277766094,0.13457067782065718,0.2094167078954013,0.41231398432475014,0.33492524417866015,0.889618872127643,0.5491052582967437,0.46300658925207117,0.4916192840507243,0.7500826993866676,0.876749702796939,0.13942176934742379,0.09638119220362541,0.24137289674362417,0.6333383075124613,0.24568169855552677,0.14428088826829594,0.31964122301688963,0.14702157078463376,0.21277752607185504,0.7193767002945325,0.5145189729687043,0.8179184380255171,0.7984923029797844,0.33115534599869934,0.4574912470510369,0.7834114104174958,0.39447006966020853,0.9846801285736919,0.10772077511422608,0.9389253095288024,0.8480061756011567,0.7918802848372336,0.7935342242997749,0.4612912171469996,0.3696144809991698,0.15111318825645242,0.3805569111144188,0.9806196626074983,0.2006275638370584,0.47784825737589176,0.2992596820685522,0.10619512763253174,0.14617902684445636,0.5572507765604947,0.24387988140877465,0.6871133181565852,0.040355798036275634,0.014540744358932914,0.8456496755956822,0.9022490454010572,0.07720226034190503,0.6509391316311413,0.7368534920727013,0.679927644990667,0.22113077788158678,0.909434669659373,0.40729621091947643,0.17498464927632779,0.8788429124139704,0.14941615789058202,0.5992036626205017,0.8503441234042917,0.5230124706489255,0.000327443795143935,0.07255305987736411,0.9362141651196411,0.8207451890749592,0.8526468634439365,0.7540733911570179,0.5833257826815562,0.225366170648071,0.8032582650582174,0.7285330324921897,0.589739687957658,0.8964742291356652,0.5956948331976524,0.6902794155605294,0.7230952872547077,0.1405644113355205,0.18832583018102755,0.5905233295597629,0.7536976735044559,0.7925406245061299,0.7491751510058352,0.012624717388161419,0.4696022329680763,0.12037316535347742,0.20774092374415126,0.9368546943716688,0.9072818196512092,0.4568728925011014,0.01079007285637115,0.19109583467699717,0.7407350043491185,0.6295294004681129,0.45127808744261794,0.2856130375012564,0.922744250178887,0.8767781449307582,0.7047364953935118,0.0073541276859521755,0.044106057516355705,0.16252189663023608,0.0011604826202428287,0.5760037002190825,0.8550715674271211,0.146961371652176,0.31704744247657635,0.03868512999733411,0.22898814774681403,0.4076835885374954,0.11306577379394332,0.3573001244922643,0.1611366556478799,0.34860597223306167,0.05029893679064332,0.24044073708719307,0.7161368718556433,0.40383682650779973,0.5728534405932988,0.5825219755382808,0.5193872083793845,0.6450765474957206,0.016136550039285075,0.10277111009158756,0.057274121991537696,0.804074660704344,0.3736892978206334,0.9821359242198549,0.9729358086543134,0.9000360657570694,0.013889343665143387,0.5653759936160547,0.43427765829277676,0.8730392498994544,0.9807222057694068,0.9630972203938808,0.06050089960076916,0.9567586049407917,0.44371381433086454,0.15197265704967594,0.9225989798874074,0.7824573246311008,0.9520254771777766,0.429219304217782,0.983120263752881,0.01376332813134301,0.4773396197083045,0.8304963727323885,0.2638425523916594,0.7537031925660135,0.367270802611987,0.5626604586222338,0.890515254199998,0.9208790793808733,0.9119327330940575,0.8964067220154759,0.3905449532241321,0.7602532897343178,0.7419321500573722,0.9548371798264943,0.07042980628606117,0.7030950451400737,0.1104515513605149,0.5354696265411549,0.44973124501172523,0.9548371798264943,0.9819443517185211,0.27822419330947834,0.21619066160114125,0.9395623333682811,0.40415984664237997,0.6466911555821676,0.3604628113605965,0.9033685346782512,0.48967967475204177,0.046183131804195955,0.9986769650045971,0.40302028066492757,0.16724483036008145,0.5940579531357089,0.9479167834191222,0.28505245427733905,0.7494623290136576,0.9551421074228056,0.09542642509741481,0.5472435144226019,0.5185081251158183,0.9940602372475139,0.19008550689918685,0.6222094116964666,0.5001470431858608,0.5663400781631739,0.8245527281706014,0.35428733898051534,0.4527982338478313,0.8516247062552507,0.6971290739449046,0.829039326543315,0.8115672653476365,0.021746488295202208,0.7084300293529983,0.6803420677108244,0.8614585593935475,0.5813886502420337,0.07909924670688856,0.8344266463708522,0.9716182848836111,0.9293387073312619,0.8079091928885451,0.8296760065913812,0.32874165576753617,0.9037539972028535,0.6183926561095151,0.7552689029021972,0.10449338829509744,0.6611810013777941,0.30130771287528013,0.9482603589465721,0.47012256430917587,0.0829579005521977,0.9673936616392794,0.05872832950091315,0.9553925082520204,0.23592211242195701,0.8254611510446781,0.6186933101480291,0.9801777797782838,0.9377940909727371,0.9516358013249594,0.9266206541302799,0.16463923344127662,0.9463855640547625,0.8655588993330092,0.48987132466193123,0.8944675737586868,0.645000138786465,0.4295089345258835,0.9509826196729892,0.18178573115778368,0.8099643498614721,0.07548919355307819,0.1613019143772736,0.45179391138188774,0.9102630573874554,0.003373813327468697,0.9688816923272767,0.7113509923509023,0.4999833112565098,0.40943466676298196,0.09650244708234472,0.5537782858331891,0.6453330371027293,0.7812156946386976,0.6017420129881635,0.6866848600134785,0.6668012546290115,0.35042990974034305,0.9591488091257058,0.9258578079489377,0.7390695587789073,0.8300496568822634,0.690952999800937,0.3066371232416433,0.02618900452231471,0.6153261138737326,0.3917509066989173,0.33949429538751835,0.5676837121062804,0.9470035842879102,0.47640249276517577,0.811040998834624,0.7935842024238513,0.8858957400419231,0.3908853521951202,0.06477947292544024,0.9950207434538481,0.4780545115888473,0.9162959014364052,0.3756106140546636,0.2890529309627749,0.0561006852187308,0.060262122670651286,0.669812566682961,0.46856687634278,0.8669411428203585,0.3438699055869235,0.23386630429867414,0.08455470478354637,0.02082005327958886,0.8820082001470959,0.11802813537279273,0.7957722398923831,0.2911461002543144,0.8530981984895012,0.5527313296781341,0.4667785748582502,0.06764477076729415,0.9645222039058672,0.2938166034978734,0.14455439907398146,0.34808435114069863,0.1989171420761119,0.024830652306646585,0.9435231054597184,0.9577316921835626,0.40612670447805993,0.7384777962014595,0.055350042397646,0.7053019636838695,0.8337490740054094,0.9750278727063365,0.07505416248774956,0.3456321045055079,0.9287302793878602,0.9758203640904336,0.5912571056016634,0.04277896144044784,0.4042384714609434,0.4768687117780877,0.5350592442038653,0.13602141108515556,0.6852604286945811,0.9851690968949476,0.07768467980970004,0.7486894811642447,0.8303789358784167,0.36320414628878855,0.7678963147813492,0.1705836515107394,0.9200122453769716,0.061535760219360115,0.3145112894545649,0.9297704156953223,0.3287528128901893,0.721454892223178,0.1785623545294844,0.5430498988361266,0.013530487779700139,0.9834386786213055,0.9127552703719432,0.3350010019749569,0.8695234353036015,0.8102325005802781,0.15578135736119417,0.13069738860989688,0.12463120721089929,0.056706040212998084,0.19111760335300051,0.6801307608233024,0.9865759269009986,0.21495671529355379,0.21439125551535712,0.3286074174182997,0.2600467070546848,0.8466814804158981,0.7726955022948904,0.06377549732615442,0.08134932810790678,0.5128897309529508,0.9246294955781026,0.5854126140993821,0.7189666109725055,0.40408989491052233,0.9522104737468834,0.46514467956416194,0.9280821516657946,0.14038354395698002,0.4507186824666108,0.22636218033044433,0.2636747472655786,0.30150502932020934,0.8551204776329456,0.20058210504030505,0.056939260611085306,0.32087948574259206,0.23973318727091894,0.8965644321204568,0.9348659794832659,0.08537635501222621,0.4457023708181106,0.46640047219347125,0.5715333391063918,0.734499156783759,0.1872998138301554,0.15857000036747465,0.8426905335332218,0.011228074984612708,0.7045588490351863,0.305563459998202,0.372873258506277,0.3307367048000895,0.031982609065907705,0.6225087540441955,0.4788917553581694,0.11052629470825598,0.2714132897067338,0.28157265390582914,0.04232364468604106,0.38159170890611344,0.9913387493459838,0.29961702661440726,0.16432811870321992,0.8288500629070918,0.05102182223018054,0.1298041943213017,0.1819777666533816,0.8596177755210632,0.35488342239184245,0.8749936861441655,0.028064096158583383,0.5948010090605211,0.24259971230245375,0.09327748891181392,0.04312270116320453,0.3492094588274298,0.6439375539454361,0.9797232165351843,0.1302075520618613,0.07071340098174243,0.11203604040227906,0.4326065797950961,0.8025649697864633,0.07720301064764766,0.9680717122908237,0.8215366258636839,0.7854369127937492,0.7341867650459306,0.14698781281095535,0.4105372597713804,0.17697214920177168,0.07595134569728242,0.7817445133210309,0.7454131434812078,0.26186715731462645,0.7603806232294309,0.09740352269583749,0.4510763855505131,0.03278177244214726,0.9081448200067027,0.9149114037613816,0.5931353938109167,0.6223607552974082,0.964846267759673,0.843906156248091,0.9854113011167226,0.4962308591104648,0.14927666213957674,0.9425605188943184,0.9239391813588184,0.36029849864171987,0.21014321970990513,0.11656814028428558,0.5487092302385946,0.8697764832305396,0.7664176964239265,0.24250672959435565,0.085571195909724,0.04558822723821103,0.20219070330510597,0.03216879388681983,0.5376704322340956,0.40102311806243957,0.7967537014412783,0.950430883456535,0.732140504144928,0.9290064084738668,0.39573415536412077,0.43047187443776636,0.5881572038391233,0.9238538723124643,0.2995476330131844,0.07631763565086074,0.38869669639168447,0.5168646286826631,0.744830295241476,0.49824968922532364,0.13093142057037635,0.9628391837689998,0.7692280464720181,0.17621488288567466,0.21058060204215243,0.7491199059542233,0.8730116176644448,0.9932888587508338,0.19845761254532163,0.20598588730608944,0.6908822079943765,0.08983949155475741,0.7130721914138747,0.502116451807168,0.1046979879174199,0.17684683610463245,0.8583132576163993,0.5363149464738873,0.4849672214132313,0.9633624067540183,0.010031151427283948,0.9508956459308536,0.5886795953689544,0.6059727476502921,0.11392681224483765,0.9812643511289694,0.2716868477016693,0.029668162803228523,0.2068929525450379,0.49195095672482464,0.20011320796486354,0.5035471751028016,0.9754724290963779,0.0009670743757164224,0.8979381487164352,0.7751451299305453,0.8770573033540462,0.8463122941193214,0.28820114844712136,0.6038011595409846,0.047684189741761876,0.7493181770270768,0.6537974241562665,0.3927511299438202,0.5401516287871581,0.23674908030721187,0.899387613346653,0.8144487968211614,0.33923659827454805,0.08629839633235765,0.812280445448532,0.5747103568344606,0.83793177456739,0.2446878752235955,0.9197197242715547,0.672881573325019,0.7732568748205094,0.23584991810516817,0.050741547148376885,0.9804746906631987,0.9754657312677166,0.6528188008148904,0.6369225114415467,0.3092623403799581,0.35090669214808645,0.013541012048909716,0.4409332368340534,0.967652397946424,0.2585006593939197,0.3691450870913317,0.2125733227246965,0.9759959629936308,0.26712659551831763,0.20086164068792184,0.6360800412466644,0.8393829171590459,0.16460502758523796,0.9663026728195746,0.5030964608247875,0.7711773587412095,0.7688469623111048,0.9249414150783315,0.9180189584315183,0.9703743621727067,0.05482979680195773,0.6261178739703681,0.4775162393847432,0.6112906483281104,0.07984657167402785,0.5810067907346246,0.06041339703215131,0.12427550469116398,0.3518179697925687,0.36167664381502745,0.9792308725917557,0.22268181748921567,0.6956803129505192,0.968407078241928,0.8588443473314917,0.5909634514047397,0.9753259255680522,0.3885685021445685,0.47384634572776124,0.9854188533782283,0.03842927041939806,0.8737971544328957,0.027482707723546253,0.7872581905682737,0.5318522688943499,0.7286443758299043,0.05161757814192156,0.05474821925853154,0.5040610083529978,0.30926051614154315,0.37064650062247134,0.6145191756120966,0.0742966052703049,0.01695208557781971,0.3347592159061197,0.9873970013631451,0.5774729123531868,0.5960553982962705,0.4810326979895575,0.9223771001735118,0.9703415141946931,0.9313985979167393,0.44340717754839293,0.17365385784203563,0.05737685990697141,0.24139173369780037,0.1110542611931881,0.7254521369688927,0.29286222752572744,0.3178405504835767,0.9578234924574816,0.45198814570808876,0.29915613984172124,0.9713993271136415,0.2984509285178581,0.3293104986062241,0.5173605582919877,0.09238210769766025,0.72792362059176,0.42354522658532173,0.8587996150731239,0.8806836404437614,0.22209550293439756,0.7364216408871201,0.13095302099586145,0.5610572741909821,0.9207561051683995,0.018419394946091384,0.3773499555606817,0.517892257201425,0.7098225792175831,0.894841347650415,0.8322307608237064,0.8962018141229281,0.6347141375429052,0.11782159889232129,0.8068956781414081,0.8903675558793211,0.07365772132663923,0.9868826674594484,0.17783320894956017,0.8507015123082088,0.010287135978526608,0.878920180018892,0.9241441935292879,0.3253393359804345,0.09951160756491535,0.5422065015853285,0.9282975715083763,0.6848598288325582,0.63400823712608,0.15935757034173148,0.7742834145869711,0.019954281080997966,0.6575120420504439,0.8391551021837746,0.01851415671506495,0.6795051951992971,0.9592046850773979,0.07687125792950013,0.8728021897236161,0.42327118388614204,0.2665562387814903,0.16619186153171828,0.013591262321462513,0.12348781813547145,0.018682121644882473,0.16612909013723393,0.08505575310781822,0.7080099723589747,0.4910009295446589,0.2793435117381373,0.29648800282583343,0.36329706212808655,0.36381075682852526,0.8869314068467637,0.9036595796010485,0.6340364861248625,0.8086260009145304,0.6510841573941633,0.11430541708996667,0.002508690037059985,0.09824509592467466,0.2158293320237,0.18356304622897623,0.1329879322040261,0.6864254858150959,0.900686862194765,0.9432256265093306,0.05827229310778487,0.5613186096688085,0.35579133765174803,0.48792933564289975,0.659143172838732,0.7476052942624695,0.1856508245193944,0.17853298577117765,0.097030759343681,0.9158627256981006,0.786179335474036,0.07432140298432141,0.3204327132434394,0.07783262573994089,0.15171528209075563,0.367935378598152,0.9423381117232567,0.4628419426012756,0.15675741817343827,0.45468767827703854,0.98841464550089,0.5885851524088599,0.9508261571999754,0.8967169315903637,0.41763979028115905,0.5080809019611513,0.43866856066271176,0.9224024307193056,0.9616390998214976,0.7224600427403013,0.29791627852400215,0.18150336903650593,0.2768070398134374,0.9461071683359258,0.00716629218299414,0.8146057112947704,0.17189280174631083,0.07894406768355217,0.28243197108278617,0.8742772466973622,0.8095387889820908,0.9931001884043558,0.0988820956317179,0.7806119282220358,0.2912676118543854,0.6727415795157017,0.784727198553187,0.9740530821106648,0.9116699409317267,0.3453843192555918,0.4745662683646324,0.13636639990771712,0.906434561823284,0.09559892969780437,0.060155358814332885,0.9137056257770918,0.8217657609559142,0.6582902918047896,0.4878055134542687,0.24056403761772602,0.9529779025804085,0.4356431201004088,0.4126730236729143,0.47907023706889657,0.20455910368834201,0.0002878814895364989,0.2988664490861898,0.04757026346798696,0.04781240256392696,0.09023739967141682,0.63565460783605,0.7757853043083529,0.046185715223267636,0.37471363040860345,0.16473181687359945,0.9555555489107415,0.7357837022872483,0.584742620886757,0.06950821184806057,0.02359955725623098,0.7255394467911866,0.9801859079068239,0.8419642063928962,0.31651713309690094,0.22479358969878985,0.22370262017637518,0.4618195715607148,0.15281838024840624,0.27162465100640193,0.7346586210971955,0.8666918796350591,0.15880971469407415,0.7253344447174147,0.3533199007372765,0.9881876200379278,0.11842501515216455,0.847010106575516,0.9543940026492597,0.057944137390097857,0.533500825696137,0.700641092753839,0.4712571130762629,0.7275487985787981,0.6434108797664744,0.6922748106218272,0.36018756047507133,0.553722101950488,0.5574875879447195,0.4447337490172086,0.6401497909094788,0.5539934764533515,0.5504277267384781,0.3386945724091087,0.9380637830289815,0.9731370140819359,0.912478554657364,0.2131558010740871,0.8541139295523662,0.14304455184020606,0.06925399599947639,0.5933373357830891,0.13057995839427558,0.19659872299775855,0.3025428491959897,0.9560289812890023,0.33755493219814503,0.0044521315694008344,0.4753085797179428,0.6308162695787591,0.2409617872300773,0.37213767439417444,0.8102172405339797,0.4271251014144922,0.5137430230893543,0.6974860891210866,0.8033260439827198,0.8940657145560492,0.9087986742988089,0.5290021364133808,0.12809599381176887,0.20355403659795493,0.7885230646019413,0.3463814168359806,0.8531811686316016,0.4269868938064156,0.7541720829335868,0.8987362972535916,0.9213598315103504,0.24093820072879385,0.03170613575241628,0.22166594245537963,0.013687346389110273,0.8684287247025413,0.18477292463150297,0.19507958800540043,0.966817943244701,0.3156892112187844,0.23502363822386335,0.5952873660691634,0.7629347886736042,0.005423480153601273,0.959616235092598,0.8834448259752078,0.4096371233643049,0.7205288356741916,0.6927624474981747,0.9183727869343788,0.998070438965791,0.34294427555349616,0.15171497477423995,0.24222728535909757,0.3827611716479581,0.005705247398160472,0.06075603771873992,0.3256051574478722,0.3109735993356294,0.20578163264655297,0.6414924615378086,0.8715955199465693,0.19802553484973198,0.9565046246502249,0.5232701414617055,0.6006919630261797,0.2193287635308953,0.9363962945316057,0.28965663742824543,0.11243644611205042,0.6428223772872402,0.06127991460121764,0.07285317227730917,0.015297000855577952,0.9303994849622764,0.9776320223683546,0.5993957959519637,0.5057782087554366,0.967898952984879,0.19452611465263558,0.9740851302836241,0.9710636053702318,0.9982638675058602,0.5051526137720649,0.8123000603213512,0.9763921165164687,0.08820599321540243,0.05890145430828275,0.9046544036985691,0.577814157563005,0.8896080579837551,0.9950435154423082,0.7842783960331927,0.40068679272896934,0.9732474213428542,0.9178773439205459,0.5729582618411159,0.34486121472710474,0.005185869044937103,0.893678592435187,0.3757186699967702,0.23626295817412277,0.8188258909247371,0.7683146483894062,0.4528028776916284,0.8691109226804026,0.26161480230770695,0.598185436024754,0.9864432016511863,0.967245167427085,0.9408746255557735,0.09475870092480862,0.47186728957484564,0.9077032987843427,0.9298618071163497,0.9490731034447549,0.1918048294546964,0.5075936877542399,0.20853372092404668,0.36975644962916177,0.7488492510700044,0.032056356891106655,0.6229222485566264,0.3462155558959129,0.7024831603739782,0.010241329772662669,0.08275067454470698,0.15102534600625245,0.5758109324416736,0.4139738520534684,0.7731591110964462,0.07731438795000477,0.7214747016219963,0.8737604639990078,0.3089241527592131,0.7181702898655414,0.8236814423945791,0.6737519951117166,0.9460403147856883,0.14415232820411866,0.1784752796888747,0.3056033567592829,0.33553173084945853,0.08404557160031448,0.6267566621410415,0.6199586879364288,0.07336243783797361,0.2799243204635542,0.1053855605814007,0.16519790093350137,0.32226429811635804,0.9746353253098885,0.9410338172557674,0.9717952893268614,0.3983047728960807,0.8371971427678203,0.6877876707048511,0.5111432485417814,0.9056713367673401,0.47155368037048795,0.7737867289144101,0.9866151756854005,0.2727365418108498,0.7212067076819669,0.25477287921202774,0.3502353333196667,0.8403967300738011,0.15052476724542846,0.87876189558448,0.4943838050944126,0.2823944152708154,0.43149591021626266,0.9650202251624713,0.5290073739720876,0.8100012258250191,0.9446510887062869,0.5197964711798146,0.8543529855966583,0.19132163378840011,0.09247414659648372,0.6642758271170871,0.8766448848969034,0.784772677876106,0.5339572482609535,0.941999511046112,0.09017613213797487,0.3665370509416366,0.9948372478110646,0.8040106469536675,0.2498091427331237,0.979242925191642,0.36502018148125054,0.6718939182989596,0.9609459465162956,0.8763799169029947,0.6079300568751703,0.8878065635323398,0.8055081026712654,0.05866559843524985,0.26089764304088564,0.5738231782725303,0.7357529515748394,0.3924451273946049,0.24339539001690472,0.22603427571585402,0.9786100864672826,0.585231156179605,0.9257490802169914,0.8957790605971089,0.8000083924220244,0.9280641959688778,0.960686114712731,0.31571751277193283,0.3510454185030212,0.9787882273381704,0.12845146959696907,0.2334481584228909,0.9243487492296705,0.9836995181718329,0.5164614305061715,0.3574650034186399,0.14350502415937608,0.33912615690417564,0.09555233172708916,0.8649787021650689,0.21123474885107252,0.9629391195900628,0.9651967058807658,0.6806106277013682,0.4109890547064782,0.7927059330371737,0.03025612514446,0.8355475926863758,0.6776232181898274,0.8214639192642144,0.7218802188219378,0.1759098628371592,0.401096863992212,0.03842416989104597,0.24144723367232124,0.2383090578548478,0.0521594382290973,0.3025834017114562,0.9889670393044864,0.4913534388616234,0.9503656280680448,0.10365676744616639,0.2369910042045621,0.9348476235961987,0.6951773412811062,0.46204379855535305,0.13552109836897283,0.05341634536826487,0.917031468192165,0.9811998394714684,0.2646769751949264,0.7267387310002146,0.4563750312619808,0.9598295110263801,0.06128688453446823,0.19887322821727862,0.7677977056429545,0.08918348633762939,0.7498516975841495,0.22115880819755296,0.5071256324782083,0.06762053397455008,0.37924413640551263,0.29321699274148294,0.9550451764757433,0.1762525737355971,0.7332474967986119,0.8177794177241304,0.04838022206688767,0.17018536119204541,0.7067863549735579,0.2702343433291747,0.7628543416661339,0.4139059353944006,0.9642702442775964,0.3184077909969093,0.20495244338721277,0.27130010732201054,0.6961121741468752,0.9830943852086134,0.27402129907126316,0.4474109673771548,0.7459144183040605,0.9669978027373151,0.9985859995952462,0.49312476474956657,0.15152847697967325,0.2649447474847076,0.6438524453643911,0.4757029422090604,0.4741525335590651,0.15205913533275517,0.9936748613035188,0.9520092942420436,0.39188060560505616,0.09976219596023311,0.8815482998256552,0.8767476524687494,0.5738175259818645,0.868068067778029,0.5362090327286888,0.3006815456205294,0.05680401570136634,0.9822337116596777,0.576083288408778,0.4624885971302865,0.025407924526802315,0.2628832770657233,0.861833798644991,0.18421106721714584,0.10375190556718,0.27474646584334733,0.5903344109721054,0.6900955270440583,0.6939904784673271,0.4147474451223787,0.5802949092912192,0.32593446814132127,0.8289069742135287,0.1258443471660071,0.9308930077675397,0.44066174738611125,0.9741984574744895,0.47369695767761205,0.8513821085979796,0.7475858061675815,0.7425953437299769,0.05860258856565009,0.030333085498503533,0.3961751934661712,0.5203400499559716,0.7905042517739411,0.9157983845348715,0.0268211644754626,0.8189315879744005,0.9189479714852369,0.18361259482351575,0.06956488971828494,0.4836115252854055,0.2805119393185766,0.9338436613491875,0.2846003940961573,0.47280241718215754,0.029689254044807507,0.019790551307244338,0.029554918557226972,0.7648862421317735,0.023097944487007274,0.07626580236900707,0.1627797316743061,0.17019435240792136,0.008187363905188687,0.5773607900294513,0.03672264564315376,0.28091846580875984,0.17539238378859565,0.05275725612518417,0.9679311314645158,0.21432966408534138,0.0010590067248607581,0.9892359748326133,0.24184852522878517,0.6245286315721607,0.16875010058289802,0.4692425364491062,0.46254426673878923,0.092293103058267,0.9950866459331136,0.4594606570413678,0.9734640500628935,0.5559643834786625,0.46490303029631264,0.8871478939174189,0.9466783392252632,0.5151990040699184,0.0161575787990456,0.19772005792956943,0.9354644673990795,0.9104919564522682,0.6628555498433931,0.8611199211333737,0.36943903638539,0.3911779628137404,0.39899002150147306,0.857394211848461,0.1635144019471228,0.453222707751054,0.8977351822059374,0.143094524721455,0.007113166488971368,0.554318444230507,0.9723438262203377,0.9989666000257563,0.06170440336843374,0.6268109173760494,0.8068618297805563,0.9750580760363333,0.2537071740635941,0.9640404733480064,0.7795654716093154,0.2989486735773402,0.9545462344325369,0.7767495738279923,0.8314732948893189,0.007580074775975687,0.17272559853277067,0.3009858905687733,0.21873488614459258,0.4954687797260459,0.010625237061902106,0.3123440068701765,0.8137024131383432,0.4637293776863383,0.8587107468912539,0.8762209786547337,0.5933722548265651,0.004598457984130212,0.37019885713579614,0.9800955701365637,0.5847646323902177,0.6474934603114814,0.7342772506268652,0.9559556797712778,0.04731263838564103,0.687046659007842,0.05780601366096631,0.745795165462976,0.9491583110279947,0.4127349720105477,0.9210914460957758,0.9286638799036689,0.8644121978701996,0.41495209179214704,0.9170888641423001,0.8310980532978791,0.7112672446806251,0.8858340202480189,0.6778338322480839,0.7064141511749769,0.97395113014077,0.03987919590200127,0.02172936552033178,0.7456283948276624,0.009678581051729,0.0074223278017345115,0.471793776946693,0.9519668288912652,0.011366867755488504,0.7634996092445019,0.9019466767382839,0.3673225228008738,0.9277837588807489,0.13550390942766186,0.17518639876868844,0.7298472082344255,0.9657614327623505,0.0015278137827751679,0.05986670190467366,0.12017925984683613,0.988597372615485,0.12475122203614335,0.09876174835842275,0.723703896202605,0.485642905119734,0.6748943421998915,0.2298409214977528,0.345741181693812,0.8433618962343687,0.3816200918878944,0.9932008458065683,0.33028925934497694,0.31535605772447173,0.6983412101922122,0.25478591030339315,0.9827237631638326,0.555398030572088,0.9112538902159733,0.0731565893123493,0.9400110866036256,0.829893458846116,0.48573952883901267,0.8952192734060749,0.047543349954087835,0.7457339871278645,0.990373137318653,0.22887430216541196,0.7383966717342669,0.9473028697255398,0.738843971787683,0.7814669740015242,0.080154748222639,0.9156438614478176,0.6583640172849625,0.19887156862354624,0.8963266127889702,0.7969448481553888,0.8371465436296143,0.9704718896950729,0.5640829219798332,0.6493453876170883,0.004527376653406782,0.017133607089521437,0.25132110781313516,0.8577252225688287,0.9110132794888357,0.6632459424395166,0.8296760065913812,0.7893633934651555,0.14715132662707786,0.5943668620136481,0.15312356365794952,0.4853342257096486,0.0015046613368618425,0.3303225546305952,0.016040499716294187,0.19442467169457978,0.8442179326296396,0.5304081810986292,0.8873184002606759,0.21713764882027065,0.045275618939994315,0.908527310108215,0.9887101807731681,0.9107805645067624,0.01754253065245119,0.04840530729302703,0.799338792338367,0.5488610045803476,0.9691836306128669,0.11616358702223847,0.6351150863916883,0.9645678798575658,0.49834242459166567,0.2747623402682977,0.9945228166500335,0.7758067746707551,0.5571745671831893,0.1092540939965137,0.29701204454461205,0.23887341475209226,0.9548371798264943,0.27130803947640436,0.6615806933703859,0.763855603145859,0.015715675196589823,0.007678700919777986,0.42601402067551947,0.007330640569753278,0.23909985486311186,0.20672052247905492,0.8391082530238168,0.9947018510495121,0.9252552545126829,0.9411941287439813,0.024607112618016406,0.14584171903003995,0.3677001061028095,0.9949361810480887,0.9817951222561991,0.7913235977304488,0.05708900393577966,0.8397540568872367,0.9917858868422681,0.9294152432593766,0.8647201479339461,0.6818629334965416,0.47495092869163785,0.9298903206908048,0.7168598703127163,0.5418635823591359,0.7171735526966161,0.03807544863135492,0.9608649620570218,0.3957904499025198,0.6939897177338543,0.7133973246647837,0.9961760612828912,0.7243454746238844,0.5471362740189634,0.922970895419741,0.2673583568736969,0.4171110747245479,0.9654959868025356,0.9588101865698544,0.971932854675817,0.9894195026646452,0.32631622760968904,0.20879857425900297,0.18621360873309603,0.21334160188296686,0.097069707105867,0.9517817143660894,0.9280814200762885,0.06513474554193212,0.8510030066365283,0.14651515522005373,0.9165745057321432,0.9812944793216142,0.754887424818194,0.8667803027861705,0.9427036686156914,0.7556420199113635,0.010915493368274815,0.7393610142472905,0.35454256863026945,0.23518570614156356,0.8025533851739056,0.3293368473661047,0.16938002358710388,0.3748479357331634,0.1548958650085467,0.517518198888348,0.9840981018706922,0.9031419630908122,0.36706708706250124,0.8900377893153378,0.8605961122274799,0.9174025257840986,0.7729961730570416,0.5377333674915855,0.48689365441530275,0.5982827718925188,0.9083273111020781,0.6571045098009418,0.42110486031129885,0.9895744571822281,0.18024888702015865,0.31825671697601243,0.7881892741444337,0.4152875742171248,0.9867276860467026,0.4596017281920185,0.6956193503163934,0.6307554139675279,0.979058721410349,0.901026522347907,0.6140610371081783,0.9308395390295274,0.25731552246755673,0.9569930782746031,0.016202195168019653,0.5515594973873998,0.017619073959528365,0.2320650868277696,0.8465193131333747,0.26201944250751796,0.8329269554879949,0.26193276759373363,0.5292496826971809,0.6618751525514412,0.9783436073330106,0.7907488151587287,0.6144477862163816,0.69826731257261,0.9137765661784095,0.06170440336843374,0.842350235852017,0.024114315602765442,0.6815102815959598,0.9028842669383303,0.8813054972659696,0.1650884036675466,0.9912087418728007,0.7851804469045232,0.9205206973481368,0.5184467095281257,0.8664217181762731,0.8531328704539856,0.957496061042998,0.9680857541155223,0.2687984414152872,0.9249367301418401,0.6180363730186262,0.5431220117262602,0.9877906081283533,0.31289455874471683,0.3229627505561541,0.53079897933008,0.4038041874559244,0.6954061156526681,0.7482526260476913,0.25060060021484126,0.7195190962163955,0.9439369630729189,0.4507186824666108,0.07577894531447608,0.9876203552302518,0.45172503592321533,0.7227385428655075,0.5509202962866835,0.1557542609108461,0.5899763337330459,0.5248197079666337,0.8260038335054809,0.4550484283876044,0.017908905223344155,0.6295993522531689,0.8015578697969685,0.3208288012091784,0.5615401149761761,0.8536008542411102,0.00024337530170872516,0.9624766511022527,0.050120102674474865,0.9122582354109515,0.9753874732736801,0.3618875945054363,0.5825867860656146,0.766219214929304,0.2079647606099461,0.9715145230796494,0.7104686227035653,0.6990962535682014,0.0513123961959644,0.4112543751440732,0.02351467541290885,0.08927067272942432,0.079888960488725,0.2666406783955904,0.8279850711924991,0.5302214598154859,0.7332770929820928,0.06809305155091872,0.6211704623160018,0.48770284886656257,0.6943529638271471,0.6138810861380395,0.8572904989462787,0.33635747091308177,0.47760576751998063,0.1930550865821987,0.9965408989922744,0.12516421763650268,0.1567371382097148,0.07349373126737815,0.7045406381320813,0.8900464005714006,0.06707736661511328,0.43634126383838356,0.26979347114959645,0.9477947716440609,0.061472769068089364,0.6172947143445421,0.20408693142261344,0.09561426320986051,0.3882613603806796,0.30658346484376997,0.29636603427888253,0.6286698462354882,0.4930465085838712,0.07024084130170258,0.6709774456177122,0.3355022882733251,0.12641111170183075,0.25676983935845743,0.015905958351222764,0.3525516662154321,0.20088884716647037,0.4468361335538375,0.04651784696316151,0.3564528155776777,0.04084655825785091,0.009604307400560261,0.3291126427610942,0.5364891720566447,0.418369978533909,0.4602375713726644,0.995554773985923,0.27859846038014574,0.0008679789409152367,0.10033254214953087,0.11285335014010667,0.02391161139399083,0.9655165522764001,0.7684376222710756,0.3493328509324695,0.3040435807706736,0.7117292634895395,0.8493949429958506,0.9057051027845249,0.7602628326687672,0.9090668511255172,0.4141864884167773,0.47097667801352977,0.13380158580073137,0.9873229462576254,0.9590232413735089,0.9552795347403867,0.49462330720396586,0.3600720074649862,0.6283655391651112,0.8720905797119812,0.962184232745825,0.7821809200291031,0.9545180996606873,0.9430786073681796,0.9128239586952068,0.3725747808161701,0.08294597037180595,0.5023280841917018,0.029103876516358883,0.008514353973587132,0.06584150458125704,0.44382673451693716,0.03264624989180973,0.3682115315861818,0.5977571338012432,0.9548371798264943,0.5479073259854106,0.8105857160107207,0.8724335592117783,0.9295863668885732,0.8767286959779629,0.8246926422579565,0.6685522596950785,0.9270653299257016,0.6009320146787852,0.050967614555081815,0.6867788865921278,0.0219942453716219,0.12172214896399439,0.9477477291085373,0.8582449816916787,0.46731028775213806,0.032434955846186615,0.9015551236066297,0.298085532691906,0.6756905657360586,0.35281579635474497,0.5422475086088804,0.5535370901203331,0.04008906506153809,0.036597809833064654,0.44698518144775085,0.5158802323371411,0.9922664561614608,0.9366844406397034,0.8094566888048557,0.8082083370190674,0.31767637107485286,0.07416602337520987,0.7939977251834478,0.9250810288412298,0.7724433763292271,0.2888046591542961,0.2575582241118554,0.6529726961135645,0.02128446636027376,0.22080662595078424,0.21174501951886074,0.9909372704641876,0.08819108179863798,0.8119605077792481,0.08456068484916225,0.1482479731015526,0.777590318163457,0.05779948158973269,0.041353667530357345,0.31402950540343916,0.04300093524868897,0.07411069023467885,0.2922436329786345,0.15969990473528822,0.5593785133666305,0.047799508427830616,0.04406706550669208,0.17579366722600265,0.1546290609306417,0.296543510576058,0.11062001797642809,0.211854335597394,0.2390540937810658,0.6095318258565616,0.09006421108524619,0.2252335191921136,0.36483586816010055,0.15358190463203725,0.04507226686281246,0.23240745199213994,0.7874349768462506,0.003362690168554229,0.16622300151935993,0.34909723829915074,0.3576605612390906,0.44434806182834174,0.17218979243889532,0.8190486579646532,0.7373691773851078,0.6931842197323956,0.2773485784204457,0.2516937086774268,0.7882755239560294,0.8551930851212005,0.018726152450871208,0.8926087208776321,0.7120420972440396,0.046524307133121307,0.5142213773452371,0.6888590119362985,0.39691176952093743,0.05235847210027491,0.23303633447635463,0.7948140719458311,0.664527152062705,0.9820322930528499,0.811893110666074,0.40111905443754087,0.07992643489756743,0.22563241624044023,0.07092251635817326,0.07420541911523262,0.6380300326228918,0.41722254175354856,0.18726420662611862,0.8751978667294048,0.3760278380289178,0.7504298466936783,0.12505750767419974,0.9534347330680485,0.9113496663827959,0.02324077327275611,0.487407886266721,0.762096773460895,0.01307840266517156,0.11420267965306248,0.4976818062190766,0.9529505875254243,0.5435312658633876,0.33681678687547256,0.9323141396966979,0.5519283474177918,0.9862683387775377,0.8978522698423409,0.9268230564914154,0.5925854551654317,0.8881430355080329,0.5445087581306489,0.06779868360469915,0.7308879158799224,0.8076151296758094,0.09430744499041165,0.8564127873845696,0.8946402019412155,0.7847955480020353,0.9524522021561578,0.7584517377043919,0.7441588969256059,0.6637062355420656,0.2659095619257786,0.014352792767538019,0.4013269621315558,0.3832175137628296,0.9832775625957844,0.8673621466670499,0.408938111303053,0.9504184932278066,0.42231485267525726,0.04959244913796267,0.5451983678250729,0.619369822853725,0.2634747781701904,0.019611321127079407,0.4728501224484826,0.952967025763884,0.9337618534697618,0.9661985912432023,0.7267048599434865,0.3986022183542257,0.171630327376875,0.7798134068171464,0.08282363824625028,0.20064538646647848,0.005335415743319088,0.03907055701968961,0.06170440336843374,0.22397931123717385,0.7152832145267346,0.0743009853998694,0.19479488572768774,0.21561810129275633,0.4385977809230068,0.5015596669545582,0.0016666219087540781,0.6532993254986449,0.5307761412030484,0.1833230270775672,0.8833599469053643,0.6303409786318775,0.39762434304663113,0.3913199874029101,0.5315577498994213,0.30282519617592857,0.6261110043162179,0.8516050806774008,0.7829948970876904,0.6667849432622084,0.5947372686139522,0.3435677961711022,0.4977600640466574,0.010819132973675084,0.6639641453687979,0.2442882823800481,0.06506709802477806,0.2665601011965228,0.9178126942892847,0.024575658244752534,0.5482949397280404,0.6094437906225546,0.027622734046254677,0.014571051552076235,0.8313538410857638,0.97720455595445,0.1107470272360908,0.08992864462698355,0.6205316205002189,0.4085877875980676,0.005042752904799879,0.9019075176359436,0.4325332597990712,0.5538951680144103,0.9766134643619778,0.05820990508115377,0.7731422049517975,0.8928715367746097,0.875919554896378,0.03233434988738224,0.45463055733785734,0.5876477795872487,0.5345560363286959,0.8628866269415792,0.6037604829474676,0.007800568914478157,0.8626914433546515,0.026275319327861646,0.5358176915992264,0.30211459123559514,0.9080209168479334,0.012540172283858021,0.030743065705586218,0.037687811692632654,0.2792937908447552,0.6342916797556717,0.8254454744244225,0.027469659033108745,0.6323185587196914,0.6926202646925502,0.7301453197654347,0.8536518441017339,0.06590643950067093,0.18320035599617518,0.27474256051201906,0.2857418281478084,0.31377198329992234,0.5529703837199863,0.7308469392851397,0.10161199107080908,0.15793020247037046,0.07752306153162342,0.2379358153107464,0.2769527500953318,0.17748242209302198,0.8818287664272132,0.8606205249556028,0.13517599386473092,0.38328306953310065,0.23624332966527467,0.8302675515976531,0.5466811712192704,0.007458553789879921,0.998680738512037,0.9437322135116298,0.3177761343781961,0.31843520408174886,0.9859124846675323,0.8781273052295127,0.9210698662191654,0.541680794784692,0.7110854772695576,0.4079370985967164,0.5867098586619914,0.7435286265582817,0.35570746987518576,0.9524090586250304,0.011665423631667667,0.710096739224171,0.20276216107720493,0.6655005912553705,0.035591063105560025,0.7241898303422525,0.6574296450203843,0.38560297420476414,0.2134947726839952,0.0676652215257508,0.7078954815081934,0.03663846961040878,0.5713668617412505,0.14959075591853552,0.4744016965926764,0.9470461893506473,0.4740155143503616,0.8922641832220196,0.00041666344539165753,0.7761745920202997,0.5417158276787878,0.07065252802161857,0.002840064286269605,0.13882005022578303,0.05697551442144893,0.003282536560893818,0.16503217697469863,0.7441839999084475,0.9360105650616113,0.6357654842636901,0.004425311789469249,0.0297064024626905,0.8866592244693444,0.9167462617658694,0.7669316425489953,0.9273984585315382,0.2679509150013847,0.012663232146245491,0.24687752583785713,0.2819691258790645,0.8192804178935581,0.30502014848764897,0.6953648995036165,0.09995387298666168,0.2696989589435923,0.28786109656696646,0.5732097700719405,0.7933110605108816,0.3878398010379927,0.9897867526619979,0.98464616138115,0.46999821270191844,0.2894701444643952,0.2861915099260794,0.4424109034886328,0.12174603319275018,0.08194783665576401,0.15143328399531913,0.3804874176787278,0.158648236461788,0.4717948648727388,0.07109539313546945,0.8705771102891464,0.398895897381054,0.4023230602268692,0.24419357452988283,0.7312862681249226,0.5742730295769223,0.5037994826399966,0.11592025220472962,0.3083776548130741,0.9619740735929647,0.4502398636282151,0.8535733096552083,0.589055995236211,0.3669819779323674,0.9380590166665898,0.6990284579500339,0.5088011580513419,0.41577033218870957,0.9181136498784033,0.06709339280036737,0.9760428492536568,0.6310222602018403,0.26319843874522303,0.7795751070658998,0.118811371865954,0.6005688165789367,0.9469964615444806,0.3930309990805109,0.21208332237766905,0.41662733131491325,0.23549007102874134]}],{\"xaxis\":{\"title\":{\"text\":\"\\\"dwelling in the past\\\" vs. \\\"forward-looking\\\"\"},\"tickformat\":\",.0%\"},\"template\":\"plotly_white\",\"margin\":{\"l\":50,\"b\":50,\"r\":50,\"t\":60},\"title\":\"Prioritizing Action-Oriented and Forward-Looking Ideas (Top-right Corner)\",\"yaxis\":{\"title\":{\"text\":\"\\\"action-oriented\\\"\"},\"tickformat\":\",.0%\"}},{\"showLink\":false,\"editable\":false,\"responsive\":true,\"staticPlot\":false,\"scrollZoom\":true}); gd.on(\"plotly_hover\",(function (data){var filtered_data=WebIO.PlotlyCommands.filterEventData(gd,data,\"hover\"); return !(filtered_data.isnil) ? (WebIO.setval({\"name\":\"hover\",\"scope\":\"4964793602311326205\",\"id\":\"221\",\"type\":\"observable\"},filtered_data.out)) : undefined})); gd.on(\"plotly_unhover\",(function (){return WebIO.setval({\"name\":\"hover\",\"scope\":\"4964793602311326205\",\"id\":\"221\",\"type\":\"observable\"},{})})); gd.on(\"plotly_selected\",(function (data){var filtered_data=WebIO.PlotlyCommands.filterEventData(gd,data,\"selected\"); return !(filtered_data.isnil) ? (WebIO.setval({\"name\":\"selected\",\"scope\":\"4964793602311326205\",\"id\":\"222\",\"type\":\"observable\"},filtered_data.out)) : undefined})); gd.on(\"plotly_deselect\",(function (){return WebIO.setval({\"name\":\"selected\",\"scope\":\"4964793602311326205\",\"id\":\"222\",\"type\":\"observable\"},{})})); gd.on(\"plotly_relayout\",(function (data){var filtered_data=WebIO.PlotlyCommands.filterEventData(gd,data,\"relayout\"); return !(filtered_data.isnil) ? (WebIO.setval({\"name\":\"relayout\",\"scope\":\"4964793602311326205\",\"id\":\"224\",\"type\":\"observable\"},filtered_data.out)) : undefined})); return gd.on(\"plotly_click\",(function (data){var filtered_data=WebIO.PlotlyCommands.filterEventData(gd,data,\"click\"); return !(filtered_data.isnil) ? (WebIO.setval({\"name\":\"click\",\"scope\":\"4964793602311326205\",\"id\":\"223\",\"type\":\"observable\"},filtered_data.out)) : undefined}))}));\n    (WebIO.importBlock({\"data\":[{\"name\":\"Plotly\",\"type\":\"js\",\"url\":\"\/assetserver\/46b0af2f03ca323adf531facbdab5be59e805cc6-plotly.min.js\"},{\"name\":null,\"type\":\"js\",\"url\":\"\/assetserver\/98d4c49067b4a590fb2b4b4ced9a48a1db12cda2-plotly_webio.bundle.js\"}],\"type\":\"async_block\"})).then((imports) => handler.apply(this, imports));\n}\n"],"observables":{"_toImage":{"sync":false,"id":"228","value":{}},"hover":{"sync":false,"id":"221","value":{}},"selected":{"sync":false,"id":"222","value":{}},"__gd_contents":{"sync":false,"id":"226","value":{}},"click":{"sync":false,"id":"223","value":{}},"image":{"sync":true,"id":"225","value":""},"__get_gd_contents":{"sync":false,"id":"230","value":""},"_downloadImage":{"sync":false,"id":"229","value":{}},"relayout":{"sync":false,"id":"224","value":{}},"_commands":{"sync":false,"id":"227","value":[]}}},"children":[{"props":{"id":"plot-9d05c4e5-e10b-410d-918b-100dfa4fd08b"},"nodeType":"DOM","type":"node","instanceArgs":{"namespace":"html","tag":"div"},"children":[]}]},
        window,
    );
    })()
    </script>
</div>

```

Perhaps you need to add some additional information to the tooltip for each data point?
You can do that with `hoverdata` argument, see `?PlotlyJS.plot` for more details.

---

*This page was generated using [Literate.jl](https://github.com/fredrikekre/Literate.jl).*

